function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var group = require('@visx/group');
var React = require('react');
var React__default = _interopDefault(React);
var axis = require('@visx/axis');
var scale = require('@visx/scale');
var shape = require('@visx/shape');
var clipPath = require('@visx/clip-path');
var text = require('@visx/text');
var event = require('@visx/event');
var tooltip = require('@visx/tooltip');
var grid = require('@visx/grid');
var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var os = _interopDefault(require('os'));
var hxReactComponents = require('hx-react-components');
var d3 = require('d3');
var PropTypes = _interopDefault(require('prop-types'));
var gradient = require('@visx/gradient');
var venn = require('venn.js');
var geo = require('@visx/geo');
var topojson = require('topojson-client');
var hierarchy = require('@visx/hierarchy');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

var ColumnChartImage = function ColumnChartImage(_ref) {
  var d = _ref.d,
      showItemsPreview = _ref.showItemsPreview,
      color = _ref.color,
      chartId = _ref.chartId;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [d.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (showItemsPreview && (!d.pic || errorLoadingImage)) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(shape.Circle, {
      r: 15,
      cx: d.x,
      cy: d.y,
      fill: color
    }));
  }

  if (!showItemsPreview) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(text.Text, {
      height: 80,
      width: 80,
      x: d.x,
      y: d.y,
      fontSize: "10px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000"
    }, d.label.toUpperCase()));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: d.pic,
    height: 30,
    width: 30,
    clipPath: "url(#category-" + chartId + "-icon-" + d.id + ")",
    x: d.x - 15,
    y: d.y - 15,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "category-" + chartId + "-icon-" + d.id,
    key: "category-" + chartId + "-icon-" + d.id,
    r: 15,
    cx: d.x,
    cy: d.y
  }));
};

function _templateObject4() {
  var data = _taggedTemplateLiteralLoose(["\n  text-align: left;\n  font-size: 12px;\n  padding: 5px;\n"]);

  _templateObject4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3() {
  var data = _taggedTemplateLiteralLoose(["\n  text-align: center;\n  font-size: 14px;\n  font-weight: bold;\n  padding: 5px;\n"]);

  _templateObject3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2() {
  var data = _taggedTemplateLiteralLoose(["\n  border: 1px solid #c6c6c6;\n"]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject() {
  var data = _taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: column;\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
var StyledTooltipContainer = styled__default.div(_templateObject());
var StyledTooltipBorder = styled__default.div(_templateObject2());
var StyledTooltipTitle = styled__default.div(_templateObject3());
var StyledTooltipContent = styled__default.div(_templateObject4());

var ChartTooltip = function ChartTooltip(props) {
  var tooltipStyles = _extends({}, tooltip.defaultStyles, {
    minWidth: 60,
    backgroundColor: 'rgba(255,255,255,0.8)',
    color: '#000',
    zIndex: 2000
  });

  return /*#__PURE__*/React__default.createElement(tooltip.TooltipWithBounds, {
    top: props.top,
    left: props.left,
    style: _extends({}, tooltipStyles, {
      borderStyle: 'solid',
      borderWidth: '2px',
      borderColor: props.data.color
    })
  }, /*#__PURE__*/React__default.createElement(StyledTooltipContainer, null, /*#__PURE__*/React__default.createElement(StyledTooltipTitle, null, props.data.label), /*#__PURE__*/React__default.createElement(StyledTooltipBorder, null), /*#__PURE__*/React__default.createElement(StyledTooltipContent, null, props.children)));
};

var METRICS = {
  AFFINITY: 'target_audience_affinity',
  REACH: 'target_audience_perc',
  BASE: 'base_population_perc',
  BASE_AFFINITY: 'base_affinity'
};
var MAP_CHART_FIELDS_THRESHOLD = {
  target_audience_affinity: 1,
  base_population_perc: 0,
  target_audience_perc: 0
};
function debounce(func, wait, immediate) {
  var _arguments = arguments,
      _this = this;

  var timeout;
  return function () {
    var context = _this;
    var args = _arguments;

    var later = function later() {
      timeout = null;
      if (!immediate) func.apply(context, args);
    };

    var callNow = immediate && !timeout;
    clearTimeout(timeout);
    timeout = setTimeout(later, wait);
    if (callNow) func.apply(context, args);
  };
}
var numberWithCommas = function numberWithCommas(number) {
  if (!number) {
    return false;
  }

  return number.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ',');
};
var MAP_CHART_FIELDS_LABEL = {
  target_audience_affinity: 'Affinity',
  base_population_perc: 'Base',
  target_audience_perc: 'Reach'
};
var DEFAULT_COLORS = ['#ff271a', '#FFF600', '#2563D5'];
var DEFAULT_OPAC_COLORS = ['#BA635E', '#94920b', '#0b5394'];
var MAP_DEFAULT_COLORS = ['#bde725', '#41B6A8'];
var MAP_DEFAULT_OPAC_COLORS = ['#99b33d', '#1e7b44'];
var convertHexToHSL = function convertHexToHSL(color, saturation, lightness) {
  var r = 0;
  var g = 0;
  var b = 0;

  if (color.length === 4) {
    r = '0x' + color[1] + color[1];
    g = '0x' + color[2] + color[2];
    b = '0x' + color[3] + color[3];
  } else if (color.length === 7) {
    r = '0x' + color[1] + color[2];
    g = '0x' + color[3] + color[4];
    b = '0x' + color[5] + color[6];
  }

  r /= 255;
  g /= 255;
  b /= 255;
  var cmin = Math.min(r, g, b);
  var cmax = Math.max(r, g, b);
  var delta = cmax - cmin;
  var h = 0;
  var s = 0;
  var l = 0;
  if (delta === 0) h = 0;else if (cmax === r) h = (g - b) / delta % 6;else if (cmax === g) h = (b - r) / delta + 2;else h = (r - g) / delta + 4;
  h = Math.round(h * 60);
  if (h < 0) h += 360;
  l = (cmax + cmin) / 2;
  s = delta === 0 ? 0 : delta / (1 - Math.abs(2 * l - 1));
  s = +(s * saturation).toFixed(1);
  l = +(l * lightness).toFixed(1);
  return 'hsl(' + h + ',' + s + '%,' + l + '%)';
};
var getColors = function getColors(color) {
  if (!color || color === 'default') {
    return DEFAULT_COLORS;
  }

  if (color === 'opac') {
    return DEFAULT_OPAC_COLORS;
  }

  return [convertHexToHSL(color, 100, 100), convertHexToHSL(color, 100, 50), convertHexToHSL(color, 70, 30)];
};
var getMapColors = function getMapColors(color) {
  return [color && !['default', 'opac'].includes(color) ? convertHexToHSL(color, 100, 100) : color === 'opac' ? MAP_DEFAULT_OPAC_COLORS[0] : MAP_DEFAULT_COLORS[0], color && !['default', 'opac'].includes(color) ? convertHexToHSL(color, 100, 50) : color === 'opac' ? MAP_DEFAULT_OPAC_COLORS[1] : MAP_DEFAULT_COLORS[1]];
};
var getBarColors = function getBarColors(value, threshold, color) {
  return value < threshold ? color && !['default', 'opac'].includes(color) ? convertHexToHSL(color, 100, 100) : color === 'opac' ? '#BA635E' : '#f11831' : color && !['default', 'opac'].includes(color) ? convertHexToHSL(color, 100, 50) : color === 'opac' ? '#1e7b44' : '#26a65b';
};

var useWindowSize = function useWindowSize() {
  var isClient = typeof window === 'object';
  var getSize = React.useCallback(function () {
    return {
      width: isClient ? window.innerWidth : undefined,
      height: isClient ? window.innerHeight : undefined
    };
  }, [isClient]);

  var _useState = React.useState(getSize),
      windowSize = _useState[0],
      setWindowSize = _useState[1];

  React.useEffect(function () {
    if (!isClient) {
      return false;
    }

    function handleResize() {
      setWindowSize(getSize());
    }

    var handleResizeFn = debounce(handleResize, 500);
    window.addEventListener('resize', handleResizeFn);
    return function () {
      return window.removeEventListener('resize', handleResizeFn);
    };
  }, [getSize, isClient]);
  return windowSize;
};

var MAP_MISSING_VALUES_LABELS = {
  low_engagement: 'L.E.',
  less_than_zero: '<0.01%',
  affinity_null: '-'
};

var getFixedParam = function getFixedParam(data, fixed) {
  var choosenFixed = fixed;
  var dataToFixed = data * 10 % 10;

  if (dataToFixed % 1 === 0) {
    choosenFixed = data % 1 === 0 ? 0 : 1;
  }

  return choosenFixed;
};

var formattedValue = function formattedValue(data, type, fixed) {
  if (fixed === void 0) {
    fixed = 2;
  }

  var choosenFixed = getFixedParam(data, fixed);

  if (data === 0) {
    return type === METRICS.AFFINITY ? data + 'x' : type === METRICS.BASE_AFFINITY ? data : data + '%';
  }

  if (data === null) {
    return type === METRICS.AFFINITY ? MAP_MISSING_VALUES_LABELS.affinity_null : MAP_MISSING_VALUES_LABELS.low_engagement;
  }

  if (type === METRICS.AFFINITY) {
    return data.toFixed(choosenFixed) + 'x';
  }

  var dataToFixed = data.toFixed(4);

  if (dataToFixed === '0.0000') {
    return type === METRICS.BASE_AFFINITY ? MAP_MISSING_VALUES_LABELS.low_engagement : MAP_MISSING_VALUES_LABELS.less_than_zero;
  }

  var dataToFixedPerCent = Number((dataToFixed * 100).toFixed(2));
  choosenFixed = getFixedParam(dataToFixedPerCent, fixed);
  return type === METRICS.BASE_AFFINITY ? dataToFixedPerCent.toFixed(choosenFixed) : dataToFixedPerCent.toFixed(choosenFixed) + '%';
};

var formatVisualItemValues = function formatVisualItemValues(item) {
  return _extends({}, item, {
    base_population_perc: formattedValue(item.base_population_perc, 'base_population_perc'),
    target_audience_perc: formattedValue(item.target_audience_perc, 'target_audience_perc'),
    target_audience_affinity: formattedValue(item.target_audience_affinity, 'target_audience_affinity')
  });
};

var FormatUtils = {
  formattedValue: formattedValue,
  formatVisualItemValues: formatVisualItemValues
};

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var uniqid = createCommonjsModule(function (module) {
/* 
(The MIT License)
Copyright (c) 2014-2021 Halász Ádám <adam@aimform.com>
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

//  Unique Hexatridecimal ID Generator
// ================================================

//  Dependencies
// ================================================
var pid = typeof process !== 'undefined' && process.pid ? process.pid.toString(36) : '' ;
var address = '';
if(typeof __webpack_require__ !== 'function'){
    var mac = '', networkInterfaces = os.networkInterfaces();
    loop:
    for(let interface_key in networkInterfaces){
        const networkInterface = networkInterfaces[interface_key];
        const length = networkInterface.length;
        for(var i = 0; i < length; i++){
            if(networkInterface[i] !== undefined && networkInterface[i].mac && networkInterface[i].mac != '00:00:00:00:00:00'){
                mac = networkInterface[i].mac; break loop;
            }
        }
    }
    address = mac ? parseInt(mac.replace(/\:|\D+/gi, '')).toString(36) : '' ;
} 

//  Exports
// ================================================
module.exports = module.exports.default = function(prefix, suffix){ return (prefix ? prefix : '') + address + pid + now().toString(36) + (suffix ? suffix : ''); };
module.exports.process = function(prefix, suffix){ return (prefix ? prefix : '') + pid + now().toString(36) + (suffix ? suffix : ''); };
module.exports.time    = function(prefix, suffix){ return (prefix ? prefix : '') + now().toString(36) + (suffix ? suffix : ''); };

//  Helpers
// ================================================
function now(){
    var time = Date.now();
    var last = now.last || time;
    return now.last = time > last ? time : last + 1;
}
});

function _templateObject$1() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$1 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledColumnChartWrapper = styled__default.div(_templateObject$1());
var tooltipTimeout;
var defaultMargin = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var ColumnChart = function ColumnChart(_ref) {
  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin : _ref$margin,
      yAxis = _ref.yAxis,
      zAxis = _ref.zAxis,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      showValuesOn100 = _ref.showValuesOn100,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      isDemographic = _ref.isDemographic,
      showItemsPreview = _ref.showItemsPreview;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var isEmpty = !data || data.length === 0;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    return limit !== 'auto' ? data.slice(0, limit) : data;
  }, [isEmpty, data, limit]);
  var yValues = filteredData && filteredData.map(function (item) {
    return item[yAxis];
  }) || [];
  var zValues = filteredData && filteredData.map(function (item) {
    return item[zAxis];
  }) || [];
  var minMaxValues = React.useMemo(function () {
    return {
      yMin: isDemographic ? 0 : Math.min.apply(Math, yValues),
      yMax: yAxis === METRICS.AFFINITY && isDemographic && Math.max.apply(Math, yValues) > 0 ? Math.max.apply(Math, yValues) / 100 : Math.max.apply(Math, yValues),
      zMin: isDemographic ? Math.min.apply(Math, zValues) : 0,
      zMax: isDemographic ? Math.max.apply(Math, zValues) : 0
    };
  }, [yAxis, isDemographic, yValues, zValues]);
  var yzDiff = Math.max(minMaxValues.yMax - minMaxValues.yMin, minMaxValues.zMax - minMaxValues.zMin, 0);
  var yzMin = Math.min(minMaxValues.yMin, minMaxValues.zMin);
  var yzMax = Math.max(minMaxValues.yMax, minMaxValues.zMax);
  var yDomain = React.useMemo(function () {
    return [yzMin - yzDiff / 3 < 0 ? 0 : yzMin - yzDiff / 3, showValuesOn100 || yAxis !== METRICS.AFFINITY && yzMax + yzDiff / 3 > 1 ? 1 : yzMax + yzDiff / 3];
  }, [minMaxValues, yzDiff, showValuesOn100, yzMin, yzMax, yAxis]);
  var yScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: yDomain,
      range: [0, showValuesOn100 || yzMax > 1 ? 1 : yzMax],
      nice: true
    });
  }, [yzMax, yDomain, showValuesOn100]);
  var xScale = React.useMemo(function () {
    return scale.scaleBand({
      domain: filteredData && filteredData.map(function (item) {
        return item.id;
      }) || [],
      padding: 0.7
    });
  }, [filteredData]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : filteredData.length / 2, isEmpty ? 0 : filteredData.length],
      range: getColors(color)
    });
  }, [filteredData, isEmpty, color]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  xScale.rangeRound([0, xMax]);
  yScale.rangeRound([yMax, 0]);
  var getTickInsightType = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.insight_type || '';
  }, [filteredData]);
  var getTickImage = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.pic || '';
  }, [filteredData]);
  var getTickLabel = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.label || '';
  }, [filteredData]);
  var getGroupContent = React.useCallback(function (group, groups, index) {
    var options = groups.tickLabelProps(group.value);

    var props = _extends({}, options, {
      x: group.to.x,
      y: 10 + group.to.y,
      index: index
    });

    return groups.tickComponent(props);
  }, []);
  var getTickComponent = React.useCallback(function (d) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "column-" + chartId.current + "-category-" + d.id
    }, /*#__PURE__*/React__default.createElement(ColumnChartImage, {
      d: d,
      color: colorScale(d.index),
      showItemsPreview: showItemsPreview,
      chartId: chartId.current
    }));
  }, [isDemographic, showItemsPreview]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index) {
    if (tooltipTimeout) clearTimeout(tooltipTimeout);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, filteredData[index], {
        color: colorScale(index)
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, filteredData, colorScale]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledColumnChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledColumnChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(grid.Grid, {
    top: margin.top,
    left: margin.left,
    xScale: xScale,
    yScale: yScale,
    width: xMax,
    height: yMax
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, filteredData.map(function (d, index) {
    var _yScale, _yScale2;

    var barWidth = xScale.bandwidth();
    var barZWidth = xScale.bandwidth() + 20;
    var barValue = yAxis === METRICS.AFFINITY && isDemographic && d[yAxis] > 0 ? d[yAxis] / 100 : d[yAxis];
    var barHeight = yMax - ((_yScale = yScale(barValue)) != null ? _yScale : 0);
    var barZHeight = yMax - ((_yScale2 = yScale(d[zAxis])) != null ? _yScale2 : 0);
    var barX = xScale(d.id);
    var barY = yMax - barHeight;
    var barZ = yMax - barZHeight;
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "column-" + chartId.current + "-bar-" + d.id
    }, barX > 0 && barY > 0 && /*#__PURE__*/React__default.createElement(shape.Bar, {
      x: barX,
      y: barY,
      width: barWidth,
      height: barHeight,
      fill: colorScale(index),
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, index);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      },
      onTouchMove: function onTouchMove(event) {
        return handleMouseMove(event, index);
      },
      onTouchEnd: function onTouchEnd(event) {
        return handleMouseLeave(event);
      }
    }), barX > 0 && barZ > 0 && isDemographic && /*#__PURE__*/React__default.createElement(shape.Bar, {
      x: barX - 10,
      y: barZ,
      width: barZWidth,
      height: barZHeight,
      fill: colorScale(index),
      fillOpacity: 0.4,
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, index);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      },
      onTouchMove: function onTouchMove(event) {
        return handleMouseMove(event, index);
      },
      onTouchEnd: function onTouchEnd(event) {
        return handleMouseLeave(event);
      }
    }));
  }), /*#__PURE__*/React__default.createElement(axis.AxisLeft, {
    label: MAP_CHART_FIELDS_LABEL[yAxis],
    scale: yScale,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, isDemographic && yAxis === METRICS.AFFINITY ? METRICS.BASE_AFFINITY : yAxis, yAxis === METRICS.REACH || isDemographic ? 1 : 2);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'end',
        dy: '0.33em',
        dx: '-0.33em',
        fontWeight: 'bold'
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold',
      dx: '-1.2em'
    }
  }), /*#__PURE__*/React__default.createElement(axis.AxisBottom, {
    top: yMax,
    scale: xScale,
    tickLabelProps: function tickLabelProps(d) {
      return {
        fontSize: '11px',
        pic: getTickImage(d),
        id: d,
        label: getTickLabel(d),
        insight_type: getTickInsightType(d)
      };
    },
    tickComponent: function tickComponent(d) {
      return getTickComponent(d);
    }
  }, function (axisGroups) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, axisGroups.ticks.map(function (group$1, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "column-" + chartId.current + "-axis-group-" + index
      }, getGroupContent(group$1, axisGroups, index));
    }), /*#__PURE__*/React__default.createElement(shape.Line, {
      from: axisGroups.axisFromPoint,
      to: axisGroups.axisToPoint,
      stroke: "#9493A6",
      strokeWidth: "1",
      strokeOpacity: 0.5
    }));
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY, 2)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE, 1))));
};

var StackedChartImage = function StackedChartImage(_ref) {
  var d = _ref.d,
      showItemsPreview = _ref.showItemsPreview,
      color = _ref.color,
      chartId = _ref.chartId;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [d.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (showItemsPreview && (!d.pic || errorLoadingImage)) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(shape.Circle, {
      r: 15,
      cx: d.x - 15,
      cy: d.y,
      fill: color
    }));
  }

  if (!showItemsPreview) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(text.Text, {
      height: 80,
      width: 80,
      x: d.x - 40,
      y: d.y,
      fontSize: "10px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000"
    }, d.label.toUpperCase()));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: d.pic,
    height: 30,
    width: 30,
    clipPath: "url(#category-" + chartId + "-icon-" + d.id + ")",
    x: d.x - 30,
    y: d.y - 15,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "category-" + chartId + "-icon-" + d.id,
    key: "category-" + chartId + "-icon-" + d.id,
    r: 15,
    cx: d.x - 15,
    cy: d.y
  }));
};

function _templateObject$2() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$2 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledStackedChartWrapper = styled__default.div(_templateObject$2());
var tooltipTimeout$1;
var defaultMargin$1 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var StackedChart = function StackedChart(_ref) {
  var data = _ref.data,
      xAxis = _ref.xAxis,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$1 : _ref$margin,
      emptyDataMessage = _ref.emptyDataMessage,
      color = _ref.color,
      limit = _ref.limit,
      _ref$showAxisLeft = _ref.showAxisLeft,
      showAxisLeft = _ref$showAxisLeft === void 0 ? true : _ref$showAxisLeft,
      showItemsPreview = _ref.showItemsPreview;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    return limit !== 'auto' ? data.slice(0, limit) : data;
  }, [isEmpty, data, limit]);
  var getGroupContent = React.useCallback(function (group, groups, index) {
    var options = groups.tickLabelProps(group.value);

    var props = _extends({}, options, {
      x: group.to.x,
      y: 10 + group.to.y,
      index: index
    });

    return groups.tickComponent(props);
  }, []);
  var values = React.useMemo(function () {
    return filteredData && filteredData.map(function (item) {
      return item[xAxis];
    }) || [];
  }, [filteredData, xAxis]);
  var getTickComponent = React.useCallback(function (d) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "stacked-" + chartId.current + "-category-" + d.id
    }, /*#__PURE__*/React__default.createElement(StackedChartImage, {
      d: d,
      chartId: chartId.current,
      color: "#e6e6e6",
      showItemsPreview: showItemsPreview
    }));
  }, []);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$1 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index, color) {
    if (color === void 0) {
      color = '#26a65b';
    }

    if (tooltipTimeout$1) clearTimeout(tooltipTimeout$1);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, filteredData[index], {
        color: color
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, filteredData]);
  var minMaxValues = React.useMemo(function () {
    return {
      xMin: Math.min.apply(Math, values),
      xMax: Math.max.apply(Math, values)
    };
  }, [values]);
  var xDiff = Math.max(minMaxValues.xMax - minMaxValues.xMin, 0);
  var offsetXMin = MAP_CHART_FIELDS_THRESHOLD[xAxis] > 0 && minMaxValues.xMin >= MAP_CHART_FIELDS_THRESHOLD[xAxis] ? MAP_CHART_FIELDS_THRESHOLD[xAxis] : (minMaxValues.xMin - xDiff) / 10;
  var offsetXMax = MAP_CHART_FIELDS_THRESHOLD[xAxis] > 0 && minMaxValues.xMax + xDiff / 10 < MAP_CHART_FIELDS_THRESHOLD[xAxis] ? MAP_CHART_FIELDS_THRESHOLD[xAxis] : minMaxValues.xMax + xDiff / 10;
  var xDomain = React.useMemo(function () {
    return [offsetXMin < 0 ? 0 : offsetXMin, offsetXMax];
  }, [offsetXMin, offsetXMax]);
  var xScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: xDomain,
      range: [0, minMaxValues.xMax],
      nice: true
    });
  }, [xDomain, minMaxValues]);
  var yScale = React.useMemo(function () {
    return scale.scaleBand({
      domain: filteredData && filteredData.map(function (item) {
        return item.id;
      }) || [],
      padding: 0.7
    });
  }, [filteredData]);
  var getTickImage = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.pic || '';
  }, [filteredData]);
  var getTickLabel = React.useCallback(function (d) {
    var item = filteredData.find(function (i) {
      return i.id === d;
    });
    return item && item.label || '';
  }, [filteredData]);
  var xTicks = React.useMemo(function () {
    var min = xDiff < 1 ? 5 : xDiff + 4;

    if (xAxis !== METRICS.AFFINITY) {
      min = xDiff <= 0.01 ? 1 : xDiff * 100;
    }

    if (width < 520) {
      return Math.min(min, 2);
    }

    return Math.min(min, 10);
  }, [xDiff, width]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  xScale.rangeRound([0, xMax]);
  yScale.rangeRound([yMax, 0]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledStackedChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledStackedChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(grid.GridRows, {
    top: margin.top,
    left: margin.left,
    scale: yScale,
    width: xMax,
    height: yMax
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, filteredData.map(function (d, index) {
    var barValue = d[xAxis] || 0;
    var barHeight = yScale.bandwidth();
    var barY = yScale(d.id);
    var barWidth = barValue < MAP_CHART_FIELDS_THRESHOLD[xAxis] ? xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]) - xScale(barValue) : xScale(barValue) - xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]);
    var barX = barValue < MAP_CHART_FIELDS_THRESHOLD[xAxis] ? xScale(barValue) : xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]);
    var barColor = getBarColors(barValue, MAP_CHART_FIELDS_THRESHOLD[xAxis], color);

    if (barX >= 0 && barY > 0 && barWidth > 0) {
      return /*#__PURE__*/React__default.createElement(shape.Bar, {
        key: "stacked-" + chartId.current + "-bar-" + d.id,
        x: barX,
        y: barY + 10,
        width: barWidth,
        height: barHeight,
        fill: barColor,
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, index, barColor);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        onTouchMove: function onTouchMove(event) {
          return handleMouseMove(event, index, barColor);
        },
        onTouchEnd: function onTouchEnd(event) {
          return handleMouseLeave(event);
        }
      });
    }

    return null;
  }), /*#__PURE__*/React__default.createElement(shape.Line, {
    from: {
      x: xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]),
      y: 0
    },
    to: {
      x: xScale(MAP_CHART_FIELDS_THRESHOLD[xAxis]),
      y: yMax
    },
    stroke: "#9493A6",
    strokeWidth: "1",
    strokeOpacity: 0.5
  }), showAxisLeft && /*#__PURE__*/React__default.createElement(axis.AxisLeft, {
    scale: yScale,
    tickLabelProps: function tickLabelProps(d) {
      return {
        fontSize: '11px',
        pic: getTickImage(d),
        id: d,
        label: getTickLabel(d)
      };
    },
    tickComponent: function tickComponent(d) {
      return getTickComponent(d);
    }
  }, function (axisGroups) {
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, axisGroups.ticks.map(function (group$1, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "stacked-" + chartId.current + "-axis-group-" + index
      }, getGroupContent(group$1, axisGroups, index));
    }), /*#__PURE__*/React__default.createElement(shape.Line, {
      from: axisGroups.axisFromPoint,
      to: axisGroups.axisToPoint,
      stroke: "#9493A6",
      strokeWidth: "1",
      strokeOpacity: 0.5
    }));
  }), /*#__PURE__*/React__default.createElement(axis.AxisBottom, {
    label: MAP_CHART_FIELDS_LABEL[xAxis],
    top: yMax,
    scale: xScale,
    numTicks: xTicks,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, xAxis, xAxis === METRICS.REACH ? 1 : 2);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'middle',
        fontWeight: 'bold'
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold'
    }
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE))));
};

var MosaicChartImage = function MosaicChartImage(_ref) {
  var id = _ref.id,
      item = _ref.item,
      width = _ref.width,
      height = _ref.height,
      x = _ref.x,
      y = _ref.y,
      color = _ref.color,
      onMouseMove = _ref.onMouseMove,
      onMouseLeave = _ref.onMouseLeave;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [item.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (!item.pic || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement("rect", {
      height: height,
      width: width,
      x: x,
      y: y,
      fill: color,
      onMouseMove: onMouseMove,
      onMouseLeave: onMouseLeave,
      onTouchMove: onMouseMove,
      onTouchEnd: onMouseLeave
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      height: height,
      width: width,
      x: x + width / 2,
      y: y + height / 2,
      fontSize: "10px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000"
    }, item.label.toUpperCase())));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    preserveAspectRatio: "xMidYMid slice",
    href: item.pic,
    width: width,
    height: height,
    clipPath: "url(#" + id + ")",
    x: x,
    y: y,
    onMouseMove: onMouseMove,
    onMouseLeave: onMouseLeave,
    onTouchMove: onMouseMove,
    onTouchEnd: onMouseLeave,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.RectClipPath, {
    id: id,
    key: id,
    width: width,
    height: height,
    x: x,
    y: y
  })));
};

function _templateObject2$1() {
  var data = _taggedTemplateLiteralLoose(["\n  z-index: 1;\n"]);

  _templateObject2$1 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$3() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  overflow: ", ";\n  z-index: 0;\n"]);

  _templateObject$3 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledMosaicChartWrapper = styled__default.div(_templateObject$3(), function (props) {
  return props.isScrollable ? 'hidden auto' : 'hidden';
});
var StyledMosaicChartSvg = styled__default.svg(_templateObject2$1());
var tooltipTimeout$2;
var defaultMargin$2 = {
  top: 0,
  right: 0,
  bottom: 0,
  left: 0
};

var MosaicChart = function MosaicChart(_ref) {
  var _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$2 : _ref$margin,
      data = _ref.data,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      isScrollable = _ref.isScrollable;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var numColumns = 5;
  var numRows = 5;
  var columnWidth = Math.max((width - margin.left - margin.right) / numColumns, 0);
  var rowHeight = Math.max((height - margin.bottom - margin.top) / numRows, 0);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  var isEmpty = !data || data.length === 0;
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$2 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index) {
    if (tooltipTimeout$2) clearTimeout(tooltipTimeout$2);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, data[index]),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, data]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : data.length / 2, isEmpty ? 0 : data.length],
      range: getColors(color)
    });
  }, [data, isEmpty, color]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledMosaicChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledMosaicChartWrapper, {
    ref: chartRef,
    isScrollable: isScrollable
  }, /*#__PURE__*/React__default.createElement(StyledMosaicChartSvg, {
    ref: svgRef,
    width: width,
    height: Math.floor((data.length - 1) / numColumns) * rowHeight + rowHeight
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "#ffffff",
    stroke: "#9493A6",
    strokeWidth: "1",
    width: xMax,
    height: yMax
  }), data.map(function (item, index) {
    var columnIndex = index % numColumns;
    var rowIndex = Math.floor(index / numColumns);
    var id = "mosaic-" + chartId.current + "-item-icon-" + index + "-" + rowIndex + "-" + columnIndex;
    return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: "mosaic-" + chartId.current + "-item-" + index + "-" + rowIndex + "-" + columnIndex
    }, /*#__PURE__*/React__default.createElement(MosaicChartImage, {
      id: id,
      item: item,
      width: columnWidth,
      height: rowHeight,
      x: columnIndex * columnWidth,
      y: rowIndex * rowHeight,
      color: colorScale(index),
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, index);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      },
      onMouseOver: function onMouseOver(event) {
        return handleMouseMove(event, index);
      }
    }));
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE, 1))));
};

function _templateObject10() {
  var data = _taggedTemplateLiteralLoose(["\n  color: ", ";\n  font-size: ", ";\n  display: inline-flex;\n"]);

  _templateObject10 = function _templateObject10() {
    return data;
  };

  return data;
}

function _templateObject9() {
  var data = _taggedTemplateLiteralLoose(["\n  background-color: ", ";\n  border-radius: 50%;\n  width: 15px;\n  height: 15px;\n  display: inline-flex;\n  margin-right: ", ";\n"]);

  _templateObject9 = function _templateObject9() {
    return data;
  };

  return data;
}

function _templateObject8() {
  var data = _taggedTemplateLiteralLoose(["\n  display: inline-flex;\n  align-items: center;\n  margin-right: ", ";\n"]);

  _templateObject8 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: ", ";\n  fill: ", ";\n  text-anchor: middle;\n  alignment-baseline: center;\n"]);

  _templateObject7 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6() {
  var data = _taggedTemplateLiteralLoose(["\n  .domain {\n    stroke: none;\n  }\n  .tick line {\n    stroke: ", ";\n  }\n"]);

  _templateObject6 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: ", ";\n  text {\n    fill: ", ";\n  }\n  .domain {\n    stroke: ", ";\n  }\n  .tick line {\n    stroke: none;\n  }\n"]);

  _templateObject5 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$1() {
  var data = _taggedTemplateLiteralLoose(["\n  .domain {\n    stroke: none;\n  }\n  .tick {\n    &:nth-child(2) line,\n    &:last-child line {\n      stroke: none;\n    }\n    & line {\n      stroke-dasharray: 5 5;\n      stroke: ", ";\n    }\n  }\n"]);

  _templateObject4$1 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$1() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: ", ";\n  text {\n    fill: ", ";\n  }\n  .domain {\n    stroke: ", ";\n  }\n  .tick line {\n    stroke: none;\n  }\n"]);

  _templateObject3$1 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$2() {
  var data = _taggedTemplateLiteralLoose(["\n  fill: none;\n"]);

  _templateObject2$2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$4() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: ", ";\n  max-height: 500px;\n"]);

  _templateObject$4 = function _templateObject() {
    return data;
  };

  return data;
}
var fontGrey = '#6C6B7C';
var ChartWrapper = styled__default.div(_templateObject$4(), function (props) {
  return props.theme.colors.light;
});
var Line = styled__default.path(_templateObject2$2());
var XAxis = styled__default.g(_templateObject3$1(), function (props) {
  return props.theme.size.small;
}, fontGrey, function (props) {
  return props.theme.colors.light_darker_1;
});
var XAxisGrid = styled__default.g(_templateObject4$1(), function (props) {
  return props.theme.colors.light_darker_1;
});
var YAxis = styled__default.g(_templateObject5(), function (props) {
  return props.theme.size.small;
}, fontGrey, function (props) {
  return props.theme.colors.light_darker_1;
});
var YAxisGrid = styled__default.g(_templateObject6(), function (props) {
  return props.theme.colors.light_darker_1;
});
var CircleLabel = styled__default.text(_templateObject7(), function (props) {
  return props.theme.size.small;
}, fontGrey);
var LabelWrapper = styled__default.div(_templateObject8(), function (props) {
  return props.theme.spacing.large;
});
var LabelCircle = styled__default.div(_templateObject9(), function (props) {
  return props.color;
}, function (props) {
  return props.theme.spacing.small;
});
var LabelText = styled__default.div(_templateObject10(), function (props) {
  return props.theme.colors.dark;
}, function (props) {
  return props.theme.size.xbody;
});

var LineChartLabels = function LineChartLabels(_ref) {
  var labels = _ref.labels,
      getColor = _ref.getColor;
  if (!labels || !labels.length) return null;
  return labels.map(function (label, i) {
    return /*#__PURE__*/React__default.createElement(LabelWrapper, {
      key: i
    }, /*#__PURE__*/React__default.createElement(LabelCircle, {
      color: getColor(i)
    }, "\xA0"), /*#__PURE__*/React__default.createElement(LabelText, null, label));
  });
};

var LineChartLabels$1 = React.memo(LineChartLabels);

var LineChartAxes = function LineChartAxes(props) {
  var chartWidth = props.chartWidth,
      chartHeight = props.chartHeight,
      padding = props.padding,
      xScale = props.xScale,
      yScale = props.yScale,
      yDelta = props.yDelta,
      allowDecimalTicks = props.allowDecimalTicks;
  var xAxisRef = React.useRef(null);
  var xAxisGridRef = React.useRef(null);
  var yAxisRef = React.useRef(null);
  var yAxisGridRef = React.useRef(null);
  React.useEffect(function () {
    var xAxis = d3.axisBottom().scale(xScale).ticks(chartWidth / 100);
    d3.select(xAxisRef.current).call(xAxis);
    var xAxisGrid = d3.axisBottom().scale(xScale).tickSize(-(chartHeight - 2 * padding)).tickFormat('').ticks(chartWidth / 100);
    d3.select(xAxisGridRef.current).call(xAxisGrid);
    var yTicks = allowDecimalTicks ? chartHeight / 50 : Math.min(yDelta, chartHeight / 50);
    var yAxis = d3.axisLeft().scale(yScale).ticks(yTicks);
    d3.select(yAxisRef.current).call(yAxis);
    var yAxisGrid = d3.axisLeft().scale(yScale).tickSize(-(chartWidth - 2 * padding)).tickFormat('').ticks(yTicks);
    d3.select(yAxisGridRef.current).call(yAxisGrid);
  }, [props]);
  return /*#__PURE__*/React__default.createElement("g", null, /*#__PURE__*/React__default.createElement(XAxis, {
    ref: xAxisRef,
    transform: "translate(0, " + (chartHeight - padding) + ")"
  }), /*#__PURE__*/React__default.createElement(XAxisGrid, {
    ref: xAxisGridRef,
    transform: "translate(0, " + (chartHeight - padding) + ")"
  }), /*#__PURE__*/React__default.createElement(YAxis, {
    ref: yAxisRef,
    transform: "translate(" + padding + ", 0)"
  }), /*#__PURE__*/React__default.createElement(YAxisGrid, {
    ref: yAxisGridRef,
    transform: "translate(" + padding + ", 0)"
  }));
};

var LineChartAxes$1 = React.memo(LineChartAxes);

var LineChart = function LineChart(_ref) {
  var _ref$data = _ref.data,
      data = _ref$data === void 0 ? {} : _ref$data,
      labels = _ref.labels,
      _ref$colors = _ref.colors,
      colors = _ref$colors === void 0 ? [] : _ref$colors,
      _ref$padding = _ref.padding,
      padding = _ref$padding === void 0 ? 40 : _ref$padding,
      emptyChartMessage = _ref.emptyChartMessage,
      _ref$allowDecimalTick = _ref.allowDecimalTicks,
      allowDecimalTicks = _ref$allowDecimalTick === void 0 ? false : _ref$allowDecimalTick,
      theme = _ref.theme;
  var _data$linesData = data.linesData,
      linesData = _data$linesData === void 0 ? [] : _data$linesData,
      _data$xAxisData = data.xAxisData,
      xAxisData = _data$xAxisData === void 0 ? [] : _data$xAxisData;

  var _useState = React.useState([]),
      lines = _useState[0],
      setLines = _useState[1];

  var _useState2 = React.useState(),
      markers = _useState2[0],
      setMarkers = _useState2[1];

  var _useState3 = React.useState(0),
      chartWidth = _useState3[0],
      setChartWidth = _useState3[1];

  var _useState4 = React.useState(0),
      chartHeight = _useState4[0],
      setChartHeight = _useState4[1];

  var chartRef = React.useRef(null);
  var windowSize = useWindowSize();
  var yDelta = React.useMemo(function () {
    var domain = d3.extent(linesData.flat(), function (d) {
      return d;
    });
    return domain[1] - domain[0] || 0;
  }, [linesData]);
  var xScale = React.useMemo(function () {
    return d3.scalePoint().domain(xAxisData).range([padding, chartWidth - padding]);
  }, [xAxisData, chartWidth, padding]);
  var yScale = React.useMemo(function () {
    return d3.scaleLinear().domain(d3.extent(linesData.flat(), function (d) {
      return d;
    })).range([chartHeight - padding, padding]);
  }, [linesData, chartHeight, padding]);
  var defaultColors = React.useMemo(function () {
    return theme ? [theme.colors.secondary, theme.colors.warning, theme.colors.error_bg, theme.colors.success_bg] : [];
  }, [theme]);
  var getColor = React.useCallback(function (index) {
    var availableColors = colors.length ? colors : defaultColors;
    return availableColors[index % availableColors.length];
  }, [colors, defaultColors]);
  React.useEffect(function () {
    if (chartRef.current) {
      setChartWidth(chartRef.current.parentElement.offsetWidth);
      setChartHeight(chartRef.current.parentElement.offsetHeight);
    }
  }, [chartRef.current, windowSize]);
  React.useEffect(function () {
    if (!windowSize || !linesData.length) {
      return;
    }

    var lineGenerator = d3.line().x(function (d, i) {
      return xScale(xAxisData[i]);
    }).y(function (d) {
      return yScale(d);
    });
    setLines(linesData.map(lineGenerator));
    setMarkers(linesData.flat().map(function (d, i) {
      var index = i % xAxisData.length;
      var lineId = Math.floor(i / xAxisData.length);
      return index > 0 ? {
        value: d,
        lineId: lineId,
        x: xScale(xAxisData[index]),
        y: yScale(d)
      } : undefined;
    }));
  }, [windowSize, linesData, xAxisData, xScale, yScale]);

  if (!linesData.length) {
    return /*#__PURE__*/React__default.createElement(ChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: "Sorry, no content.",
      smallText: emptyChartMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(ChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement(LineChartLabels$1, {
    labels: labels,
    getColor: getColor
  }), /*#__PURE__*/React__default.createElement("svg", {
    width: chartWidth,
    height: chartHeight
  }, /*#__PURE__*/React__default.createElement(LineChartAxes$1, {
    chartWidth: chartWidth,
    chartHeight: chartHeight,
    padding: padding,
    xScale: xScale,
    yScale: yScale,
    yDelta: yDelta,
    allowDecimalTicks: allowDecimalTicks
  }), /*#__PURE__*/React__default.createElement("g", null, lines && lines.map(function (line, i) {
    return /*#__PURE__*/React__default.createElement(Line, {
      key: i,
      stroke: getColor(i),
      d: line,
      data: linesData
    });
  }), markers && markers.map(function (marker, i) {
    return marker && /*#__PURE__*/React__default.createElement(React__default.Fragment, {
      key: i
    }, /*#__PURE__*/React__default.createElement("circle", {
      cx: marker.x,
      cy: marker.y,
      r: 7.5,
      stroke: getColor(marker.lineId),
      fill: getColor(marker.lineId)
    }), /*#__PURE__*/React__default.createElement(CircleLabel, {
      x: marker.x,
      y: marker.y - 15
    }, marker.value));
  }))));
};

LineChart.propTypes = {
  data: PropTypes.shape({
    linesData: PropTypes.array,
    xAxisData: PropTypes.array
  }),
  labels: PropTypes.array,
  colors: PropTypes.array,
  padding: PropTypes.number,
  emptyChartMessage: PropTypes.string,
  allowDecimalTicks: PropTypes.bool
};
var LineChart$1 = React.memo(styled.withTheme(LineChart));

var PieChartImage = function PieChartImage(_ref) {
  var d = _ref.d,
      showItemsPreview = _ref.showItemsPreview,
      color = _ref.color,
      chartId = _ref.chartId;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [d.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (showItemsPreview && (!d.pic || errorLoadingImage)) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(shape.Circle, {
      r: 15,
      cx: d.x,
      cy: d.y,
      fill: color
    }));
  }

  if (!showItemsPreview) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(text.Text, {
      height: 80,
      width: 80,
      x: d.x,
      y: d.y,
      fontSize: "10px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000"
    }, d.label.toUpperCase()));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: d.pic,
    height: 30,
    width: 30,
    clipPath: "url(#category-" + chartId + "-icon-" + d.id + ")",
    x: d.x - 15,
    y: d.y - 15,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "category-" + chartId + "-icon-" + d.id,
    key: "category-" + chartId + "-icon-" + d.id,
    r: 15,
    cx: d.x,
    cy: d.y
  }));
};

function _templateObject$5() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$5 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledPieChartWrapper = styled__default.div(_templateObject$5());
var tooltipTimeout$3;
var defaultMargin$3 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var PieChart = function PieChart(_ref) {
  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$3 : _ref$margin,
      hasInnerRadius = _ref.hasInnerRadius,
      metric = _ref.metric,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      showItemsPreview = _ref.showItemsPreview;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var innerWidth = width - margin.left - margin.right;
  var innerHeight = height - margin.top - margin.bottom;
  var radius = Math.min(innerWidth, innerHeight) / 2;
  var centerY = innerHeight / 2;
  var centerX = innerWidth / 2;
  var isEmpty = !data || data.length === 0;
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    var filtered = limit !== 'auto' ? data.slice(0, limit) : data;
    return filtered.filter(function (d) {
      return d[metric] && d[metric] > 0;
    });
  }, [isEmpty, data, limit, metric]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : filteredData.length / 2, isEmpty ? 0 : filteredData.length],
      range: getColors(color)
    });
  }, [isEmpty, filteredData, color]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$3 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, index) {
    if (tooltipTimeout$3) clearTimeout(tooltipTimeout$3);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, filteredData[index], {
        color: colorScale(index)
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, filteredData, colorScale]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledPieChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledPieChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: centerY + margin.top,
    left: centerX + margin.left,
    key: "group-" + chartId.current
  }, /*#__PURE__*/React__default.createElement(shape.Pie, {
    data: filteredData,
    pieValue: function pieValue(d) {
      return metric === METRICS.BASE ? d[metric] * 100 : d[metric];
    },
    pieSortValues: function pieSortValues() {
      return -1;
    },
    outerRadius: radius - 2 * 1.3
  }, function (pie) {
    return pie.arcs.map(function (arc, index) {
      var _pie$path$centroid = pie.path.centroid(arc),
          centroidX = _pie$path$centroid[0],
          centroidY = _pie$path$centroid[1];

      var point = (arc.startAngle + arc.endAngle) / 2 - Math.PI / 2;
      var offsetX = Math.cos(point) * (radius / 2) < 0 ? Math.cos(point) * (radius / 2) - 30 : Math.cos(point) * (radius / 2) + 30;
      var offsetY = Math.sin(point) * (radius / 2) < 0 ? Math.sin(point) * (radius / 2) - 30 : Math.sin(point) * (radius / 2) + 30;
      return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
        key: "arc-" + chartId.current + "-" + index
      }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement(shape.Arc, {
        startAngle: arc.startAngle,
        endAngle: arc.endAngle,
        innerRadius: hasInnerRadius ? radius / 2 : 0,
        cornerRadius: 1,
        outerRadius: radius,
        padAngle: arc.padAngle,
        padRadius: 2,
        fill: colorScale(index),
        stroke: "#fff",
        strokeWidth: "1",
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, index);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        onTouchMove: function onTouchMove(event) {
          return handleMouseMove(event, index);
        },
        onTouchEnd: function onTouchEnd(event) {
          return handleMouseLeave(event);
        }
      }), /*#__PURE__*/React__default.createElement(PieChartImage, {
        d: _extends({}, arc.data, {
          x: centroidX + offsetX,
          y: centroidY + offsetY
        }),
        color: colorScale(index),
        showItemsPreview: showItemsPreview,
        chartId: chartId.current
      })));
    });
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY, 1)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE, 1))));
};

function _templateObject3$2() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: ", ";\n"]);

  _templateObject3$2 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$3() {
  var data = _taggedTemplateLiteralLoose(["\n  border-radius: ", ";\n  display: flex;\n  flex-wrap: wrap;\n  flex-direction: column;\n  text-align: left;\n  width: max-content;\n  max-width: 250px;\n  white-space: pre-line;\n  font-size: ", ";\n  line-height: 18px;\n  color: ", ";\n  background-color: ", ";\n  box-shadow: ", "\n    ", ";\n  padding: ", ";\n  ", ";\n  ", ";\n  z-index: ", ";\n"]);

  _templateObject2$3 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$6() {
  var data = _taggedTemplateLiteralLoose(["\n    &::after {\n      content: '';\n      width: 0;\n      height: 0;\n      border-style: solid;\n      border-width: 6px 4px 0 4px;\n      border-color: rgb(58, 57, 73) transparent transparent transparent;\n      z-index: 1;\n      position: absolute;\n      bottom: -6px;\n      left: 50%;\n      transform: translate(-50%, 0);\n    }\n  "]);

  _templateObject$6 = function _templateObject() {
    return data;
  };

  return data;
}

var getTriangle = function getTriangle() {
  return styled.css(_templateObject$6());
};

var getPosition = function getPosition(_ref) {
  var left = _ref.left,
      top = _ref.top;
  return "\n    position: absolute;\n    top: " + top + "px;\n    left: " + left + "px;\n    transform: translate(-50%, calc(-100% - 12px));\n  ";
};

var StyledDotTooltip = styled__default.div(_templateObject2$3(), function (props) {
  return props.theme.border_radius.standard;
}, function (props) {
  return props.theme.size.small;
}, function (props) {
  return props.theme.colors.light;
}, function (props) {
  return props.theme.colors.dark_light;
}, function (props) {
  return props.theme.shadow.position;
}, function (props) {
  return props.theme.shadow.color;
}, function (props) {
  return props.theme.spacing.small;
}, function (props) {
  return getTriangle();
}, function (props) {
  return getPosition(props);
}, function (props) {
  return props.theme.zindex.small;
});
var StyledDotsChartWrapper = styled__default.div(_templateObject3$2(), function (props) {
  return props.theme.colors.light;
});

var DotsChart = function DotsChart(_ref) {
  var _ref$data = _ref.data,
      data = _ref$data === void 0 ? [] : _ref$data,
      _ref$padding = _ref.padding,
      padding = _ref$padding === void 0 ? 40 : _ref$padding,
      radius = _ref.radius,
      showTooltips = _ref.showTooltips,
      emptyDataMessage = _ref.emptyDataMessage;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var windowSize = useWindowSize();

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useState3 = React.useState(0),
      tooltipTop = _useState3[0],
      setTooltipTop = _useState3[1];

  var _useState4 = React.useState(0),
      tooltipLeft = _useState4[0],
      setTooltipLeft = _useState4[1];

  var _useState5 = React.useState(null),
      tooltipData = _useState5[0],
      setTooltipData = _useState5[1];

  var _useState6 = React.useState(false),
      tooltipOpen = _useState6[0],
      setTooltipOpen = _useState6[1];

  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var points = [];
  data.map(function (segment) {
    points = points.concat(segment.values);
  });

  var _points$reduce = points.reduce(function (_ref2, _ref3) {
    var xList = _ref2[0],
        yList = _ref2[1];
    var x = _ref3.x,
        y = _ref3.y;
    xList.push(x);
    yList.push(y);
    return [xList, yList];
  }, [[], []]),
      xValues = _points$reduce[0],
      yValues = _points$reduce[1];

  var minMaxValues = {
    xMin: Math.min.apply(Math, xValues),
    xMax: Math.max.apply(Math, xValues),
    yMin: Math.min.apply(Math, yValues),
    yMax: Math.max.apply(Math, yValues)
  };
  var xScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [minMaxValues.xMin, minMaxValues.xMax],
      range: [padding, width - padding],
      clamp: true
    });
  }, [width, padding]);
  var yScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [minMaxValues.yMin, minMaxValues.yMax],
      range: [height - padding, padding],
      clamp: true
    });
  }, [height, padding]);
  var getColor = React.useCallback(function (color, index) {
    var availableColors = ['#AB47BC', '#009A7F', '#FF3B30', '#F5A741', '#5B53DF', '#47F5F0', '#FF8896', '#7B9A1D'];
    return color || availableColors[index % availableColors.length];
  }, []);
  var handleMouseMove = React.useCallback(function (event$1, label) {
    if (!svgRef.current) return;
    var point = event.localPoint(svgRef.current, event$1);
    if (!point) return;
    setTooltipLeft(point.x);
    setTooltipTop(point.y);
    setTooltipOpen(true);
    setTooltipData(label);
  }, [svgRef, xScale, yScale]);
  var handleMouseLeave = React.useCallback(function (event) {
    window.setTimeout(function () {
      setTooltipOpen(false);
    }, 300);
  }, []);

  if (!data || data.length === 0) {
    return /*#__PURE__*/React__default.createElement(StyledDotsChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledDotsChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    rx: 14,
    fill: "white"
  }), data.map(function (group$1, index) {
    return /*#__PURE__*/React__default.createElement(group.Group, {
      key: "group-" + chartId.current + "-" + index
    }, /*#__PURE__*/React__default.createElement(gradient.RadialGradient, {
      to: "#ffffff",
      from: getColor(group$1.color, index),
      id: "dots-gradient-" + chartId.current + "-" + index,
      r: "70%"
    }), group$1.values.map(function (point, i) {
      return /*#__PURE__*/React__default.createElement(shape.Circle, {
        key: "point-" + chartId.current + "-" + index + "-" + i,
        id: "point-" + chartId.current + "-" + index + "-" + i,
        className: "dot",
        cx: xScale(point.x),
        cy: yScale(point.y),
        r: radius,
        fill: "url(#dots-gradient-" + chartId.current + "-" + index + ")",
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, group$1.label);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        onTouchMove: function onTouchMove(event) {
          return handleMouseMove(event, group$1.label);
        },
        onTouchEnd: function onTouchEnd(event) {
          return handleMouseLeave(event);
        }
      });
    }));
  })), showTooltips && tooltipOpen && tooltipLeft != null && tooltipTop != null && /*#__PURE__*/React__default.createElement(StyledDotTooltip, {
    left: tooltipLeft,
    top: tooltipTop
  }, /*#__PURE__*/React__default.createElement("div", null, tooltipData)));
};

DotsChart.propTypes = {
  data: PropTypes.array,
  padding: PropTypes.number,
  radius: PropTypes.number,
  showTooltips: PropTypes.bool,
  emptyDataMessage: PropTypes.string
};
var DotsChart$1 = React.memo(styled.withTheme(DotsChart));

function _templateObject$7() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  max-height: 500px;\n"]);

  _templateObject$7 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledSpiderChartWrapper = styled__default.div(_templateObject$7());

var SpiderChartImage = function SpiderChartImage(item) {
  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [item.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);
  var radius = Math.max(item.width, item.height) / 2;

  if (!item.pic || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement(shape.Circle, {
      key: "point-" + item.x + "-" + item.y,
      id: "point-" + item.x + "-" + item.y,
      cx: item.x,
      cy: item.y,
      r: radius,
      fill: item.color
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      x: item.x,
      y: item.y,
      fontSize: "11px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#ffffff"
    }, item.initials.toUpperCase())));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: item.pic,
    height: item.width,
    width: item.height,
    x: item.x - radius,
    y: item.y - radius,
    clipPath: "url(#icon-" + item.x + "-" + item.y + ")",
    onError: function onError() {
      onErrorLoadingImage();
    }
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "icon-" + item.x + "-" + item.y,
    key: "icon-" + item.x + "-" + item.y,
    className: "dot",
    cx: item.x,
    cy: item.y,
    r: radius
  }));
};

var tooltipTimeout$4;
var defaultMargin$4 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var SpiderChart = function SpiderChart(_ref) {
  var _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$4 : _ref$margin,
      metric = _ref.metric,
      degrees = _ref.degrees,
      levels = _ref.levels,
      showItemsPreview = _ref.showItemsPreview,
      categories = _ref.categories,
      groups = _ref.groups,
      showPolygonPoints = _ref.showPolygonPoints,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      limit = _ref.limit;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var isEmptyCategories = !categories || categories.length === 0;
  var xMax = width - margin.left - margin.right - 70;
  var yMax = height - margin.top - margin.bottom - 70;
  var radius = Math.min(xMax, yMax) / 2;
  var zeroPoint = {
    x: 0,
    y: 0
  };
  var filteredCategories = React.useMemo(function () {
    if (isEmptyCategories) {
      return [];
    }

    return limit !== 'auto' ? categories.slice(0, limit) : categories;
  }, [isEmptyCategories, categories, limit]);
  var sides = filteredCategories && filteredCategories.length || 0;
  var webs = React.useMemo(function () {
    var list = [];

    for (var i = 0; i < sides + 5; i++) {
      list.push({
        angle: i * (degrees / sides)
      });
    }

    return list;
  }, [sides, degrees]);
  var radialScale = React.useMemo(function () {
    return scale.scaleLinear({
      range: [0, Math.PI * 2],
      domain: [degrees, 0]
    });
  }, [degrees]);
  var points = React.useMemo(function () {
    var step = Math.PI * 2 / sides;
    var xMax = width - margin.left - margin.right - 70;
    var yMax = height - margin.top - margin.bottom - 70;
    var r = Math.min(xMax, yMax) / 2;
    var list = [];

    for (var i = 0; i < sides; i++) {
      list.push({
        x: r * Math.sin(i * step),
        y: r * Math.cos(i * step)
      });
    }

    return list;
  }, [height, width, sides, margin]);
  var maxValue = React.useMemo(function () {
    var max = 0;

    if (groups) {
      groups.forEach(function (group) {
        max = Math.max.apply(Math, [max].concat(group.values.map(function (item) {
          return item[metric];
        })));
      });
    }

    return max;
  }, [groups, metric]);
  var yScale = React.useMemo(function () {
    return scale.scaleLinear({
      range: [0, radius],
      domain: [0, maxValue],
      clamp: true
    });
  }, [radius, maxValue]);
  var getPolygonPoints = React.useCallback(function (group) {
    var listOfPoints = [];
    var step = Math.PI * 2 / sides;
    var values = group.values;
    var res = '';
    filteredCategories.forEach(function (category, i) {
      var point = values.find(function (item) {
        return item.id === category.id;
      });
      var xVal = point[metric] && yScale(point[metric]) * Math.sin(i * step) || 0;
      var yVal = point[metric] && yScale(point[metric]) * Math.cos(i * step) || 0;
      listOfPoints.push({
        x: xVal,
        y: yVal
      });
      res += xVal + "," + yVal + " ";
    });
    return {
      path: res,
      points: listOfPoints
    };
  }, [sides, metric, yScale, filteredCategories]);
  var icons = React.useMemo(function () {
    var step = Math.PI * 2 / sides;
    var xMax = width - margin.left - margin.right;
    var yMax = height - margin.top - margin.bottom;
    var r = Math.min(xMax, yMax) / 2;
    var list = [];

    for (var i = 0; i < sides; i++) {
      list.push({
        x: r * Math.sin(i * step),
        y: r * Math.cos(i * step)
      });
    }

    return list;
  }, [height, width, sides, margin]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmptyCategories ? 0 : filteredCategories.length / 2, isEmptyCategories ? 0 : filteredCategories.length],
      range: getColors(color)
    });
  }, [filteredCategories, isEmptyCategories, color]);
  var handlePointMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$4 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handlePointMouseMove = React.useCallback(function (event$1, index, group, groupIndex) {
    if (tooltipTimeout$4) clearTimeout(tooltipTimeout$4);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, filteredCategories[index], group.values[index], {
        color: colorScale(groupIndex)
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, filteredCategories, colorScale]);
  var handlePolygonMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$4 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handlePolygonMouseMove = React.useCallback(function (event$1, group, groupIndex) {
    if (tooltipTimeout$4) clearTimeout(tooltipTimeout$4);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: {
        label: group.label,
        color: colorScale(groupIndex)
      },
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, colorScale]);
  var levelsList = React.useMemo(function () {
    var list = [];

    for (var i = 0; i < levels; i++) {
      list.push(i);
    }

    return list;
  }, [levels]);

  if (!groups || groups.length === 0) {
    return /*#__PURE__*/React__default.createElement(StyledSpiderChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledSpiderChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "white",
    width: width,
    height: height,
    rx: 14
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: height / 2,
    left: width / 2,
    key: "group-" + chartId.current
  }, levelsList.map(function (_, i) {
    return /*#__PURE__*/React__default.createElement(shape.LineRadial, {
      key: "web-" + chartId.current + "-" + i,
      data: webs,
      angle: function angle(d) {
        var _radialScale;

        return (_radialScale = radialScale(d.angle)) != null ? _radialScale : 0;
      },
      radius: (i + 1) * radius / levels,
      fill: "none",
      stroke: "#d9d9d9",
      strokeWidth: 2,
      strokeOpacity: 0.8,
      strokeLinecap: "round"
    });
  }), filteredCategories.map(function (category, i) {
    return /*#__PURE__*/React__default.createElement(React.Fragment, {
      key: "line-" + chartId.current + "-icon-" + i
    }, showItemsPreview ? /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement(SpiderChartImage, {
      pic: category.img || category.pic,
      x: icons[i].x,
      y: icons[i].y,
      width: 48,
      height: 48,
      initials: category.label.substring(0, 2),
      color: colorScale(i)
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      width: 100,
      height: 100,
      x: icons[i].x,
      y: icons[i].y < 0 ? icons[i].y - 30 : icons[i].y + 30,
      fontSize: "11px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: icons[i].y < 0 ? 'end' : 'start'
    }, category.label)) : /*#__PURE__*/React__default.createElement(text.Text, {
      width: 100,
      height: 100,
      x: icons[i].x,
      y: icons[i].y,
      fontSize: "11px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: icons[i].y < 0 ? 'end' : 'start'
    }, category.label), /*#__PURE__*/React__default.createElement(shape.Line, {
      key: "radar-" + chartId.current + "-line-" + i,
      from: zeroPoint,
      to: points[i],
      stroke: "#d9d9d9"
    }));
  }), groups.map(function (group, index) {
    var polygonPoints = getPolygonPoints(group);
    return /*#__PURE__*/React__default.createElement(React.Fragment, {
      key: "polygon-" + chartId.current + "-" + index
    }, /*#__PURE__*/React__default.createElement("polygon", {
      points: polygonPoints.path,
      fill: colorScale(index),
      fillOpacity: 0.3,
      stroke: colorScale(index),
      strokeWidth: 1,
      onMouseMove: function onMouseMove(event) {
        return !showPolygonPoints && handlePolygonMouseMove(event, group, index);
      },
      onMouseLeave: function onMouseLeave(event) {
        return !showPolygonPoints && handlePolygonMouseLeave(event);
      },
      onTouchMove: function onTouchMove(event) {
        return !showPolygonPoints && handlePolygonMouseMove(event, group, index);
      },
      onTouchEnd: function onTouchEnd(event) {
        return !showPolygonPoints && handlePolygonMouseLeave(event);
      }
    }), showPolygonPoints && polygonPoints.points.map(function (point, i) {
      return /*#__PURE__*/React__default.createElement("circle", {
        key: "radar-" + chartId.current + "-point-" + i,
        cx: point.x,
        cy: point.y,
        r: 4,
        fill: colorScale(index),
        onMouseMove: function onMouseMove(event) {
          return handlePointMouseMove(event, i, group, index);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handlePointMouseLeave(event);
        },
        onTouchMove: function onTouchMove(event) {
          return handlePointMouseMove(event, i, group, index);
        },
        onTouchEnd: function onTouchEnd(event) {
          return handlePointMouseLeave(event);
        }
      });
    }));
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, metric === METRICS.REACH && showPolygonPoints && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), metric === METRICS.AFFINITY && showPolygonPoints && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), metric === METRICS.BASE && showPolygonPoints && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE, 1))));
};

function _templateObject3$3() {
  var data = _taggedTemplateLiteralLoose(["\n  position: absolute;\n  text-align: center;\n"]);

  _templateObject3$3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$4() {
  var data = _taggedTemplateLiteralLoose(["\n  position: relative;\n  width: ", ";\n  height: ", ";\n"]);

  _templateObject2$4 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$8() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n"]);

  _templateObject$8 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledDonutChartWrapper = styled__default.div(_templateObject$8());
var StyledDonutChartSvg = styled__default.div(_templateObject2$4(), function (props) {
  return props.width + 'px';
}, function (props) {
  return props.height + 'px';
});
var StyledDonutChartText = styled__default.div(_templateObject3$3());

var defaultMargin$5 = {
  top: 20,
  left: 20,
  right: 20,
  bottom: 20
};

var DonutChart = function DonutChart(_ref) {
  var donutThickness = _ref.donutThickness,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$5 : _ref$margin,
      data = _ref.data,
      color = _ref.color,
      children = _ref.children;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var chartId = React.useRef(uniqid());
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var innerWidth = width - margin.left - margin.right;
  var innerHeight = height - margin.top - margin.bottom;
  var radius = Math.min(innerWidth, innerHeight) / 2;
  var centerY = innerHeight / 2;
  var centerX = innerWidth / 2;
  var pieData = React.useMemo(function () {
    var arcs = [{
      index: 0,
      value: data,
      isBackground: false
    }];
    var diff = Number((1 - data).toFixed(2));

    if (data !== 0 && data % 1 !== 0) {
      arcs = arcs.concat({
        index: 1,
        value: diff,
        isBackground: true
      });
    }

    if (data === 0) {
      arcs = [{
        index: 1,
        value: diff,
        isBackground: true
      }];
    }

    return arcs;
  }, [data]);
  var chartText = React.useMemo(function () {
    var texts = children && React.Children.map(children, function (child, index) {
      return /*#__PURE__*/React__default.createElement(React.Fragment, {
        key: "child-" + chartId.current + "-" + index
      }, child);
    });
    return /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement("div", {
      style: {
        fontSize: '24px',
        fontWeight: 'bold',
        paddingBottom: '10px'
      }
    }, Number((data * 100).toFixed(2)), "%"), texts);
  }, [data, children]);

  var pieSort = function pieSort(a, b) {
    return a.index - b.index;
  };

  var pieValue = function pieValue(d) {
    return d.value;
  };

  return /*#__PURE__*/React__default.createElement(StyledDonutChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement(StyledDonutChartSvg, {
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    rx: 14,
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    key: "group-" + chartId.current,
    top: centerY + margin.top,
    left: centerX + margin.left
  }, /*#__PURE__*/React__default.createElement(shape.Pie, {
    data: pieData,
    pieValue: pieValue,
    outerRadius: radius,
    innerRadius: radius - donutThickness,
    cornerRadius: 25,
    pieSort: pieSort
  }, function (pie) {
    return pie.arcs.map(function (arc, index) {
      return /*#__PURE__*/React__default.createElement(React.Fragment, {
        key: "arc-" + chartId.current + "-" + index
      }, !arc.data.isBackground && /*#__PURE__*/React__default.createElement(shape.Arc, {
        startAngle: arc.startAngle,
        endAngle: arc.endAngle,
        innerRadius: radius - donutThickness,
        cornerRadius: donutThickness / 2,
        outerRadius: radius,
        padAngle: arc.padAngle,
        padRadius: arc.padRadius,
        fill: color
      }), arc.data.isBackground && /*#__PURE__*/React__default.createElement(shape.Arc, {
        startAngle: 0,
        endAngle: arc.endAngle,
        innerRadius: radius - donutThickness,
        cornerRadius: 3,
        outerRadius: radius,
        padAngle: arc.padAngle,
        padRadius: arc.padRadius,
        fill: color,
        opacity: 0.15
      }));
    });
  })))), /*#__PURE__*/React__default.createElement(StyledDonutChartText, null, chartText));
};

DonutChart.propTypes = {
  donutThickness: PropTypes.number,
  margin: PropTypes.object,
  data: PropTypes.number,
  color: PropTypes.string
};
var DonutChart$1 = React.memo(styled.withTheme(DonutChart));

function _templateObject4$2() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 11px;\n  font-weight: normal;\n  padding-left: 10px;\n"]);

  _templateObject4$2 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$4() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 16px;\n  background: ", ";\n  border-radius: 8px;\n  height: 16px;\n"]);

  _templateObject3$4 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$5() {
  var data = _taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: center;\n  padding-left: 10px;\n"]);

  _templateObject2$5 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$9() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: ", ";\n  display: flex;\n  flex-direction: column;\n"]);

  _templateObject$9 = function _templateObject() {
    return data;
  };

  return data;
}
var StyledBarGroupChartWrapper = styled__default.div(_templateObject$9(), function (props) {
  return props.theme.colors.light;
});
var LegendWrapper = styled__default.div(_templateObject2$5());
var LegendCircle = styled__default.div(_templateObject3$4(), function (props) {
  return props.color;
});
var LegendText = styled__default.div(_templateObject4$2());

var BarGroupChartLegend = function BarGroupChartLegend(_ref) {
  var legend = _ref.legend;
  return legend.map(function (item, i) {
    return /*#__PURE__*/React__default.createElement(LegendWrapper, {
      key: i
    }, /*#__PURE__*/React__default.createElement(LegendCircle, {
      color: item.color
    }, "\xA0"), /*#__PURE__*/React__default.createElement(LegendText, null, item.label));
  });
};

var ChartTickImage = function ChartTickImage(item) {
  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [item.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);
  var radius = Math.max(item.width, item.height) / 2;

  if (!item.pic || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement(shape.Circle, {
      key: "point-" + item.parentId + "-" + item.x + "-" + item.y,
      id: "point-" + item.parentId + "-" + item.x + "-" + item.y,
      cx: item.x,
      cy: item.y,
      r: radius,
      fill: "#5b53df"
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      x: item.x,
      y: item.y,
      fontSize: "11px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#ffffff"
    }, item.initials.toUpperCase())));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: item.pic,
    height: item.width,
    width: item.height,
    x: item.x - radius,
    y: item.y - radius,
    clipPath: "url(#icon-" + item.parentId + "-" + item.x + "-" + item.y + ")",
    onError: function onError() {
      onErrorLoadingImage();
    }
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "icon-" + item.parentId + "-" + item.x + "-" + item.y,
    key: "icon-" + item.parentId + "-" + item.x + "-" + item.y,
    className: "dot",
    cx: item.x,
    cy: item.y,
    r: radius
  }));
};

var defaultMargin$6 = {
  top: 40,
  left: 0,
  right: 0,
  bottom: 120
};

var BarGroupChart = function BarGroupChart(_ref) {
  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$6 : _ref$margin,
      xValueKey = _ref.xValueKey,
      xLabelKey = _ref.xLabelKey,
      xImageKey = _ref.xImageKey,
      keys = _ref.keys,
      colors = _ref.colors,
      legend = _ref.legend,
      emptyDataMessage = _ref.emptyDataMessage,
      areBarsRounded = _ref.areBarsRounded;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var chartId = React.useRef(uniqid());
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;

  var getXValue = function getXValue(d) {
    return d[xValueKey];
  };

  var xScale = scale.scaleBand({
    domain: data && data.map(getXValue) || [],
    padding: 0.6
  });
  var keysScale = scale.scaleBand({
    domain: keys,
    padding: 0.0
  });
  var valueScale = scale.scaleLinear({
    domain: [0, Math.max.apply(Math, data && data.map(function (d) {
      return Math.max.apply(Math, keys.map(function (key) {
        return Number(d[key]);
      }));
    }) || [])]
  });
  var colorScale = scale.scaleOrdinal({
    domain: keys,
    range: colors || ['#D8D7EA']
  });
  xScale.rangeRound([0, xMax]);
  keysScale.rangeRound([0, xScale.bandwidth()]);
  valueScale.range([yMax, 0]);
  var getTickComponent = React.useCallback(function (d) {
    return /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement(ChartTickImage, {
      pic: d.pic,
      x: d.x,
      y: d.y,
      width: 36,
      height: 36,
      parentId: chartId.current,
      initials: d.label.substring(0, 2)
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      width: 80,
      height: 80,
      x: d.x,
      y: d.y + 25,
      fontSize: "10px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "start"
    }, d.label));
  }, []);
  var getTickLabel = React.useCallback(function (d) {
    var item = data.find(function (i) {
      return i[xValueKey] === d;
    });
    return item && item[xLabelKey] || '';
  }, [data, xValueKey, xLabelKey]);
  var getTickImage = React.useCallback(function (d) {
    var item = data.find(function (i) {
      return i[xValueKey] === d;
    });
    return item && item[xImageKey] || '';
  }, [data, xValueKey, xImageKey]);
  var getGroupContent = React.useCallback(function (group, groups) {
    var options = groups.tickLabelProps(group.value);

    var props = _extends({}, options, {
      x: group.to.x,
      y: 10 + group.to.y
    });

    return groups.tickComponent(props);
  }, []);

  if (!data || data.length === 0) {
    return /*#__PURE__*/React__default.createElement(StyledBarGroupChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledBarGroupChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    rx: 14,
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    key: "group-" + chartId.current,
    top: margin.top,
    left: margin.left
  }, /*#__PURE__*/React__default.createElement(shape.BarGroup, {
    data: data,
    keys: keys,
    height: yMax,
    x0: getXValue,
    x0Scale: xScale,
    x1Scale: keysScale,
    yScale: valueScale,
    color: colorScale
  }, function (barGroups) {
    return barGroups.map(function (barGroup, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "bar-group-" + chartId.current + "-" + barGroup.index,
        left: barGroup.x0
      }, barGroup.bars.map(function (bar) {
        return /*#__PURE__*/React__default.createElement(React.Fragment, {
          key: "bar-group-bar-" + chartId.current + "-" + barGroup.index + "-" + bar.index
        }, areBarsRounded && /*#__PURE__*/React__default.createElement(shape.BarRounded, {
          x: bar.x,
          y: bar.y,
          width: 12,
          height: bar.height,
          radius: bar.width / 2,
          all: true,
          fill: bar.color
        }), !areBarsRounded && /*#__PURE__*/React__default.createElement(shape.Bar, {
          x: bar.x,
          y: bar.y,
          width: bar.width,
          height: bar.height,
          fill: bar.color
        }));
      }));
    });
  })), /*#__PURE__*/React__default.createElement(axis.AxisBottom, {
    top: yMax + margin.top + 10,
    left: margin.left,
    scale: xScale,
    hideAxisLine: true,
    hideTicks: true,
    tickLabelProps: function tickLabelProps(d) {
      return {
        fontSize: '11px',
        pic: getTickImage(d),
        label: getTickLabel(d)
      };
    },
    tickComponent: function tickComponent(d) {
      return getTickComponent(d);
    }
  }, function (axisGroups) {
    return axisGroups.ticks.map(function (group$1, index) {
      return /*#__PURE__*/React__default.createElement(group.Group, {
        key: "axis-group-" + chartId.current + "-" + index
      }, getGroupContent(group$1, axisGroups));
    });
  })), legend && /*#__PURE__*/React__default.createElement(BarGroupChartLegend, {
    legend: legend
  }));
};

BarGroupChart.propTypes = {
  data: PropTypes.array,
  margin: PropTypes.object,
  xValueKey: PropTypes.string,
  xLabelKey: PropTypes.string,
  keys: PropTypes.array,
  colors: PropTypes.array,
  legend: PropTypes.array,
  padding: PropTypes.number,
  emptyDataMessage: PropTypes.string,
  areBarsRounded: PropTypes.bool
};
BarGroupChart.defaultProps = {
  emptyDataMessage: 'No content'
};
var BarGroupChart$1 = React.memo(styled.withTheme(BarGroupChart));

function _templateObject$a() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  .venntooltip {\n    position: absolute;\n    text-align: center;\n    background: #000000;\n    opacity: 0;\n    color: #ffffff;\n    padding: 2px;\n    min-width: 128px;\n    border-radius: 8px;\n  }\n"]);

  _templateObject$a = function _templateObject() {
    return data;
  };

  return data;
}
var ChartWrapper$1 = styled__default.div(_templateObject$a());

var VennDiagram = function VennDiagram(_ref) {
  var sets = _ref.sets,
      emptyDataMessage = _ref.emptyDataMessage;
  var vennRef = React.useRef();
  var getColor = React.useCallback(function (color, index) {
    var availableColors = ['#AB47BC', '#009A7F', '#FF3B30', '#F5A741', '#5B53DF', '#47F5F0', '#FF8896', '#7B9A1D'];
    return color || availableColors[index % availableColors.length];
  }, []);
  React.useEffect(function () {
    if (vennRef && vennRef.current) {
      var chart = venn.VennDiagram();
      var vennDiagramNode = d3.select(vennRef.current);
      vennDiagramNode.datum(sets).call(chart);
      vennDiagramNode.selectAll('.venn-circle path').style('fill', function (d, i) {
        return getColor(sets[i].color);
      }).style('fill-opacity', 0.4);
      vennDiagramNode.selectAll('.venn-circle text').style('fill', function (d, i) {
        return getColor(sets[i].color);
      }).style('font-weight', '700').style('font-size', '14px');
      var tooltip = vennDiagramNode.append('div').attr('class', 'venntooltip');
      vennDiagramNode.selectAll('g').on('mouseover', function (event, item) {
        tooltip.transition().duration(400).style('opacity', 0.7);
        tooltip.text(numberWithCommas(item.size) + ' users');
        var selection = d3.select(event.currentTarget).transition('tooltip').duration(400);
        selection.select('path').style('stroke', '#ffffff').style('stroke-width', '3').style('fill-opacity', item.sets && item.sets.length === 1 ? 0.5 : 0.1).style('stroke-opacity', 1);
      }).on('mousemove', function (event) {
        tooltip.style('left', event.pageX + 'px').style('top', event.pageY - 28 + 'px');
      }).on('mouseout', function (event, item) {
        tooltip.transition().duration(400).style('opacity', 0);
        var selection = d3.select(event.currentTarget).transition('tooltip').duration(400);
        selection.select('path').style('stroke-width', 0).style('fill-opacity', item.sets && item.sets.length === 1 ? 0.4 : 0.0).style('stroke-opacity', 0);
      });
    }
  }, [vennRef, sets, getColor]);

  if (!sets || sets.length === 0) {
    return /*#__PURE__*/React__default.createElement(ChartWrapper$1, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(ChartWrapper$1, null, /*#__PURE__*/React__default.createElement("div", {
    ref: vennRef
  }));
};

function _templateObject6$1() {
  var data = _taggedTemplateLiteralLoose(["\n  border-radius: 4px;\n  display: flex;\n  flex-wrap: wrap;\n  flex-direction: column;\n  text-align: left;\n  width: max-content;\n  max-width: 250px;\n  white-space: pre-line;\n  font-size: 11px;\n  line-height: 18px;\n  color: #ffffff;\n  background-color: rgb(58, 57, 73);\n  box-shadow: rgb(25 25 39 / 25%) 0px 2px 6px 0px;\n  padding: 5px;\n  ", ";\n  ", ";\n  z-index: 1000;\n"]);

  _templateObject6$1 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$1() {
  var data = _taggedTemplateLiteralLoose(["\n    &::after {\n      content: '';\n      width: 0;\n      height: 0;\n      border-style: solid;\n      border-width: 6px 4px 0 4px;\n      border-color: rgb(58, 57, 73) transparent transparent transparent;\n      z-index: 1;\n      position: absolute;\n      bottom: -6px;\n      left: 50%;\n      transform: translate(-50%, 0);\n    }\n  "]);

  _templateObject5$1 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$3() {
  var data = _taggedTemplateLiteralLoose(["\n  cursor: ", ";\n\n  & path:hover {\n    ", ";\n  }\n"]);

  _templateObject4$3 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$5() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n"]);

  _templateObject3$5 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$6() {
  var data = _taggedTemplateLiteralLoose(["\n    fill: #9493a6;\n  "]);

  _templateObject2$6 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$b() {
  var data = _taggedTemplateLiteralLoose(["\n      fill-opacity: 0.8;\n    "]);

  _templateObject$b = function _templateObject() {
    return data;
  };

  return data;
}

var getColorHover = function getColorHover(metric) {
  if (metric) {
    return styled.css(_templateObject$b());
  }

  return styled.css(_templateObject2$6());
};

var StyledUsaMapChartWrapper = styled__default.div(_templateObject3$5());
var StyledMapFeatureSvg = styled__default.svg(_templateObject4$3(), function (props) {
  return props.selectable && 'pointer';
}, function (props) {
  return props.selectable && getColorHover(props.metric);
});

var getTriangle$1 = function getTriangle() {
  return styled.css(_templateObject5$1());
};

var getPosition$1 = function getPosition(left, top) {
  return "\n    position: absolute;\n    top: " + top + "px;\n    left: " + left + "px;\n    transform: translate(-50%, calc(-100% - 12px));\n  ";
};

var StyledUsaMapChartTooltip = styled__default.div(_templateObject6$1(), function (props) {
  return getTriangle$1();
}, function (props) {
  return getPosition$1(props.left, props.top);
});

var statesAbbr = [
	{
		id: "01",
		label: "AL"
	},
	{
		id: "02",
		label: "AK"
	},
	{
		id: "60",
		label: "AS"
	},
	{
		id: "04",
		label: "AZ"
	},
	{
		id: "05",
		label: "AR"
	},
	{
		id: "06",
		label: "CA"
	},
	{
		id: "08",
		label: "CO"
	},
	{
		id: "09",
		label: "CT"
	},
	{
		id: "10",
		label: "DE"
	},
	{
		id: "12",
		label: "FL"
	},
	{
		id: "64",
		label: "FM"
	},
	{
		id: "13",
		label: "GA"
	},
	{
		id: "66",
		label: "GU"
	},
	{
		id: "15",
		label: "HI"
	},
	{
		id: "16",
		label: "ID"
	},
	{
		id: "17",
		label: "IL"
	},
	{
		id: "18",
		label: "IN"
	},
	{
		id: "19",
		label: "IA"
	},
	{
		id: "20",
		label: "KS"
	},
	{
		id: "21",
		label: "KY"
	},
	{
		id: "22",
		label: "LA"
	},
	{
		id: "23",
		label: "ME"
	},
	{
		id: "68",
		label: "MH"
	},
	{
		id: "24",
		label: "MD"
	},
	{
		id: "25",
		label: "MA"
	},
	{
		id: "26",
		label: "MI"
	},
	{
		id: "27",
		label: "MN"
	},
	{
		id: "28",
		label: "MS"
	},
	{
		id: "29",
		label: "MO"
	},
	{
		id: "30",
		label: "MT"
	},
	{
		id: "31",
		label: "NE"
	},
	{
		id: "32",
		label: "NV"
	},
	{
		id: "33",
		label: "NH"
	},
	{
		id: "34",
		label: "NJ"
	},
	{
		id: "35",
		label: "NM"
	},
	{
		id: "36",
		label: "NY"
	},
	{
		id: "37",
		label: "NC"
	},
	{
		id: "38",
		label: "ND"
	},
	{
		id: "69",
		label: "MP"
	},
	{
		id: "39",
		label: "OH"
	},
	{
		id: "40",
		label: "OK"
	},
	{
		id: "41",
		label: "OR"
	},
	{
		id: "70",
		label: "PW"
	},
	{
		id: "42",
		label: "PA"
	},
	{
		id: "72",
		label: "PR"
	},
	{
		id: "44",
		label: "RI"
	},
	{
		id: "45",
		label: "SC"
	},
	{
		id: "46",
		label: "SD"
	},
	{
		id: "47",
		label: "TN"
	},
	{
		id: "48",
		label: "TX"
	},
	{
		id: "74",
		label: "UM"
	},
	{
		id: "49",
		label: "UT"
	},
	{
		id: "50",
		label: "VT"
	},
	{
		id: "51",
		label: "VA"
	},
	{
		id: "78",
		label: "VI"
	},
	{
		id: "53",
		label: "WA"
	},
	{
		id: "54",
		label: "WV"
	},
	{
		id: "55",
		label: "WI"
	},
	{
		id: "56",
		label: "WY"
	}
];

var arcs = [
	[
		[
			25302,
			52136
		],
		[
			56,
			31
		],
		[
			1,
			25
		],
		[
			14,
			-40
		],
		[
			-9,
			-28
		],
		[
			-10,
			16
		],
		[
			-18,
			-2
		],
		[
			-20,
			-17
		],
		[
			-14,
			15
		]
	],
	[
		[
			25338,
			57677
		],
		[
			0,
			15
		],
		[
			150,
			-6
		],
		[
			63,
			0
		],
		[
			160,
			-13
		],
		[
			93,
			-2
		],
		[
			37,
			2
		],
		[
			159,
			-4
		],
		[
			61,
			-5
		]
	],
	[
		[
			26061,
			57664
		],
		[
			15,
			-321
		],
		[
			23,
			-443
		],
		[
			18,
			-379
		],
		[
			13,
			-294
		],
		[
			15,
			-311
		],
		[
			33,
			-713
		],
		[
			9,
			-32
		],
		[
			-4,
			-36
		],
		[
			13,
			-45
		],
		[
			5,
			-149
		],
		[
			10,
			-72
		],
		[
			17,
			-69
		],
		[
			3,
			-82
		],
		[
			9,
			-36
		],
		[
			-10,
			-117
		],
		[
			18,
			-28
		],
		[
			12,
			-40
		],
		[
			-10,
			-52
		],
		[
			-11,
			0
		],
		[
			2,
			-24
		],
		[
			-14,
			-21
		],
		[
			-13,
			-52
		],
		[
			3,
			-56
		],
		[
			-2,
			-86
		],
		[
			-7,
			-86
		],
		[
			-14,
			-72
		],
		[
			-3,
			-45
		],
		[
			6,
			-124
		],
		[
			-2,
			-44
		],
		[
			19,
			-87
		],
		[
			3,
			-120
		],
		[
			-7,
			-57
		],
		[
			2,
			-43
		],
		[
			-8,
			-80
		],
		[
			1,
			-79
		],
		[
			-7,
			-21
		],
		[
			5,
			-51
		],
		[
			-3,
			-54
		],
		[
			20,
			-91
		],
		[
			7,
			-64
		],
		[
			2,
			-61
		]
	],
	[
		[
			26229,
			53027
		],
		[
			-67,
			0
		],
		[
			-71,
			-5
		],
		[
			-110,
			-4
		],
		[
			-174,
			0
		],
		[
			-135,
			7
		],
		[
			-166,
			-2
		],
		[
			3,
			-38
		],
		[
			-13,
			-115
		],
		[
			2,
			-23
		],
		[
			23,
			-79
		],
		[
			3,
			-41
		],
		[
			36,
			-80
		],
		[
			3,
			-69
		],
		[
			-15,
			-102
		],
		[
			3,
			-55
		],
		[
			20,
			-51
		],
		[
			-18,
			-35
		],
		[
			-8,
			-82
		],
		[
			-9,
			-15
		],
		[
			7,
			-24
		],
		[
			-15,
			-26
		]
	],
	[
		[
			25528,
			52188
		],
		[
			-38,
			-35
		],
		[
			-40,
			-24
		],
		[
			-56,
			-4
		],
		[
			18,
			41
		],
		[
			12,
			-26
		],
		[
			35,
			27
		],
		[
			3,
			34
		],
		[
			-15,
			48
		],
		[
			-7,
			43
		],
		[
			-20,
			47
		],
		[
			-7,
			90
		],
		[
			9,
			74
		],
		[
			-3,
			76
		],
		[
			-7,
			48
		],
		[
			-20,
			32
		],
		[
			-15,
			-46
		],
		[
			2,
			-38
		],
		[
			-9,
			-57
		],
		[
			1,
			-41
		],
		[
			-6,
			-32
		],
		[
			-1,
			-144
		],
		[
			-8,
			-66
		],
		[
			-15,
			-4
		],
		[
			1,
			36
		],
		[
			-20,
			40
		],
		[
			-15,
			-16
		],
		[
			-5,
			23
		],
		[
			-18,
			-22
		]
	],
	[
		[
			25284,
			52292
		],
		[
			-3,
			222
		],
		[
			-3,
			357
		],
		[
			-6,
			423
		],
		[
			-10,
			773
		],
		[
			9,
			283
		],
		[
			21,
			710
		],
		[
			5,
			212
		],
		[
			33,
			1120
		],
		[
			6,
			160
		],
		[
			19,
			643
		],
		[
			12,
			362
		],
		[
			-16,
			35
		],
		[
			-13,
			85
		]
	],
	[
		[
			8053,
			88108
		],
		[
			6,
			38
		],
		[
			18,
			-11
		],
		[
			-20,
			-43
		],
		[
			-4,
			16
		]
	],
	[
		[
			7905,
			86007
		],
		[
			29,
			90
		],
		[
			15,
			-17
		],
		[
			-1,
			-46
		],
		[
			-28,
			-74
		],
		[
			-15,
			19
		],
		[
			0,
			28
		]
	],
	[
		[
			7695,
			85792
		],
		[
			26,
			-14
		],
		[
			-3,
			-36
		],
		[
			-23,
			50
		]
	],
	[
		[
			7642,
			85774
		],
		[
			22,
			-17
		],
		[
			-7,
			-33
		],
		[
			-14,
			14
		],
		[
			-1,
			36
		]
	],
	[
		[
			7602,
			85813
		],
		[
			20,
			-2
		],
		[
			-5,
			-34
		],
		[
			-15,
			36
		]
	],
	[
		[
			7594,
			84711
		],
		[
			8,
			45
		],
		[
			20,
			-13
		],
		[
			-8,
			-73
		],
		[
			-15,
			-17
		],
		[
			-5,
			58
		]
	],
	[
		[
			7543,
			85532
		],
		[
			12,
			28
		],
		[
			21,
			-40
		],
		[
			-33,
			-2
		],
		[
			0,
			14
		]
	],
	[
		[
			7540,
			87187
		],
		[
			29,
			79
		],
		[
			8,
			112
		],
		[
			31,
			-29
		],
		[
			-28,
			-64
		],
		[
			-9,
			-49
		],
		[
			5,
			-24
		],
		[
			-36,
			-25
		]
	],
	[
		[
			7464,
			85521
		],
		[
			14,
			55
		],
		[
			18,
			-28
		],
		[
			23,
			-4
		],
		[
			-33,
			-33
		],
		[
			-22,
			10
		]
	],
	[
		[
			7385,
			86976
		],
		[
			17,
			6
		],
		[
			5,
			-88
		],
		[
			-22,
			82
		]
	],
	[
		[
			7168,
			84530
		],
		[
			29,
			89
		],
		[
			15,
			6
		],
		[
			26,
			-66
		],
		[
			5,
			20
		],
		[
			-21,
			65
		],
		[
			6,
			54
		],
		[
			9,
			10
		],
		[
			27,
			-25
		],
		[
			21,
			19
		],
		[
			-29,
			54
		],
		[
			16,
			56
		],
		[
			29,
			-31
		],
		[
			15,
			4
		],
		[
			-14,
			56
		],
		[
			12,
			17
		],
		[
			20,
			-20
		],
		[
			14,
			45
		],
		[
			-18,
			6
		],
		[
			-13,
			33
		],
		[
			20,
			3
		],
		[
			22,
			67
		],
		[
			34,
			18
		],
		[
			-12,
			35
		],
		[
			-3,
			68
		],
		[
			27,
			66
		],
		[
			7,
			-31
		],
		[
			53,
			51
		],
		[
			7,
			-7
		],
		[
			-12,
			-118
		],
		[
			-13,
			-18
		],
		[
			-26,
			-103
		],
		[
			5,
			-84
		],
		[
			36,
			11
		],
		[
			2,
			69
		],
		[
			22,
			-9
		],
		[
			21,
			-71
		],
		[
			20,
			48
		],
		[
			12,
			-33
		],
		[
			-17,
			-117
		],
		[
			9,
			-22
		],
		[
			9,
			72
		],
		[
			27,
			47
		],
		[
			7,
			-25
		],
		[
			-3,
			-115
		],
		[
			-30,
			-89
		],
		[
			-32,
			23
		],
		[
			-11,
			81
		],
		[
			-21,
			-26
		],
		[
			13,
			-99
		],
		[
			-22,
			-20
		],
		[
			-39,
			13
		],
		[
			-16,
			-54
		],
		[
			-8,
			36
		],
		[
			2,
			74
		],
		[
			-10,
			2
		],
		[
			-9,
			-114
		],
		[
			-8,
			-24
		],
		[
			-31,
			-17
		],
		[
			2,
			-37
		],
		[
			-16,
			-22
		],
		[
			-45,
			-13
		],
		[
			-86,
			76
		],
		[
			-21,
			-13
		],
		[
			-15,
			29
		]
	],
	[
		[
			7129,
			86075
		],
		[
			41,
			28
		],
		[
			18,
			-43
		],
		[
			-5,
			-48
		],
		[
			-13,
			-16
		],
		[
			-29,
			-3
		],
		[
			-16,
			59
		],
		[
			4,
			23
		]
	],
	[
		[
			6962,
			82933
		],
		[
			31,
			45
		],
		[
			8,
			-48
		],
		[
			-37,
			-9
		],
		[
			-2,
			12
		]
	],
	[
		[
			6905,
			82759
		],
		[
			20,
			62
		],
		[
			19,
			20
		],
		[
			11,
			-11
		],
		[
			25,
			17
		],
		[
			5,
			-40
		],
		[
			19,
			-37
		],
		[
			36,
			16
		],
		[
			-2,
			-37
		],
		[
			-19,
			-31
		],
		[
			-46,
			-6
		],
		[
			-32,
			-13
		],
		[
			-32,
			25
		],
		[
			-4,
			35
		]
	],
	[
		[
			6789,
			83718
		],
		[
			20,
			17
		],
		[
			4,
			76
		],
		[
			18,
			75
		],
		[
			25,
			34
		],
		[
			5,
			44
		],
		[
			15,
			-8
		],
		[
			34,
			70
		],
		[
			33,
			36
		],
		[
			39,
			-15
		],
		[
			29,
			1
		],
		[
			0,
			-112
		],
		[
			26,
			-57
		],
		[
			4,
			45
		],
		[
			17,
			53
		],
		[
			-18,
			48
		],
		[
			6,
			25
		],
		[
			53,
			-14
		],
		[
			-3,
			35
		],
		[
			-52,
			44
		],
		[
			-19,
			-4
		],
		[
			-1,
			127
		],
		[
			31,
			61
		],
		[
			29,
			29
		],
		[
			20,
			-12
		],
		[
			22,
			-56
		],
		[
			6,
			-133
		],
		[
			15,
			13
		],
		[
			9,
			77
		],
		[
			-5,
			55
		],
		[
			35,
			-38
		],
		[
			7,
			47
		],
		[
			-37,
			36
		],
		[
			-21,
			58
		],
		[
			7,
			44
		],
		[
			17,
			-6
		],
		[
			51,
			-87
		],
		[
			9,
			4
		],
		[
			30,
			-41
		],
		[
			11,
			10
		],
		[
			-31,
			75
		],
		[
			-20,
			34
		],
		[
			-7,
			44
		],
		[
			17,
			0
		],
		[
			30,
			-58
		],
		[
			29,
			12
		],
		[
			41,
			-29
		],
		[
			7,
			49
		],
		[
			36,
			15
		],
		[
			-8,
			-63
		],
		[
			-39,
			-106
		],
		[
			-7,
			-83
		],
		[
			19,
			-36
		],
		[
			0,
			95
		],
		[
			16,
			43
		],
		[
			16,
			-49
		],
		[
			5,
			46
		],
		[
			17,
			32
		],
		[
			5,
			41
		],
		[
			14,
			10
		],
		[
			10,
			-31
		],
		[
			22,
			72
		],
		[
			17,
			8
		],
		[
			-4,
			-45
		],
		[
			28,
			-16
		],
		[
			-11,
			-38
		],
		[
			-11,
			20
		],
		[
			-18,
			-15
		],
		[
			19,
			-36
		],
		[
			-5,
			-49
		],
		[
			19,
			22
		],
		[
			11,
			-51
		],
		[
			27,
			1
		],
		[
			-24,
			-53
		],
		[
			-16,
			33
		],
		[
			-24,
			2
		],
		[
			-15,
			-48
		],
		[
			16,
			-9
		],
		[
			-8,
			-53
		],
		[
			26,
			-8
		],
		[
			-26,
			-89
		],
		[
			23,
			17
		],
		[
			13,
			47
		],
		[
			5,
			-35
		],
		[
			47,
			-4
		],
		[
			-3,
			-41
		],
		[
			-36,
			-78
		],
		[
			-13,
			-110
		],
		[
			-38,
			13
		],
		[
			-2,
			39
		],
		[
			-10,
			-41
		],
		[
			-23,
			42
		],
		[
			-17,
			-6
		],
		[
			-23,
			49
		],
		[
			-15,
			-13
		],
		[
			-24,
			19
		],
		[
			-8,
			-46
		],
		[
			27,
			1
		],
		[
			15,
			-17
		],
		[
			45,
			-87
		],
		[
			-8,
			-70
		],
		[
			-23,
			-52
		],
		[
			-11,
			36
		],
		[
			-19,
			-50
		],
		[
			-19,
			30
		],
		[
			-6,
			38
		],
		[
			-21,
			18
		],
		[
			-20,
			-12
		],
		[
			-17,
			-37
		],
		[
			29,
			2
		],
		[
			20,
			-49
		],
		[
			-38,
			-53
		],
		[
			-34,
			12
		],
		[
			-4,
			-20
		],
		[
			25,
			-34
		],
		[
			14,
			13
		],
		[
			35,
			1
		],
		[
			22,
			-43
		],
		[
			-11,
			-28
		],
		[
			-24,
			-8
		],
		[
			-34,
			-33
		],
		[
			-8,
			11
		],
		[
			-19,
			-29
		],
		[
			3,
			-49
		],
		[
			-27,
			-50
		],
		[
			-13,
			20
		],
		[
			7,
			34
		],
		[
			-23,
			50
		],
		[
			7,
			47
		],
		[
			27,
			62
		],
		[
			-8,
			24
		],
		[
			-15,
			-21
		],
		[
			-34,
			-105
		],
		[
			-3,
			-24
		],
		[
			-22,
			32
		],
		[
			-22,
			-10
		],
		[
			-5,
			-35
		],
		[
			26,
			-6
		],
		[
			10,
			-63
		],
		[
			-16,
			-61
		],
		[
			-25,
			-20
		],
		[
			1,
			-70
		],
		[
			-25,
			-41
		],
		[
			-12,
			13
		],
		[
			-23,
			-82
		],
		[
			-19,
			-30
		],
		[
			-18,
			21
		],
		[
			-31,
			-20
		],
		[
			22,
			116
		],
		[
			11,
			11
		],
		[
			26,
			71
		],
		[
			24,
			31
		],
		[
			-2,
			37
		],
		[
			-33,
			-23
		],
		[
			3,
			52
		],
		[
			22,
			102
		],
		[
			29,
			52
		],
		[
			-7,
			30
		],
		[
			-15,
			-45
		],
		[
			-34,
			-61
		],
		[
			-26,
			-112
		],
		[
			-24,
			-59
		],
		[
			-14,
			-11
		],
		[
			-5,
			-44
		],
		[
			-19,
			-30
		],
		[
			-4,
			84
		],
		[
			-26,
			58
		],
		[
			-33,
			27
		],
		[
			3,
			100
		],
		[
			-4,
			106
		],
		[
			-13,
			83
		],
		[
			-11,
			32
		],
		[
			-23,
			20
		],
		[
			-27,
			5
		],
		[
			14,
			30
		],
		[
			-15,
			37
		],
		[
			5,
			23
		]
	],
	[
		[
			6782,
			82633
		],
		[
			27,
			101
		],
		[
			51,
			97
		],
		[
			21,
			-4
		],
		[
			16,
			-54
		],
		[
			-12,
			-23
		],
		[
			-55,
			-73
		],
		[
			-29,
			-79
		],
		[
			-19,
			35
		]
	],
	[
		[
			6519,
			81925
		],
		[
			26,
			41
		],
		[
			5,
			38
		],
		[
			13,
			22
		],
		[
			8,
			-32
		],
		[
			-6,
			-43
		],
		[
			5,
			-68
		],
		[
			-7,
			-33
		],
		[
			-36,
			13
		],
		[
			-8,
			62
		]
	],
	[
		[
			6240,
			82171
		],
		[
			5,
			47
		],
		[
			14,
			25
		],
		[
			13,
			-59
		],
		[
			-13,
			-63
		],
		[
			-19,
			50
		]
	],
	[
		[
			6225,
			82357
		],
		[
			9,
			35
		],
		[
			3,
			-82
		],
		[
			-10,
			-1
		],
		[
			-2,
			48
		]
	],
	[
		[
			6080,
			82757
		],
		[
			21,
			48
		],
		[
			48,
			-3
		],
		[
			25,
			-54
		],
		[
			-35,
			23
		],
		[
			-16,
			-26
		],
		[
			-43,
			-6
		],
		[
			0,
			18
		]
	],
	[
		[
			5919,
			82533
		],
		[
			19,
			25
		],
		[
			11,
			-57
		],
		[
			-9,
			-11
		],
		[
			-21,
			43
		]
	],
	[
		[
			5642,
			81925
		],
		[
			8,
			64
		],
		[
			19,
			12
		],
		[
			27,
			-58
		],
		[
			-8,
			-18
		],
		[
			-21,
			37
		],
		[
			-25,
			-37
		]
	],
	[
		[
			5573,
			81984
		],
		[
			16,
			-49
		],
		[
			-27,
			12
		],
		[
			11,
			37
		]
	],
	[
		[
			5524,
			80844
		],
		[
			-1,
			36
		],
		[
			13,
			24
		],
		[
			20,
			-25
		],
		[
			-9,
			-59
		],
		[
			-19,
			-15
		],
		[
			-4,
			39
		]
	],
	[
		[
			5506,
			81836
		],
		[
			8,
			67
		],
		[
			10,
			10
		],
		[
			11,
			-62
		],
		[
			-29,
			-15
		]
	],
	[
		[
			5485,
			80904
		],
		[
			12,
			85
		],
		[
			-11,
			46
		],
		[
			31,
			-2
		],
		[
			4,
			-99
		],
		[
			-27,
			-38
		],
		[
			-9,
			8
		]
	],
	[
		[
			5445,
			80747
		],
		[
			10,
			13
		],
		[
			16,
			-42
		],
		[
			-1,
			-34
		],
		[
			-23,
			-4
		],
		[
			-2,
			67
		]
	],
	[
		[
			5429,
			81185
		],
		[
			17,
			-21
		],
		[
			5,
			49
		],
		[
			17,
			46
		],
		[
			5,
			-22
		],
		[
			-8,
			-58
		],
		[
			9,
			-13
		],
		[
			1,
			-44
		],
		[
			-10,
			-61
		],
		[
			13,
			-30
		],
		[
			-7,
			-19
		],
		[
			-17,
			22
		],
		[
			-2,
			-21
		],
		[
			-20,
			8
		],
		[
			-3,
			164
		]
	],
	[
		[
			5385,
			80755
		],
		[
			21,
			25
		],
		[
			11,
			-30
		],
		[
			-20,
			-26
		],
		[
			-12,
			31
		]
	],
	[
		[
			5377,
			81028
		],
		[
			9,
			39
		],
		[
			23,
			41
		],
		[
			5,
			-36
		],
		[
			-23,
			-38
		],
		[
			-9,
			-58
		],
		[
			-5,
			52
		]
	],
	[
		[
			5303,
			81352
		],
		[
			14,
			11
		],
		[
			5,
			-42
		],
		[
			-19,
			31
		]
	],
	[
		[
			5265,
			80882
		],
		[
			33,
			98
		],
		[
			15,
			27
		],
		[
			-5,
			18
		],
		[
			-22,
			0
		],
		[
			-4,
			76
		],
		[
			22,
			50
		],
		[
			27,
			-44
		],
		[
			-1,
			38
		],
		[
			-13,
			52
		],
		[
			30,
			-13
		],
		[
			18,
			114
		],
		[
			12,
			-23
		],
		[
			-2,
			-43
		],
		[
			-9,
			-2
		],
		[
			-5,
			-75
		],
		[
			12,
			-18
		],
		[
			0,
			33
		],
		[
			13,
			1
		],
		[
			-4,
			-60
		],
		[
			-11,
			-37
		],
		[
			-22,
			12
		],
		[
			-1,
			-45
		],
		[
			-28,
			-71
		],
		[
			-18,
			-24
		],
		[
			-31,
			-141
		],
		[
			-6,
			77
		]
	],
	[
		[
			5246,
			85264
		],
		[
			5,
			41
		],
		[
			14,
			-83
		],
		[
			-7,
			-25
		],
		[
			-12,
			67
		]
	],
	[
		[
			5238,
			81460
		],
		[
			22,
			42
		],
		[
			36,
			-14
		],
		[
			-1,
			-78
		],
		[
			-50,
			12
		],
		[
			-7,
			38
		]
	],
	[
		[
			5213,
			85252
		],
		[
			8,
			77
		],
		[
			5,
			-57
		],
		[
			-13,
			-20
		]
	],
	[
		[
			5096,
			81334
		],
		[
			16,
			74
		],
		[
			25,
			25
		],
		[
			18,
			-23
		],
		[
			-2,
			-46
		],
		[
			10,
			5
		],
		[
			12,
			47
		],
		[
			15,
			-32
		],
		[
			26,
			-26
		],
		[
			26,
			25
		],
		[
			7,
			-66
		],
		[
			-9,
			-60
		],
		[
			-14,
			40
		],
		[
			-22,
			3
		],
		[
			-14,
			23
		],
		[
			-3,
			40
		],
		[
			-10,
			-12
		],
		[
			0,
			-69
		],
		[
			11,
			-20
		],
		[
			11,
			-87
		],
		[
			-11,
			-60
		],
		[
			-36,
			35
		],
		[
			-10,
			59
		],
		[
			-18,
			-18
		],
		[
			-18,
			-90
		],
		[
			4,
			58
		],
		[
			-10,
			43
		],
		[
			0,
			104
		],
		[
			-4,
			28
		]
	],
	[
		[
			5033,
			85142
		],
		[
			7,
			131
		],
		[
			39,
			52
		],
		[
			21,
			6
		],
		[
			39,
			76
		],
		[
			5,
			-2
		],
		[
			-55,
			-273
		],
		[
			-22,
			-32
		],
		[
			-32,
			-4
		],
		[
			-2,
			46
		]
	],
	[
		[
			4937,
			81216
		],
		[
			27,
			3
		],
		[
			-4,
			-71
		],
		[
			-26,
			47
		],
		[
			3,
			21
		]
	],
	[
		[
			4863,
			81217
		],
		[
			10,
			31
		],
		[
			36,
			8
		],
		[
			-9,
			-51
		],
		[
			-37,
			-10
		],
		[
			0,
			22
		]
	],
	[
		[
			4804,
			81100
		],
		[
			4,
			51
		],
		[
			17,
			20
		],
		[
			25,
			-19
		],
		[
			12,
			-29
		],
		[
			35,
			-42
		],
		[
			6,
			-41
		],
		[
			-30,
			44
		],
		[
			-23,
			-57
		],
		[
			-28,
			74
		],
		[
			-11,
			-38
		],
		[
			-7,
			37
		]
	],
	[
		[
			4656,
			80881
		],
		[
			30,
			66
		],
		[
			26,
			-27
		],
		[
			0,
			-83
		],
		[
			-11,
			-53
		],
		[
			-13,
			-21
		],
		[
			-27,
			58
		],
		[
			-5,
			60
		]
	],
	[
		[
			4587,
			90956
		],
		[
			19,
			44
		],
		[
			21,
			16
		],
		[
			24,
			-17
		],
		[
			22,
			6
		],
		[
			9,
			-37
		],
		[
			-1,
			-50
		],
		[
			-75,
			-13
		],
		[
			-18,
			19
		],
		[
			-1,
			32
		]
	],
	[
		[
			4545,
			80324
		],
		[
			1,
			51
		],
		[
			68,
			-54
		],
		[
			19,
			-39
		],
		[
			26,
			0
		],
		[
			18,
			-28
		],
		[
			-20,
			-23
		],
		[
			-10,
			-33
		],
		[
			-22,
			40
		],
		[
			-17,
			-9
		],
		[
			-31,
			37
		],
		[
			-18,
			-29
		],
		[
			-22,
			57
		],
		[
			8,
			30
		]
	],
	[
		[
			4451,
			81463
		],
		[
			14,
			-1
		],
		[
			-5,
			-38
		],
		[
			-9,
			39
		]
	],
	[
		[
			3979,
			80040
		],
		[
			12,
			22
		],
		[
			16,
			-18
		],
		[
			-21,
			-37
		],
		[
			-7,
			33
		]
	],
	[
		[
			3880,
			79918
		],
		[
			22,
			34
		],
		[
			33,
			-11
		],
		[
			24,
			18
		],
		[
			5,
			-24
		],
		[
			-9,
			-45
		],
		[
			-26,
			-13
		],
		[
			-47,
			27
		],
		[
			-2,
			14
		]
	],
	[
		[
			3807,
			79887
		],
		[
			60,
			24
		],
		[
			9,
			-35
		],
		[
			-15,
			-32
		],
		[
			-13,
			37
		],
		[
			-34,
			-4
		],
		[
			-7,
			10
		]
	],
	[
		[
			3781,
			79848
		],
		[
			17,
			29
		],
		[
			7,
			-36
		],
		[
			-18,
			-14
		],
		[
			-6,
			21
		]
	],
	[
		[
			3751,
			80090
		],
		[
			13,
			56
		],
		[
			14,
			-15
		],
		[
			18,
			18
		],
		[
			12,
			-21
		],
		[
			-22,
			-33
		],
		[
			13,
			-48
		],
		[
			30,
			0
		],
		[
			1,
			-41
		],
		[
			-23,
			3
		],
		[
			-18,
			-79
		],
		[
			-23,
			24
		],
		[
			-2,
			78
		],
		[
			16,
			35
		],
		[
			-9,
			20
		],
		[
			-16,
			-21
		],
		[
			-4,
			24
		]
	],
	[
		[
			3635,
			79967
		],
		[
			5,
			36
		],
		[
			28,
			54
		],
		[
			30,
			-6
		],
		[
			3,
			-58
		],
		[
			20,
			6
		],
		[
			14,
			-15
		],
		[
			8,
			-44
		],
		[
			13,
			13
		],
		[
			-2,
			-41
		],
		[
			-26,
			-36
		],
		[
			-12,
			11
		],
		[
			-18,
			-45
		],
		[
			-6,
			28
		],
		[
			-25,
			1
		],
		[
			-17,
			-20
		],
		[
			-18,
			91
		],
		[
			3,
			25
		]
	],
	[
		[
			3608,
			79782
		],
		[
			7,
			15
		],
		[
			27,
			-33
		],
		[
			-32,
			-11
		],
		[
			-2,
			29
		]
	],
	[
		[
			3261,
			87028
		],
		[
			35,
			25
		],
		[
			57,
			0
		],
		[
			22,
			-20
		],
		[
			23,
			10
		],
		[
			9,
			-24
		],
		[
			21,
			10
		],
		[
			10,
			30
		],
		[
			-8,
			38
		],
		[
			34,
			68
		],
		[
			37,
			-11
		],
		[
			0,
			37
		],
		[
			25,
			46
		],
		[
			33,
			-40
		],
		[
			24,
			32
		],
		[
			23,
			9
		],
		[
			15,
			54
		],
		[
			19,
			-132
		],
		[
			27,
			-10
		],
		[
			29,
			34
		],
		[
			29,
			-20
		],
		[
			27,
			-40
		],
		[
			-12,
			-65
		],
		[
			11,
			-44
		],
		[
			-11,
			-40
		],
		[
			13,
			-11
		],
		[
			4,
			-65
		],
		[
			-13,
			-38
		],
		[
			21,
			-54
		],
		[
			2,
			-58
		],
		[
			21,
			10
		],
		[
			-11,
			-34
		],
		[
			2,
			-48
		],
		[
			-71,
			-21
		],
		[
			-6,
			-34
		],
		[
			-20,
			19
		],
		[
			-26,
			-18
		],
		[
			-28,
			-58
		],
		[
			8,
			-64
		],
		[
			-26,
			-8
		],
		[
			-23,
			71
		],
		[
			-38,
			47
		],
		[
			-57,
			-4
		],
		[
			-14,
			35
		],
		[
			-28,
			18
		],
		[
			-27,
			58
		],
		[
			-35,
			42
		],
		[
			-40,
			19
		],
		[
			-32,
			72
		],
		[
			-25,
			10
		],
		[
			-2,
			70
		],
		[
			-28,
			97
		]
	],
	[
		[
			3147,
			79003
		],
		[
			17,
			23
		],
		[
			22,
			53
		],
		[
			25,
			5
		],
		[
			37,
			40
		],
		[
			9,
			27
		],
		[
			28,
			-21
		],
		[
			14,
			19
		],
		[
			8,
			44
		],
		[
			22,
			-19
		],
		[
			3,
			72
		],
		[
			24,
			-11
		],
		[
			-17,
			106
		],
		[
			20,
			32
		],
		[
			8,
			-16
		],
		[
			15,
			18
		],
		[
			-18,
			35
		],
		[
			4,
			39
		],
		[
			17,
			23
		],
		[
			29,
			-1
		],
		[
			9,
			-68
		],
		[
			15,
			7
		],
		[
			-7,
			50
		],
		[
			13,
			31
		],
		[
			-53,
			47
		],
		[
			-14,
			-21
		],
		[
			-32,
			81
		],
		[
			0,
			46
		],
		[
			31,
			92
		],
		[
			42,
			50
		],
		[
			36,
			32
		],
		[
			6,
			-15
		],
		[
			23,
			13
		],
		[
			16,
			-63
		],
		[
			-16,
			-42
		],
		[
			7,
			-35
		],
		[
			17,
			-18
		],
		[
			14,
			53
		],
		[
			6,
			-33
		],
		[
			15,
			29
		],
		[
			-1,
			41
		],
		[
			18,
			63
		],
		[
			15,
			-58
		],
		[
			11,
			26
		],
		[
			20,
			-62
		],
		[
			-8,
			-56
		],
		[
			-23,
			-13
		],
		[
			-24,
			-70
		],
		[
			-40,
			-70
		],
		[
			2,
			-39
		],
		[
			34,
			54
		],
		[
			58,
			64
		],
		[
			4,
			22
		],
		[
			22,
			22
		],
		[
			7,
			-19
		],
		[
			-5,
			-72
		],
		[
			-16,
			-51
		],
		[
			-26,
			-34
		],
		[
			-6,
			-23
		],
		[
			-45,
			-51
		],
		[
			-30,
			-20
		],
		[
			12,
			-46
		],
		[
			-16,
			-1
		],
		[
			-4,
			-61
		],
		[
			-16,
			17
		],
		[
			-7,
			-70
		],
		[
			-20,
			25
		],
		[
			-4,
			-76
		],
		[
			-36,
			-13
		],
		[
			-22,
			30
		],
		[
			-10,
			-31
		],
		[
			-12,
			23
		],
		[
			-21,
			-37
		],
		[
			-6,
			11
		],
		[
			-44,
			-73
		],
		[
			-3,
			-31
		],
		[
			-23,
			4
		],
		[
			-16,
			-23
		],
		[
			-13,
			-60
		],
		[
			-28,
			23
		],
		[
			-9,
			-45
		],
		[
			-49,
			40
		],
		[
			-15,
			36
		]
	],
	[
		[
			3070,
			93368
		],
		[
			7,
			34
		],
		[
			34,
			50
		],
		[
			123,
			108
		],
		[
			63,
			74
		],
		[
			48,
			74
		],
		[
			45,
			56
		],
		[
			42,
			64
		],
		[
			84,
			105
		],
		[
			55,
			56
		],
		[
			146,
			167
		],
		[
			172,
			154
		],
		[
			133,
			90
		],
		[
			87,
			45
		],
		[
			135,
			15
		],
		[
			52,
			-11
		],
		[
			34,
			-31
		],
		[
			-41,
			-11
		],
		[
			7,
			-38
		],
		[
			-10,
			-71
		],
		[
			-31,
			-77
		],
		[
			1,
			-70
		],
		[
			12,
			-56
		],
		[
			-21,
			-59
		],
		[
			-49,
			-33
		],
		[
			-4,
			-20
		],
		[
			49,
			7
		],
		[
			42,
			-151
		],
		[
			40,
			-3
		],
		[
			36,
			32
		],
		[
			42,
			-1
		],
		[
			49,
			-30
		],
		[
			47,
			21
		],
		[
			69,
			15
		],
		[
			32,
			-58
		],
		[
			50,
			21
		],
		[
			18,
			-34
		],
		[
			52,
			32
		],
		[
			18,
			26
		],
		[
			84,
			-65
		],
		[
			18,
			59
		],
		[
			26,
			44
		],
		[
			37,
			150
		],
		[
			18,
			26
		],
		[
			40,
			-9
		],
		[
			8,
			-39
		],
		[
			32,
			-12
		],
		[
			31,
			27
		],
		[
			26,
			0
		],
		[
			-32,
			110
		],
		[
			-71,
			55
		],
		[
			-45,
			24
		],
		[
			-48,
			-1
		],
		[
			-60,
			-60
		],
		[
			13,
			112
		],
		[
			-3,
			83
		],
		[
			-62,
			114
		],
		[
			-22,
			91
		],
		[
			-26,
			35
		],
		[
			-59,
			14
		],
		[
			-8,
			56
		],
		[
			-32,
			90
		],
		[
			7,
			50
		],
		[
			27,
			18
		],
		[
			10,
			43
		],
		[
			16,
			-37
		],
		[
			24,
			28
		],
		[
			27,
			-89
		],
		[
			36,
			-91
		],
		[
			24,
			-10
		],
		[
			-19,
			-101
		],
		[
			3,
			-55
		],
		[
			28,
			-50
		],
		[
			57,
			-123
		],
		[
			53,
			-68
		],
		[
			39,
			18
		],
		[
			30,
			28
		],
		[
			9,
			49
		],
		[
			-45,
			2
		],
		[
			-10,
			45
		],
		[
			-56,
			70
		],
		[
			-53,
			112
		],
		[
			10,
			52
		],
		[
			0,
			60
		],
		[
			14,
			23
		],
		[
			1,
			57
		],
		[
			33,
			93
		],
		[
			30,
			-32
		],
		[
			22,
			3
		],
		[
			1,
			28
		],
		[
			-38,
			55
		],
		[
			-25,
			-8
		],
		[
			-28,
			57
		],
		[
			-87,
			-29
		],
		[
			-32,
			-37
		],
		[
			-34,
			0
		],
		[
			-39,
			-19
		],
		[
			-34,
			17
		],
		[
			-20,
			43
		],
		[
			-17,
			-16
		],
		[
			-21,
			23
		],
		[
			-4,
			-51
		],
		[
			-36,
			39
		],
		[
			-91,
			42
		],
		[
			-54,
			31
		],
		[
			-48,
			15
		],
		[
			-22,
			30
		],
		[
			1,
			98
		],
		[
			-22,
			163
		],
		[
			-52,
			216
		],
		[
			-20,
			58
		],
		[
			-36,
			62
		],
		[
			-91,
			101
		],
		[
			-145,
			228
		],
		[
			-21,
			24
		],
		[
			-51,
			87
		],
		[
			-50,
			49
		],
		[
			-54,
			37
		],
		[
			-51,
			23
		],
		[
			-29,
			35
		],
		[
			-19,
			70
		],
		[
			-54,
			84
		],
		[
			-45,
			40
		],
		[
			-81,
			41
		],
		[
			-42,
			-6
		],
		[
			37,
			40
		],
		[
			92,
			59
		],
		[
			20,
			46
		],
		[
			3,
			57
		],
		[
			19,
			76
		],
		[
			11,
			236
		],
		[
			-8,
			117
		],
		[
			179,
			-31
		],
		[
			68,
			6
		],
		[
			144,
			42
		],
		[
			79,
			28
		],
		[
			77,
			15
		],
		[
			77,
			63
		],
		[
			41,
			65
		],
		[
			29,
			30
		],
		[
			53,
			87
		],
		[
			81,
			192
		],
		[
			21,
			92
		],
		[
			7,
			79
		],
		[
			-2,
			186
		],
		[
			39,
			233
		],
		[
			84,
			183
		],
		[
			65,
			179
		],
		[
			37,
			77
		],
		[
			129,
			162
		],
		[
			96,
			-35
		],
		[
			69,
			-3
		],
		[
			68,
			40
		],
		[
			64,
			53
		],
		[
			93,
			104
		],
		[
			74,
			108
		],
		[
			44,
			86
		],
		[
			114,
			188
		],
		[
			33,
			31
		],
		[
			99,
			63
		],
		[
			7,
			-47
		],
		[
			55,
			-44
		],
		[
			82,
			-12
		],
		[
			68,
			15
		],
		[
			13,
			24
		],
		[
			32,
			-3
		],
		[
			61,
			17
		],
		[
			73,
			51
		],
		[
			74,
			85
		],
		[
			71,
			121
		],
		[
			36,
			88
		],
		[
			86,
			185
		],
		[
			68,
			76
		],
		[
			12,
			-68
		],
		[
			47,
			-38
		],
		[
			39,
			-2
		],
		[
			39,
			-20
		],
		[
			16,
			-82
		],
		[
			27,
			41
		],
		[
			99,
			-49
		],
		[
			15,
			-98
		],
		[
			-54,
			-71
		],
		[
			-35,
			-63
		],
		[
			-41,
			-4
		],
		[
			12,
			-146
		],
		[
			81,
			-15
		],
		[
			44,
			59
		],
		[
			-7,
			76
		],
		[
			16,
			8
		],
		[
			31,
			67
		],
		[
			23,
			12
		],
		[
			19,
			-48
		],
		[
			4,
			63
		],
		[
			-27,
			43
		],
		[
			35,
			55
		],
		[
			21,
			-47
		],
		[
			-3,
			65
		],
		[
			15,
			22
		],
		[
			71,
			-74
		],
		[
			45,
			-66
		],
		[
			13,
			-42
		],
		[
			-11,
			-33
		],
		[
			1,
			-109
		],
		[
			9,
			-49
		],
		[
			61,
			10
		],
		[
			35,
			-37
		],
		[
			16,
			-40
		],
		[
			48,
			62
		],
		[
			30,
			75
		],
		[
			112,
			0
		],
		[
			69,
			42
		],
		[
			53,
			-11
		],
		[
			40,
			-34
		],
		[
			84,
			-2
		],
		[
			61,
			-32
		],
		[
			45,
			-35
		],
		[
			9,
			-34
		],
		[
			-26,
			-11
		],
		[
			-26,
			-83
		],
		[
			-26,
			-30
		],
		[
			14,
			-93
		],
		[
			25,
			5
		],
		[
			19,
			-24
		],
		[
			45,
			-6
		],
		[
			10,
			-28
		],
		[
			69,
			-20
		],
		[
			33,
			9
		],
		[
			-17,
			-43
		],
		[
			9,
			-25
		],
		[
			-53,
			-26
		],
		[
			-8,
			-24
		],
		[
			20,
			-25
		],
		[
			89,
			6
		],
		[
			72,
			-41
		],
		[
			14,
			-33
		],
		[
			28,
			5
		],
		[
			44,
			86
		],
		[
			57,
			15
		],
		[
			24,
			-18
		],
		[
			10,
			34
		],
		[
			40,
			7
		],
		[
			29,
			-27
		],
		[
			15,
			-59
		],
		[
			42,
			27
		],
		[
			38,
			8
		],
		[
			58,
			83
		],
		[
			13,
			-22
		],
		[
			45,
			20
		],
		[
			21,
			-15
		],
		[
			34,
			26
		],
		[
			12,
			-30
		],
		[
			66,
			-8
		],
		[
			62,
			-72
		],
		[
			28,
			-1
		],
		[
			19,
			-24
		],
		[
			26,
			31
		],
		[
			24,
			-8
		],
		[
			37,
			-73
		],
		[
			0,
			-45
		],
		[
			35,
			-19
		],
		[
			41,
			51
		],
		[
			1,
			-63
		],
		[
			26,
			57
		],
		[
			81,
			-77
		],
		[
			14,
			-67
		],
		[
			24,
			-23
		],
		[
			49,
			1
		],
		[
			43,
			-15
		],
		[
			29,
			36
		],
		[
			23,
			-73
		],
		[
			48,
			-10
		],
		[
			29,
			45
		],
		[
			43,
			-12
		],
		[
			62,
			12
		],
		[
			66,
			-10
		],
		[
			49,
			-38
		],
		[
			50,
			-3
		],
		[
			17,
			28
		],
		[
			65,
			-95
		],
		[
			28,
			-8
		],
		[
			32,
			-54
		],
		[
			45,
			-16
		],
		[
			20,
			-30
		],
		[
			45,
			-12
		],
		[
			17,
			-26
		],
		[
			27,
			32
		],
		[
			66,
			-20
		],
		[
			45,
			77
		],
		[
			48,
			6
		],
		[
			9,
			20
		],
		[
			84,
			49
		],
		[
			18,
			24
		],
		[
			86,
			30
		],
		[
			42,
			-25
		],
		[
			48,
			32
		],
		[
			9,
			-18
		],
		[
			79,
			-73
		],
		[
			53,
			-37
		],
		[
			70,
			-80
		],
		[
			26,
			-67
		],
		[
			37,
			-11
		],
		[
			87,
			-97
		],
		[
			68,
			-40
		],
		[
			52,
			-62
		],
		[
			27,
			-47
		],
		[
			61,
			-13
		],
		[
			58,
			-45
		],
		[
			0,
			-9012
		],
		[
			2,
			-971
		],
		[
			-1,
			-889
		],
		[
			130,
			-95
		],
		[
			17,
			100
		],
		[
			135,
			-145
		],
		[
			81,
			180
		],
		[
			170,
			20
		],
		[
			1,
			-39
		],
		[
			-33,
			-272
		],
		[
			47,
			-112
		],
		[
			66,
			-76
		],
		[
			26,
			-22
		],
		[
			11,
			-116
		],
		[
			29,
			-80
		],
		[
			266,
			-580
		],
		[
			30,
			-299
		],
		[
			-8,
			-93
		],
		[
			22,
			4
		],
		[
			51,
			108
		],
		[
			111,
			158
		],
		[
			11,
			23
		],
		[
			68,
			8
		],
		[
			32,
			139
		],
		[
			-2,
			209
		],
		[
			30,
			-19
		],
		[
			18,
			19
		],
		[
			19,
			71
		],
		[
			-1,
			39
		],
		[
			-32,
			47
		],
		[
			45,
			48
		],
		[
			68,
			28
		],
		[
			131,
			158
		],
		[
			62,
			-115
		],
		[
			28,
			-88
		],
		[
			11,
			-2
		],
		[
			24,
			-70
		],
		[
			0,
			-104
		],
		[
			-12,
			-24
		],
		[
			1,
			-37
		],
		[
			16,
			-47
		],
		[
			-5,
			-42
		],
		[
			18,
			-76
		],
		[
			73,
			-38
		],
		[
			5,
			-66
		],
		[
			32,
			-73
		],
		[
			24,
			0
		],
		[
			29,
			-108
		],
		[
			-6,
			-69
		],
		[
			26,
			-20
		],
		[
			-6,
			-46
		],
		[
			22,
			-71
		],
		[
			114,
			-152
		],
		[
			32,
			-119
		],
		[
			46,
			-120
		],
		[
			50,
			-110
		],
		[
			-23,
			-49
		],
		[
			33,
			-134
		],
		[
			47,
			-140
		],
		[
			28,
			-176
		],
		[
			57,
			-182
		],
		[
			32,
			-161
		],
		[
			30,
			-111
		],
		[
			25,
			-123
		],
		[
			53,
			-180
		],
		[
			32,
			-155
		],
		[
			-33,
			-140
		],
		[
			89,
			-52
		],
		[
			-21,
			-205
		],
		[
			71,
			-81
		],
		[
			-8,
			-61
		],
		[
			11,
			-57
		],
		[
			7,
			-119
		],
		[
			71,
			14
		],
		[
			33,
			-77
		],
		[
			82,
			-115
		],
		[
			23,
			-48
		],
		[
			85,
			-47
		],
		[
			44,
			-115
		],
		[
			44,
			-33
		],
		[
			11,
			-116
		],
		[
			23,
			-15
		],
		[
			27,
			-36
		],
		[
			40,
			23
		],
		[
			28,
			-143
		],
		[
			-3,
			-90
		],
		[
			-20,
			-107
		],
		[
			-18,
			-67
		],
		[
			1,
			-60
		],
		[
			10,
			-38
		],
		[
			-5,
			-118
		],
		[
			12,
			-104
		],
		[
			11,
			-46
		],
		[
			6,
			-133
		],
		[
			12,
			-63
		],
		[
			-32,
			-100
		],
		[
			-24,
			-122
		],
		[
			-1,
			-33
		],
		[
			-20,
			-90
		],
		[
			-23,
			-77
		],
		[
			-37,
			-97
		],
		[
			-27,
			-55
		],
		[
			-19,
			-14
		],
		[
			3,
			-46
		],
		[
			-19,
			-23
		],
		[
			-12,
			40
		],
		[
			-1,
			56
		],
		[
			-13,
			24
		],
		[
			-1,
			-44
		],
		[
			-12,
			-22
		],
		[
			-18,
			18
		],
		[
			-13,
			52
		],
		[
			-4,
			108
		],
		[
			3,
			57
		],
		[
			-17,
			33
		],
		[
			8,
			103
		],
		[
			-9,
			6
		],
		[
			-16,
			56
		],
		[
			-6,
			64
		],
		[
			30,
			63
		],
		[
			17,
			63
		],
		[
			15,
			-8
		],
		[
			-3,
			75
		],
		[
			-11,
			82
		],
		[
			14,
			122
		],
		[
			-9,
			190
		],
		[
			-10,
			67
		],
		[
			-43,
			164
		],
		[
			-22,
			55
		],
		[
			-12,
			48
		],
		[
			-7,
			-34
		],
		[
			23,
			-62
		],
		[
			25,
			-85
		],
		[
			7,
			-72
		],
		[
			22,
			-90
		],
		[
			10,
			-131
		],
		[
			-16,
			-43
		],
		[
			-2,
			-79
		],
		[
			7,
			-92
		],
		[
			11,
			-62
		],
		[
			-9,
			-28
		],
		[
			-11,
			96
		],
		[
			-8,
			12
		],
		[
			3,
			-70
		],
		[
			-4,
			-74
		],
		[
			-36,
			-102
		],
		[
			-14,
			-5
		],
		[
			-24,
			49
		],
		[
			19,
			73
		],
		[
			11,
			73
		],
		[
			-3,
			38
		],
		[
			-25,
			-10
		],
		[
			10,
			-72
		],
		[
			-8,
			-42
		],
		[
			-33,
			-56
		],
		[
			-7,
			1
		],
		[
			-23,
			108
		],
		[
			-11,
			-45
		],
		[
			-25,
			54
		],
		[
			-17,
			18
		],
		[
			-12,
			50
		],
		[
			-28,
			68
		],
		[
			0,
			76
		],
		[
			31,
			31
		],
		[
			22,
			51
		],
		[
			-20,
			47
		],
		[
			7,
			75
		],
		[
			-9,
			39
		],
		[
			23,
			44
		],
		[
			3,
			24
		],
		[
			-18,
			1
		],
		[
			-3,
			74
		],
		[
			7,
			43
		],
		[
			-41,
			-17
		],
		[
			6,
			-45
		],
		[
			11,
			-16
		],
		[
			-1,
			-37
		],
		[
			-13,
			-85
		],
		[
			-1,
			-60
		],
		[
			-19,
			-73
		],
		[
			-18,
			13
		],
		[
			7,
			-93
		],
		[
			-10,
			-43
		],
		[
			-24,
			52
		],
		[
			-25,
			22
		],
		[
			-9,
			30
		],
		[
			-12,
			132
		],
		[
			-16,
			70
		],
		[
			21,
			-29
		],
		[
			7,
			75
		],
		[
			27,
			37
		],
		[
			12,
			147
		],
		[
			-8,
			102
		],
		[
			10,
			57
		],
		[
			6,
			-21
		],
		[
			12,
			42
		],
		[
			7,
			92
		],
		[
			-21,
			-11
		],
		[
			-4,
			-58
		],
		[
			-19,
			-30
		],
		[
			-21,
			-61
		],
		[
			13,
			-113
		],
		[
			-8,
			-42
		],
		[
			-33,
			3
		],
		[
			-12,
			-43
		],
		[
			3,
			-30
		],
		[
			-17,
			-14
		],
		[
			-7,
			34
		],
		[
			4,
			67
		],
		[
			-19,
			23
		],
		[
			-12,
			128
		],
		[
			-32,
			-17
		],
		[
			0,
			-48
		],
		[
			-28,
			118
		],
		[
			-3,
			123
		],
		[
			8,
			25
		],
		[
			25,
			1
		],
		[
			7,
			66
		],
		[
			13,
			49
		],
		[
			30,
			12
		],
		[
			16,
			-72
		],
		[
			7,
			63
		],
		[
			-15,
			168
		],
		[
			9,
			3
		],
		[
			30,
			-45
		],
		[
			4,
			-59
		],
		[
			11,
			-32
		],
		[
			6,
			23
		],
		[
			-9,
			77
		],
		[
			-22,
			35
		],
		[
			-19,
			48
		],
		[
			-3,
			53
		],
		[
			-11,
			13
		],
		[
			-12,
			-25
		],
		[
			-10,
			49
		],
		[
			-23,
			32
		],
		[
			-5,
			57
		],
		[
			12,
			23
		],
		[
			-4,
			64
		],
		[
			-22,
			28
		],
		[
			-37,
			66
		],
		[
			-13,
			69
		],
		[
			-15,
			33
		],
		[
			-13,
			79
		],
		[
			29,
			43
		],
		[
			-11,
			58
		],
		[
			-18,
			-47
		],
		[
			-19,
			18
		],
		[
			-2,
			-27
		],
		[
			-23,
			58
		],
		[
			-31,
			8
		],
		[
			-11,
			56
		],
		[
			-27,
			-28
		],
		[
			-54,
			76
		],
		[
			-8,
			75
		],
		[
			15,
			73
		],
		[
			18,
			-22
		],
		[
			33,
			4
		],
		[
			9,
			48
		],
		[
			-22,
			3
		],
		[
			-32,
			36
		],
		[
			2,
			35
		],
		[
			-18,
			125
		],
		[
			13,
			81
		],
		[
			-24,
			-10
		],
		[
			-15,
			19
		],
		[
			-16,
			53
		],
		[
			7,
			103
		],
		[
			20,
			2
		],
		[
			16,
			-36
		],
		[
			33,
			-24
		],
		[
			63,
			-89
		],
		[
			5,
			15
		],
		[
			-25,
			58
		],
		[
			-20,
			19
		],
		[
			-66,
			130
		],
		[
			-3,
			95
		],
		[
			-17,
			-15
		],
		[
			-2,
			-65
		],
		[
			-20,
			3
		],
		[
			-39,
			166
		],
		[
			-55,
			147
		],
		[
			-11,
			140
		],
		[
			9,
			65
		],
		[
			-2,
			52
		],
		[
			27,
			41
		],
		[
			-13,
			100
		],
		[
			-8,
			-2
		],
		[
			-9,
			-85
		],
		[
			-20,
			-30
		],
		[
			0,
			-42
		],
		[
			12,
			-22
		],
		[
			-13,
			-57
		],
		[
			-10,
			10
		],
		[
			-22,
			-20
		],
		[
			-25,
			11
		],
		[
			-36,
			34
		],
		[
			-7,
			-15
		],
		[
			-35,
			36
		],
		[
			-40,
			174
		],
		[
			-4,
			110
		],
		[
			-42,
			140
		],
		[
			-13,
			79
		],
		[
			19,
			1
		],
		[
			-11,
			174
		],
		[
			-19,
			-56
		],
		[
			1,
			-58
		],
		[
			-35,
			132
		],
		[
			-8,
			177
		],
		[
			-8,
			92
		],
		[
			-21,
			135
		],
		[
			-32,
			116
		],
		[
			-36,
			37
		],
		[
			-5,
			-16
		],
		[
			28,
			-38
		],
		[
			4,
			-41
		],
		[
			17,
			-39
		],
		[
			20,
			-131
		],
		[
			-15,
			11
		],
		[
			-34,
			140
		],
		[
			-22,
			36
		],
		[
			-22,
			10
		],
		[
			41,
			-92
		],
		[
			13,
			-85
		],
		[
			17,
			-29
		],
		[
			-7,
			-97
		],
		[
			9,
			-88
		],
		[
			13,
			-23
		],
		[
			-5,
			-24
		],
		[
			27,
			-124
		],
		[
			3,
			-55
		],
		[
			25,
			-139
		],
		[
			2,
			-32
		],
		[
			-14,
			11
		],
		[
			27,
			-204
		],
		[
			9,
			-85
		],
		[
			1,
			-69
		],
		[
			-12,
			8
		],
		[
			-1,
			-61
		],
		[
			12,
			-64
		],
		[
			-29,
			23
		],
		[
			-19,
			32
		],
		[
			-14,
			-4
		],
		[
			-18,
			43
		],
		[
			-15,
			66
		],
		[
			-10,
			84
		],
		[
			-22,
			-16
		],
		[
			-33,
			50
		],
		[
			-27,
			-37
		],
		[
			-50,
			-19
		],
		[
			3,
			81
		],
		[
			-25,
			16
		],
		[
			-4,
			19
		],
		[
			30,
			39
		],
		[
			-10,
			69
		],
		[
			5,
			53
		],
		[
			-28,
			109
		],
		[
			0,
			36
		],
		[
			-22,
			84
		],
		[
			13,
			24
		],
		[
			-2,
			90
		],
		[
			-19,
			64
		],
		[
			-12,
			10
		],
		[
			15,
			-131
		],
		[
			-12,
			-125
		],
		[
			-27,
			-5
		],
		[
			-42,
			70
		],
		[
			-26,
			30
		],
		[
			-15,
			150
		],
		[
			-11,
			-68
		],
		[
			-13,
			-22
		],
		[
			-44,
			54
		],
		[
			-14,
			-20
		],
		[
			-10,
			50
		],
		[
			-12,
			-18
		],
		[
			-3,
			-54
		],
		[
			45,
			-35
		],
		[
			7,
			7
		],
		[
			45,
			-44
		],
		[
			33,
			-66
		],
		[
			30,
			-104
		],
		[
			-11,
			-44
		],
		[
			-24,
			-44
		],
		[
			6,
			-11
		],
		[
			33,
			44
		],
		[
			7,
			30
		],
		[
			27,
			1
		],
		[
			7,
			-105
		],
		[
			26,
			-78
		],
		[
			16,
			-157
		],
		[
			-19,
			-44
		],
		[
			-43,
			-32
		],
		[
			-11,
			10
		],
		[
			9,
			47
		],
		[
			-18,
			16
		],
		[
			-12,
			-17
		],
		[
			7,
			-39
		],
		[
			-10,
			-37
		],
		[
			-43,
			22
		],
		[
			-11,
			-23
		],
		[
			5,
			-60
		],
		[
			-8,
			-35
		],
		[
			-29,
			5
		],
		[
			-8,
			78
		],
		[
			-36,
			35
		],
		[
			3,
			15
		],
		[
			-28,
			74
		],
		[
			-17,
			19
		],
		[
			-29,
			-19
		],
		[
			-35,
			70
		],
		[
			-16,
			15
		],
		[
			-56,
			107
		],
		[
			-51,
			75
		],
		[
			-2,
			50
		],
		[
			-30,
			70
		],
		[
			-37,
			64
		],
		[
			-5,
			28
		],
		[
			4,
			75
		],
		[
			-15,
			48
		],
		[
			-55,
			121
		],
		[
			-30,
			47
		],
		[
			-96,
			89
		],
		[
			-36,
			71
		],
		[
			-43,
			66
		],
		[
			-98,
			104
		],
		[
			-42,
			49
		],
		[
			-91,
			144
		],
		[
			-30,
			39
		],
		[
			5,
			29
		],
		[
			31,
			89
		],
		[
			24,
			-14
		],
		[
			-9,
			-27
		],
		[
			24,
			3
		],
		[
			0,
			43
		],
		[
			21,
			70
		],
		[
			-22,
			7
		],
		[
			2,
			77
		],
		[
			-14,
			116
		],
		[
			7,
			35
		],
		[
			22,
			41
		],
		[
			-5,
			34
		],
		[
			16,
			30
		],
		[
			-13,
			56
		],
		[
			-19,
			-51
		],
		[
			-2,
			-59
		],
		[
			-25,
			-21
		],
		[
			-21,
			-72
		],
		[
			-1,
			-49
		],
		[
			-107,
			-100
		],
		[
			-12,
			-28
		],
		[
			-28,
			-28
		],
		[
			-95,
			22
		],
		[
			-67,
			36
		],
		[
			-26,
			32
		],
		[
			-123,
			125
		],
		[
			-17,
			56
		],
		[
			18,
			-10
		],
		[
			34,
			24
		],
		[
			11,
			71
		],
		[
			-33,
			131
		],
		[
			3,
			42
		],
		[
			-20,
			-17
		],
		[
			-31,
			44
		],
		[
			6,
			-50
		],
		[
			45,
			-120
		],
		[
			-10,
			-21
		],
		[
			-54,
			-51
		],
		[
			-39,
			0
		],
		[
			-49,
			55
		],
		[
			-61,
			24
		],
		[
			-32,
			23
		],
		[
			-81,
			40
		],
		[
			-45,
			11
		],
		[
			-59,
			-4
		],
		[
			-63,
			-33
		],
		[
			-77,
			-12
		],
		[
			-80,
			-28
		],
		[
			-54,
			-48
		],
		[
			-39,
			39
		],
		[
			-45,
			-26
		],
		[
			-64,
			-120
		],
		[
			-46,
			-115
		],
		[
			6,
			65
		],
		[
			36,
			103
		],
		[
			62,
			117
		],
		[
			46,
			2
		],
		[
			-16,
			66
		],
		[
			-49,
			48
		],
		[
			-8,
			25
		],
		[
			-10,
			-82
		],
		[
			-26,
			84
		],
		[
			-26,
			30
		],
		[
			-17,
			-9
		],
		[
			-16,
			27
		],
		[
			-71,
			19
		],
		[
			9,
			28
		],
		[
			38,
			23
		],
		[
			-42,
			33
		],
		[
			-19,
			-6
		],
		[
			-2,
			25
		],
		[
			37,
			156
		],
		[
			-15,
			15
		],
		[
			-13,
			-36
		],
		[
			-29,
			-22
		],
		[
			-1,
			-57
		],
		[
			-20,
			-66
		],
		[
			-39,
			12
		],
		[
			-70,
			97
		],
		[
			1,
			31
		],
		[
			-26,
			36
		],
		[
			-39,
			26
		],
		[
			-41,
			-35
		],
		[
			-22,
			27
		],
		[
			13,
			29
		],
		[
			31,
			32
		],
		[
			25,
			74
		],
		[
			-14,
			10
		],
		[
			-18,
			-49
		],
		[
			-79,
			-93
		],
		[
			-29,
			-23
		],
		[
			-38,
			5
		],
		[
			1,
			-54
		],
		[
			60,
			27
		],
		[
			11,
			-24
		],
		[
			2,
			-53
		],
		[
			-17,
			2
		],
		[
			-28,
			-37
		],
		[
			-18,
			6
		],
		[
			-41,
			-38
		],
		[
			-41,
			-77
		],
		[
			-12,
			2
		],
		[
			-12,
			48
		],
		[
			47,
			77
		],
		[
			-37,
			-12
		],
		[
			-17,
			11
		],
		[
			-1,
			54
		],
		[
			23,
			83
		],
		[
			13,
			27
		],
		[
			18,
			2
		],
		[
			20,
			-31
		],
		[
			24,
			17
		],
		[
			22,
			41
		],
		[
			38,
			13
		],
		[
			57,
			58
		],
		[
			42,
			20
		],
		[
			-9,
			25
		],
		[
			-19,
			-2
		],
		[
			1,
			71
		],
		[
			-11,
			-49
		],
		[
			-19,
			-20
		],
		[
			1,
			30
		],
		[
			25,
			65
		],
		[
			1,
			21
		],
		[
			-33,
			-58
		],
		[
			-45,
			-47
		],
		[
			-19,
			-3
		],
		[
			-4,
			30
		],
		[
			63,
			112
		],
		[
			-6,
			38
		],
		[
			-29,
			-60
		],
		[
			-38,
			-14
		],
		[
			-12,
			26
		],
		[
			-15,
			-49
		],
		[
			-20,
			-14
		],
		[
			-54,
			13
		],
		[
			-10,
			58
		],
		[
			27,
			19
		],
		[
			11,
			-9
		],
		[
			18,
			25
		],
		[
			40,
			16
		],
		[
			29,
			28
		],
		[
			23,
			65
		],
		[
			-25,
			2
		],
		[
			-14,
			-46
		],
		[
			-23,
			-19
		],
		[
			-45,
			-2
		],
		[
			-18,
			68
		],
		[
			-12,
			3
		],
		[
			-17,
			-69
		],
		[
			-21,
			-8
		],
		[
			-4,
			59
		],
		[
			16,
			26
		],
		[
			17,
			-6
		],
		[
			-11,
			44
		],
		[
			-3,
			55
		],
		[
			13,
			34
		],
		[
			26,
			114
		],
		[
			96,
			6
		],
		[
			-7,
			38
		],
		[
			-91,
			-5
		],
		[
			-21,
			-63
		],
		[
			-27,
			-26
		],
		[
			-21,
			-77
		],
		[
			-31,
			-48
		],
		[
			-23,
			12
		],
		[
			20,
			36
		],
		[
			-10,
			113
		],
		[
			-12,
			53
		],
		[
			18,
			30
		],
		[
			-22,
			10
		],
		[
			-14,
			-23
		],
		[
			-1,
			-51
		],
		[
			12,
			-63
		],
		[
			-14,
			-63
		],
		[
			1,
			-41
		],
		[
			-13,
			-15
		],
		[
			-26,
			48
		],
		[
			-2,
			-67
		],
		[
			-27,
			-45
		],
		[
			-21,
			22
		],
		[
			0,
			52
		],
		[
			-11,
			19
		],
		[
			-7,
			-73
		],
		[
			-9,
			15
		],
		[
			4,
			129
		],
		[
			9,
			62
		],
		[
			-15,
			11
		],
		[
			-17,
			-130
		],
		[
			9,
			-111
		],
		[
			-4,
			-29
		],
		[
			-19,
			-9
		],
		[
			1,
			49
		],
		[
			-27,
			34
		],
		[
			-7,
			-46
		],
		[
			16,
			-65
		],
		[
			-13,
			-8
		],
		[
			-38,
			16
		],
		[
			-34,
			-48
		],
		[
			-28,
			9
		],
		[
			-5,
			31
		],
		[
			14,
			95
		],
		[
			42,
			151
		],
		[
			1,
			53
		],
		[
			49,
			123
		],
		[
			16,
			81
		],
		[
			-6,
			18
		],
		[
			-73,
			-211
		],
		[
			-1,
			-35
		],
		[
			-18,
			-58
		],
		[
			-8,
			8
		],
		[
			-8,
			69
		],
		[
			-12,
			-1
		],
		[
			-3,
			-81
		],
		[
			-11,
			-54
		],
		[
			-18,
			-42
		],
		[
			-3,
			-64
		],
		[
			-16,
			-68
		],
		[
			-21,
			27
		],
		[
			-7,
			-44
		],
		[
			24,
			-28
		],
		[
			-5,
			-91
		],
		[
			10,
			-8
		],
		[
			19,
			85
		],
		[
			37,
			6
		],
		[
			11,
			-22
		],
		[
			4,
			-91
		],
		[
			-14,
			-45
		],
		[
			-31,
			-32
		],
		[
			-22,
			-76
		],
		[
			1,
			-63
		],
		[
			21,
			20
		],
		[
			17,
			75
		],
		[
			30,
			44
		],
		[
			30,
			-89
		],
		[
			0,
			-44
		],
		[
			10,
			-43
		],
		[
			-23,
			-192
		],
		[
			-26,
			0
		],
		[
			-9,
			52
		],
		[
			-19,
			9
		],
		[
			1,
			-36
		],
		[
			-27,
			-44
		],
		[
			0,
			-17
		],
		[
			28,
			14
		],
		[
			23,
			-27
		],
		[
			61,
			-124
		],
		[
			26,
			-85
		],
		[
			-15,
			-77
		],
		[
			-13,
			-26
		],
		[
			-34,
			-35
		],
		[
			-17,
			16
		],
		[
			-14,
			-18
		],
		[
			-29,
			-6
		],
		[
			9,
			51
		],
		[
			-26,
			67
		],
		[
			9,
			60
		],
		[
			-17,
			63
		],
		[
			-16,
			-126
		],
		[
			0,
			-62
		],
		[
			-12,
			-41
		],
		[
			-19,
			69
		],
		[
			-9,
			-8
		],
		[
			-7,
			-59
		],
		[
			-18,
			-33
		],
		[
			-34,
			50
		],
		[
			-29,
			-40
		],
		[
			-15,
			52
		],
		[
			-27,
			-21
		],
		[
			-22,
			5
		],
		[
			-9,
			28
		],
		[
			24,
			74
		],
		[
			-9,
			14
		],
		[
			-27,
			-38
		],
		[
			-29,
			-175
		],
		[
			-30,
			-42
		],
		[
			-9,
			18
		],
		[
			14,
			55
		],
		[
			13,
			84
		],
		[
			-15,
			172
		],
		[
			-16,
			5
		],
		[
			-5,
			-28
		],
		[
			1,
			-81
		],
		[
			13,
			-53
		],
		[
			-10,
			-4
		],
		[
			-10,
			-72
		],
		[
			-17,
			11
		],
		[
			-8,
			-20
		],
		[
			-5,
			-68
		],
		[
			-11,
			-17
		],
		[
			4,
			-47
		],
		[
			25,
			-31
		],
		[
			-6,
			-74
		],
		[
			-27,
			32
		],
		[
			-12,
			127
		],
		[
			8,
			37
		],
		[
			-11,
			78
		],
		[
			-17,
			6
		],
		[
			6,
			-52
		],
		[
			-8,
			-49
		],
		[
			5,
			-196
		],
		[
			-5,
			-64
		],
		[
			-27,
			74
		],
		[
			-1,
			43
		],
		[
			-16,
			28
		],
		[
			-34,
			31
		],
		[
			3,
			-40
		],
		[
			24,
			-36
		],
		[
			-1,
			-63
		],
		[
			-69,
			-158
		],
		[
			-32,
			-91
		],
		[
			0,
			-36
		],
		[
			-16,
			-10
		],
		[
			-9,
			-86
		],
		[
			-12,
			2
		],
		[
			-3,
			70
		],
		[
			34,
			211
		],
		[
			0,
			29
		],
		[
			-26,
			-65
		],
		[
			-19,
			-111
		],
		[
			-12,
			11
		],
		[
			-9,
			142
		],
		[
			-13,
			-52
		],
		[
			-11,
			2
		],
		[
			16,
			-62
		],
		[
			-5,
			-80
		],
		[
			-39,
			0
		],
		[
			-8,
			-61
		],
		[
			-18,
			-24
		],
		[
			-22,
			-55
		],
		[
			7,
			-43
		],
		[
			-15,
			-41
		],
		[
			-16,
			-10
		],
		[
			0,
			54
		],
		[
			-16,
			36
		],
		[
			-13,
			-45
		],
		[
			-1,
			-53
		],
		[
			-22,
			-17
		],
		[
			-24,
			31
		],
		[
			-9,
			-23
		],
		[
			-21,
			38
		],
		[
			-7,
			43
		],
		[
			-12,
			-36
		],
		[
			-21,
			-27
		],
		[
			6,
			-35
		],
		[
			-20,
			0
		],
		[
			-5,
			-39
		],
		[
			-41,
			-7
		],
		[
			-6,
			76
		],
		[
			-22,
			-14
		],
		[
			-21,
			22
		],
		[
			3,
			22
		],
		[
			-21,
			8
		],
		[
			-3,
			70
		],
		[
			8,
			36
		],
		[
			16,
			18
		],
		[
			5,
			71
		],
		[
			32,
			31
		],
		[
			9,
			-11
		],
		[
			29,
			51
		],
		[
			33,
			3
		],
		[
			0,
			45
		],
		[
			33,
			21
		],
		[
			34,
			62
		],
		[
			31,
			-9
		],
		[
			-11,
			69
		],
		[
			22,
			26
		],
		[
			3,
			32
		],
		[
			37,
			102
		],
		[
			-13,
			15
		],
		[
			-24,
			-22
		],
		[
			-60,
			-109
		],
		[
			-30,
			-20
		],
		[
			-18,
			-39
		],
		[
			-39,
			16
		],
		[
			-43,
			67
		],
		[
			-15,
			40
		],
		[
			-5,
			46
		],
		[
			18,
			117
		],
		[
			13,
			45
		],
		[
			15,
			133
		],
		[
			27,
			79
		],
		[
			17,
			33
		],
		[
			35,
			99
		],
		[
			11,
			98
		],
		[
			0,
			71
		],
		[
			23,
			32
		],
		[
			5,
			156
		],
		[
			4,
			27
		],
		[
			-18,
			44
		],
		[
			-22,
			163
		],
		[
			39,
			35
		],
		[
			5,
			27
		],
		[
			63,
			27
		],
		[
			89,
			164
		],
		[
			92,
			118
		],
		[
			51,
			-161
		],
		[
			41,
			-16
		],
		[
			13,
			-27
		],
		[
			34,
			112
		],
		[
			30,
			8
		],
		[
			36,
			-45
		],
		[
			19,
			10
		],
		[
			63,
			-48
		],
		[
			65,
			-20
		],
		[
			30,
			-55
		],
		[
			-1,
			27
		],
		[
			-22,
			63
		],
		[
			-29,
			36
		],
		[
			-38,
			-14
		],
		[
			-51,
			63
		],
		[
			-24,
			-1
		],
		[
			-40,
			42
		],
		[
			-25,
			68
		],
		[
			-39,
			66
		],
		[
			-29,
			28
		],
		[
			18,
			55
		],
		[
			24,
			9
		],
		[
			31,
			124
		],
		[
			23,
			18
		],
		[
			8,
			60
		],
		[
			46,
			27
		],
		[
			30,
			45
		],
		[
			-32,
			50
		],
		[
			-20,
			4
		],
		[
			-43,
			-64
		],
		[
			-11,
			-49
		],
		[
			-19,
			-14
		],
		[
			-12,
			-70
		],
		[
			0,
			-70
		],
		[
			-18,
			-31
		],
		[
			-25,
			19
		],
		[
			-36,
			7
		],
		[
			-74,
			-17
		],
		[
			-26,
			43
		],
		[
			-28,
			16
		],
		[
			-14,
			-52
		],
		[
			-87,
			-84
		],
		[
			-39,
			-154
		],
		[
			-36,
			-12
		],
		[
			-19,
			-31
		],
		[
			-33,
			2
		],
		[
			-39,
			-63
		],
		[
			-48,
			-109
		],
		[
			-1,
			-29
		],
		[
			26,
			-124
		],
		[
			-2,
			-23
		],
		[
			-38,
			25
		],
		[
			-19,
			-18
		],
		[
			-30,
			-52
		],
		[
			-21,
			-92
		],
		[
			-27,
			-29
		],
		[
			-32,
			-74
		],
		[
			-6,
			-73
		],
		[
			8,
			-34
		],
		[
			19,
			-24
		],
		[
			-40,
			-56
		],
		[
			-9,
			-67
		],
		[
			-13,
			-4
		],
		[
			-28,
			-70
		],
		[
			-19,
			-7
		],
		[
			-9,
			28
		],
		[
			-25,
			-11
		],
		[
			4,
			-68
		],
		[
			16,
			-13
		],
		[
			-3,
			-30
		],
		[
			25,
			-42
		],
		[
			8,
			-35
		],
		[
			-12,
			-73
		],
		[
			-19,
			-47
		],
		[
			-7,
			-62
		],
		[
			-25,
			-21
		],
		[
			-4,
			-22
		],
		[
			-39,
			-2
		],
		[
			-15,
			12
		],
		[
			-40,
			-31
		],
		[
			-18,
			3
		],
		[
			-19,
			-60
		],
		[
			23,
			16
		],
		[
			15,
			-20
		],
		[
			15,
			30
		],
		[
			19,
			1
		],
		[
			7,
			-50
		],
		[
			-16,
			-116
		],
		[
			-19,
			-16
		],
		[
			-26,
			-51
		],
		[
			-28,
			37
		],
		[
			5,
			-34
		],
		[
			-13,
			-18
		],
		[
			-18,
			18
		],
		[
			7,
			35
		],
		[
			2,
			75
		],
		[
			-22,
			71
		],
		[
			3,
			-119
		],
		[
			-9,
			-55
		],
		[
			-18,
			-15
		],
		[
			-13,
			25
		],
		[
			-6,
			-35
		],
		[
			16,
			-28
		],
		[
			-9,
			-53
		],
		[
			-49,
			-10
		],
		[
			17,
			-93
		],
		[
			-8,
			-32
		],
		[
			-27,
			-21
		],
		[
			-10,
			8
		],
		[
			-24,
			-45
		],
		[
			-12,
			13
		],
		[
			-36,
			-37
		],
		[
			5,
			-26
		],
		[
			20,
			-18
		],
		[
			-23,
			-32
		],
		[
			-7,
			-43
		],
		[
			2,
			-61
		],
		[
			-12,
			-44
		],
		[
			-24,
			-35
		],
		[
			24,
			-26
		],
		[
			-6,
			-59
		],
		[
			10,
			-60
		],
		[
			27,
			63
		],
		[
			59,
			-23
		],
		[
			16,
			22
		],
		[
			12,
			-22
		],
		[
			15,
			25
		],
		[
			22,
			-78
		],
		[
			19,
			-27
		],
		[
			19,
			13
		],
		[
			23,
			-34
		],
		[
			18,
			-53
		],
		[
			8,
			-53
		],
		[
			15,
			-22
		],
		[
			-28,
			-14
		],
		[
			-14,
			-118
		],
		[
			-12,
			-39
		],
		[
			-30,
			-25
		],
		[
			-11,
			-55
		],
		[
			-24,
			-33
		],
		[
			-48,
			0
		],
		[
			-15,
			-17
		],
		[
			-4,
			-94
		],
		[
			-12,
			-33
		],
		[
			-27,
			1
		],
		[
			-5,
			-20
		],
		[
			10,
			-79
		],
		[
			11,
			-32
		],
		[
			-27,
			-36
		],
		[
			-20,
			15
		],
		[
			-2,
			-45
		],
		[
			20,
			-46
		],
		[
			-11,
			-81
		],
		[
			-21,
			-30
		],
		[
			-6,
			-33
		],
		[
			9,
			-24
		],
		[
			-23,
			0
		],
		[
			-14,
			-52
		],
		[
			-26,
			66
		],
		[
			-9,
			-7
		],
		[
			5,
			-57
		],
		[
			-4,
			-40
		],
		[
			-21,
			-3
		],
		[
			-12,
			-43
		],
		[
			-17,
			16
		],
		[
			0,
			27
		],
		[
			-20,
			-1
		],
		[
			-4,
			-39
		],
		[
			-22,
			-24
		],
		[
			-23,
			31
		],
		[
			-28,
			-17
		],
		[
			-35,
			-69
		],
		[
			15,
			-52
		],
		[
			-9,
			-51
		],
		[
			-40,
			-44
		],
		[
			-28,
			-2
		],
		[
			1,
			-53
		],
		[
			14,
			-25
		],
		[
			-6,
			-40
		],
		[
			-20,
			-16
		],
		[
			-36,
			59
		],
		[
			-10,
			30
		],
		[
			-20,
			-20
		],
		[
			-5,
			-63
		],
		[
			1,
			-69
		],
		[
			-26,
			-27
		],
		[
			-3,
			-97
		],
		[
			-65,
			-7
		],
		[
			-21,
			24
		],
		[
			-2,
			-74
		],
		[
			8,
			-71
		],
		[
			-20,
			0
		],
		[
			-12,
			37
		],
		[
			-21,
			3
		],
		[
			-4,
			-39
		],
		[
			-32,
			-27
		],
		[
			-39,
			-92
		],
		[
			-15,
			-12
		],
		[
			-5,
			-44
		],
		[
			13,
			-11
		],
		[
			47,
			64
		],
		[
			4,
			-50
		],
		[
			-6,
			-53
		],
		[
			-15,
			-7
		],
		[
			0,
			-31
		],
		[
			18,
			-38
		],
		[
			-10,
			-38
		],
		[
			-18,
			-26
		],
		[
			-2,
			-49
		],
		[
			-26,
			-44
		],
		[
			-8,
			-32
		],
		[
			2,
			-42
		],
		[
			-32,
			14
		],
		[
			-31,
			-28
		],
		[
			-4,
			-70
		],
		[
			-12,
			-12
		],
		[
			-19,
			75
		],
		[
			-8,
			-53
		],
		[
			-27,
			-42
		],
		[
			-11,
			-53
		],
		[
			-24,
			-6
		],
		[
			5,
			-50
		],
		[
			-17,
			-27
		],
		[
			-25,
			43
		],
		[
			-24,
			67
		],
		[
			-22,
			-16
		],
		[
			0,
			-51
		],
		[
			11,
			-5
		],
		[
			1,
			-36
		],
		[
			-29,
			-10
		],
		[
			-13,
			-67
		],
		[
			6,
			-32
		],
		[
			18,
			-6
		],
		[
			5,
			-52
		],
		[
			-36,
			-4
		],
		[
			-24,
			-15
		],
		[
			-17,
			77
		],
		[
			-51,
			-38
		],
		[
			-18,
			-51
		],
		[
			-16,
			-3
		],
		[
			-9,
			-49
		],
		[
			19,
			-1
		],
		[
			27,
			25
		],
		[
			20,
			-17
		],
		[
			6,
			-54
		],
		[
			-16,
			-47
		],
		[
			-43,
			44
		],
		[
			-23,
			11
		],
		[
			-5,
			-70
		],
		[
			-33,
			6
		],
		[
			-23,
			21
		],
		[
			-20,
			-33
		],
		[
			-27,
			-88
		],
		[
			2,
			-44
		],
		[
			47,
			-20
		],
		[
			32,
			-36
		],
		[
			-3,
			-29
		],
		[
			-32,
			-42
		],
		[
			1,
			-23
		],
		[
			18,
			-4
		],
		[
			25,
			31
		],
		[
			16,
			-7
		],
		[
			-55,
			-78
		],
		[
			-23,
			-63
		],
		[
			1,
			-52
		],
		[
			-13,
			50
		],
		[
			-10,
			-17
		],
		[
			16,
			-66
		],
		[
			-6,
			-50
		],
		[
			-7,
			39
		],
		[
			-10,
			-2
		],
		[
			-2,
			-53
		],
		[
			-25,
			80
		],
		[
			0,
			95
		],
		[
			-19,
			-60
		],
		[
			8,
			-73
		],
		[
			-4,
			-67
		],
		[
			-24,
			-6
		],
		[
			3,
			58
		],
		[
			-35,
			1
		],
		[
			-16,
			-80
		],
		[
			-25,
			-9
		],
		[
			-75,
			-43
		],
		[
			-29,
			-22
		],
		[
			-7,
			-22
		],
		[
			-3,
			-74
		],
		[
			-17,
			46
		],
		[
			5,
			80
		],
		[
			-23,
			-19
		],
		[
			10,
			-30
		],
		[
			1,
			-104
		],
		[
			-16,
			-71
		],
		[
			6,
			-46
		],
		[
			-24,
			-81
		],
		[
			-32,
			-30
		],
		[
			2,
			52
		],
		[
			24,
			4
		],
		[
			-1,
			40
		],
		[
			-10,
			4
		],
		[
			2,
			111
		],
		[
			18,
			72
		],
		[
			-29,
			39
		],
		[
			-28,
			12
		],
		[
			-13,
			-18
		],
		[
			3,
			-45
		],
		[
			-12,
			-21
		],
		[
			-13,
			22
		],
		[
			-25,
			-13
		],
		[
			-9,
			-82
		],
		[
			-35,
			-74
		],
		[
			-26,
			-20
		],
		[
			-37,
			28
		],
		[
			-6,
			-29
		],
		[
			11,
			-44
		],
		[
			-20,
			-81
		],
		[
			1,
			-31
		],
		[
			-21,
			-37
		],
		[
			-12,
			105
		],
		[
			-10,
			13
		],
		[
			-14,
			-37
		],
		[
			-11,
			14
		],
		[
			-18,
			-31
		],
		[
			31,
			-13
		],
		[
			-2,
			-68
		],
		[
			-32,
			-10
		],
		[
			-16,
			25
		],
		[
			5,
			39
		],
		[
			-13,
			24
		],
		[
			-22,
			-22
		],
		[
			-19,
			-90
		],
		[
			-61,
			-85
		],
		[
			-26,
			2
		],
		[
			-11,
			29
		],
		[
			-26,
			-29
		],
		[
			-13,
			4
		],
		[
			10,
			156
		],
		[
			29,
			96
		],
		[
			1,
			46
		],
		[
			-15,
			16
		],
		[
			-31,
			-2
		],
		[
			-24,
			-29
		],
		[
			-24,
			-101
		],
		[
			4,
			-129
		],
		[
			-40,
			-140
		],
		[
			-7,
			-12
		],
		[
			-14,
			-85
		],
		[
			-21,
			36
		],
		[
			-19,
			-12
		],
		[
			13,
			-65
		],
		[
			10,
			-17
		],
		[
			1,
			-56
		],
		[
			-25,
			-38
		],
		[
			-19,
			33
		],
		[
			0,
			45
		],
		[
			-16,
			15
		],
		[
			-13,
			-60
		],
		[
			10,
			-49
		],
		[
			-17,
			-47
		],
		[
			-14,
			27
		],
		[
			-32,
			-8
		],
		[
			-16,
			18
		],
		[
			-14,
			74
		],
		[
			32,
			6
		],
		[
			-21,
			47
		],
		[
			-8,
			104
		],
		[
			-21,
			56
		],
		[
			-11,
			7
		],
		[
			-16,
			-33
		],
		[
			-10,
			-65
		],
		[
			7,
			-27
		],
		[
			14,
			0
		],
		[
			18,
			-70
		],
		[
			-11,
			-46
		],
		[
			14,
			-95
		],
		[
			0,
			-52
		],
		[
			-22,
			30
		],
		[
			-20,
			-19
		],
		[
			3,
			-26
		],
		[
			-17,
			-30
		],
		[
			-18,
			-7
		],
		[
			-22,
			28
		],
		[
			-16,
			59
		],
		[
			4,
			36
		],
		[
			-13,
			56
		],
		[
			-21,
			37
		],
		[
			-31,
			-25
		],
		[
			-10,
			-56
		],
		[
			49,
			-85
		],
		[
			4,
			-31
		],
		[
			-50,
			-111
		],
		[
			-24,
			-21
		],
		[
			-20,
			-33
		],
		[
			16,
			-56
		],
		[
			27,
			2
		],
		[
			9,
			24
		],
		[
			22,
			-50
		],
		[
			13,
			-83
		],
		[
			-26,
			6
		],
		[
			8,
			34
		],
		[
			-17,
			6
		],
		[
			-10,
			-28
		],
		[
			-16,
			22
		],
		[
			-17,
			62
		],
		[
			-25,
			-39
		],
		[
			2,
			-69
		],
		[
			-18,
			-1
		],
		[
			-28,
			-50
		],
		[
			-23,
			18
		],
		[
			-37,
			10
		],
		[
			-45,
			-5
		],
		[
			-34,
			-14
		],
		[
			-41,
			-40
		],
		[
			-29,
			-71
		],
		[
			-4,
			-69
		],
		[
			-29,
			-53
		],
		[
			-51,
			-33
		],
		[
			-29,
			3
		],
		[
			-28,
			28
		],
		[
			-9,
			30
		],
		[
			-9,
			74
		],
		[
			-10,
			30
		],
		[
			-1,
			55
		],
		[
			8,
			29
		],
		[
			44,
			41
		],
		[
			14,
			25
		],
		[
			23,
			110
		],
		[
			19,
			110
		],
		[
			-1,
			29
		],
		[
			22,
			54
		],
		[
			14,
			13
		],
		[
			25,
			-46
		],
		[
			38,
			39
		],
		[
			25,
			49
		],
		[
			25,
			0
		],
		[
			37,
			81
		],
		[
			34,
			20
		],
		[
			36,
			-14
		],
		[
			31,
			5
		],
		[
			1,
			-37
		],
		[
			28,
			-72
		],
		[
			9,
			-61
		],
		[
			-5,
			-50
		],
		[
			27,
			24
		],
		[
			-8,
			52
		],
		[
			2,
			37
		],
		[
			30,
			-30
		],
		[
			-15,
			42
		],
		[
			2,
			77
		],
		[
			-10,
			109
		],
		[
			32,
			46
		],
		[
			26,
			21
		],
		[
			42,
			-15
		],
		[
			21,
			14
		],
		[
			10,
			69
		],
		[
			-16,
			4
		],
		[
			4,
			28
		],
		[
			18,
			10
		],
		[
			7,
			38
		],
		[
			18,
			-4
		],
		[
			26,
			99
		],
		[
			3,
			-32
		],
		[
			15,
			-20
		],
		[
			21,
			48
		],
		[
			-5,
			83
		],
		[
			-20,
			-9
		],
		[
			27,
			68
		],
		[
			64,
			206
		],
		[
			33,
			52
		],
		[
			23,
			62
		],
		[
			19,
			13
		],
		[
			27,
			42
		],
		[
			25,
			68
		],
		[
			27,
			14
		],
		[
			35,
			39
		],
		[
			37,
			20
		],
		[
			89,
			70
		],
		[
			30,
			-9
		],
		[
			10,
			18
		],
		[
			45,
			5
		],
		[
			10,
			-10
		],
		[
			-20,
			-27
		],
		[
			-1,
			-47
		],
		[
			14,
			-2
		],
		[
			-3,
			-49
		],
		[
			-29,
			-18
		],
		[
			-3,
			-85
		],
		[
			38,
			-98
		],
		[
			11,
			22
		],
		[
			27,
			-39
		],
		[
			4,
			19
		],
		[
			-29,
			53
		],
		[
			-3,
			85
		],
		[
			-6,
			32
		],
		[
			26,
			-28
		],
		[
			57,
			3
		],
		[
			7,
			-86
		],
		[
			23,
			7
		],
		[
			26,
			-36
		],
		[
			7,
			22
		],
		[
			-14,
			40
		],
		[
			27,
			15
		],
		[
			-56,
			89
		],
		[
			-32,
			36
		],
		[
			1,
			58
		],
		[
			-16,
			-7
		],
		[
			39,
			166
		],
		[
			15,
			123
		],
		[
			11,
			56
		],
		[
			23,
			44
		],
		[
			36,
			96
		],
		[
			18,
			13
		],
		[
			40,
			74
		],
		[
			30,
			81
		],
		[
			82,
			96
		],
		[
			41,
			74
		],
		[
			35,
			39
		],
		[
			68,
			106
		],
		[
			17,
			42
		],
		[
			29,
			-68
		],
		[
			19,
			-14
		],
		[
			31,
			19
		],
		[
			8,
			59
		],
		[
			-13,
			47
		],
		[
			-2,
			46
		],
		[
			15,
			122
		],
		[
			29,
			108
		],
		[
			41,
			130
		],
		[
			24,
			62
		],
		[
			22,
			37
		],
		[
			40,
			41
		],
		[
			21,
			52
		],
		[
			22,
			87
		],
		[
			14,
			15
		],
		[
			26,
			62
		],
		[
			30,
			25
		],
		[
			8,
			-74
		],
		[
			18,
			-15
		],
		[
			4,
			41
		],
		[
			-10,
			105
		],
		[
			-23,
			-2
		],
		[
			-6,
			34
		],
		[
			2,
			95
		],
		[
			9,
			59
		],
		[
			25,
			409
		],
		[
			14,
			42
		],
		[
			38,
			16
		],
		[
			12,
			53
		],
		[
			-20,
			-9
		],
		[
			-34,
			77
		],
		[
			-3,
			62
		],
		[
			9,
			97
		],
		[
			20,
			106
		],
		[
			27,
			33
		],
		[
			29,
			101
		],
		[
			49,
			102
		],
		[
			4,
			57
		],
		[
			19,
			93
		],
		[
			-5,
			45
		],
		[
			13,
			33
		],
		[
			-3,
			43
		],
		[
			13,
			38
		],
		[
			-20,
			0
		],
		[
			-11,
			-32
		],
		[
			0,
			-38
		],
		[
			-21,
			-53
		],
		[
			-28,
			-31
		],
		[
			-38,
			-27
		],
		[
			-21,
			-31
		],
		[
			-29,
			-22
		],
		[
			-5,
			-21
		],
		[
			-41,
			-28
		],
		[
			-44,
			-61
		],
		[
			-79,
			-73
		],
		[
			-26,
			5
		],
		[
			-28,
			53
		],
		[
			-5,
			73
		],
		[
			-20,
			49
		],
		[
			-40,
			38
		],
		[
			2,
			46
		],
		[
			11,
			17
		],
		[
			9,
			167
		],
		[
			-12,
			-3
		],
		[
			-25,
			-101
		],
		[
			-41,
			-54
		],
		[
			-6,
			-58
		],
		[
			5,
			-58
		],
		[
			-8,
			-37
		],
		[
			-14,
			-12
		],
		[
			-3,
			-32
		],
		[
			9,
			-80
		],
		[
			16,
			-91
		],
		[
			19,
			-76
		],
		[
			-26,
			-87
		],
		[
			-28,
			-21
		],
		[
			-42,
			32
		],
		[
			-39,
			161
		],
		[
			-47,
			208
		],
		[
			-26,
			73
		],
		[
			-23,
			42
		],
		[
			-31,
			13
		],
		[
			16,
			65
		],
		[
			-16,
			44
		],
		[
			-25,
			-9
		],
		[
			-6,
			-87
		],
		[
			-15,
			7
		],
		[
			1,
			-65
		],
		[
			-29,
			-30
		],
		[
			-24,
			79
		],
		[
			3,
			26
		],
		[
			-19,
			19
		],
		[
			-11,
			-30
		],
		[
			-16,
			6
		],
		[
			-1,
			59
		],
		[
			-22,
			-18
		],
		[
			-25,
			61
		],
		[
			18,
			47
		],
		[
			-17,
			89
		],
		[
			-44,
			-52
		],
		[
			-46,
			-72
		],
		[
			-31,
			-62
		],
		[
			-20,
			-95
		],
		[
			-13,
			57
		],
		[
			-36,
			-33
		],
		[
			-94,
			-124
		],
		[
			-10,
			-41
		],
		[
			0,
			-49
		],
		[
			-41,
			-38
		],
		[
			-8,
			-26
		],
		[
			-22,
			-10
		],
		[
			-15,
			-44
		],
		[
			-20,
			-15
		],
		[
			-4,
			55
		],
		[
			-29,
			45
		],
		[
			-54,
			-20
		],
		[
			-29,
			33
		],
		[
			49,
			47
		],
		[
			15,
			-39
		],
		[
			18,
			12
		],
		[
			5,
			50
		],
		[
			25,
			77
		],
		[
			3,
			60
		],
		[
			-8,
			85
		],
		[
			1,
			81
		],
		[
			-16,
			74
		],
		[
			5,
			21
		],
		[
			-16,
			20
		],
		[
			-29,
			97
		],
		[
			-20,
			139
		],
		[
			29,
			128
		],
		[
			21,
			23
		],
		[
			24,
			79
		],
		[
			24,
			26
		],
		[
			-15,
			77
		],
		[
			-18,
			44
		],
		[
			-15,
			64
		],
		[
			-10,
			107
		],
		[
			-50,
			162
		],
		[
			-3,
			74
		],
		[
			-25,
			67
		],
		[
			-10,
			63
		],
		[
			-30,
			85
		],
		[
			-10,
			44
		],
		[
			-22,
			9
		],
		[
			-11,
			-37
		],
		[
			-2,
			-74
		],
		[
			6,
			-37
		],
		[
			-8,
			-56
		],
		[
			-12,
			-21
		],
		[
			-27,
			-10
		],
		[
			-18,
			21
		],
		[
			-19,
			-54
		],
		[
			-36,
			-29
		],
		[
			-50,
			-68
		],
		[
			-73,
			-48
		],
		[
			-88,
			-28
		],
		[
			-75,
			10
		],
		[
			-51,
			38
		],
		[
			-13,
			32
		],
		[
			-13,
			99
		],
		[
			23,
			18
		],
		[
			-18,
			69
		],
		[
			-54,
			62
		],
		[
			-32,
			108
		],
		[
			-5,
			34
		],
		[
			-33,
			51
		],
		[
			-18,
			62
		],
		[
			-42,
			8
		],
		[
			-31,
			42
		],
		[
			-47,
			110
		],
		[
			23,
			32
		],
		[
			24,
			55
		],
		[
			-2,
			36
		],
		[
			-24,
			6
		],
		[
			-38,
			-54
		],
		[
			-48,
			10
		],
		[
			-16,
			51
		],
		[
			11,
			32
		],
		[
			32,
			1
		],
		[
			57,
			128
		],
		[
			10,
			-4
		],
		[
			17,
			45
		],
		[
			-16,
			34
		],
		[
			-4,
			41
		],
		[
			32,
			24
		],
		[
			-27,
			7
		],
		[
			5,
			70
		],
		[
			27,
			78
		],
		[
			-17,
			3
		],
		[
			-18,
			-48
		],
		[
			-40,
			42
		],
		[
			-6,
			40
		],
		[
			22,
			49
		],
		[
			27,
			-6
		],
		[
			19,
			23
		],
		[
			0,
			45
		],
		[
			-17,
			-21
		],
		[
			-30,
			32
		],
		[
			-16,
			54
		],
		[
			2,
			23
		],
		[
			-20,
			7
		],
		[
			-13,
			35
		],
		[
			-10,
			-14
		],
		[
			-12,
			-99
		],
		[
			-14,
			-6
		],
		[
			-38,
			16
		],
		[
			-10,
			21
		],
		[
			-10,
			66
		],
		[
			1,
			129
		],
		[
			-11,
			19
		],
		[
			-43,
			10
		],
		[
			-18,
			37
		],
		[
			-10,
			98
		],
		[
			42,
			44
		],
		[
			6,
			38
		],
		[
			-17,
			46
		],
		[
			-30,
			31
		],
		[
			-45,
			-27
		],
		[
			0,
			-46
		],
		[
			-21,
			23
		],
		[
			-9,
			88
		],
		[
			8,
			147
		],
		[
			6,
			11
		],
		[
			-2,
			-107
		],
		[
			92,
			47
		],
		[
			0,
			19
		],
		[
			-35,
			20
		],
		[
			-20,
			28
		],
		[
			-24,
			82
		],
		[
			2,
			18
		],
		[
			36,
			19
		],
		[
			55,
			-8
		],
		[
			33,
			25
		],
		[
			-29,
			134
		],
		[
			-4,
			46
		],
		[
			3,
			84
		],
		[
			21,
			77
		],
		[
			101,
			278
		],
		[
			4,
			29
		],
		[
			27,
			77
		],
		[
			29,
			61
		],
		[
			5,
			70
		],
		[
			18,
			67
		],
		[
			21,
			34
		],
		[
			19,
			-4
		],
		[
			9,
			23
		],
		[
			-11,
			115
		],
		[
			26,
			188
		],
		[
			18,
			70
		],
		[
			38,
			61
		],
		[
			-18,
			24
		],
		[
			4,
			22
		],
		[
			58,
			133
		],
		[
			60,
			46
		],
		[
			48,
			11
		],
		[
			42,
			-45
		],
		[
			43,
			-11
		],
		[
			32,
			-84
		],
		[
			24,
			-6
		],
		[
			6,
			-26
		],
		[
			54,
			-88
		],
		[
			73,
			24
		],
		[
			61,
			124
		],
		[
			4,
			47
		],
		[
			44,
			29
		],
		[
			63,
			172
		],
		[
			23,
			89
		],
		[
			23,
			39
		],
		[
			-9,
			58
		],
		[
			14,
			5
		],
		[
			28,
			-28
		],
		[
			22,
			-5
		],
		[
			13,
			-77
		],
		[
			52,
			0
		],
		[
			45,
			20
		],
		[
			26,
			-20
		],
		[
			77,
			28
		],
		[
			48,
			38
		],
		[
			9,
			51
		],
		[
			56,
			128
		],
		[
			38,
			135
		],
		[
			0,
			71
		],
		[
			-12,
			81
		],
		[
			-23,
			95
		],
		[
			-17,
			121
		],
		[
			-1,
			118
		],
		[
			-5,
			52
		],
		[
			-71,
			157
		],
		[
			-9,
			32
		],
		[
			-41,
			28
		],
		[
			-27,
			1
		],
		[
			10,
			97
		],
		[
			27,
			33
		],
		[
			14,
			-25
		],
		[
			35,
			-20
		],
		[
			51,
			7
		],
		[
			-10,
			45
		],
		[
			31,
			10
		],
		[
			41,
			81
		],
		[
			2,
			114
		],
		[
			-42,
			122
		],
		[
			-47,
			68
		],
		[
			-25,
			48
		],
		[
			-1,
			-32
		],
		[
			-27,
			-48
		],
		[
			-20,
			-86
		],
		[
			-42,
			-30
		],
		[
			-42,
			42
		],
		[
			-59,
			-93
		],
		[
			-81,
			-34
		],
		[
			-18,
			-71
		],
		[
			-85,
			-103
		],
		[
			-21,
			-70
		],
		[
			-5,
			-99
		],
		[
			-44,
			-70
		],
		[
			-4,
			93
		],
		[
			-15,
			110
		],
		[
			-23,
			50
		],
		[
			-28,
			-3
		],
		[
			4,
			34
		],
		[
			-32,
			46
		],
		[
			-9,
			36
		],
		[
			-38,
			-60
		],
		[
			16,
			-45
		],
		[
			21,
			-7
		],
		[
			16,
			-39
		],
		[
			24,
			11
		],
		[
			2,
			-48
		],
		[
			-22,
			-81
		],
		[
			-19,
			-11
		],
		[
			-22,
			82
		],
		[
			-55,
			76
		],
		[
			-41,
			33
		],
		[
			-64,
			13
		],
		[
			-41,
			-27
		],
		[
			-27,
			12
		],
		[
			-52,
			3
		],
		[
			-45,
			-22
		],
		[
			-108,
			-112
		],
		[
			-58,
			-17
		],
		[
			-111,
			74
		],
		[
			-94,
			45
		],
		[
			-47,
			14
		],
		[
			-88,
			40
		],
		[
			-49,
			79
		],
		[
			-20,
			96
		],
		[
			1,
			74
		],
		[
			20,
			36
		],
		[
			-6,
			64
		],
		[
			-28,
			63
		],
		[
			-45,
			56
		],
		[
			-1,
			59
		],
		[
			-46,
			64
		],
		[
			-10,
			56
		],
		[
			39,
			-33
		],
		[
			33,
			3
		],
		[
			9,
			27
		],
		[
			24,
			15
		],
		[
			16,
			32
		],
		[
			-3,
			55
		],
		[
			35,
			61
		],
		[
			-38,
			63
		],
		[
			-19,
			9
		],
		[
			-29,
			-16
		],
		[
			-39,
			15
		],
		[
			-64,
			52
		],
		[
			-104,
			21
		],
		[
			-49,
			52
		],
		[
			-38,
			63
		],
		[
			-55,
			60
		],
		[
			-46,
			30
		],
		[
			-15,
			93
		]
	],
	[
		[
			2812,
			78476
		],
		[
			27,
			27
		],
		[
			-1,
			59
		],
		[
			18,
			0
		],
		[
			10,
			36
		],
		[
			0,
			57
		],
		[
			21,
			33
		],
		[
			5,
			57
		],
		[
			-10,
			16
		],
		[
			11,
			87
		],
		[
			46,
			106
		],
		[
			16,
			-26
		],
		[
			27,
			16
		],
		[
			28,
			-3
		],
		[
			-9,
			65
		],
		[
			-12,
			5
		],
		[
			9,
			77
		],
		[
			-6,
			26
		],
		[
			18,
			76
		],
		[
			40,
			67
		],
		[
			54,
			37
		],
		[
			29,
			-53
		],
		[
			31,
			1
		],
		[
			2,
			-23
		],
		[
			-21,
			-74
		],
		[
			5,
			-60
		],
		[
			-55,
			-95
		],
		[
			-65,
			-72
		],
		[
			-19,
			-66
		],
		[
			-1,
			-36
		],
		[
			-28,
			-81
		],
		[
			-15,
			-58
		],
		[
			-25,
			-10
		],
		[
			-28,
			-71
		],
		[
			-15,
			-17
		],
		[
			-4,
			-51
		],
		[
			-15,
			21
		],
		[
			-27,
			-49
		],
		[
			-54,
			-69
		],
		[
			13,
			45
		]
	],
	[
		[
			2752,
			78371
		],
		[
			29,
			49
		],
		[
			-1,
			-45
		],
		[
			-26,
			-25
		],
		[
			-2,
			21
		]
	],
	[
		[
			2615,
			78610
		],
		[
			4,
			50
		],
		[
			19,
			16
		],
		[
			4,
			-44
		],
		[
			-9,
			-45
		],
		[
			-12,
			-8
		],
		[
			-6,
			31
		]
	],
	[
		[
			2607,
			82847
		],
		[
			50,
			-13
		],
		[
			29,
			5
		],
		[
			10,
			-14
		],
		[
			-27,
			-68
		],
		[
			-23,
			4
		],
		[
			-9,
			46
		],
		[
			-20,
			10
		],
		[
			-10,
			30
		]
	],
	[
		[
			2611,
			78728
		],
		[
			8,
			-39
		],
		[
			-15,
			13
		],
		[
			7,
			26
		]
	],
	[
		[
			2547,
			78457
		],
		[
			17,
			17
		],
		[
			23,
			-3
		],
		[
			-2,
			19
		],
		[
			27,
			23
		],
		[
			19,
			-10
		],
		[
			10,
			-25
		],
		[
			-17,
			-105
		],
		[
			-30,
			50
		],
		[
			-25,
			-29
		],
		[
			-19,
			14
		],
		[
			-3,
			49
		]
	],
	[
		[
			2517,
			78521
		],
		[
			8,
			26
		],
		[
			23,
			-16
		],
		[
			1,
			-31
		],
		[
			-14,
			-31
		],
		[
			-13,
			16
		],
		[
			-5,
			36
		]
	],
	[
		[
			2497,
			78313
		],
		[
			4,
			72
		],
		[
			33,
			-18
		],
		[
			-7,
			-57
		],
		[
			-30,
			3
		]
	],
	[
		[
			2431,
			83489
		],
		[
			9,
			43
		],
		[
			22,
			15
		],
		[
			12,
			-10
		],
		[
			29,
			22
		],
		[
			-2,
			-56
		],
		[
			-32,
			-62
		],
		[
			-5,
			31
		],
		[
			-33,
			17
		]
	],
	[
		[
			2316,
			78170
		],
		[
			5,
			42
		],
		[
			40,
			72
		],
		[
			31,
			-27
		],
		[
			1,
			-27
		],
		[
			-13,
			-58
		],
		[
			-19,
			2
		],
		[
			-17,
			-26
		],
		[
			-15,
			-48
		],
		[
			-15,
			21
		],
		[
			2,
			49
		]
	],
	[
		[
			2228,
			78152
		],
		[
			9,
			-32
		],
		[
			-16,
			2
		],
		[
			7,
			30
		]
	],
	[
		[
			2183,
			78046
		],
		[
			17,
			42
		],
		[
			16,
			-37
		],
		[
			-12,
			-55
		],
		[
			-19,
			-1
		],
		[
			-2,
			51
		]
	],
	[
		[
			2036,
			90914
		],
		[
			2,
			37
		],
		[
			25,
			87
		],
		[
			-3,
			75
		],
		[
			8,
			18
		],
		[
			-5,
			57
		],
		[
			21,
			3
		],
		[
			8,
			-42
		],
		[
			-4,
			-48
		],
		[
			12,
			-34
		],
		[
			64,
			-57
		],
		[
			77,
			-48
		],
		[
			55,
			-20
		],
		[
			58,
			87
		],
		[
			58,
			58
		],
		[
			58,
			-14
		],
		[
			29,
			-69
		],
		[
			23,
			-15
		],
		[
			15,
			-104
		],
		[
			-2,
			-38
		],
		[
			53,
			-56
		],
		[
			56,
			-14
		],
		[
			22,
			-32
		],
		[
			9,
			-35
		],
		[
			36,
			-20
		],
		[
			88,
			-20
		],
		[
			14,
			6
		],
		[
			102,
			-55
		],
		[
			-27,
			-131
		],
		[
			-22,
			-43
		],
		[
			-51,
			35
		],
		[
			-43,
			-1
		],
		[
			-50,
			-29
		],
		[
			-44,
			-89
		],
		[
			-10,
			-61
		],
		[
			1,
			-53
		],
		[
			-20,
			-46
		],
		[
			-30,
			22
		],
		[
			3,
			24
		],
		[
			-26,
			119
		],
		[
			-32,
			62
		],
		[
			-50,
			60
		],
		[
			-39,
			-5
		],
		[
			-11,
			69
		],
		[
			-17,
			55
		],
		[
			-54,
			80
		],
		[
			-86,
			69
		],
		[
			-65,
			11
		],
		[
			-47,
			-44
		],
		[
			-18,
			-58
		],
		[
			-36,
			-34
		],
		[
			-28,
			33
		],
		[
			-49,
			36
		],
		[
			-24,
			83
		],
		[
			-7,
			56
		],
		[
			3,
			73
		]
	],
	[
		[
			1818,
			77819
		],
		[
			15,
			59
		],
		[
			33,
			49
		],
		[
			12,
			-2
		],
		[
			27,
			-39
		],
		[
			-1,
			-41
		],
		[
			-28,
			-51
		],
		[
			-32,
			-27
		],
		[
			-22,
			-1
		],
		[
			-4,
			53
		]
	],
	[
		[
			1695,
			87369
		],
		[
			6,
			69
		],
		[
			25,
			52
		],
		[
			11,
			-3
		],
		[
			-4,
			-58
		],
		[
			12,
			-54
		],
		[
			33,
			-70
		],
		[
			48,
			-63
		],
		[
			22,
			-14
		],
		[
			25,
			13
		],
		[
			57,
			-94
		],
		[
			-21,
			-19
		],
		[
			-9,
			37
		],
		[
			-51,
			8
		],
		[
			-26,
			-17
		],
		[
			-33,
			46
		],
		[
			-58,
			136
		],
		[
			-37,
			31
		]
	],
	[
		[
			1687,
			87598
		],
		[
			8,
			-5
		],
		[
			5,
			-84
		],
		[
			-20,
			42
		],
		[
			7,
			47
		]
	],
	[
		[
			1421,
			77626
		],
		[
			35,
			0
		],
		[
			33,
			-31
		],
		[
			9,
			30
		],
		[
			14,
			-2
		],
		[
			33,
			27
		],
		[
			25,
			-1
		],
		[
			-6,
			-28
		],
		[
			10,
			-29
		],
		[
			8,
			15
		],
		[
			31,
			-24
		],
		[
			23,
			16
		],
		[
			10,
			-11
		],
		[
			32,
			11
		],
		[
			5,
			-12
		],
		[
			41,
			-7
		],
		[
			-25,
			-23
		],
		[
			-16,
			6
		],
		[
			-14,
			-22
		],
		[
			-44,
			-1
		],
		[
			-22,
			-35
		],
		[
			-8,
			16
		],
		[
			-16,
			-19
		],
		[
			-19,
			4
		],
		[
			-18,
			25
		],
		[
			-52,
			3
		],
		[
			-9,
			-15
		],
		[
			-29,
			19
		],
		[
			-10,
			49
		],
		[
			-11,
			-1
		],
		[
			-10,
			40
		]
	],
	[
		[
			1064,
			77503
		],
		[
			55,
			37
		],
		[
			11,
			-28
		],
		[
			25,
			50
		],
		[
			3,
			-22
		],
		[
			19,
			38
		],
		[
			5,
			29
		],
		[
			18,
			-29
		],
		[
			27,
			8
		],
		[
			8,
			34
		],
		[
			6,
			-24
		],
		[
			35,
			37
		],
		[
			1,
			42
		],
		[
			44,
			10
		],
		[
			-13,
			41
		],
		[
			43,
			-5
		],
		[
			13,
			34
		],
		[
			-1,
			36
		],
		[
			-32,
			7
		],
		[
			-23,
			29
		],
		[
			5,
			26
		],
		[
			21,
			-16
		],
		[
			12,
			36
		],
		[
			-2,
			39
		],
		[
			38,
			46
		],
		[
			33,
			-32
		],
		[
			22,
			-76
		],
		[
			1,
			-31
		],
		[
			-21,
			-85
		],
		[
			-34,
			8
		],
		[
			-4,
			-43
		],
		[
			33,
			-79
		],
		[
			-3,
			-24
		],
		[
			-15,
			21
		],
		[
			-17,
			-10
		],
		[
			-4,
			-27
		],
		[
			-16,
			-4
		],
		[
			-20,
			23
		],
		[
			-19,
			-95
		],
		[
			-25,
			31
		],
		[
			-64,
			-55
		],
		[
			-13,
			29
		],
		[
			-29,
			12
		],
		[
			-23,
			-6
		],
		[
			-13,
			-35
		],
		[
			-22,
			-8
		],
		[
			-33,
			6
		],
		[
			-32,
			25
		]
	],
	[
		[
			1013,
			77451
		],
		[
			17,
			17
		],
		[
			7,
			-29
		],
		[
			-22,
			-4
		],
		[
			-2,
			16
		]
	],
	[
		[
			1005,
			77685
		],
		[
			16,
			-19
		],
		[
			-11,
			-12
		],
		[
			-5,
			31
		]
	],
	[
		[
			949,
			77433
		],
		[
			5,
			9
		],
		[
			40,
			-3
		],
		[
			1,
			-26
		],
		[
			-19,
			3
		],
		[
			-22,
			-24
		],
		[
			-5,
			41
		]
	],
	[
		[
			890,
			77452
		],
		[
			11,
			14
		],
		[
			28,
			-1
		],
		[
			15,
			-90
		],
		[
			-16,
			5
		],
		[
			-17,
			49
		],
		[
			-21,
			23
		]
	],
	[
		[
			821,
			77563
		],
		[
			14,
			45
		],
		[
			26,
			-9
		],
		[
			23,
			-80
		],
		[
			-20,
			-38
		],
		[
			15,
			-56
		],
		[
			-13,
			-34
		],
		[
			-18,
			-2
		],
		[
			-18,
			22
		],
		[
			3,
			57
		],
		[
			-7,
			2
		],
		[
			-8,
			77
		],
		[
			3,
			16
		]
	],
	[
		[
			811,
			77269
		],
		[
			5,
			56
		],
		[
			12,
			10
		],
		[
			10,
			-27
		],
		[
			19,
			10
		],
		[
			-12,
			22
		],
		[
			34,
			30
		],
		[
			10,
			-23
		],
		[
			-2,
			-55
		],
		[
			-23,
			0
		],
		[
			13,
			-52
		],
		[
			-29,
			29
		],
		[
			2,
			-40
		],
		[
			-12,
			12
		],
		[
			-5,
			-39
		],
		[
			-7,
			45
		],
		[
			-15,
			22
		]
	],
	[
		[
			601,
			77040
		],
		[
			11,
			67
		],
		[
			15,
			16
		],
		[
			7,
			36
		],
		[
			-13,
			66
		],
		[
			4,
			27
		],
		[
			32,
			7
		],
		[
			7,
			59
		],
		[
			-13,
			69
		],
		[
			10,
			45
		],
		[
			15,
			4
		],
		[
			18,
			-20
		],
		[
			19,
			59
		],
		[
			9,
			-14
		],
		[
			3,
			-74
		],
		[
			-20,
			-29
		],
		[
			-2,
			-50
		],
		[
			13,
			-20
		],
		[
			19,
			4
		],
		[
			31,
			26
		],
		[
			30,
			5
		],
		[
			7,
			-64
		],
		[
			-7,
			-88
		],
		[
			-15,
			-12
		],
		[
			-36,
			18
		],
		[
			-13,
			-52
		],
		[
			-18,
			-12
		],
		[
			-13,
			-41
		],
		[
			-23,
			31
		],
		[
			-6,
			-25
		],
		[
			6,
			-48
		],
		[
			-11,
			17
		],
		[
			-13,
			-26
		],
		[
			-4,
			55
		],
		[
			-14,
			29
		],
		[
			-19,
			-108
		],
		[
			-14,
			11
		],
		[
			-2,
			32
		]
	],
	[
		[
			469,
			77371
		],
		[
			13,
			9
		],
		[
			2,
			-26
		],
		[
			-14,
			-17
		],
		[
			-1,
			34
		]
	],
	[
		[
			402,
			77131
		],
		[
			18,
			33
		],
		[
			24,
			-17
		],
		[
			26,
			34
		],
		[
			50,
			39
		],
		[
			21,
			43
		],
		[
			2,
			128
		],
		[
			12,
			16
		],
		[
			16,
			-10
		],
		[
			15,
			-44
		],
		[
			-26,
			-98
		],
		[
			5,
			-86
		],
		[
			-7,
			-38
		],
		[
			-33,
			-31
		],
		[
			-36,
			61
		],
		[
			-27,
			-33
		],
		[
			-40,
			-10
		],
		[
			-1,
			-43
		],
		[
			-10,
			5
		],
		[
			-9,
			51
		]
	],
	[
		[
			257,
			77332
		],
		[
			8,
			29
		],
		[
			29,
			17
		],
		[
			39,
			-5
		],
		[
			11,
			-42
		],
		[
			-2,
			-30
		],
		[
			19,
			-32
		],
		[
			15,
			17
		],
		[
			18,
			-17
		],
		[
			33,
			34
		],
		[
			-10,
			-40
		],
		[
			-41,
			-32
		],
		[
			-12,
			-71
		],
		[
			4,
			-31
		],
		[
			-12,
			-31
		],
		[
			-8,
			16
		],
		[
			-9,
			-44
		],
		[
			8,
			-57
		],
		[
			-8,
			-5
		],
		[
			-9,
			56
		],
		[
			-14,
			-24
		],
		[
			-16,
			48
		],
		[
			-13,
			8
		],
		[
			4,
			28
		],
		[
			41,
			25
		],
		[
			-3,
			64
		],
		[
			-20,
			1
		],
		[
			-13,
			34
		],
		[
			-39,
			66
		],
		[
			0,
			18
		]
	],
	[
		[
			130,
			77016
		],
		[
			32,
			-12
		],
		[
			-3,
			-18
		],
		[
			-27,
			7
		],
		[
			-2,
			23
		]
	],
	[
		[
			81,
			76979
		],
		[
			27,
			-17
		],
		[
			7,
			-23
		],
		[
			-25,
			5
		],
		[
			-9,
			35
		]
	],
	[
		[
			77,
			77233
		],
		[
			14,
			52
		],
		[
			20,
			-35
		],
		[
			0,
			-61
		],
		[
			-19,
			-10
		],
		[
			-15,
			54
		]
	],
	[
		[
			43,
			76751
		],
		[
			8,
			25
		],
		[
			10,
			-22
		],
		[
			5,
			-50
		],
		[
			-12,
			-2
		],
		[
			-10,
			-32
		],
		[
			-1,
			81
		]
	],
	[
		[
			3,
			76640
		],
		[
			12,
			18
		],
		[
			6,
			-59
		],
		[
			-18,
			-25
		],
		[
			0,
			66
		]
	],
	[
		[
			99917,
			77451
		],
		[
			12,
			-2
		],
		[
			12,
			35
		],
		[
			26,
			14
		],
		[
			31,
			-61
		],
		[
			-9,
			-68
		],
		[
			-24,
			-42
		],
		[
			-12,
			-5
		],
		[
			-25,
			29
		],
		[
			-11,
			29
		],
		[
			0,
			71
		]
	],
	[
		[
			99678,
			77049
		],
		[
			5,
			24
		],
		[
			26,
			-29
		],
		[
			19,
			3
		],
		[
			27,
			-24
		],
		[
			4,
			-31
		],
		[
			24,
			-42
		],
		[
			27,
			-78
		],
		[
			25,
			-26
		],
		[
			11,
			-57
		],
		[
			44,
			-11
		],
		[
			21,
			-33
		],
		[
			-18,
			-19
		],
		[
			-9,
			14
		],
		[
			-29,
			-16
		],
		[
			-15,
			41
		],
		[
			-41,
			72
		],
		[
			-30,
			101
		],
		[
			-30,
			43
		],
		[
			-17,
			-8
		],
		[
			-22,
			25
		],
		[
			-22,
			51
		]
	],
	[
		[
			99628,
			77446
		],
		[
			9,
			11
		],
		[
			20,
			-16
		],
		[
			11,
			-33
		],
		[
			-14,
			-49
		],
		[
			-10,
			-4
		],
		[
			-16,
			91
		]
	],
	[
		[
			99570,
			77271
		],
		[
			19,
			-7
		],
		[
			21,
			-67
		],
		[
			-22,
			15
		],
		[
			-18,
			59
		]
	],
	[
		[
			99530,
			77510
		],
		[
			7,
			22
		],
		[
			17,
			-22
		],
		[
			3,
			-34
		],
		[
			-17,
			-20
		],
		[
			-10,
			54
		]
	],
	[
		[
			99282,
			77351
		],
		[
			24,
			27
		],
		[
			15,
			50
		],
		[
			39,
			26
		],
		[
			6,
			63
		],
		[
			16,
			96
		],
		[
			11,
			18
		],
		[
			20,
			-52
		],
		[
			-12,
			-32
		],
		[
			-8,
			-57
		],
		[
			-20,
			-53
		],
		[
			21,
			-18
		],
		[
			0,
			-35
		],
		[
			-13,
			-10
		],
		[
			-42,
			17
		],
		[
			-17,
			-31
		],
		[
			-4,
			-70
		],
		[
			-11,
			2
		],
		[
			-25,
			40
		],
		[
			0,
			19
		]
	],
	[
		[
			98911,
			77903
		],
		[
			26,
			-13
		],
		[
			-18,
			-27
		],
		[
			-8,
			40
		]
	],
	[
		[
			98408,
			78327
		],
		[
			22,
			-8
		],
		[
			3,
			-26
		],
		[
			-24,
			15
		],
		[
			-1,
			19
		]
	],
	[
		[
			98376,
			78346
		],
		[
			14,
			-8
		],
		[
			0,
			-29
		],
		[
			-14,
			37
		]
	],
	[
		[
			98352,
			78374
		],
		[
			20,
			-27
		],
		[
			-12,
			-2
		],
		[
			-8,
			29
		]
	],
	[
		[
			98210,
			77943
		],
		[
			6,
			31
		],
		[
			19,
			27
		],
		[
			23,
			-6
		],
		[
			26,
			67
		],
		[
			41,
			5
		],
		[
			-17,
			-40
		],
		[
			-5,
			-37
		],
		[
			10,
			-104
		],
		[
			-21,
			0
		],
		[
			-17,
			52
		],
		[
			-35,
			-19
		],
		[
			-30,
			24
		]
	],
	[
		[
			97960,
			78551
		],
		[
			47,
			86
		],
		[
			33,
			11
		],
		[
			100,
			-20
		],
		[
			29,
			-63
		],
		[
			24,
			-15
		],
		[
			35,
			-94
		],
		[
			2,
			-18
		],
		[
			-35,
			-8
		],
		[
			-21,
			38
		],
		[
			-17,
			-71
		],
		[
			-9,
			-13
		],
		[
			-38,
			15
		],
		[
			-26,
			-41
		],
		[
			-27,
			32
		],
		[
			-12,
			40
		],
		[
			-3,
			63
		],
		[
			-32,
			56
		],
		[
			-35,
			-24
		],
		[
			-15,
			26
		]
	],
	[
		[
			13347,
			81071
		],
		[
			9,
			23
		],
		[
			10,
			-28
		],
		[
			-5,
			-52
		],
		[
			-16,
			34
		],
		[
			2,
			23
		]
	],
	[
		[
			13279,
			80906
		],
		[
			61,
			56
		],
		[
			7,
			-80
		],
		[
			13,
			-14
		],
		[
			-20,
			-68
		],
		[
			-24,
			-1
		],
		[
			-33,
			63
		],
		[
			-4,
			44
		]
	],
	[
		[
			13241,
			80901
		],
		[
			26,
			65
		],
		[
			8,
			-25
		],
		[
			-26,
			-58
		],
		[
			-8,
			18
		]
	],
	[
		[
			13234,
			81005
		],
		[
			16,
			62
		],
		[
			-2,
			43
		],
		[
			13,
			20
		],
		[
			-14,
			43
		],
		[
			-2,
			70
		],
		[
			5,
			39
		],
		[
			11,
			9
		],
		[
			19,
			-32
		],
		[
			5,
			-35
		],
		[
			13,
			-7
		],
		[
			17,
			-40
		],
		[
			0,
			-165
		],
		[
			-9,
			-34
		],
		[
			-27,
			-2
		],
		[
			-13,
			32
		],
		[
			-23,
			-36
		],
		[
			-9,
			33
		]
	],
	[
		[
			13172,
			81388
		],
		[
			4,
			66
		],
		[
			6,
			1
		],
		[
			52,
			-135
		],
		[
			-12,
			-28
		],
		[
			-1,
			-68
		],
		[
			-15,
			-111
		],
		[
			-23,
			74
		],
		[
			-9,
			113
		],
		[
			-2,
			88
		]
	],
	[
		[
			12999,
			82714
		],
		[
			4,
			48
		],
		[
			9,
			-30
		],
		[
			-13,
			-18
		]
	],
	[
		[
			12979,
			82569
		],
		[
			2,
			29
		],
		[
			21,
			40
		],
		[
			21,
			-38
		],
		[
			-1,
			-22
		],
		[
			-24,
			-37
		],
		[
			-19,
			28
		]
	],
	[
		[
			12954,
			82690
		],
		[
			20,
			33
		],
		[
			17,
			52
		],
		[
			-5,
			-50
		],
		[
			-18,
			-75
		],
		[
			-14,
			40
		]
	],
	[
		[
			12888,
			80934
		],
		[
			18,
			6
		],
		[
			-4,
			-53
		],
		[
			-14,
			47
		]
	],
	[
		[
			12850,
			82395
		],
		[
			7,
			53
		],
		[
			10,
			-24
		],
		[
			22,
			-97
		],
		[
			10,
			-68
		],
		[
			-13,
			-15
		],
		[
			-21,
			61
		],
		[
			-9,
			4
		],
		[
			-6,
			86
		]
	],
	[
		[
			12838,
			82543
		],
		[
			18,
			86
		],
		[
			21,
			30
		],
		[
			30,
			-20
		],
		[
			24,
			22
		],
		[
			28,
			-42
		],
		[
			4,
			-36
		],
		[
			-18,
			-53
		],
		[
			6,
			-82
		],
		[
			-16,
			-19
		],
		[
			-44,
			-22
		],
		[
			-23,
			65
		],
		[
			-24,
			29
		],
		[
			-6,
			42
		]
	],
	[
		[
			12768,
			81460
		],
		[
			21,
			27
		],
		[
			-2,
			-46
		],
		[
			-16,
			-11
		],
		[
			-3,
			30
		]
	],
	[
		[
			12700,
			80811
		],
		[
			9,
			0
		],
		[
			10,
			-128
		],
		[
			-15,
			29
		],
		[
			-4,
			99
		]
	],
	[
		[
			12674,
			81692
		],
		[
			9,
			23
		],
		[
			1,
			61
		],
		[
			20,
			-30
		],
		[
			1,
			-32
		],
		[
			-22,
			-72
		],
		[
			-9,
			50
		]
	],
	[
		[
			12659,
			81749
		],
		[
			12,
			9
		],
		[
			-1,
			-36
		],
		[
			-11,
			27
		]
	],
	[
		[
			12637,
			81497
		],
		[
			8,
			92
		],
		[
			8,
			25
		],
		[
			32,
			-9
		],
		[
			10,
			-16
		],
		[
			-2,
			-35
		],
		[
			-16,
			-42
		],
		[
			8,
			-16
		],
		[
			20,
			40
		],
		[
			5,
			43
		],
		[
			13,
			-19
		],
		[
			19,
			68
		],
		[
			19,
			-2
		],
		[
			16,
			-39
		],
		[
			-5,
			-60
		],
		[
			-15,
			-35
		],
		[
			-19,
			15
		],
		[
			-13,
			-35
		],
		[
			17,
			-22
		],
		[
			-2,
			-37
		],
		[
			-22,
			-21
		],
		[
			-22,
			-50
		],
		[
			-9,
			-97
		],
		[
			-23,
			78
		],
		[
			17,
			61
		],
		[
			-1,
			78
		],
		[
			-29,
			51
		],
		[
			-14,
			-16
		]
	],
	[
		[
			12629,
			82086
		],
		[
			11,
			22
		],
		[
			24,
			102
		],
		[
			28,
			10
		],
		[
			11,
			20
		],
		[
			-22,
			13
		],
		[
			-1,
			47
		],
		[
			15,
			-22
		],
		[
			9,
			34
		],
		[
			-36,
			62
		],
		[
			14,
			29
		],
		[
			-10,
			86
		],
		[
			23,
			49
		],
		[
			45,
			-24
		],
		[
			71,
			-17
		],
		[
			24,
			-82
		],
		[
			11,
			-73
		],
		[
			-5,
			-69
		],
		[
			14,
			-6
		],
		[
			13,
			-68
		],
		[
			17,
			-48
		],
		[
			17,
			5
		],
		[
			57,
			-119
		],
		[
			12,
			-52
		],
		[
			33,
			-111
		],
		[
			3,
			-126
		],
		[
			29,
			-29
		],
		[
			8,
			-82
		],
		[
			8,
			-32
		],
		[
			31,
			-50
		],
		[
			13,
			-58
		],
		[
			-10,
			-6
		],
		[
			-19,
			46
		],
		[
			-75,
			98
		],
		[
			-3,
			-31
		],
		[
			-23,
			-74
		],
		[
			11,
			-8
		],
		[
			14,
			47
		],
		[
			8,
			-19
		],
		[
			23,
			10
		],
		[
			5,
			-37
		],
		[
			20,
			-13
		],
		[
			10,
			-29
		],
		[
			-38,
			-14
		],
		[
			8,
			-36
		],
		[
			32,
			21
		],
		[
			14,
			-52
		],
		[
			16,
			-14
		],
		[
			11,
			-87
		],
		[
			8,
			-9
		],
		[
			-12,
			-49
		],
		[
			-20,
			9
		],
		[
			2,
			-32
		],
		[
			22,
			-22
		],
		[
			11,
			8
		],
		[
			3,
			46
		],
		[
			14,
			36
		],
		[
			9,
			-21
		],
		[
			5,
			-91
		],
		[
			-15,
			-34
		],
		[
			4,
			-36
		],
		[
			-22,
			-94
		],
		[
			-29,
			-40
		],
		[
			18,
			-23
		],
		[
			27,
			59
		],
		[
			15,
			-10
		],
		[
			0,
			-203
		],
		[
			7,
			-72
		],
		[
			-20,
			-105
		],
		[
			-37,
			-9
		],
		[
			-26,
			48
		],
		[
			-14,
			-19
		],
		[
			-17,
			38
		],
		[
			-1,
			37
		],
		[
			-38,
			-2
		],
		[
			17,
			53
		],
		[
			27,
			-10
		],
		[
			1,
			39
		],
		[
			-19,
			42
		],
		[
			-19,
			13
		],
		[
			-35,
			78
		],
		[
			9,
			38
		],
		[
			10,
			115
		],
		[
			-15,
			9
		],
		[
			-11,
			-58
		],
		[
			7,
			101
		],
		[
			8,
			28
		],
		[
			-11,
			39
		],
		[
			-5,
			-55
		],
		[
			-27,
			-21
		],
		[
			14,
			-103
		],
		[
			-18,
			-58
		],
		[
			-47,
			56
		],
		[
			-4,
			35
		],
		[
			17,
			58
		],
		[
			-18,
			100
		],
		[
			-20,
			-5
		],
		[
			-10,
			50
		],
		[
			-21,
			3
		],
		[
			12,
			-78
		],
		[
			18,
			-65
		],
		[
			6,
			-72
		],
		[
			-7,
			-36
		],
		[
			15,
			-17
		],
		[
			20,
			-145
		],
		[
			24,
			-26
		],
		[
			-4,
			58
		],
		[
			24,
			18
		],
		[
			28,
			-65
		],
		[
			4,
			-124
		],
		[
			-14,
			-16
		],
		[
			-18,
			74
		],
		[
			-7,
			-7
		],
		[
			23,
			-170
		],
		[
			-29,
			0
		],
		[
			-26,
			32
		],
		[
			-2,
			60
		],
		[
			-20,
			40
		],
		[
			-49,
			177
		],
		[
			-10,
			22
		],
		[
			-2,
			84
		],
		[
			-12,
			10
		],
		[
			-8,
			61
		],
		[
			29,
			8
		],
		[
			-27,
			33
		],
		[
			3,
			119
		],
		[
			-33,
			-28
		],
		[
			-10,
			26
		],
		[
			-18,
			-19
		],
		[
			-9,
			42
		],
		[
			6,
			84
		],
		[
			33,
			30
		],
		[
			11,
			-63
		],
		[
			17,
			20
		],
		[
			-13,
			29
		],
		[
			6,
			39
		],
		[
			14,
			20
		],
		[
			14,
			-14
		],
		[
			22,
			44
		],
		[
			-29,
			96
		],
		[
			14,
			12
		],
		[
			-16,
			32
		],
		[
			4,
			66
		],
		[
			-24,
			-21
		],
		[
			-49,
			87
		],
		[
			-4,
			28
		],
		[
			16,
			-1
		],
		[
			-9,
			50
		],
		[
			3,
			35
		],
		[
			-27,
			18
		],
		[
			6,
			-57
		],
		[
			-10,
			-13
		],
		[
			-32,
			39
		],
		[
			-16,
			58
		],
		[
			12,
			52
		],
		[
			28,
			14
		],
		[
			37,
			-54
		],
		[
			28,
			35
		],
		[
			-17,
			67
		],
		[
			-18,
			16
		],
		[
			-12,
			-20
		],
		[
			-9,
			17
		],
		[
			8,
			30
		],
		[
			-2,
			42
		],
		[
			7,
			63
		],
		[
			-5,
			16
		],
		[
			-13,
			-47
		],
		[
			-27,
			-65
		],
		[
			-22,
			-33
		],
		[
			-23,
			38
		],
		[
			-5,
			45
		]
	],
	[
		[
			12611,
			83642
		],
		[
			15,
			25
		],
		[
			14,
			-33
		],
		[
			-27,
			-31
		],
		[
			-2,
			39
		]
	],
	[
		[
			12594,
			82026
		],
		[
			14,
			28
		],
		[
			11,
			-6
		],
		[
			4,
			-52
		],
		[
			-8,
			-48
		],
		[
			-10,
			3
		],
		[
			-11,
			75
		]
	],
	[
		[
			12476,
			82024
		],
		[
			28,
			22
		],
		[
			1,
			-43
		],
		[
			31,
			33
		],
		[
			8,
			75
		],
		[
			7,
			-2
		],
		[
			-9,
			-101
		],
		[
			-22,
			-24
		],
		[
			-20,
			-56
		],
		[
			-18,
			17
		],
		[
			8,
			30
		],
		[
			-14,
			49
		]
	],
	[
		[
			12463,
			83115
		],
		[
			17,
			52
		],
		[
			16,
			17
		],
		[
			7,
			33
		],
		[
			33,
			-1
		],
		[
			1,
			26
		],
		[
			28,
			-40
		],
		[
			11,
			-83
		],
		[
			18,
			-54
		],
		[
			31,
			-2
		],
		[
			9,
			-21
		],
		[
			10,
			26
		],
		[
			-29,
			44
		],
		[
			-13,
			80
		],
		[
			-2,
			55
		],
		[
			-35,
			79
		],
		[
			11,
			53
		],
		[
			34,
			26
		],
		[
			51,
			-37
		],
		[
			25,
			-9
		],
		[
			47,
			-44
		],
		[
			31,
			-20
		],
		[
			7,
			14
		],
		[
			57,
			-11
		],
		[
			30,
			-74
		],
		[
			14,
			-82
		],
		[
			3,
			-56
		],
		[
			9,
			-23
		],
		[
			23,
			-11
		],
		[
			16,
			-48
		],
		[
			5,
			-46
		],
		[
			33,
			-52
		],
		[
			9,
			-64
		],
		[
			15,
			-34
		],
		[
			-31,
			-38
		],
		[
			-20,
			-42
		],
		[
			-26,
			-24
		],
		[
			-16,
			16
		],
		[
			-31,
			4
		],
		[
			-43,
			24
		],
		[
			5,
			-48
		],
		[
			-23,
			-51
		],
		[
			-40,
			25
		],
		[
			-19,
			29
		],
		[
			-12,
			-47
		],
		[
			-15,
			-20
		],
		[
			-25,
			-2
		],
		[
			-17,
			15
		],
		[
			-3,
			87
		],
		[
			-11,
			32
		],
		[
			-30,
			-64
		],
		[
			13,
			-29
		],
		[
			-2,
			-90
		],
		[
			-23,
			-3
		],
		[
			-2,
			-31
		],
		[
			10,
			-51
		],
		[
			-11,
			-51
		],
		[
			-2,
			-62
		],
		[
			-17,
			-50
		],
		[
			4,
			-39
		],
		[
			-9,
			-64
		],
		[
			-10,
			-11
		],
		[
			-25,
			15
		],
		[
			-14,
			-103
		],
		[
			-15,
			19
		],
		[
			-12,
			52
		],
		[
			-7,
			63
		],
		[
			-1,
			109
		],
		[
			-10,
			87
		],
		[
			2,
			75
		],
		[
			14,
			48
		],
		[
			-3,
			57
		],
		[
			15,
			101
		],
		[
			-12,
			28
		],
		[
			-22,
			-1
		],
		[
			5,
			77
		],
		[
			-20,
			56
		],
		[
			-8,
			75
		],
		[
			2,
			43
		],
		[
			-5,
			91
		]
	],
	[
		[
			12311,
			84926
		],
		[
			43,
			-96
		],
		[
			7,
			-47
		],
		[
			14,
			-9
		],
		[
			8,
			-130
		],
		[
			19,
			1
		],
		[
			21,
			38
		],
		[
			11,
			-23
		],
		[
			20,
			-2
		],
		[
			21,
			-29
		],
		[
			54,
			13
		],
		[
			-3,
			-89
		],
		[
			25,
			-75
		],
		[
			2,
			-52
		],
		[
			21,
			-52
		],
		[
			14,
			-87
		],
		[
			17,
			-55
		],
		[
			2,
			-142
		],
		[
			21,
			-60
		],
		[
			4,
			-65
		],
		[
			-9,
			-2
		],
		[
			-5,
			47
		],
		[
			-38,
			120
		],
		[
			-10,
			115
		],
		[
			-19,
			37
		],
		[
			-9,
			53
		],
		[
			-21,
			0
		],
		[
			26,
			-101
		],
		[
			4,
			-34
		],
		[
			-13,
			-23
		],
		[
			35,
			-121
		],
		[
			23,
			-49
		],
		[
			-2,
			-62
		],
		[
			24,
			-113
		],
		[
			-19,
			6
		],
		[
			15,
			-102
		],
		[
			0,
			-27
		],
		[
			-25,
			-62
		],
		[
			-20,
			26
		],
		[
			-17,
			-1
		],
		[
			4,
			-34
		],
		[
			-21,
			-104
		],
		[
			-38,
			-83
		],
		[
			-24,
			-25
		],
		[
			-2,
			-33
		],
		[
			-31,
			-65
		],
		[
			-29,
			3
		],
		[
			-9,
			89
		],
		[
			-4,
			135
		],
		[
			21,
			80
		],
		[
			15,
			23
		],
		[
			-16,
			31
		],
		[
			-1,
			69
		],
		[
			14,
			6
		],
		[
			12,
			-39
		],
		[
			6,
			23
		],
		[
			-40,
			141
		],
		[
			-1,
			58
		],
		[
			-18,
			60
		],
		[
			-5,
			82
		],
		[
			-11,
			43
		],
		[
			8,
			125
		],
		[
			-12,
			81
		],
		[
			-3,
			95
		],
		[
			-11,
			91
		],
		[
			4,
			44
		],
		[
			-20,
			93
		],
		[
			-17,
			45
		],
		[
			-9,
			77
		],
		[
			-6,
			101
		],
		[
			3,
			42
		]
	],
	[
		[
			12292,
			85061
		],
		[
			35,
			-45
		],
		[
			27,
			-125
		],
		[
			-10,
			-5
		],
		[
			-22,
			115
		],
		[
			-23,
			19
		],
		[
			-7,
			41
		]
	],
	[
		[
			12202,
			85643
		],
		[
			15,
			-71
		],
		[
			0,
			-46
		],
		[
			-10,
			29
		],
		[
			-5,
			88
		]
	],
	[
		[
			12106,
			83714
		],
		[
			16,
			11
		],
		[
			1,
			26
		],
		[
			28,
			65
		],
		[
			-4,
			68
		],
		[
			36,
			64
		],
		[
			18,
			-12
		],
		[
			25,
			-85
		],
		[
			15,
			10
		],
		[
			18,
			-58
		],
		[
			23,
			-24
		],
		[
			38,
			4
		],
		[
			22,
			-14
		],
		[
			12,
			-79
		],
		[
			-2,
			-49
		],
		[
			-20,
			35
		],
		[
			-19,
			-2
		],
		[
			-1,
			-22
		],
		[
			21,
			-25
		],
		[
			11,
			-46
		],
		[
			29,
			-278
		],
		[
			-1,
			-71
		],
		[
			12,
			-56
		],
		[
			0,
			-58
		],
		[
			18,
			-142
		],
		[
			5,
			-107
		],
		[
			-5,
			-112
		],
		[
			-11,
			1
		],
		[
			8,
			-81
		],
		[
			3,
			-240
		],
		[
			-9,
			-111
		],
		[
			-11,
			6
		],
		[
			-28,
			70
		],
		[
			-10,
			86
		],
		[
			-21,
			59
		],
		[
			-40,
			212
		],
		[
			4,
			48
		],
		[
			22,
			23
		],
		[
			-18,
			30
		],
		[
			-26,
			-31
		],
		[
			-14,
			88
		],
		[
			-11,
			-15
		],
		[
			-17,
			42
		],
		[
			-12,
			55
		],
		[
			2,
			34
		],
		[
			-14,
			-22
		],
		[
			-10,
			24
		],
		[
			-30,
			2
		],
		[
			-19,
			96
		],
		[
			19,
			3
		],
		[
			10,
			-29
		],
		[
			10,
			13
		],
		[
			-3,
			105
		],
		[
			19,
			53
		],
		[
			6,
			38
		],
		[
			-39,
			86
		],
		[
			24,
			63
		],
		[
			-4,
			22
		],
		[
			14,
			35
		],
		[
			4,
			53
		],
		[
			-33,
			16
		],
		[
			-21,
			-28
		],
		[
			-14,
			79
		],
		[
			-26,
			72
		]
	],
	[
		[
			12097,
			84881
		],
		[
			16,
			18
		],
		[
			19,
			-7
		],
		[
			16,
			-52
		],
		[
			-29,
			-6
		],
		[
			-22,
			47
		]
	],
	[
		[
			12062,
			83572
		],
		[
			4,
			48
		],
		[
			-3,
			66
		],
		[
			25,
			9
		],
		[
			34,
			-62
		],
		[
			15,
			-74
		],
		[
			12,
			-19
		],
		[
			17,
			30
		],
		[
			23,
			-10
		],
		[
			-16,
			-82
		],
		[
			-24,
			-14
		],
		[
			-27,
			-161
		],
		[
			-12,
			6
		],
		[
			-40,
			-30
		],
		[
			-9,
			8
		],
		[
			3,
			102
		],
		[
			25,
			47
		],
		[
			1,
			50
		],
		[
			-22,
			4
		],
		[
			2,
			29
		],
		[
			-13,
			31
		],
		[
			5,
			22
		]
	],
	[
		[
			11978,
			85151
		],
		[
			9,
			14
		],
		[
			7,
			-59
		],
		[
			-16,
			45
		]
	],
	[
		[
			11978,
			84786
		],
		[
			30,
			41
		],
		[
			3,
			-53
		],
		[
			-16,
			-19
		],
		[
			-17,
			31
		]
	],
	[
		[
			11861,
			84371
		],
		[
			5,
			174
		],
		[
			16,
			33
		],
		[
			8,
			-9
		],
		[
			29,
			60
		],
		[
			3,
			51
		],
		[
			-12,
			92
		],
		[
			32,
			-2
		],
		[
			0,
			-54
		],
		[
			12,
			-60
		],
		[
			28,
			61
		],
		[
			29,
			-6
		],
		[
			17,
			-20
		],
		[
			17,
			49
		],
		[
			36,
			50
		],
		[
			14,
			-55
		],
		[
			41,
			-30
		],
		[
			25,
			-53
		],
		[
			-12,
			-78
		],
		[
			-31,
			-76
		],
		[
			4,
			-49
		],
		[
			12,
			-5
		],
		[
			8,
			60
		],
		[
			32,
			108
		],
		[
			15,
			12
		],
		[
			34,
			-55
		],
		[
			46,
			-10
		],
		[
			11,
			-32
		],
		[
			29,
			-16
		],
		[
			15,
			-79
		],
		[
			-4,
			-67
		],
		[
			-22,
			-44
		],
		[
			-37,
			49
		],
		[
			-10,
			-8
		],
		[
			12,
			-40
		],
		[
			18,
			-18
		],
		[
			33,
			-75
		],
		[
			-21,
			-29
		],
		[
			-25,
			-2
		],
		[
			4,
			-28
		],
		[
			21,
			-13
		],
		[
			23,
			24
		],
		[
			7,
			-95
		],
		[
			14,
			-69
		],
		[
			12,
			-143
		],
		[
			-14,
			-42
		],
		[
			-42,
			-11
		],
		[
			-17,
			12
		],
		[
			-44,
			95
		],
		[
			-65,
			99
		],
		[
			-27,
			50
		],
		[
			-22,
			-26
		],
		[
			-9,
			29
		],
		[
			-4,
			-32
		],
		[
			30,
			-55
		],
		[
			22,
			-8
		],
		[
			-21,
			-31
		],
		[
			6,
			-25
		],
		[
			0,
			-72
		],
		[
			-9,
			-50
		],
		[
			-31,
			-87
		],
		[
			-51,
			47
		],
		[
			-1,
			38
		],
		[
			-42,
			85
		],
		[
			-20,
			90
		],
		[
			-12,
			-38
		],
		[
			-19,
			43
		],
		[
			-10,
			79
		],
		[
			4,
			25
		],
		[
			-18,
			86
		],
		[
			2,
			24
		],
		[
			-16,
			57
		],
		[
			-26,
			30
		],
		[
			-7,
			49
		],
		[
			-25,
			36
		]
	],
	[
		[
			9331,
			87212
		],
		[
			28,
			-14
		],
		[
			12,
			-44
		],
		[
			-27,
			-9
		],
		[
			-13,
			67
		]
	],
	[
		[
			9232,
			87245
		],
		[
			16,
			14
		],
		[
			58,
			-26
		],
		[
			-3,
			-31
		],
		[
			-21,
			-10
		],
		[
			-50,
			53
		]
	],
	[
		[
			8867,
			87809
		],
		[
			26,
			35
		],
		[
			27,
			3
		],
		[
			15,
			-16
		],
		[
			-18,
			-53
		],
		[
			-50,
			31
		]
	],
	[
		[
			8817,
			87545
		],
		[
			4,
			86
		],
		[
			28,
			16
		],
		[
			21,
			-89
		],
		[
			-11,
			-44
		],
		[
			-37,
			-10
		],
		[
			-5,
			41
		]
	],
	[
		[
			8816,
			87079
		],
		[
			2,
			14
		],
		[
			43,
			47
		],
		[
			1,
			-36
		],
		[
			-40,
			-59
		],
		[
			-6,
			34
		]
	],
	[
		[
			8698,
			86532
		],
		[
			8,
			21
		],
		[
			3,
			71
		],
		[
			23,
			12
		],
		[
			-3,
			42
		],
		[
			21,
			54
		],
		[
			16,
			7
		],
		[
			-3,
			41
		],
		[
			30,
			34
		],
		[
			9,
			30
		],
		[
			43,
			75
		],
		[
			22,
			118
		],
		[
			27,
			44
		],
		[
			-3,
			40
		],
		[
			10,
			71
		],
		[
			27,
			34
		],
		[
			4,
			-43
		],
		[
			24,
			2
		],
		[
			-17,
			-51
		],
		[
			9,
			-17
		],
		[
			24,
			28
		],
		[
			8,
			-22
		],
		[
			-11,
			-37
		],
		[
			-62,
			-118
		],
		[
			-49,
			-129
		],
		[
			-8,
			-80
		],
		[
			-33,
			-60
		],
		[
			30,
			-57
		],
		[
			-19,
			-42
		],
		[
			-23,
			-8
		],
		[
			-22,
			15
		],
		[
			-17,
			-57
		],
		[
			-9,
			6
		],
		[
			-45,
			-47
		],
		[
			-14,
			23
		]
	],
	[
		[
			8692,
			87068
		],
		[
			44,
			270
		],
		[
			11,
			-41
		],
		[
			12,
			13
		],
		[
			-4,
			66
		],
		[
			44,
			84
		],
		[
			0,
			-54
		],
		[
			-12,
			-32
		],
		[
			-3,
			-82
		],
		[
			-20,
			-37
		],
		[
			20,
			-42
		],
		[
			-24,
			-97
		],
		[
			2,
			-46
		],
		[
			-17,
			-104
		],
		[
			-24,
			45
		],
		[
			-3,
			25
		],
		[
			-25,
			7
		],
		[
			-1,
			25
		]
	],
	[
		[
			8672,
			87628
		],
		[
			15,
			31
		],
		[
			17,
			-19
		],
		[
			17,
			-48
		],
		[
			-24,
			-45
		],
		[
			-25,
			81
		]
	],
	[
		[
			17950,
			55027
		],
		[
			5,
			31
		],
		[
			24,
			-13
		],
		[
			25,
			26
		],
		[
			-2,
			40
		],
		[
			18,
			63
		],
		[
			1,
			79
		],
		[
			-15,
			136
		],
		[
			-16,
			8
		],
		[
			-7,
			-13
		],
		[
			-13,
			25
		],
		[
			-3,
			-17
		],
		[
			-14,
			68
		],
		[
			7,
			67
		],
		[
			2,
			142
		],
		[
			-15,
			41
		],
		[
			9,
			65
		],
		[
			-8,
			51
		],
		[
			19,
			9
		],
		[
			28,
			138
		],
		[
			9,
			24
		],
		[
			-4,
			46
		],
		[
			4,
			110
		],
		[
			8,
			12
		],
		[
			-2,
			74
		],
		[
			-7,
			64
		],
		[
			1,
			51
		],
		[
			6,
			6
		],
		[
			-2,
			55
		],
		[
			-7,
			20
		],
		[
			28,
			116
		],
		[
			0,
			69
		],
		[
			8,
			28
		],
		[
			23,
			29
		],
		[
			10,
			40
		],
		[
			17,
			21
		],
		[
			1,
			19
		],
		[
			25,
			65
		],
		[
			-1,
			49
		],
		[
			-11,
			54
		],
		[
			-14,
			19
		],
		[
			-31,
			100
		],
		[
			-13,
			7
		],
		[
			2,
			58
		],
		[
			-26,
			239
		],
		[
			-23,
			63
		],
		[
			-7,
			69
		],
		[
			-16,
			57
		],
		[
			1,
			147
		]
	],
	[
		[
			17974,
			57684
		],
		[
			6,
			95
		],
		[
			-10,
			22
		],
		[
			21,
			43
		],
		[
			0,
			72
		],
		[
			-9,
			178
		],
		[
			-6,
			65
		],
		[
			-11,
			47
		],
		[
			-4,
			58
		],
		[
			6,
			36
		],
		[
			0,
			103
		],
		[
			-9,
			38
		],
		[
			3,
			39
		],
		[
			-7,
			31
		],
		[
			3,
			51
		],
		[
			-5,
			59
		],
		[
			4,
			56
		],
		[
			9,
			24
		],
		[
			-10,
			31
		],
		[
			-12,
			97
		],
		[
			4,
			43
		],
		[
			-7,
			80
		],
		[
			25,
			31
		],
		[
			9,
			29
		],
		[
			5,
			-14
		],
		[
			12,
			25
		],
		[
			17,
			-1
		],
		[
			2,
			-25
		],
		[
			24,
			19
		],
		[
			13,
			-3
		],
		[
			18,
			-71
		],
		[
			-2,
			-28
		],
		[
			21,
			-51
		],
		[
			24,
			11
		],
		[
			24,
			183
		],
		[
			5,
			15
		],
		[
			1,
			230
		],
		[
			-2,
			272
		],
		[
			0,
			437
		]
	],
	[
		[
			18136,
			60011
		],
		[
			200,
			0
		],
		[
			222,
			0
		],
		[
			313,
			1
		],
		[
			97,
			1
		],
		[
			160,
			2
		],
		[
			6,
			-7
		],
		[
			235,
			0
		],
		[
			162,
			1
		]
	],
	[
		[
			19531,
			60009
		],
		[
			0,
			-1691
		],
		[
			-1,
			-237
		],
		[
			1,
			-30
		],
		[
			0,
			-925
		],
		[
			-1,
			-608
		],
		[
			1,
			-145
		],
		[
			-1,
			-113
		],
		[
			0,
			-2847
		]
	],
	[
		[
			19530,
			53413
		],
		[
			-64,
			2
		],
		[
			-201,
			-1
		],
		[
			-128,
			-1
		],
		[
			-172,
			0
		],
		[
			-359,
			476
		],
		[
			-212,
			269
		],
		[
			-102,
			136
		],
		[
			-368,
			471
		],
		[
			5,
			66
		],
		[
			-5,
			17
		],
		[
			1,
			60
		],
		[
			8,
			16
		],
		[
			17,
			103
		]
	],
	[
		[
			19530,
			64667
		],
		[
			242,
			0
		],
		[
			154,
			2
		],
		[
			327,
			0
		],
		[
			66,
			-5
		],
		[
			137,
			-1
		],
		[
			242,
			1
		],
		[
			7,
			2
		],
		[
			217,
			2
		]
	],
	[
		[
			20922,
			64668
		],
		[
			282,
			1
		],
		[
			135,
			0
		],
		[
			140,
			0
		],
		[
			0,
			-1163
		]
	],
	[
		[
			21479,
			63506
		],
		[
			1,
			-381
		],
		[
			0,
			-434
		],
		[
			1,
			-193
		],
		[
			0,
			-1270
		],
		[
			1,
			-137
		],
		[
			0,
			-1089
		]
	],
	[
		[
			21482,
			60002
		],
		[
			-183,
			3
		],
		[
			-22,
			5
		],
		[
			-62,
			1
		]
	],
	[
		[
			21215,
			60011
		],
		[
			-204,
			-3
		],
		[
			-169,
			-5
		],
		[
			-184,
			0
		],
		[
			-34,
			2
		],
		[
			-301,
			-1
		],
		[
			-186,
			-2
		],
		[
			-2,
			9
		],
		[
			-152,
			-1
		],
		[
			-230,
			-1
		],
		[
			-222,
			0
		]
	],
	[
		[
			19531,
			60009
		],
		[
			0,
			583
		],
		[
			1,
			36
		],
		[
			0,
			738
		],
		[
			-5,
			129
		],
		[
			0,
			517
		],
		[
			2,
			216
		],
		[
			0,
			1857
		],
		[
			1,
			46
		],
		[
			0,
			536
		]
	],
	[
		[
			27414,
			45876
		],
		[
			14,
			60
		],
		[
			5,
			-33
		],
		[
			-14,
			-44
		],
		[
			-5,
			17
		]
	],
	[
		[
			27386,
			45813
		],
		[
			9,
			39
		],
		[
			11,
			4
		],
		[
			-5,
			-33
		],
		[
			-15,
			-10
		]
	],
	[
		[
			27310,
			45701
		],
		[
			52,
			90
		],
		[
			6,
			-30
		],
		[
			-45,
			-80
		],
		[
			-13,
			20
		]
	],
	[
		[
			27118,
			45540
		],
		[
			19,
			106
		],
		[
			20,
			46
		],
		[
			25,
			43
		],
		[
			3,
			23
		],
		[
			36,
			66
		],
		[
			38,
			-67
		],
		[
			4,
			-52
		],
		[
			14,
			-43
		],
		[
			-4,
			-11
		],
		[
			-40,
			-48
		],
		[
			-3,
			27
		],
		[
			-27,
			-5
		],
		[
			-3,
			-24
		],
		[
			-46,
			-73
		],
		[
			-36,
			-15
		],
		[
			0,
			27
		]
	],
	[
		[
			27062,
			45510
		],
		[
			39,
			24
		],
		[
			-10,
			-43
		],
		[
			-17,
			-14
		],
		[
			-13,
			8
		],
		[
			1,
			25
		]
	],
	[
		[
			27020,
			45533
		],
		[
			6,
			35
		],
		[
			12,
			-10
		],
		[
			-5,
			-41
		],
		[
			-13,
			16
		]
	],
	[
		[
			26992,
			48019
		],
		[
			5,
			-18
		],
		[
			19,
			-211
		],
		[
			8,
			-28
		],
		[
			17,
			-26
		],
		[
			7,
			17
		],
		[
			14,
			-21
		],
		[
			-14,
			-31
		],
		[
			-9,
			-1
		],
		[
			-21,
			50
		],
		[
			-7,
			28
		],
		[
			-13,
			115
		],
		[
			-6,
			76
		],
		[
			0,
			50
		]
	],
	[
		[
			26806,
			45614
		],
		[
			15,
			13
		],
		[
			4,
			-23
		],
		[
			-20,
			-10
		],
		[
			1,
			20
		]
	],
	[
		[
			26322,
			51623
		],
		[
			29,
			47
		],
		[
			0,
			-29
		],
		[
			-16,
			-37
		],
		[
			-11,
			-6
		],
		[
			-2,
			25
		]
	],
	[
		[
			26229,
			53027
		],
		[
			6,
			-79
		],
		[
			11,
			-52
		],
		[
			2,
			-83
		],
		[
			6,
			-75
		],
		[
			14,
			-48
		],
		[
			136,
			-25
		],
		[
			261,
			-56
		],
		[
			206,
			-51
		],
		[
			135,
			-34
		],
		[
			-5,
			-14
		],
		[
			2,
			-57
		],
		[
			7,
			-26
		],
		[
			-3,
			-71
		],
		[
			11,
			-76
		],
		[
			37,
			13
		],
		[
			0,
			75
		],
		[
			6,
			47
		],
		[
			3,
			119
		],
		[
			-12,
			91
		],
		[
			4,
			60
		],
		[
			-1,
			49
		],
		[
			8,
			16
		],
		[
			-4,
			24
		],
		[
			12,
			-8
		],
		[
			9,
			59
		],
		[
			15,
			-7
		],
		[
			7,
			-33
		],
		[
			17,
			-3
		],
		[
			18,
			-28
		],
		[
			7,
			-25
		],
		[
			33,
			-19
		],
		[
			17,
			-18
		],
		[
			14,
			15
		],
		[
			13,
			-19
		]
	],
	[
		[
			27221,
			52688
		],
		[
			4,
			-13
		],
		[
			-4,
			-113
		],
		[
			3,
			-92
		],
		[
			-4,
			-22
		],
		[
			10,
			-25
		],
		[
			4,
			-95
		],
		[
			1,
			-113
		],
		[
			23,
			-389
		],
		[
			13,
			-129
		],
		[
			0,
			-51
		],
		[
			28,
			-302
		],
		[
			32,
			-288
		],
		[
			29,
			-229
		],
		[
			65,
			-412
		],
		[
			38,
			-200
		],
		[
			4,
			-63
		],
		[
			10,
			-83
		],
		[
			-18,
			-57
		],
		[
			-4,
			-54
		],
		[
			-1,
			-87
		],
		[
			5,
			-130
		],
		[
			6,
			-96
		],
		[
			16,
			-145
		],
		[
			35,
			-269
		],
		[
			15,
			-166
		],
		[
			5,
			-84
		],
		[
			5,
			-29
		],
		[
			11,
			-140
		],
		[
			17,
			-152
		],
		[
			9,
			-66
		],
		[
			6,
			-94
		],
		[
			13,
			-109
		],
		[
			17,
			-258
		],
		[
			-1,
			-235
		],
		[
			-7,
			-175
		],
		[
			-5,
			-210
		],
		[
			-3,
			-37
		],
		[
			-8,
			-286
		],
		[
			0,
			-169
		],
		[
			-3,
			-80
		],
		[
			-7,
			-81
		],
		[
			0,
			-44
		],
		[
			-6,
			23
		],
		[
			3,
			51
		],
		[
			-5,
			20
		],
		[
			-16,
			-25
		],
		[
			-10,
			-102
		],
		[
			-6,
			-17
		],
		[
			-1,
			-64
		],
		[
			-8,
			-40
		],
		[
			-2,
			-78
		],
		[
			5,
			-33
		],
		[
			-2,
			-46
		],
		[
			6,
			-16
		],
		[
			-8,
			-53
		],
		[
			-8,
			-13
		],
		[
			-1,
			-49
		],
		[
			21,
			39
		],
		[
			25,
			194
		],
		[
			7,
			41
		],
		[
			0,
			-41
		],
		[
			-8,
			-83
		],
		[
			-34,
			-222
		],
		[
			-9,
			-82
		],
		[
			-25,
			-93
		],
		[
			-34,
			-139
		],
		[
			-24,
			-66
		],
		[
			-3,
			12
		],
		[
			34,
			122
		],
		[
			14,
			40
		],
		[
			7,
			53
		],
		[
			3,
			81
		],
		[
			5,
			32
		],
		[
			-6,
			23
		],
		[
			-9,
			-11
		],
		[
			-7,
			26
		],
		[
			-6,
			-18
		],
		[
			-34,
			-22
		],
		[
			-14,
			-41
		],
		[
			-9,
			-6
		],
		[
			-18,
			45
		],
		[
			-18,
			-13
		],
		[
			-7,
			-41
		],
		[
			-27,
			-18
		],
		[
			-23,
			-6
		],
		[
			-17,
			52
		],
		[
			-8,
			68
		],
		[
			2,
			79
		],
		[
			6,
			60
		],
		[
			6,
			-3
		],
		[
			-2,
			49
		],
		[
			-12,
			97
		],
		[
			-11,
			47
		],
		[
			2,
			34
		],
		[
			-8,
			62
		],
		[
			-11,
			32
		],
		[
			-5,
			85
		],
		[
			-6,
			18
		],
		[
			-11,
			-15
		],
		[
			-9,
			101
		],
		[
			-24,
			31
		],
		[
			-1,
			16
		],
		[
			-21,
			38
		],
		[
			-21,
			55
		],
		[
			-11,
			-13
		],
		[
			-8,
			-39
		],
		[
			-16,
			126
		],
		[
			-15,
			148
		],
		[
			-5,
			173
		],
		[
			-7,
			109
		],
		[
			-7,
			57
		],
		[
			-28,
			113
		],
		[
			-11,
			9
		],
		[
			-1,
			52
		],
		[
			-12,
			23
		],
		[
			0,
			-64
		],
		[
			-14,
			-11
		],
		[
			-1,
			66
		],
		[
			-8,
			113
		],
		[
			-12,
			51
		],
		[
			3,
			24
		],
		[
			13,
			-3
		],
		[
			9,
			-39
		],
		[
			11,
			159
		],
		[
			-2,
			86
		],
		[
			-8,
			14
		],
		[
			0,
			40
		],
		[
			8,
			10
		],
		[
			-4,
			31
		],
		[
			-12,
			-4
		],
		[
			-5,
			-33
		],
		[
			-11,
			-11
		],
		[
			8,
			-148
		],
		[
			-9,
			-20
		],
		[
			-20,
			-11
		],
		[
			-5,
			-50
		],
		[
			0,
			75
		],
		[
			-6,
			50
		],
		[
			-17,
			94
		],
		[
			-26,
			177
		],
		[
			-9,
			94
		],
		[
			-19,
			140
		],
		[
			-27,
			149
		],
		[
			-14,
			56
		],
		[
			-4,
			58
		],
		[
			-10,
			61
		],
		[
			10,
			-19
		],
		[
			1,
			-30
		],
		[
			15,
			30
		],
		[
			10,
			72
		],
		[
			12,
			28
		],
		[
			13,
			98
		],
		[
			13,
			34
		],
		[
			-2,
			23
		],
		[
			14,
			26
		],
		[
			11,
			84
		],
		[
			-5,
			75
		],
		[
			-22,
			21
		],
		[
			5,
			-113
		],
		[
			-22,
			30
		],
		[
			6,
			34
		],
		[
			-1,
			65
		],
		[
			-5,
			39
		],
		[
			-38,
			71
		],
		[
			1,
			-65
		],
		[
			-11,
			-28
		],
		[
			11,
			-37
		],
		[
			16,
			-6
		],
		[
			11,
			-110
		],
		[
			-10,
			-42
		],
		[
			0,
			-62
		],
		[
			-4,
			-27
		],
		[
			-21,
			-6
		],
		[
			-3,
			-32
		],
		[
			7,
			-38
		],
		[
			-9,
			-30
		],
		[
			-4,
			40
		],
		[
			2,
			83
		],
		[
			-14,
			85
		],
		[
			-9,
			26
		],
		[
			-8,
			58
		],
		[
			6,
			182
		],
		[
			-5,
			66
		],
		[
			-4,
			164
		],
		[
			9,
			1
		],
		[
			0,
			-93
		],
		[
			4,
			-89
		],
		[
			9,
			-7
		],
		[
			-4,
			153
		],
		[
			9,
			37
		],
		[
			1,
			41
		],
		[
			8,
			44
		],
		[
			0,
			38
		],
		[
			7,
			50
		],
		[
			0,
			39
		],
		[
			9,
			47
		],
		[
			1,
			91
		],
		[
			5,
			83
		],
		[
			-6,
			66
		],
		[
			2,
			56
		],
		[
			-13,
			29
		],
		[
			4,
			42
		],
		[
			-9,
			109
		],
		[
			12,
			64
		],
		[
			-21,
			110
		],
		[
			3,
			31
		],
		[
			-8,
			55
		],
		[
			-10,
			3
		],
		[
			5,
			33
		],
		[
			-1,
			49
		],
		[
			-7,
			13
		],
		[
			-47,
			23
		],
		[
			-9,
			-51
		],
		[
			-7,
			-4
		],
		[
			-9,
			100
		],
		[
			3,
			45
		],
		[
			-14,
			32
		],
		[
			-12,
			9
		],
		[
			-2,
			63
		],
		[
			-7,
			58
		],
		[
			-11,
			45
		],
		[
			-15,
			6
		],
		[
			-5,
			44
		],
		[
			-24,
			48
		],
		[
			0,
			111
		],
		[
			-4,
			67
		],
		[
			-12,
			7
		],
		[
			-10,
			38
		],
		[
			-13,
			17
		],
		[
			-13,
			61
		],
		[
			0,
			42
		],
		[
			-9,
			35
		],
		[
			-5,
			51
		],
		[
			-14,
			44
		],
		[
			-28,
			62
		],
		[
			-40,
			72
		],
		[
			-26,
			75
		],
		[
			-11,
			-2
		],
		[
			-26,
			-33
		],
		[
			-31,
			29
		],
		[
			-1,
			-35
		],
		[
			-26,
			-69
		],
		[
			9,
			-99
		],
		[
			-3,
			-28
		],
		[
			-10,
			-7
		],
		[
			-15,
			15
		],
		[
			-5,
			26
		],
		[
			-24,
			-22
		],
		[
			-31,
			-73
		],
		[
			-65,
			-132
		],
		[
			-6,
			2
		],
		[
			7,
			44
		],
		[
			-10,
			12
		],
		[
			-7,
			-39
		],
		[
			-15,
			-41
		],
		[
			-36,
			1
		],
		[
			13,
			-49
		],
		[
			2,
			-38
		],
		[
			16,
			-22
		],
		[
			30,
			53
		],
		[
			29,
			40
		],
		[
			27,
			84
		],
		[
			3,
			-13
		],
		[
			-24,
			-82
		],
		[
			-28,
			-43
		],
		[
			-35,
			-66
		],
		[
			-12,
			-14
		],
		[
			-10,
			33
		],
		[
			-16,
			22
		],
		[
			-23,
			51
		],
		[
			-19,
			7
		],
		[
			-17,
			-28
		],
		[
			-13,
			94
		],
		[
			-5,
			119
		],
		[
			8,
			42
		],
		[
			0,
			-105
		],
		[
			6,
			-91
		],
		[
			7,
			-22
		],
		[
			10,
			39
		],
		[
			1,
			97
		],
		[
			-17,
			105
		],
		[
			-18,
			60
		],
		[
			-17,
			13
		],
		[
			-15,
			40
		],
		[
			-16,
			71
		],
		[
			-27,
			47
		],
		[
			-22,
			69
		],
		[
			-41,
			95
		],
		[
			-47,
			76
		],
		[
			-58,
			70
		],
		[
			-31,
			20
		],
		[
			-62,
			18
		],
		[
			-33,
			-5
		],
		[
			-47,
			-25
		],
		[
			-65,
			-49
		],
		[
			-32,
			-15
		],
		[
			-7,
			10
		],
		[
			-63,
			-51
		]
	],
	[
		[
			26061,
			57664
		],
		[
			39,
			-2
		],
		[
			136,
			6
		],
		[
			183,
			1
		]
	],
	[
		[
			26419,
			57669
		],
		[
			196,
			-2
		],
		[
			-1,
			6
		],
		[
			143,
			10
		]
	],
	[
		[
			26757,
			57683
		],
		[
			-3,
			-72
		],
		[
			-31,
			-68
		],
		[
			-26,
			-105
		],
		[
			1,
			-36
		],
		[
			-8,
			-26
		],
		[
			3,
			-64
		],
		[
			30,
			-82
		],
		[
			17,
			-7
		],
		[
			23,
			-104
		],
		[
			23,
			-51
		],
		[
			28,
			16
		],
		[
			8,
			-12
		],
		[
			8,
			-64
		],
		[
			3,
			-64
		],
		[
			12,
			-30
		],
		[
			3,
			-50
		],
		[
			11,
			-52
		],
		[
			0,
			-51
		],
		[
			7,
			-68
		],
		[
			12,
			-24
		],
		[
			8,
			-67
		],
		[
			14,
			-48
		],
		[
			11,
			-101
		],
		[
			9,
			-1
		],
		[
			19,
			-72
		],
		[
			29,
			-52
		],
		[
			29,
			-98
		],
		[
			4,
			-61
		],
		[
			9,
			-41
		],
		[
			1,
			-40
		],
		[
			13,
			-38
		],
		[
			12,
			-2
		],
		[
			17,
			-37
		],
		[
			18,
			-93
		],
		[
			15,
			-26
		],
		[
			4,
			-24
		],
		[
			-7,
			-43
		],
		[
			4,
			-39
		],
		[
			-4,
			-32
		],
		[
			28,
			-82
		],
		[
			-4,
			-30
		],
		[
			13,
			-42
		],
		[
			11,
			5
		],
		[
			-2,
			-41
		],
		[
			8,
			-45
		],
		[
			27,
			-55
		],
		[
			9,
			1
		],
		[
			16,
			-58
		],
		[
			19,
			-43
		],
		[
			-5,
			-67
		],
		[
			12,
			-64
		],
		[
			2,
			-49
		],
		[
			9,
			-15
		],
		[
			0,
			-85
		],
		[
			4,
			-32
		],
		[
			-5,
			-45
		],
		[
			6,
			-8
		],
		[
			4,
			-48
		],
		[
			-5,
			-41
		],
		[
			12,
			-48
		],
		[
			25,
			-26
		],
		[
			0,
			-23
		],
		[
			23,
			-81
		],
		[
			-4,
			-34
		],
		[
			15,
			-105
		],
		[
			4,
			4
		],
		[
			6,
			-76
		],
		[
			-10,
			-44
		],
		[
			11,
			-67
		],
		[
			-4,
			-26
		],
		[
			5,
			-62
		],
		[
			21,
			-34
		],
		[
			11,
			17
		],
		[
			22,
			-71
		],
		[
			9,
			-4
		]
	],
	[
		[
			27376,
			54230
		],
		[
			12,
			-12
		],
		[
			-5,
			-64
		],
		[
			-14,
			-29
		],
		[
			-10,
			15
		],
		[
			-6,
			-48
		],
		[
			10,
			-8
		],
		[
			-16,
			-60
		],
		[
			-21,
			23
		],
		[
			-3,
			-56
		],
		[
			11,
			-11
		],
		[
			-9,
			-59
		],
		[
			-17,
			-54
		],
		[
			-17,
			13
		],
		[
			-3,
			-16
		],
		[
			12,
			-33
		],
		[
			8,
			5
		],
		[
			-1,
			-84
		],
		[
			-7,
			-62
		],
		[
			-28,
			-26
		],
		[
			0,
			-22
		],
		[
			17,
			10
		],
		[
			6,
			-24
		],
		[
			-23,
			-131
		],
		[
			-6,
			-91
		],
		[
			7,
			-13
		],
		[
			-5,
			-30
		],
		[
			-5,
			-97
		],
		[
			-13,
			-22
		],
		[
			-8,
			-59
		],
		[
			-9,
			-3
		],
		[
			0,
			-71
		],
		[
			-7,
			-69
		],
		[
			-7,
			2
		],
		[
			-12,
			-44
		],
		[
			13,
			-24
		],
		[
			11,
			24
		],
		[
			1,
			-81
		],
		[
			-16,
			-161
		],
		[
			5,
			-70
		]
	],
	[
		[
			25527,
			65491
		],
		[
			15,
			-41
		],
		[
			12,
			20
		],
		[
			7,
			-15
		],
		[
			-6,
			-40
		],
		[
			27,
			-23
		],
		[
			29,
			1
		],
		[
			28,
			25
		],
		[
			52,
			75
		],
		[
			31,
			59
		]
	],
	[
		[
			25722,
			65552
		],
		[
			90,
			-1
		],
		[
			198,
			-1
		],
		[
			187,
			1
		],
		[
			87,
			1
		],
		[
			0,
			-75
		]
	],
	[
		[
			26284,
			65477
		],
		[
			1,
			-242
		],
		[
			0,
			-1380
		],
		[
			-3,
			-437
		],
		[
			0,
			-441
		],
		[
			-2,
			-278
		],
		[
			0,
			-238
		]
	],
	[
		[
			26280,
			62461
		],
		[
			-19,
			-45
		],
		[
			-2,
			-20
		],
		[
			16,
			-71
		],
		[
			2,
			-31
		],
		[
			-11,
			-38
		],
		[
			3,
			-37
		],
		[
			17,
			-7
		],
		[
			4,
			-25
		],
		[
			-13,
			-46
		],
		[
			6,
			-44
		],
		[
			-22,
			3
		],
		[
			-16,
			-23
		],
		[
			-9,
			5
		],
		[
			-35,
			-63
		],
		[
			-14,
			-39
		],
		[
			-19,
			10
		],
		[
			-10,
			43
		],
		[
			-26,
			-7
		],
		[
			-16,
			7
		],
		[
			-12,
			-33
		],
		[
			4,
			-125
		],
		[
			6,
			-71
		],
		[
			-16,
			-40
		],
		[
			-7,
			-44
		],
		[
			-30,
			-34
		],
		[
			-19,
			-161
		],
		[
			-19,
			-39
		],
		[
			-14,
			24
		],
		[
			-10,
			-13
		],
		[
			-6,
			-63
		],
		[
			-16,
			-72
		],
		[
			1,
			-87
		],
		[
			-5,
			-70
		],
		[
			-8,
			-24
		],
		[
			-23,
			-18
		],
		[
			-4,
			-36
		],
		[
			-13,
			58
		],
		[
			-22,
			1
		],
		[
			-26,
			55
		],
		[
			-1,
			94
		],
		[
			-21,
			67
		],
		[
			-8,
			-2
		],
		[
			1,
			-34
		],
		[
			13,
			-12
		],
		[
			-1,
			-25
		],
		[
			-13,
			-2
		],
		[
			-8,
			-29
		],
		[
			-8,
			23
		],
		[
			-9,
			-29
		],
		[
			9,
			-17
		],
		[
			-6,
			-42
		],
		[
			-18,
			-9
		],
		[
			-2,
			-94
		],
		[
			5,
			-38
		],
		[
			-23,
			-9
		],
		[
			-2,
			-63
		],
		[
			-11,
			-29
		],
		[
			-7,
			24
		],
		[
			5,
			51
		],
		[
			-10,
			10
		],
		[
			-10,
			-25
		],
		[
			-10,
			22
		],
		[
			-12,
			89
		],
		[
			-17,
			-2
		],
		[
			-14,
			-52
		],
		[
			-29,
			-27
		],
		[
			-10,
			-30
		],
		[
			-5,
			-97
		],
		[
			-7,
			-27
		],
		[
			-11,
			-3
		],
		[
			-8,
			62
		],
		[
			-18,
			13
		],
		[
			-22,
			57
		],
		[
			-22,
			44
		],
		[
			-20,
			6
		],
		[
			-14,
			-37
		],
		[
			-14,
			19
		],
		[
			-6,
			49
		],
		[
			-8,
			6
		],
		[
			-7,
			-66
		],
		[
			11,
			-64
		],
		[
			-13,
			-40
		],
		[
			-11,
			3
		],
		[
			3,
			56
		],
		[
			-5,
			30
		],
		[
			-42,
			-31
		],
		[
			-11,
			52
		],
		[
			-9,
			4
		],
		[
			-10,
			-40
		],
		[
			10,
			-91
		],
		[
			-12,
			-47
		],
		[
			-23,
			32
		]
	],
	[
		[
			25386,
			60941
		],
		[
			-11,
			2
		],
		[
			-4,
			34
		],
		[
			12,
			-9
		],
		[
			-16,
			92
		],
		[
			24,
			-8
		],
		[
			-15,
			29
		],
		[
			15,
			67
		],
		[
			1,
			60
		],
		[
			-8,
			26
		],
		[
			19,
			19
		],
		[
			2,
			38
		],
		[
			-12,
			-19
		],
		[
			22,
			73
		],
		[
			-14,
			60
		],
		[
			-4,
			59
		],
		[
			9,
			-10
		],
		[
			9,
			68
		],
		[
			5,
			-35
		],
		[
			7,
			41
		],
		[
			8,
			-33
		],
		[
			13,
			102
		],
		[
			8,
			9
		],
		[
			13,
			84
		],
		[
			-2,
			38
		],
		[
			24,
			42
		],
		[
			0,
			66
		],
		[
			9,
			83
		],
		[
			7,
			32
		],
		[
			14,
			12
		],
		[
			14,
			76
		],
		[
			-1,
			42
		],
		[
			-15,
			94
		],
		[
			11,
			111
		],
		[
			-18,
			40
		],
		[
			1,
			79
		],
		[
			-16,
			55
		],
		[
			-3,
			73
		],
		[
			19,
			60
		],
		[
			-9,
			50
		],
		[
			2,
			60
		],
		[
			6,
			32
		],
		[
			13,
			9
		],
		[
			0,
			347
		],
		[
			-1,
			0
		],
		[
			0,
			397
		],
		[
			1,
			12
		],
		[
			0,
			294
		],
		[
			1,
			247
		],
		[
			0,
			1196
		],
		[
			1,
			254
		]
	],
	[
		[
			21479,
			63506
		],
		[
			257,
			-1
		],
		[
			104,
			0
		],
		[
			263,
			-1
		],
		[
			273,
			1
		],
		[
			163,
			0
		],
		[
			279,
			-1
		],
		[
			263,
			-1
		],
		[
			144,
			0
		],
		[
			133,
			0
		]
	],
	[
		[
			23358,
			63503
		],
		[
			16,
			-60
		],
		[
			13,
			-11
		],
		[
			1,
			-43
		],
		[
			13,
			6
		],
		[
			5,
			-36
		],
		[
			26,
			-14
		],
		[
			8,
			41
		],
		[
			24,
			-13
		],
		[
			-4,
			-28
		],
		[
			7,
			-33
		],
		[
			11,
			-11
		],
		[
			-4,
			-42
		],
		[
			-9,
			-1
		],
		[
			3,
			-36
		],
		[
			12,
			16
		],
		[
			-1,
			-49
		],
		[
			-10,
			-6
		],
		[
			-13,
			24
		],
		[
			-5,
			-75
		],
		[
			-15,
			-19
		],
		[
			-7,
			-41
		],
		[
			2,
			-41
		],
		[
			-17,
			-24
		],
		[
			1,
			-48
		],
		[
			15,
			-41
		],
		[
			1,
			-29
		],
		[
			16,
			-31
		],
		[
			12,
			-61
		],
		[
			14,
			0
		],
		[
			5,
			-21
		],
		[
			-9,
			-25
		],
		[
			6,
			-79
		],
		[
			18,
			-52
		],
		[
			-3,
			-28
		],
		[
			15,
			-13
		],
		[
			5,
			-31
		],
		[
			14,
			-11
		],
		[
			9,
			16
		],
		[
			5,
			-31
		],
		[
			20,
			-3
		],
		[
			-5,
			-41
		],
		[
			0,
			-444
		],
		[
			-1,
			-120
		],
		[
			0,
			-696
		],
		[
			-1,
			-52
		],
		[
			0,
			-779
		],
		[
			-1,
			-97
		],
		[
			0,
			-281
		]
	],
	[
		[
			23550,
			60009
		],
		[
			-249,
			1
		],
		[
			-196,
			-1
		],
		[
			-169,
			0
		],
		[
			-218,
			0
		],
		[
			-208,
			-1
		],
		[
			-258,
			2
		],
		[
			-103,
			0
		],
		[
			-154,
			3
		],
		[
			-149,
			-4
		],
		[
			-209,
			-4
		],
		[
			-155,
			-3
		]
	],
	[
		[
			30863,
			68384
		],
		[
			14,
			7
		],
		[
			-7,
			-35
		],
		[
			-7,
			28
		]
	],
	[
		[
			30827,
			68345
		],
		[
			7,
			83
		],
		[
			6,
			-34
		],
		[
			19,
			-55
		],
		[
			-15,
			-45
		],
		[
			-5,
			34
		],
		[
			-12,
			17
		]
	],
	[
		[
			30819,
			68560
		],
		[
			3,
			42
		],
		[
			11,
			-71
		],
		[
			-14,
			29
		]
	],
	[
		[
			30732,
			68434
		],
		[
			14,
			2
		],
		[
			3,
			-41
		],
		[
			-17,
			39
		]
	],
	[
		[
			30712,
			67988
		],
		[
			8,
			37
		],
		[
			1,
			-75
		],
		[
			-9,
			38
		]
	],
	[
		[
			30703,
			68290
		],
		[
			8,
			41
		],
		[
			25,
			45
		],
		[
			11,
			-50
		],
		[
			-9,
			-8
		],
		[
			14,
			-78
		],
		[
			-11,
			-39
		],
		[
			-18,
			-13
		],
		[
			-12,
			24
		],
		[
			5,
			25
		],
		[
			-3,
			50
		],
		[
			-10,
			3
		]
	],
	[
		[
			30697,
			68452
		],
		[
			13,
			68
		],
		[
			2,
			64
		],
		[
			9,
			25
		],
		[
			6,
			-26
		],
		[
			-9,
			-35
		],
		[
			1,
			-36
		],
		[
			-8,
			-70
		],
		[
			-10,
			-29
		],
		[
			-4,
			39
		]
	],
	[
		[
			30213,
			67064
		],
		[
			-35,
			81
		],
		[
			0,
			69
		],
		[
			6,
			42
		],
		[
			-41,
			128
		],
		[
			-9,
			53
		],
		[
			8,
			101
		],
		[
			-4,
			10
		],
		[
			6,
			88
		],
		[
			-6,
			23
		],
		[
			-5,
			313
		],
		[
			0,
			89
		],
		[
			-11,
			861
		],
		[
			-15,
			757
		]
	],
	[
		[
			30107,
			69679
		],
		[
			21,
			15
		],
		[
			0,
			33
		],
		[
			25,
			-41
		],
		[
			-1,
			-38
		],
		[
			7,
			-43
		],
		[
			11,
			-15
		],
		[
			13,
			85
		],
		[
			2,
			86
		],
		[
			-6,
			28
		],
		[
			12,
			36
		],
		[
			8,
			-3
		],
		[
			12,
			-44
		],
		[
			21,
			-9
		],
		[
			1,
			39
		],
		[
			-24,
			83
		],
		[
			-1,
			32
		],
		[
			22,
			107
		],
		[
			14,
			27
		],
		[
			11,
			43
		],
		[
			8,
			-1
		],
		[
			15,
			41
		],
		[
			24,
			38
		],
		[
			-9,
			71
		],
		[
			21,
			66
		],
		[
			23,
			45
		],
		[
			5,
			56
		],
		[
			-7,
			28
		],
		[
			-14,
			0
		],
		[
			0,
			66
		],
		[
			10,
			38
		],
		[
			-8,
			14
		],
		[
			15,
			51
		],
		[
			5,
			46
		],
		[
			-15,
			44
		],
		[
			16,
			115
		],
		[
			8,
			18
		],
		[
			-1,
			37
		],
		[
			17,
			32
		],
		[
			14,
			59
		],
		[
			11,
			8
		],
		[
			17,
			324
		],
		[
			215,
			890
		],
		[
			13,
			-3
		],
		[
			27,
			-38
		],
		[
			11,
			4
		],
		[
			-3,
			-58
		],
		[
			1,
			-141
		],
		[
			4,
			-18
		],
		[
			37,
			-73
		],
		[
			25,
			43
		],
		[
			26,
			30
		],
		[
			28,
			2
		],
		[
			11,
			52
		],
		[
			30,
			11
		],
		[
			25,
			-12
		],
		[
			0,
			62
		],
		[
			16,
			23
		],
		[
			25,
			-6
		],
		[
			23,
			-36
		],
		[
			4,
			-32
		],
		[
			33,
			-68
		],
		[
			36,
			-132
		],
		[
			0,
			-15
		],
		[
			28,
			-51
		],
		[
			0,
			-545
		],
		[
			3,
			-693
		],
		[
			-1,
			-71
		],
		[
			9,
			-30
		],
		[
			-15,
			-39
		],
		[
			14,
			-70
		],
		[
			-15,
			-34
		],
		[
			1,
			-136
		],
		[
			23,
			-18
		],
		[
			3,
			20
		],
		[
			10,
			-57
		],
		[
			19,
			-28
		],
		[
			30,
			-23
		],
		[
			14,
			19
		],
		[
			8,
			-62
		],
		[
			1,
			-56
		],
		[
			-13,
			8
		],
		[
			-11,
			-22
		],
		[
			7,
			-68
		],
		[
			16,
			-63
		],
		[
			-9,
			-73
		],
		[
			-10,
			-41
		],
		[
			23,
			-116
		],
		[
			0,
			-23
		],
		[
			18,
			-40
		],
		[
			13,
			28
		],
		[
			1,
			46
		],
		[
			18,
			-30
		],
		[
			19,
			-3
		],
		[
			13,
			-56
		],
		[
			6,
			-51
		],
		[
			-8,
			-14
		],
		[
			10,
			-32
		],
		[
			12,
			-98
		],
		[
			15,
			-38
		],
		[
			1,
			-118
		],
		[
			-12,
			-50
		],
		[
			-10,
			2
		],
		[
			-4,
			-32
		],
		[
			-32,
			-113
		],
		[
			-24,
			-25
		],
		[
			4,
			-22
		],
		[
			-15,
			-8
		],
		[
			6,
			42
		],
		[
			-4,
			85
		],
		[
			-27,
			-30
		],
		[
			12,
			-58
		],
		[
			-12,
			-43
		],
		[
			-11,
			13
		],
		[
			-13,
			-58
		],
		[
			-13,
			18
		],
		[
			-10,
			-12
		],
		[
			2,
			-35
		],
		[
			16,
			-40
		],
		[
			-22,
			-57
		],
		[
			-13,
			46
		],
		[
			-6,
			57
		],
		[
			-13,
			-10
		],
		[
			-3,
			-38
		],
		[
			-8,
			3
		],
		[
			-7,
			59
		],
		[
			-7,
			-62
		],
		[
			-9,
			-14
		],
		[
			-8,
			-74
		],
		[
			-7,
			19
		],
		[
			-6,
			-48
		],
		[
			-4,
			42
		],
		[
			-20,
			-51
		],
		[
			-5,
			27
		],
		[
			-12,
			-92
		],
		[
			-16,
			39
		],
		[
			0,
			36
		],
		[
			-10,
			-21
		],
		[
			-11,
			9
		],
		[
			2,
			-66
		],
		[
			-16,
			-71
		],
		[
			11,
			-33
		],
		[
			-35,
			-16
		],
		[
			-23,
			32
		],
		[
			-16,
			107
		],
		[
			6,
			29
		],
		[
			22,
			27
		],
		[
			-9,
			45
		],
		[
			-13,
			-35
		],
		[
			2,
			44
		],
		[
			-10,
			-3
		],
		[
			1,
			-68
		],
		[
			-5,
			0
		],
		[
			0,
			64
		],
		[
			-24,
			-56
		],
		[
			5,
			-35
		],
		[
			-6,
			-43
		],
		[
			14,
			-67
		],
		[
			-3,
			-45
		],
		[
			-23,
			-77
		],
		[
			9,
			-11
		],
		[
			-12,
			-31
		],
		[
			11,
			-56
		],
		[
			-5,
			-69
		],
		[
			-16,
			-10
		],
		[
			-3,
			85
		],
		[
			6,
			4
		],
		[
			-3,
			55
		],
		[
			-17,
			45
		],
		[
			-4,
			64
		],
		[
			15,
			51
		],
		[
			-19,
			40
		],
		[
			6,
			26
		],
		[
			-10,
			10
		],
		[
			-18,
			-21
		],
		[
			1,
			113
		],
		[
			11,
			44
		],
		[
			1,
			50
		],
		[
			-7,
			14
		],
		[
			-7,
			-46
		],
		[
			-14,
			-40
		],
		[
			-11,
			33
		],
		[
			-7,
			-32
		],
		[
			-15,
			-4
		],
		[
			14,
			-81
		],
		[
			-3,
			-48
		],
		[
			-12,
			-23
		],
		[
			-10,
			-71
		],
		[
			-4,
			-72
		],
		[
			-13,
			-78
		],
		[
			19,
			-30
		],
		[
			-13,
			-28
		],
		[
			10,
			-57
		],
		[
			-10,
			-38
		],
		[
			-27,
			4
		],
		[
			-13,
			-72
		],
		[
			-15,
			-1
		],
		[
			-2,
			-58
		],
		[
			-11,
			-9
		],
		[
			0,
			52
		],
		[
			7,
			37
		],
		[
			-9,
			15
		],
		[
			-3,
			-30
		],
		[
			-12,
			-13
		],
		[
			5,
			65
		],
		[
			-18,
			-9
		],
		[
			1,
			-52
		],
		[
			-16,
			-37
		],
		[
			-5,
			-50
		],
		[
			-12,
			51
		],
		[
			-2,
			-47
		],
		[
			-15,
			-32
		],
		[
			-12,
			26
		],
		[
			-3,
			-66
		],
		[
			-13,
			51
		],
		[
			-13,
			-92
		],
		[
			-23,
			-27
		],
		[
			-5,
			-19
		],
		[
			-5,
			83
		],
		[
			-16,
			5
		],
		[
			-15,
			-42
		],
		[
			-5,
			-39
		],
		[
			-20,
			4
		],
		[
			-7,
			-49
		],
		[
			-20,
			4
		],
		[
			-10,
			-49
		],
		[
			-3,
			-50
		],
		[
			5,
			-29
		],
		[
			-8,
			-32
		],
		[
			-13,
			29
		],
		[
			-22,
			-31
		],
		[
			-9,
			-46
		],
		[
			6,
			-67
		],
		[
			-8,
			-43
		],
		[
			-10,
			-15
		],
		[
			3,
			-33
		],
		[
			-14,
			-24
		],
		[
			-14,
			4
		],
		[
			-10,
			-25
		],
		[
			-11,
			-98
		],
		[
			5,
			-19
		],
		[
			-14,
			-80
		],
		[
			1,
			-22
		],
		[
			-14,
			-74
		],
		[
			-9,
			-13
		]
	],
	[
		[
			30332,
			65028
		],
		[
			13,
			-24
		],
		[
			29,
			5
		],
		[
			18,
			17
		],
		[
			12,
			70
		],
		[
			16,
			-105
		],
		[
			-1,
			-30
		],
		[
			-10,
			-16
		],
		[
			-33,
			4
		],
		[
			-41,
			60
		],
		[
			-3,
			19
		]
	],
	[
		[
			30177,
			65078
		],
		[
			18,
			0
		],
		[
			19,
			90
		],
		[
			27,
			60
		],
		[
			11,
			-15
		],
		[
			7,
			-70
		],
		[
			15,
			-27
		],
		[
			10,
			40
		],
		[
			-1,
			-84
		],
		[
			-41,
			1
		],
		[
			-31,
			-9
		],
		[
			-18,
			-47
		],
		[
			-16,
			61
		]
	],
	[
		[
			29500,
			66699
		],
		[
			224,
			-22
		]
	],
	[
		[
			29724,
			66677
		],
		[
			199,
			-23
		],
		[
			126,
			-12
		],
		[
			10,
			46
		],
		[
			21,
			1
		],
		[
			-1,
			62
		],
		[
			15,
			36
		],
		[
			19,
			-18
		],
		[
			9,
			62
		],
		[
			36,
			32
		],
		[
			15,
			-30
		],
		[
			8,
			13
		]
	],
	[
		[
			30181,
			66846
		],
		[
			2,
			-72
		],
		[
			9,
			-136
		],
		[
			25,
			-47
		],
		[
			12,
			42
		],
		[
			14,
			-34
		],
		[
			-16,
			-90
		],
		[
			-23,
			-7
		],
		[
			-38,
			-35
		],
		[
			12,
			-50
		],
		[
			-18,
			-50
		],
		[
			-7,
			9
		],
		[
			-5,
			-59
		],
		[
			-4,
			41
		],
		[
			-11,
			-53
		],
		[
			11,
			-74
		],
		[
			-13,
			10
		],
		[
			-5,
			-28
		],
		[
			8,
			-26
		],
		[
			-5,
			-27
		],
		[
			14,
			-14
		],
		[
			6,
			36
		],
		[
			14,
			8
		],
		[
			9,
			-47
		],
		[
			24,
			-28
		],
		[
			12,
			-42
		],
		[
			2,
			-46
		],
		[
			21,
			-93
		],
		[
			-1,
			-50
		],
		[
			-7,
			-39
		],
		[
			-12,
			-5
		],
		[
			3,
			-24
		],
		[
			21,
			-51
		],
		[
			12,
			8
		],
		[
			8,
			-24
		],
		[
			8,
			-83
		],
		[
			-5,
			-50
		],
		[
			13,
			-48
		],
		[
			23,
			-35
		],
		[
			34,
			-12
		],
		[
			9,
			-23
		],
		[
			19,
			44
		],
		[
			19,
			8
		],
		[
			27,
			33
		],
		[
			6,
			25
		],
		[
			-1,
			79
		],
		[
			-6,
			61
		],
		[
			-13,
			-31
		],
		[
			0,
			97
		],
		[
			-5,
			55
		],
		[
			-15,
			34
		],
		[
			-9,
			-7
		],
		[
			-5,
			-39
		],
		[
			-11,
			59
		],
		[
			13,
			11
		],
		[
			21,
			-18
		],
		[
			23,
			-58
		],
		[
			18,
			-123
		],
		[
			9,
			-119
		],
		[
			2,
			-137
		],
		[
			-15,
			-129
		],
		[
			-2,
			-44
		],
		[
			-7,
			9
		],
		[
			12,
			112
		],
		[
			-7,
			23
		],
		[
			-26,
			-5
		],
		[
			-43,
			-40
		],
		[
			-30,
			8
		],
		[
			-7,
			-28
		],
		[
			-17,
			-7
		],
		[
			-15,
			-62
		],
		[
			-33,
			-10
		],
		[
			-34,
			-66
		],
		[
			-16,
			-47
		],
		[
			-21,
			-28
		],
		[
			-23,
			-15
		],
		[
			6,
			26
		],
		[
			35,
			34
		],
		[
			16,
			47
		],
		[
			24,
			49
		],
		[
			5,
			40
		],
		[
			-2,
			117
		],
		[
			6,
			41
		],
		[
			-26,
			26
		],
		[
			0,
			-59
		],
		[
			-7,
			14
		],
		[
			-4,
			-50
		],
		[
			-14,
			3
		],
		[
			2,
			-32
		],
		[
			-31,
			-11
		],
		[
			-7,
			-49
		],
		[
			2,
			-44
		],
		[
			-6,
			-29
		],
		[
			-25,
			-23
		],
		[
			-12,
			17
		],
		[
			-10,
			-14
		]
	],
	[
		[
			30097,
			65246
		],
		[
			-3,
			189
		],
		[
			-18,
			18
		]
	],
	[
		[
			30076,
			65453
		],
		[
			-8,
			41
		]
	],
	[
		[
			30068,
			65494
		],
		[
			-10,
			48
		],
		[
			-19,
			33
		],
		[
			-5,
			56
		],
		[
			2,
			81
		],
		[
			-12,
			-6
		],
		[
			0,
			147
		],
		[
			-116,
			-13
		]
	],
	[
		[
			29908,
			65840
		],
		[
			-1,
			18
		],
		[
			-202,
			13
		],
		[
			-22,
			-4
		],
		[
			-42,
			6
		],
		[
			-3,
			-39
		],
		[
			-14,
			-6
		],
		[
			1,
			45
		],
		[
			-54,
			3
		],
		[
			-118,
			14
		],
		[
			-15,
			-1
		]
	],
	[
		[
			29438,
			65889
		],
		[
			-6,
			42
		],
		[
			34,
			395
		],
		[
			34,
			373
		]
	],
	[
		[
			22823,
			73980
		],
		[
			83,
			-1
		],
		[
			266,
			0
		],
		[
			229,
			-1
		],
		[
			0,
			449
		],
		[
			27,
			-37
		],
		[
			28,
			20
		],
		[
			29,
			-53
		],
		[
			8,
			-35
		],
		[
			14,
			-202
		],
		[
			7,
			-25
		],
		[
			18,
			-251
		],
		[
			-6,
			-69
		],
		[
			4,
			-54
		],
		[
			14,
			-43
		],
		[
			29,
			-45
		],
		[
			24,
			-12
		],
		[
			8,
			19
		],
		[
			44,
			-11
		],
		[
			11,
			-58
		],
		[
			61,
			-7
		],
		[
			48,
			-21
		],
		[
			8,
			-66
		],
		[
			-3,
			-49
		],
		[
			6,
			-12
		],
		[
			42,
			2
		],
		[
			5,
			15
		],
		[
			22,
			-2
		],
		[
			23,
			20
		],
		[
			-1,
			48
		],
		[
			33,
			46
		],
		[
			39,
			18
		],
		[
			9,
			-22
		],
		[
			53,
			0
		],
		[
			72,
			-98
		],
		[
			26,
			4
		],
		[
			1,
			-49
		],
		[
			-19,
			-7
		],
		[
			-4,
			-37
		],
		[
			16,
			-31
		],
		[
			41,
			13
		],
		[
			15,
			-54
		],
		[
			-6,
			-34
		],
		[
			6,
			-49
		],
		[
			24,
			-127
		],
		[
			25,
			27
		],
		[
			-8,
			84
		],
		[
			13,
			45
		],
		[
			15,
			-11
		],
		[
			42,
			16
		],
		[
			16,
			-44
		],
		[
			-2,
			-65
		],
		[
			17,
			-41
		],
		[
			14,
			9
		],
		[
			9,
			-36
		],
		[
			41,
			-9
		],
		[
			5,
			-67
		],
		[
			-4,
			-31
		],
		[
			20,
			-21
		],
		[
			23,
			13
		],
		[
			-3,
			-75
		],
		[
			22,
			28
		],
		[
			14,
			-22
		],
		[
			19,
			24
		],
		[
			34,
			17
		],
		[
			46,
			113
		],
		[
			17,
			13
		],
		[
			13,
			32
		],
		[
			25,
			30
		],
		[
			14,
			-13
		],
		[
			0,
			-67
		],
		[
			17,
			-17
		],
		[
			-6,
			-26
		],
		[
			10,
			-48
		],
		[
			16,
			-3
		],
		[
			35,
			29
		],
		[
			6,
			-29
		],
		[
			25,
			15
		],
		[
			26,
			-18
		],
		[
			19,
			13
		],
		[
			48,
			8
		],
		[
			29,
			-28
		],
		[
			9,
			-66
		],
		[
			34,
			-53
		],
		[
			15,
			35
		],
		[
			20,
			9
		],
		[
			13,
			-20
		],
		[
			23,
			6
		],
		[
			11,
			-18
		],
		[
			25,
			22
		],
		[
			-27,
			-56
		],
		[
			-10,
			20
		],
		[
			-4,
			-34
		],
		[
			-17,
			-15
		],
		[
			-26,
			-58
		],
		[
			-37,
			-34
		],
		[
			-14,
			-37
		],
		[
			-52,
			-44
		],
		[
			-48,
			-54
		],
		[
			-15,
			-6
		],
		[
			-42,
			-45
		],
		[
			-4,
			-14
		],
		[
			-51,
			-77
		],
		[
			-37,
			-79
		],
		[
			-72,
			-183
		],
		[
			-17,
			-69
		],
		[
			-55,
			-178
		],
		[
			-26,
			-72
		],
		[
			-26,
			-41
		],
		[
			-26,
			-88
		],
		[
			-11,
			-11
		],
		[
			-28,
			-83
		],
		[
			-10,
			-10
		],
		[
			-61,
			-134
		],
		[
			-9,
			-25
		],
		[
			8,
			-50
		],
		[
			14,
			-46
		]
	],
	[
		[
			24276,
			71309
		],
		[
			-21,
			50
		],
		[
			-14,
			-11
		],
		[
			-3,
			-29
		],
		[
			-16,
			-14
		],
		[
			9,
			-19
		],
		[
			-11,
			-43
		],
		[
			-22,
			16
		],
		[
			0,
			-685
		],
		[
			-10,
			-10
		],
		[
			-6,
			-59
		],
		[
			-24,
			7
		],
		[
			-10,
			-56
		],
		[
			-14,
			13
		],
		[
			-8,
			-38
		],
		[
			-25,
			-23
		],
		[
			-20,
			-47
		],
		[
			-20,
			-148
		],
		[
			-22,
			-49
		],
		[
			-7,
			-114
		],
		[
			1,
			-53
		],
		[
			21,
			-21
		],
		[
			10,
			9
		],
		[
			14,
			-32
		],
		[
			-1,
			-31
		],
		[
			23,
			-85
		],
		[
			-1,
			-50
		],
		[
			-15,
			-47
		],
		[
			1,
			-29
		],
		[
			-17,
			-49
		],
		[
			2,
			-91
		],
		[
			-4,
			-32
		],
		[
			6,
			-91
		],
		[
			-16,
			-58
		],
		[
			11,
			-34
		],
		[
			-2,
			-65
		],
		[
			6,
			-41
		],
		[
			-7,
			-42
		],
		[
			3,
			-75
		],
		[
			-12,
			-80
		],
		[
			5,
			-36
		],
		[
			16,
			-27
		],
		[
			31,
			-87
		],
		[
			-1,
			-24
		],
		[
			14,
			-16
		],
		[
			9,
			-44
		],
		[
			50,
			-9
		],
		[
			12,
			-17
		],
		[
			10,
			-78
		],
		[
			14,
			-38
		],
		[
			50,
			-51
		],
		[
			22,
			-39
		],
		[
			14,
			-40
		],
		[
			0,
			-53
		],
		[
			8,
			-15
		],
		[
			5,
			-84
		],
		[
			17,
			-45
		],
		[
			27,
			-41
		],
		[
			3,
			-29
		],
		[
			36,
			-90
		],
		[
			39,
			-29
		],
		[
			15,
			-55
		],
		[
			30,
			-136
		],
		[
			9,
			-75
		],
		[
			-8,
			-113
		],
		[
			2,
			-71
		],
		[
			10,
			-37
		],
		[
			-4,
			-44
		],
		[
			8,
			-53
		]
	],
	[
		[
			24498,
			67577
		],
		[
			-204,
			0
		],
		[
			-224,
			0
		],
		[
			-116,
			-1
		],
		[
			-223,
			0
		],
		[
			-180,
			1
		],
		[
			-313,
			0
		],
		[
			-199,
			0
		]
	],
	[
		[
			23039,
			67577
		],
		[
			0,
			1215
		],
		[
			1,
			101
		],
		[
			-1,
			302
		],
		[
			0,
			479
		],
		[
			-10,
			65
		],
		[
			-36,
			59
		],
		[
			-18,
			4
		],
		[
			-14,
			55
		],
		[
			-9,
			73
		],
		[
			-26,
			98
		],
		[
			5,
			46
		],
		[
			25,
			62
		],
		[
			22,
			39
		],
		[
			12,
			63
		],
		[
			14,
			46
		],
		[
			4,
			128
		]
	],
	[
		[
			23008,
			70412
		],
		[
			-4,
			106
		],
		[
			6,
			37
		],
		[
			-11,
			188
		],
		[
			-1,
			129
		],
		[
			-13,
			27
		],
		[
			-20,
			98
		],
		[
			-5,
			49
		],
		[
			-4,
			119
		],
		[
			-11,
			57
		],
		[
			-2,
			39
		],
		[
			5,
			68
		],
		[
			-6,
			112
		],
		[
			5,
			17
		],
		[
			6,
			117
		],
		[
			-6,
			-11
		],
		[
			-11,
			51
		],
		[
			1,
			171
		],
		[
			-5,
			92
		],
		[
			-2,
			114
		],
		[
			3,
			50
		],
		[
			-7,
			103
		],
		[
			1,
			217
		],
		[
			-5,
			3
		],
		[
			-7,
			89
		],
		[
			-11,
			92
		],
		[
			-8,
			17
		],
		[
			-11,
			101
		],
		[
			-3,
			58
		],
		[
			-11,
			34
		],
		[
			-5,
			121
		],
		[
			-16,
			101
		],
		[
			-3,
			110
		],
		[
			7,
			53
		],
		[
			-8,
			93
		],
		[
			3,
			52
		],
		[
			-1,
			107
		],
		[
			-7,
			59
		],
		[
			7,
			76
		],
		[
			9,
			24
		],
		[
			3,
			62
		],
		[
			-15,
			80
		],
		[
			-8,
			124
		],
		[
			-6,
			24
		],
		[
			-11,
			98
		],
		[
			3,
			40
		]
	],
	[
		[
			28860,
			63072
		],
		[
			14,
			65
		]
	],
	[
		[
			28874,
			63137
		],
		[
			9,
			32
		],
		[
			5,
			61
		],
		[
			12,
			42
		]
	],
	[
		[
			28900,
			63272
		],
		[
			17,
			44
		],
		[
			38,
			25
		],
		[
			25,
			45
		],
		[
			0,
			69
		],
		[
			16,
			25
		],
		[
			7,
			33
		],
		[
			34,
			72
		],
		[
			18,
			15
		],
		[
			12,
			51
		],
		[
			10,
			-8
		],
		[
			17,
			39
		],
		[
			-14,
			71
		],
		[
			-20,
			41
		],
		[
			-7,
			52
		],
		[
			-21,
			54
		],
		[
			-7,
			68
		],
		[
			-25,
			19
		],
		[
			-4,
			45
		],
		[
			2,
			95
		],
		[
			-10,
			37
		],
		[
			-17,
			-5
		],
		[
			-9,
			14
		],
		[
			-2,
			83
		],
		[
			7,
			30
		],
		[
			-8,
			22
		],
		[
			9,
			100
		],
		[
			11,
			-5
		],
		[
			23,
			113
		],
		[
			-24,
			120
		],
		[
			13,
			48
		],
		[
			18,
			29
		],
		[
			16,
			56
		],
		[
			-4,
			24
		],
		[
			17,
			35
		],
		[
			11,
			49
		],
		[
			14,
			124
		],
		[
			22,
			69
		],
		[
			16,
			13
		]
	],
	[
		[
			29101,
			65083
		],
		[
			88,
			-173
		],
		[
			132,
			-246
		],
		[
			3,
			-19
		],
		[
			-20,
			-187
		],
		[
			-12,
			-65
		],
		[
			-4,
			-65
		],
		[
			-6,
			-22
		]
	],
	[
		[
			29282,
			64306
		],
		[
			-7,
			-34
		]
	],
	[
		[
			29275,
			64272
		],
		[
			-37,
			-35
		],
		[
			-4,
			-84
		],
		[
			-9,
			-16
		],
		[
			-3,
			-50
		]
	],
	[
		[
			29222,
			64087
		],
		[
			0,
			-43
		],
		[
			19,
			-28
		],
		[
			16,
			18
		],
		[
			24,
			-44
		],
		[
			14,
			-9
		],
		[
			4,
			44
		],
		[
			4,
			-90
		],
		[
			-3,
			-107
		],
		[
			-14,
			-182
		],
		[
			-13,
			-247
		],
		[
			-5,
			-173
		],
		[
			-40,
			-241
		],
		[
			-11,
			-48
		],
		[
			-9,
			-9
		],
		[
			3,
			-32
		],
		[
			-10,
			-55
		],
		[
			-20,
			-63
		],
		[
			-1,
			-19
		],
		[
			-31,
			-55
		],
		[
			-32,
			-108
		],
		[
			-21,
			-118
		],
		[
			-22,
			-149
		],
		[
			-20,
			-60
		],
		[
			-19,
			-14
		],
		[
			-11,
			14
		],
		[
			6,
			88
		],
		[
			15,
			97
		],
		[
			3,
			69
		],
		[
			-21,
			37
		],
		[
			-18,
			4
		],
		[
			-6,
			25
		],
		[
			-18,
			-3
		],
		[
			-7,
			-36
		],
		[
			-9,
			24
		],
		[
			-2,
			47
		],
		[
			-18,
			37
		],
		[
			-3,
			30
		],
		[
			-10,
			-12
		],
		[
			-15,
			68
		],
		[
			-7,
			-8
		],
		[
			-18,
			58
		],
		[
			-10,
			56
		],
		[
			-19,
			25
		],
		[
			6,
			140
		],
		[
			-12,
			29
		]
	],
	[
		[
			28861,
			63044
		],
		[
			-1,
			28
		]
	],
	[
		[
			28814,
			58772
		],
		[
			18,
			-19
		],
		[
			12,
			-74
		],
		[
			1,
			-47
		],
		[
			-15,
			9
		],
		[
			2,
			45
		],
		[
			-18,
			86
		]
	],
	[
		[
			28734,
			57762
		],
		[
			8,
			60
		],
		[
			8,
			0
		],
		[
			47,
			86
		],
		[
			15,
			12
		],
		[
			14,
			33
		],
		[
			12,
			2
		],
		[
			16,
			35
		],
		[
			13,
			10
		],
		[
			5,
			74
		],
		[
			11,
			252
		],
		[
			0,
			54
		],
		[
			-8,
			95
		],
		[
			-6,
			105
		],
		[
			3,
			-2
		],
		[
			11,
			-106
		],
		[
			5,
			-95
		],
		[
			-3,
			-136
		],
		[
			-15,
			-286
		],
		[
			-24,
			-8
		],
		[
			-50,
			-64
		],
		[
			-43,
			-78
		],
		[
			-19,
			-43
		]
	],
	[
		[
			27156,
			59531
		],
		[
			84,
			-16
		],
		[
			55,
			-3
		],
		[
			95,
			-15
		],
		[
			37,
			4
		],
		[
			114,
			-21
		],
		[
			48,
			-2
		],
		[
			170,
			-2
		],
		[
			279,
			0
		],
		[
			74,
			4
		],
		[
			264,
			0
		],
		[
			106,
			-1
		],
		[
			0,
			10
		],
		[
			31,
			-2
		],
		[
			120,
			0
		],
		[
			142,
			0
		]
	],
	[
		[
			28775,
			59487
		],
		[
			2,
			-58
		],
		[
			17,
			-245
		],
		[
			16,
			-158
		],
		[
			23,
			-156
		],
		[
			35,
			-271
		],
		[
			-9,
			14
		],
		[
			-18,
			146
		],
		[
			-14,
			80
		],
		[
			-13,
			11
		],
		[
			-9,
			174
		],
		[
			-16,
			155
		],
		[
			-8,
			23
		],
		[
			3,
			39
		],
		[
			-5,
			89
		],
		[
			-10,
			30
		],
		[
			-4,
			48
		],
		[
			-25,
			13
		],
		[
			-1,
			40
		],
		[
			-13,
			-20
		],
		[
			6,
			-61
		],
		[
			16,
			-48
		],
		[
			11,
			10
		],
		[
			0,
			-67
		],
		[
			15,
			-135
		],
		[
			9,
			-61
		],
		[
			-1,
			-26
		],
		[
			11,
			-75
		],
		[
			0,
			-47
		],
		[
			-19,
			64
		],
		[
			1,
			37
		],
		[
			-13,
			61
		],
		[
			-3,
			38
		],
		[
			-12,
			12
		],
		[
			6,
			-38
		],
		[
			-3,
			-28
		],
		[
			14,
			-39
		],
		[
			-31,
			25
		],
		[
			-32,
			118
		],
		[
			-15,
			12
		],
		[
			19,
			-97
		],
		[
			10,
			-17
		],
		[
			6,
			-52
		],
		[
			-9,
			-23
		],
		[
			-24,
			-14
		],
		[
			-21,
			71
		],
		[
			7,
			-63
		],
		[
			10,
			-27
		],
		[
			-7,
			-14
		],
		[
			-31,
			45
		],
		[
			-13,
			5
		],
		[
			-5,
			29
		],
		[
			-18,
			24
		],
		[
			23,
			-73
		],
		[
			21,
			-23
		],
		[
			-7,
			-19
		],
		[
			-24,
			-8
		],
		[
			-13,
			-62
		],
		[
			-16,
			-22
		],
		[
			-17,
			1
		],
		[
			-8,
			31
		],
		[
			-20,
			12
		],
		[
			-12,
			121
		],
		[
			0,
			61
		],
		[
			12,
			78
		],
		[
			-5,
			13
		],
		[
			-14,
			-76
		],
		[
			-2,
			-76
		],
		[
			8,
			-94
		],
		[
			11,
			-77
		],
		[
			-5,
			-42
		],
		[
			8,
			-34
		],
		[
			40,
			10
		],
		[
			37,
			47
		],
		[
			9,
			-49
		],
		[
			13,
			6
		],
		[
			13,
			30
		],
		[
			26,
			24
		],
		[
			32,
			-1
		],
		[
			14,
			-41
		],
		[
			0,
			-43
		],
		[
			-14,
			-78
		],
		[
			3,
			-55
		],
		[
			2,
			-164
		],
		[
			9,
			5
		],
		[
			7,
			115
		],
		[
			3,
			150
		],
		[
			14,
			40
		],
		[
			-6,
			33
		],
		[
			14,
			20
		],
		[
			25,
			-21
		],
		[
			16,
			-94
		],
		[
			7,
			-65
		],
		[
			-4,
			-52
		],
		[
			7,
			-98
		],
		[
			-8,
			-25
		],
		[
			4,
			-54
		],
		[
			-13,
			-54
		],
		[
			-17,
			-10
		],
		[
			-6,
			18
		],
		[
			-10,
			-16
		],
		[
			-6,
			-40
		],
		[
			-10,
			-9
		],
		[
			-3,
			-43
		],
		[
			-7,
			-11
		],
		[
			-7,
			-71
		],
		[
			-13,
			-15
		],
		[
			-3,
			-46
		],
		[
			-17,
			-25
		],
		[
			-3,
			-24
		],
		[
			-26,
			25
		],
		[
			-29,
			-4
		],
		[
			-26,
			18
		],
		[
			-5,
			25
		],
		[
			-10,
			-14
		],
		[
			-15,
			45
		],
		[
			-13,
			115
		],
		[
			31,
			3
		],
		[
			5,
			45
		],
		[
			-28,
			-25
		],
		[
			-12,
			11
		],
		[
			-9,
			-33
		],
		[
			9,
			-57
		],
		[
			6,
			-86
		],
		[
			-7,
			0
		],
		[
			-29,
			47
		],
		[
			-14,
			-10
		],
		[
			-20,
			34
		],
		[
			-31,
			30
		],
		[
			-23,
			48
		],
		[
			-1,
			-29
		],
		[
			17,
			-61
		],
		[
			21,
			-5
		],
		[
			63,
			-102
		],
		[
			46,
			-28
		],
		[
			8,
			-31
		],
		[
			1,
			-40
		],
		[
			-7,
			-56
		],
		[
			-13,
			-54
		],
		[
			1,
			-28
		],
		[
			-9,
			-53
		],
		[
			-15,
			-42
		],
		[
			-50,
			-112
		],
		[
			-50,
			112
		],
		[
			1,
			-65
		],
		[
			24,
			-55
		],
		[
			36,
			-43
		],
		[
			36,
			80
		],
		[
			13,
			2
		],
		[
			27,
			30
		],
		[
			4,
			62
		],
		[
			11,
			-14
		],
		[
			3,
			-66
		],
		[
			8,
			-31
		],
		[
			18,
			-5
		],
		[
			-9,
			75
		],
		[
			20,
			-29
		],
		[
			2,
			-85
		],
		[
			-17,
			-75
		],
		[
			-18,
			-13
		],
		[
			0,
			-34
		],
		[
			-11,
			-20
		],
		[
			-14,
			-84
		],
		[
			-7,
			-71
		],
		[
			-17,
			20
		],
		[
			1,
			80
		],
		[
			-10,
			19
		],
		[
			1,
			-82
		],
		[
			-16,
			-7
		],
		[
			42,
			-64
		],
		[
			23,
			123
		],
		[
			33,
			120
		],
		[
			24,
			75
		],
		[
			47,
			176
		],
		[
			8,
			-21
		],
		[
			-28,
			-83
		],
		[
			-26,
			-96
		],
		[
			-22,
			-62
		],
		[
			-21,
			-78
		],
		[
			-18,
			-82
		],
		[
			-21,
			-115
		],
		[
			-3,
			-32
		],
		[
			-4,
			67
		],
		[
			-35,
			55
		],
		[
			-39,
			1
		],
		[
			-60,
			-38
		],
		[
			-29,
			-33
		],
		[
			-20,
			-32
		],
		[
			-32,
			-81
		],
		[
			-39,
			-75
		],
		[
			-26,
			-63
		],
		[
			-37,
			-113
		],
		[
			-14,
			-55
		],
		[
			-25,
			-128
		],
		[
			-14,
			-111
		],
		[
			-10,
			-112
		],
		[
			-9,
			-69
		],
		[
			-4,
			-69
		],
		[
			-13,
			7
		],
		[
			-3,
			34
		],
		[
			-21,
			21
		],
		[
			-23,
			9
		],
		[
			-28,
			-2
		],
		[
			-30,
			-12
		],
		[
			-35,
			-42
		],
		[
			-8,
			-17
		]
	],
	[
		[
			28030,
			56345
		],
		[
			-93,
			330
		],
		[
			-104,
			362
		],
		[
			-31,
			116
		],
		[
			-88,
			302
		],
		[
			-61,
			1
		],
		[
			-74,
			7
		],
		[
			-178,
			10
		],
		[
			4,
			135
		],
		[
			-42,
			199
		],
		[
			-30,
			-73
		],
		[
			-5,
			21
		],
		[
			7,
			48
		],
		[
			-2,
			53
		],
		[
			-55,
			13
		],
		[
			-105,
			16
		],
		[
			-188,
			29
		],
		[
			-23,
			-20
		],
		[
			-5,
			39
		],
		[
			-12,
			-52
		],
		[
			-7,
			9
		],
		[
			-20,
			-27
		],
		[
			-6,
			5
		],
		[
			-29,
			-47
		],
		[
			-28,
			-60
		],
		[
			-7,
			21
		],
		[
			-91,
			-99
		]
	],
	[
		[
			26419,
			57669
		],
		[
			9,
			275
		],
		[
			22,
			48
		],
		[
			3,
			-26
		],
		[
			28,
			4
		],
		[
			22,
			63
		],
		[
			-5,
			57
		],
		[
			9,
			25
		],
		[
			-4,
			44
		],
		[
			17,
			62
		],
		[
			13,
			15
		],
		[
			8,
			48
		],
		[
			16,
			8
		],
		[
			15,
			45
		],
		[
			80,
			7
		],
		[
			11,
			50
		],
		[
			22,
			32
		],
		[
			5,
			26
		],
		[
			10,
			-7
		],
		[
			16,
			48
		],
		[
			4,
			35
		],
		[
			16,
			4
		],
		[
			8,
			40
		],
		[
			21,
			29
		],
		[
			24,
			-18
		],
		[
			26,
			115
		],
		[
			-3,
			63
		],
		[
			10,
			30
		],
		[
			15,
			-36
		],
		[
			20,
			98
		],
		[
			33,
			70
		],
		[
			10,
			-40
		],
		[
			-5,
			-70
		],
		[
			15,
			-20
		],
		[
			28,
			62
		],
		[
			15,
			93
		],
		[
			15,
			35
		],
		[
			17,
			21
		],
		[
			12,
			-5
		],
		[
			9,
			33
		],
		[
			19,
			-12
		],
		[
			4,
			-50
		],
		[
			15,
			0
		],
		[
			14,
			28
		],
		[
			33,
			200
		],
		[
			21,
			53
		],
		[
			11,
			12
		],
		[
			8,
			-23
		],
		[
			17,
			0
		],
		[
			-10,
			74
		],
		[
			7,
			65
		],
		[
			6,
			12
		],
		[
			-4,
			80
		],
		[
			9,
			60
		]
	],
	[
		[
			20923,
			73979
		],
		[
			188,
			-1
		],
		[
			322,
			0
		],
		[
			212,
			0
		],
		[
			92,
			0
		],
		[
			193,
			1
		],
		[
			160,
			-1
		],
		[
			135,
			0
		],
		[
			141,
			1
		],
		[
			256,
			1
		],
		[
			201,
			0
		]
	],
	[
		[
			23008,
			70412
		],
		[
			-210,
			-1
		],
		[
			-186,
			1
		],
		[
			-119,
			1
		],
		[
			-252,
			4
		],
		[
			-192,
			2
		],
		[
			-179,
			2
		],
		[
			-253,
			1
		],
		[
			-123,
			0
		],
		[
			-292,
			1
		],
		[
			-173,
			0
		],
		[
			-105,
			0
		]
	],
	[
		[
			20924,
			70423
		],
		[
			0,
			2828
		],
		[
			-1,
			17
		],
		[
			0,
			711
		]
	],
	[
		[
			23550,
			60009
		],
		[
			0,
			-581
		]
	],
	[
		[
			23550,
			59428
		],
		[
			6,
			-130
		],
		[
			7,
			-206
		],
		[
			6,
			-127
		],
		[
			14,
			-355
		],
		[
			4,
			-82
		],
		[
			15,
			-387
		],
		[
			-2,
			-319
		],
		[
			-3,
			-261
		],
		[
			-1,
			-235
		],
		[
			-2,
			-170
		],
		[
			-2,
			-417
		],
		[
			-5,
			-642
		]
	],
	[
		[
			23587,
			56097
		],
		[
			-9,
			-25
		],
		[
			-19,
			73
		],
		[
			-16,
			-13
		],
		[
			-1,
			23
		],
		[
			-17,
			-1
		],
		[
			-18,
			79
		],
		[
			-15,
			-16
		],
		[
			-12,
			5
		],
		[
			-21,
			78
		],
		[
			-7,
			58
		],
		[
			-22,
			2
		],
		[
			-23,
			85
		],
		[
			-27,
			28
		],
		[
			-7,
			-68
		],
		[
			-11,
			-32
		],
		[
			-13,
			-7
		],
		[
			-34,
			4
		],
		[
			0,
			15
		],
		[
			-21,
			-7
		],
		[
			-7,
			61
		],
		[
			-10,
			3
		],
		[
			-24,
			-52
		],
		[
			-20,
			3
		],
		[
			1,
			-45
		],
		[
			-13,
			9
		],
		[
			-9,
			-31
		],
		[
			-29,
			61
		],
		[
			-1,
			-30
		],
		[
			-30,
			-29
		],
		[
			-15,
			13
		],
		[
			1,
			-20
		],
		[
			-14,
			8
		],
		[
			-8,
			-90
		],
		[
			-14,
			-14
		],
		[
			-19,
			19
		],
		[
			-7,
			-81
		],
		[
			-12,
			-3
		],
		[
			-1,
			22
		],
		[
			-17,
			79
		],
		[
			-21,
			-6
		],
		[
			-8,
			57
		],
		[
			-11,
			-4
		],
		[
			-16,
			30
		],
		[
			12,
			58
		],
		[
			-25,
			16
		],
		[
			-8,
			-86
		],
		[
			-18,
			-9
		],
		[
			-4,
			42
		],
		[
			-13,
			14
		],
		[
			-6,
			-33
		],
		[
			-9,
			25
		],
		[
			-6,
			95
		],
		[
			-5,
			11
		],
		[
			-14,
			-27
		],
		[
			-6,
			15
		],
		[
			3,
			-73
		],
		[
			-16,
			-57
		],
		[
			-13,
			19
		],
		[
			11,
			-42
		],
		[
			-13,
			-22
		],
		[
			3,
			-64
		],
		[
			-11,
			-31
		],
		[
			-11,
			14
		],
		[
			-12,
			94
		],
		[
			10,
			30
		],
		[
			-2,
			66
		],
		[
			-9,
			28
		],
		[
			-10,
			-19
		],
		[
			-2,
			-42
		],
		[
			-13,
			19
		],
		[
			-9,
			-7
		],
		[
			-11,
			-64
		],
		[
			-20,
			5
		],
		[
			-5,
			30
		],
		[
			1,
			63
		],
		[
			-12,
			19
		],
		[
			-16,
			-27
		],
		[
			-11,
			25
		],
		[
			3,
			41
		],
		[
			-19,
			42
		],
		[
			-9,
			-3
		],
		[
			-12,
			-58
		],
		[
			-29,
			-92
		],
		[
			-12,
			-9
		],
		[
			-16,
			34
		],
		[
			-9,
			3
		],
		[
			4,
			65
		],
		[
			-5,
			-1
		],
		[
			7,
			60
		],
		[
			-7,
			20
		],
		[
			-13,
			-14
		],
		[
			-19,
			11
		],
		[
			-10,
			91
		],
		[
			8,
			35
		],
		[
			-4,
			50
		],
		[
			-17,
			-47
		],
		[
			-20,
			22
		],
		[
			-15,
			0
		],
		[
			-19,
			28
		],
		[
			-11,
			-40
		],
		[
			-3,
			-44
		],
		[
			-20,
			-26
		],
		[
			-24,
			96
		],
		[
			-21,
			23
		],
		[
			-12,
			-37
		],
		[
			-21,
			4
		],
		[
			-13,
			26
		],
		[
			-13,
			3
		],
		[
			-17,
			24
		],
		[
			-19,
			46
		],
		[
			-16,
			-27
		],
		[
			-9,
			15
		],
		[
			-12,
			-11
		],
		[
			-2,
			20
		],
		[
			-18,
			-3
		],
		[
			-5,
			140
		],
		[
			-18,
			56
		],
		[
			4,
			22
		],
		[
			-16,
			5
		],
		[
			-18,
			57
		],
		[
			-4,
			-92
		],
		[
			-12,
			-4
		],
		[
			-22,
			47
		],
		[
			-17,
			2
		],
		[
			-6,
			-49
		],
		[
			-30,
			15
		],
		[
			-24,
			78
		],
		[
			-37,
			143
		],
		[
			-20,
			-19
		],
		[
			0,
			2257
		],
		[
			-123,
			0
		],
		[
			-179,
			0
		],
		[
			-150,
			0
		],
		[
			-175,
			1
		],
		[
			-210,
			0
		]
	],
	[
		[
			21214,
			59429
		],
		[
			1,
			119
		],
		[
			0,
			463
		]
	],
	[
		[
			27478,
			65805
		],
		[
			48,
			61
		],
		[
			45,
			74
		],
		[
			9,
			24
		],
		[
			10,
			60
		],
		[
			13,
			3
		],
		[
			3,
			-28
		],
		[
			36,
			72
		],
		[
			47,
			74
		]
	],
	[
		[
			27689,
			66145
		],
		[
			0,
			-314
		],
		[
			1,
			-2
		],
		[
			247,
			-1
		],
		[
			77,
			3
		],
		[
			167,
			-2
		],
		[
			243,
			1
		],
		[
			105,
			3
		],
		[
			111,
			-4
		],
		[
			169,
			-1
		],
		[
			107,
			2
		],
		[
			14,
			-59
		],
		[
			5,
			4
		],
		[
			8,
			-100
		],
		[
			15,
			4
		],
		[
			27,
			-34
		],
		[
			10,
			-49
		],
		[
			-8,
			-32
		],
		[
			14,
			-21
		],
		[
			2,
			-159
		],
		[
			-8,
			-12
		],
		[
			25,
			-113
		],
		[
			1,
			-34
		],
		[
			11,
			5
		],
		[
			15,
			-33
		],
		[
			-2,
			-18
		],
		[
			25,
			3
		],
		[
			3,
			-22
		],
		[
			16,
			8
		],
		[
			-1,
			-30
		],
		[
			13,
			-55
		]
	],
	[
		[
			28900,
			63272
		],
		[
			-23,
			37
		],
		[
			-22,
			6
		],
		[
			-24,
			-20
		],
		[
			-15,
			-34
		],
		[
			-20,
			-82
		]
	],
	[
		[
			28796,
			63179
		],
		[
			-217,
			-1
		],
		[
			-118,
			-1
		],
		[
			-151,
			0
		],
		[
			-236,
			3
		],
		[
			-305,
			-2
		]
	],
	[
		[
			27769,
			63178
		],
		[
			-167,
			0
		],
		[
			-124,
			0
		],
		[
			0,
			1068
		]
	],
	[
		[
			27478,
			64246
		],
		[
			0,
			1559
		]
	],
	[
		[
			20920,
			69320
		],
		[
			5,
			4
		],
		[
			0,
			872
		],
		[
			-1,
			227
		]
	],
	[
		[
			23039,
			67577
		],
		[
			-40,
			0
		],
		[
			5,
			-22
		],
		[
			-7,
			-37
		],
		[
			22,
			-64
		],
		[
			-1,
			-110
		],
		[
			-14,
			-5
		],
		[
			8,
			-52
		],
		[
			-3,
			-31
		],
		[
			24,
			-3
		],
		[
			2,
			-83
		],
		[
			9,
			-35
		],
		[
			-7,
			-66
		],
		[
			-14,
			-16
		],
		[
			5,
			-56
		],
		[
			-8,
			-28
		],
		[
			6,
			-21
		],
		[
			-12,
			-46
		],
		[
			0,
			-80
		],
		[
			-11,
			-16
		],
		[
			-3,
			-52
		],
		[
			-11,
			-26
		],
		[
			1,
			-76
		],
		[
			15,
			-27
		],
		[
			17,
			-60
		],
		[
			10,
			-87
		],
		[
			-4,
			-45
		],
		[
			13,
			-31
		]
	],
	[
		[
			23041,
			66402
		],
		[
			-17,
			-7
		],
		[
			-5,
			30
		],
		[
			-24,
			-5
		],
		[
			-7,
			53
		],
		[
			-21,
			66
		],
		[
			7,
			52
		],
		[
			-11,
			16
		],
		[
			-21,
			3
		],
		[
			-1,
			40
		],
		[
			-28,
			35
		],
		[
			-12,
			-17
		],
		[
			-8,
			48
		],
		[
			-43,
			13
		],
		[
			-5,
			28
		],
		[
			-18,
			20
		],
		[
			-1,
			38
		],
		[
			-25,
			25
		],
		[
			-15,
			-14
		],
		[
			-15,
			13
		],
		[
			-7,
			-23
		],
		[
			-18,
			14
		],
		[
			-16,
			-13
		],
		[
			-16,
			11
		],
		[
			-18,
			-17
		],
		[
			-25,
			9
		],
		[
			-20,
			21
		],
		[
			-8,
			-11
		],
		[
			-9,
			-74
		],
		[
			-12,
			-29
		],
		[
			-19,
			-9
		],
		[
			-31,
			69
		],
		[
			-36,
			62
		],
		[
			-58,
			85
		],
		[
			-9,
			59
		],
		[
			-112,
			0
		],
		[
			-186,
			-1
		],
		[
			-153,
			1
		],
		[
			-214,
			-1
		],
		[
			-206,
			-2
		],
		[
			-62,
			4
		],
		[
			-178,
			0
		],
		[
			-143,
			1
		],
		[
			-293,
			1
		]
	],
	[
		[
			20922,
			66996
		],
		[
			0,
			345
		],
		[
			-1,
			8
		],
		[
			0,
			1828
		],
		[
			-1,
			143
		]
	],
	[
		[
			23587,
			56097
		],
		[
			8,
			8
		],
		[
			0,
			-54
		],
		[
			11,
			-25
		],
		[
			9,
			6
		],
		[
			-2,
			-36
		],
		[
			10,
			-9
		],
		[
			5,
			27
		],
		[
			8,
			-18
		],
		[
			3,
			29
		],
		[
			21,
			-27
		],
		[
			11,
			46
		],
		[
			12,
			-17
		],
		[
			5,
			-30
		],
		[
			6,
			21
		],
		[
			16,
			-22
		]
	],
	[
		[
			23710,
			55996
		],
		[
			0,
			0
		]
	],
	[
		[
			23710,
			55996
		],
		[
			1,
			-11
		],
		[
			0,
			-608
		]
	],
	[
		[
			23711,
			55377
		],
		[
			0,
			-1196
		],
		[
			8,
			-12
		],
		[
			11,
			-72
		],
		[
			18,
			-31
		],
		[
			9,
			-83
		],
		[
			15,
			-55
		],
		[
			-2,
			-34
		],
		[
			8,
			-56
		],
		[
			-7,
			-42
		],
		[
			3,
			-45
		],
		[
			-7,
			-28
		],
		[
			6,
			-51
		],
		[
			9,
			-32
		],
		[
			13,
			-6
		],
		[
			3,
			-35
		],
		[
			-6,
			-27
		],
		[
			14,
			-36
		],
		[
			-1,
			-32
		],
		[
			8,
			-15
		],
		[
			3,
			-49
		],
		[
			-6,
			-53
		],
		[
			12,
			-47
		],
		[
			6,
			2
		],
		[
			6,
			-113
		],
		[
			19,
			12
		],
		[
			-6,
			-102
		],
		[
			8,
			-31
		],
		[
			2,
			-54
		],
		[
			-13,
			-21
		],
		[
			-1,
			-33
		],
		[
			12,
			-55
		],
		[
			-9,
			-22
		],
		[
			-3,
			-38
		],
		[
			4,
			-63
		],
		[
			-9,
			-33
		],
		[
			-9,
			-63
		],
		[
			-3,
			-73
		],
		[
			-12,
			-25
		],
		[
			-2,
			-68
		],
		[
			-14,
			-30
		],
		[
			-3,
			-40
		],
		[
			7,
			-24
		],
		[
			5,
			-91
		],
		[
			-13,
			-51
		],
		[
			-6,
			-74
		],
		[
			16,
			-52
		],
		[
			1,
			-53
		],
		[
			-5,
			-39
		],
		[
			9,
			-79
		],
		[
			-12,
			-70
		],
		[
			9,
			-19
		],
		[
			-11,
			-51
		],
		[
			-14,
			-39
		],
		[
			-7,
			-78
		],
		[
			-13,
			-74
		],
		[
			-17,
			-45
		],
		[
			-2,
			-25
		],
		[
			9,
			-30
		],
		[
			17,
			-94
		]
	],
	[
		[
			23768,
			51502
		],
		[
			0,
			-14
		],
		[
			-46,
			3
		],
		[
			-37,
			-40
		],
		[
			-128,
			-208
		],
		[
			-28,
			-61
		],
		[
			-10,
			-54
		],
		[
			-15,
			7
		],
		[
			22,
			71
		],
		[
			9,
			47
		],
		[
			13,
			-1
		],
		[
			9,
			19
		],
		[
			8,
			46
		],
		[
			9,
			-16
		],
		[
			11,
			8
		],
		[
			-15,
			55
		],
		[
			-54,
			-54
		],
		[
			-8,
			26
		],
		[
			17,
			90
		],
		[
			4,
			80
		],
		[
			0,
			74
		],
		[
			-12,
			5
		],
		[
			-5,
			23
		],
		[
			-17,
			-29
		],
		[
			-10,
			-41
		],
		[
			-4,
			-50
		],
		[
			-15,
			-24
		],
		[
			-6,
			46
		],
		[
			-18,
			-45
		],
		[
			-2,
			-35
		],
		[
			9,
			-32
		],
		[
			-10,
			-50
		],
		[
			10,
			-55
		],
		[
			20,
			-17
		],
		[
			-6,
			-54
		],
		[
			11,
			-20
		],
		[
			2,
			-78
		],
		[
			-2,
			-67
		],
		[
			-8,
			-31
		],
		[
			-9,
			10
		],
		[
			-19,
			-71
		],
		[
			-22,
			-65
		],
		[
			-3,
			26
		],
		[
			-13,
			-8
		],
		[
			-2,
			-88
		],
		[
			6,
			-26
		],
		[
			13,
			44
		],
		[
			26,
			65
		],
		[
			3,
			19
		],
		[
			32,
			99
		],
		[
			15,
			23
		],
		[
			0,
			45
		],
		[
			26,
			-15
		],
		[
			-20,
			-61
		],
		[
			-62,
			-153
		],
		[
			-24,
			-69
		],
		[
			-4,
			-25
		],
		[
			-32,
			-91
		],
		[
			-40,
			-143
		],
		[
			-15,
			-8
		],
		[
			-69,
			-146
		],
		[
			-35,
			-80
		],
		[
			-53,
			-89
		],
		[
			-61,
			-112
		],
		[
			-34,
			-87
		],
		[
			-13,
			-42
		],
		[
			-15,
			-74
		],
		[
			-53,
			-111
		],
		[
			-24,
			-68
		],
		[
			-47,
			-155
		],
		[
			-32,
			-143
		],
		[
			-11,
			-83
		],
		[
			-14,
			-59
		],
		[
			-33,
			-221
		],
		[
			-24,
			-197
		],
		[
			-11,
			-127
		],
		[
			-10,
			-192
		],
		[
			-2,
			-108
		],
		[
			1,
			-103
		],
		[
			8,
			-205
		],
		[
			14,
			-207
		],
		[
			12,
			-134
		],
		[
			16,
			-229
		],
		[
			11,
			-260
		],
		[
			-7,
			47
		],
		[
			-5,
			147
		],
		[
			-12,
			189
		],
		[
			-11,
			152
		],
		[
			-24,
			16
		],
		[
			18,
			27
		],
		[
			-9,
			83
		],
		[
			-6,
			87
		],
		[
			-9,
			88
		],
		[
			-3,
			106
		],
		[
			1,
			138
		],
		[
			-1,
			122
		],
		[
			11,
			276
		],
		[
			16,
			180
		],
		[
			19,
			148
		],
		[
			14,
			70
		],
		[
			10,
			87
		],
		[
			8,
			35
		],
		[
			-2,
			47
		],
		[
			13,
			86
		],
		[
			18,
			38
		],
		[
			9,
			45
		],
		[
			18,
			127
		],
		[
			28,
			58
		],
		[
			8,
			53
		],
		[
			16,
			2
		],
		[
			35,
			105
		],
		[
			23,
			49
		],
		[
			24,
			23
		],
		[
			-4,
			43
		],
		[
			9,
			29
		],
		[
			-9,
			16
		],
		[
			-16,
			-41
		],
		[
			-20,
			-35
		],
		[
			-11,
			-40
		],
		[
			-17,
			-5
		],
		[
			-6,
			40
		],
		[
			0,
			60
		],
		[
			-18,
			12
		],
		[
			-6,
			-31
		],
		[
			0,
			-84
		],
		[
			-5,
			-25
		],
		[
			6,
			-41
		],
		[
			-4,
			-36
		],
		[
			-20,
			-56
		],
		[
			-17,
			-61
		],
		[
			-8,
			-1
		],
		[
			-18,
			30
		],
		[
			-3,
			43
		],
		[
			-32,
			-61
		],
		[
			-17,
			-67
		],
		[
			21,
			-22
		],
		[
			24,
			57
		],
		[
			8,
			-74
		],
		[
			-7,
			-23
		],
		[
			-38,
			-223
		],
		[
			-12,
			-2
		],
		[
			-6,
			55
		],
		[
			-21,
			-10
		],
		[
			-4,
			18
		],
		[
			-32,
			-11
		],
		[
			-11,
			12
		],
		[
			-6,
			-38
		],
		[
			12,
			-32
		],
		[
			15,
			-1
		],
		[
			11,
			17
		],
		[
			-4,
			-64
		],
		[
			7,
			-48
		],
		[
			15,
			-34
		],
		[
			17,
			-18
		],
		[
			-19,
			-146
		],
		[
			-13,
			-185
		],
		[
			-12,
			-106
		],
		[
			-20,
			-27
		],
		[
			-7,
			-27
		],
		[
			-11,
			18
		],
		[
			14,
			21
		],
		[
			3,
			59
		],
		[
			-8,
			3
		],
		[
			-6,
			-31
		],
		[
			-29,
			-75
		],
		[
			4,
			-32
		],
		[
			24,
			-16
		],
		[
			25,
			38
		],
		[
			8,
			2
		],
		[
			-5,
			-116
		],
		[
			3,
			-4
		],
		[
			-4,
			-202
		],
		[
			-6,
			-207
		],
		[
			-4,
			-3
		],
		[
			10,
			-230
		],
		[
			8,
			-65
		],
		[
			1,
			-84
		],
		[
			9,
			-1
		],
		[
			23,
			-215
		],
		[
			5,
			-29
		],
		[
			-9,
			-47
		],
		[
			4,
			-34
		],
		[
			-1,
			-62
		],
		[
			8,
			-72
		],
		[
			20,
			-11
		],
		[
			1,
			-35
		],
		[
			12,
			18
		],
		[
			2,
			-127
		],
		[
			-23,
			7
		],
		[
			-13,
			-8
		],
		[
			0,
			-19
		],
		[
			-21,
			-12
		],
		[
			-6,
			-99
		],
		[
			-20,
			11
		],
		[
			-7,
			40
		],
		[
			-15,
			3
		],
		[
			-6,
			55
		],
		[
			-11,
			4
		],
		[
			-18,
			98
		],
		[
			-31,
			12
		],
		[
			-11,
			33
		],
		[
			-17,
			-9
		],
		[
			-7,
			16
		],
		[
			-23,
			-17
		],
		[
			-4,
			18
		],
		[
			-13,
			-1
		],
		[
			-3,
			-29
		],
		[
			-10,
			31
		],
		[
			-20,
			-14
		],
		[
			-8,
			22
		],
		[
			-6,
			-22
		],
		[
			-14,
			20
		],
		[
			-8,
			30
		],
		[
			3,
			25
		],
		[
			-16,
			1
		],
		[
			-3,
			44
		],
		[
			-15,
			-1
		],
		[
			-21,
			75
		],
		[
			-9,
			-11
		],
		[
			-25,
			48
		],
		[
			-19,
			-22
		],
		[
			-13,
			35
		],
		[
			-15,
			69
		],
		[
			-10,
			8
		],
		[
			-2,
			33
		],
		[
			-8,
			12
		],
		[
			-18,
			-15
		],
		[
			-21,
			47
		],
		[
			-12,
			-3
		],
		[
			-8,
			20
		],
		[
			-12,
			-19
		],
		[
			-9,
			44
		],
		[
			6,
			50
		],
		[
			-10,
			56
		],
		[
			-11,
			13
		],
		[
			-3,
			98
		],
		[
			-6,
			42
		],
		[
			-3,
			79
		],
		[
			-8,
			25
		],
		[
			-1,
			49
		],
		[
			-7,
			64
		],
		[
			-17,
			43
		],
		[
			2,
			31
		],
		[
			-13,
			26
		],
		[
			-7,
			37
		],
		[
			5,
			20
		],
		[
			-11,
			46
		],
		[
			-9,
			7
		],
		[
			-1,
			52
		],
		[
			6,
			31
		],
		[
			-3,
			66
		],
		[
			4,
			29
		],
		[
			-4,
			86
		],
		[
			-16,
			25
		],
		[
			1,
			37
		],
		[
			-12,
			11
		],
		[
			9,
			30
		],
		[
			5,
			86
		],
		[
			-3,
			31
		],
		[
			4,
			60
		],
		[
			-13,
			10
		],
		[
			5,
			76
		],
		[
			-12,
			58
		],
		[
			-7,
			-14
		],
		[
			-7,
			46
		],
		[
			-9,
			-18
		],
		[
			-9,
			39
		],
		[
			-10,
			-6
		],
		[
			-18,
			90
		],
		[
			-9,
			11
		],
		[
			-3,
			38
		],
		[
			-8,
			-9
		],
		[
			-10,
			38
		],
		[
			0,
			50
		],
		[
			-7,
			26
		],
		[
			3,
			41
		],
		[
			-13,
			48
		],
		[
			2,
			47
		],
		[
			-17,
			16
		],
		[
			-7,
			81
		],
		[
			-10,
			23
		],
		[
			-8,
			70
		],
		[
			-35,
			53
		],
		[
			-4,
			53
		],
		[
			-7,
			-2
		],
		[
			-13,
			59
		],
		[
			2,
			38
		],
		[
			-17,
			100
		],
		[
			3,
			47
		],
		[
			-9,
			39
		],
		[
			9,
			29
		],
		[
			-12,
			11
		],
		[
			-9,
			47
		],
		[
			4,
			39
		],
		[
			-14,
			28
		],
		[
			1,
			33
		],
		[
			-15,
			28
		],
		[
			-4,
			51
		],
		[
			2,
			41
		],
		[
			-8,
			26
		],
		[
			-4,
			73
		],
		[
			-6,
			1
		],
		[
			-9,
			88
		],
		[
			-8,
			1
		],
		[
			-6,
			47
		],
		[
			1,
			76
		],
		[
			-7,
			106
		],
		[
			-18,
			46
		],
		[
			-10,
			40
		],
		[
			3,
			14
		],
		[
			-9,
			71
		],
		[
			-23,
			41
		],
		[
			-2,
			30
		],
		[
			-17,
			46
		],
		[
			-18,
			25
		],
		[
			-13,
			84
		],
		[
			0,
			21
		],
		[
			-26,
			21
		],
		[
			-6,
			44
		],
		[
			-23,
			7
		],
		[
			3,
			57
		],
		[
			-2,
			65
		],
		[
			-5,
			5
		],
		[
			-6,
			-67
		],
		[
			-6,
			27
		],
		[
			2,
			53
		],
		[
			-17,
			27
		],
		[
			-13,
			108
		],
		[
			-8,
			-4
		],
		[
			-9,
			32
		],
		[
			-13,
			-25
		],
		[
			-7,
			44
		],
		[
			-8,
			-27
		],
		[
			-37,
			-13
		],
		[
			-19,
			31
		],
		[
			-6,
			-8
		],
		[
			-15,
			22
		],
		[
			-22,
			-14
		],
		[
			-12,
			24
		],
		[
			-17,
			-7
		],
		[
			-4,
			-22
		],
		[
			-26,
			21
		],
		[
			-11,
			50
		],
		[
			-13,
			-3
		],
		[
			-20,
			40
		],
		[
			-14,
			-18
		],
		[
			-10,
			-111
		],
		[
			-34,
			19
		],
		[
			-9,
			-37
		],
		[
			-7,
			11
		],
		[
			-22,
			-32
		],
		[
			-7,
			10
		],
		[
			-8,
			-54
		],
		[
			2,
			-23
		],
		[
			-13,
			-40
		],
		[
			0,
			-50
		],
		[
			-7,
			0
		],
		[
			-2,
			-59
		],
		[
			-11,
			-30
		],
		[
			1,
			-33
		],
		[
			-7,
			-58
		],
		[
			2,
			-52
		],
		[
			-5,
			-48
		],
		[
			-10,
			-5
		],
		[
			-3,
			-72
		],
		[
			-5,
			-37
		],
		[
			10,
			-22
		],
		[
			-5,
			-38
		],
		[
			-18,
			-38
		],
		[
			-10,
			8
		],
		[
			-7,
			-67
		],
		[
			-17,
			-43
		],
		[
			-7,
			-36
		],
		[
			-4,
			-84
		],
		[
			-14,
			-8
		],
		[
			-17,
			15
		],
		[
			-15,
			-11
		],
		[
			-14,
			46
		],
		[
			-27,
			24
		],
		[
			-27,
			111
		],
		[
			-24,
			33
		],
		[
			-10,
			-8
		],
		[
			-22,
			38
		],
		[
			-18,
			77
		],
		[
			-13,
			24
		],
		[
			-39,
			21
		],
		[
			-17,
			28
		],
		[
			-19,
			61
		],
		[
			-11,
			12
		],
		[
			-19,
			81
		],
		[
			0,
			24
		],
		[
			-14,
			47
		],
		[
			-21,
			7
		],
		[
			-12,
			27
		],
		[
			-5,
			34
		],
		[
			-30,
			78
		],
		[
			-9,
			43
		],
		[
			-7,
			110
		],
		[
			-12,
			56
		],
		[
			-7,
			60
		],
		[
			-13,
			63
		],
		[
			0,
			59
		],
		[
			-7,
			57
		],
		[
			6,
			72
		],
		[
			-3,
			54
		],
		[
			2,
			55
		],
		[
			-7,
			68
		],
		[
			-11,
			30
		],
		[
			-3,
			44
		],
		[
			-13,
			39
		],
		[
			-1,
			30
		],
		[
			-13,
			34
		],
		[
			2,
			33
		],
		[
			-13,
			177
		],
		[
			-7,
			40
		],
		[
			-12,
			4
		],
		[
			-11,
			91
		],
		[
			-15,
			0
		],
		[
			-14,
			66
		],
		[
			-12,
			10
		],
		[
			-3,
			24
		],
		[
			-15,
			34
		],
		[
			-12,
			-4
		],
		[
			-7,
			28
		],
		[
			-31,
			39
		],
		[
			0,
			39
		],
		[
			-44,
			118
		],
		[
			-13,
			107
		],
		[
			-12,
			37
		],
		[
			-18,
			26
		],
		[
			-9,
			33
		],
		[
			-9,
			2
		],
		[
			-2,
			36
		],
		[
			-24,
			106
		],
		[
			-20,
			35
		],
		[
			-4,
			54
		],
		[
			-14,
			32
		],
		[
			-21,
			7
		],
		[
			-35,
			78
		],
		[
			-11,
			88
		],
		[
			-10,
			24
		],
		[
			-6,
			68
		],
		[
			-13,
			89
		],
		[
			-9,
			41
		],
		[
			-19,
			38
		],
		[
			-11,
			-19
		],
		[
			-11,
			41
		]
	],
	[
		[
			20232,
			53938
		],
		[
			-5,
			28
		],
		[
			-16,
			20
		],
		[
			1,
			23
		],
		[
			-10,
			25
		],
		[
			-3,
			38
		],
		[
			7,
			18
		],
		[
			1,
			101
		],
		[
			331,
			0
		],
		[
			250,
			-1
		],
		[
			226,
			0
		],
		[
			183,
			1
		],
		[
			0,
			1212
		],
		[
			2,
			254
		],
		[
			0,
			149
		],
		[
			2,
			417
		],
		[
			2,
			232
		],
		[
			0,
			1518
		],
		[
			1,
			434
		],
		[
			0,
			809
		],
		[
			-1,
			213
		],
		[
			11,
			0
		]
	],
	[
		[
			20922,
			66996
		],
		[
			0,
			-2328
		]
	],
	[
		[
			19530,
			64667
		],
		[
			-136,
			-2
		],
		[
			-143,
			-1
		],
		[
			-52,
			-3
		],
		[
			-133,
			1
		],
		[
			-93,
			2
		],
		[
			0,
			442
		],
		[
			1,
			219
		],
		[
			-1,
			508
		]
	],
	[
		[
			18973,
			65833
		],
		[
			0,
			676
		],
		[
			1,
			163
		],
		[
			0,
			1090
		],
		[
			-1,
			26
		],
		[
			0,
			516
		],
		[
			-1,
			267
		],
		[
			1,
			140
		]
	],
	[
		[
			18973,
			68711
		],
		[
			-2,
			175
		],
		[
			-1,
			282
		],
		[
			1,
			156
		],
		[
			75,
			2
		],
		[
			22,
			-12
		],
		[
			85,
			2
		],
		[
			11,
			8
		],
		[
			45,
			-5
		],
		[
			25,
			8
		],
		[
			87,
			-2
		],
		[
			194,
			5
		],
		[
			11,
			-7
		],
		[
			221,
			0
		],
		[
			316,
			0
		],
		[
			14,
			-4
		],
		[
			144,
			-2
		],
		[
			178,
			-1
		],
		[
			23,
			7
		],
		[
			132,
			0
		],
		[
			251,
			-2
		],
		[
			115,
			-1
		]
	],
	[
		[
			29908,
			65840
		],
		[
			0,
			-107
		],
		[
			3,
			-222
		],
		[
			0,
			-150
		],
		[
			-3,
			-209
		],
		[
			-12,
			-8
		],
		[
			3,
			-76
		],
		[
			-8,
			-29
		]
	],
	[
		[
			29891,
			65039
		],
		[
			-7,
			19
		],
		[
			-17,
			2
		],
		[
			-21,
			-24
		],
		[
			-18,
			3
		],
		[
			-13,
			-24
		],
		[
			-16,
			28
		],
		[
			-6,
			-37
		],
		[
			-49,
			-35
		],
		[
			-3,
			20
		],
		[
			-15,
			0
		],
		[
			-27,
			-33
		],
		[
			-6,
			21
		],
		[
			-26,
			1
		],
		[
			-7,
			-26
		],
		[
			-18,
			23
		],
		[
			-40,
			-27
		],
		[
			-3,
			60
		],
		[
			-9,
			-17
		],
		[
			-19,
			-82
		],
		[
			-12,
			0
		],
		[
			-22,
			-73
		],
		[
			-13,
			23
		],
		[
			-24,
			-58
		],
		[
			-7,
			13
		],
		[
			-23,
			-28
		],
		[
			5,
			-22
		],
		[
			-10,
			-32
		],
		[
			-29,
			-11
		],
		[
			-22,
			-54
		],
		[
			-9,
			15
		],
		[
			-15,
			-35
		]
	],
	[
		[
			29390,
			64649
		],
		[
			1,
			33
		],
		[
			-20,
			102
		],
		[
			68,
			130
		],
		[
			-19,
			97
		],
		[
			4,
			161
		],
		[
			5,
			295
		],
		[
			9,
			422
		]
	],
	[
		[
			23231,
			64184
		],
		[
			167,
			-9
		],
		[
			159,
			-8
		],
		[
			156,
			3
		],
		[
			130,
			8
		],
		[
			62,
			0
		],
		[
			197,
			12
		],
		[
			152,
			13
		],
		[
			101,
			14
		],
		[
			12,
			-38
		],
		[
			1,
			-33
		],
		[
			18,
			-14
		],
		[
			-1,
			-36
		],
		[
			16,
			-57
		],
		[
			10,
			-2
		],
		[
			1,
			-56
		],
		[
			11,
			-31
		],
		[
			19,
			-7
		]
	],
	[
		[
			24442,
			63943
		],
		[
			-8,
			-18
		],
		[
			-17,
			-144
		],
		[
			-2,
			-71
		],
		[
			6,
			-165
		],
		[
			14,
			-99
		],
		[
			7,
			-28
		],
		[
			-8,
			-66
		],
		[
			5,
			-38
		],
		[
			15,
			-34
		],
		[
			4,
			-28
		],
		[
			-3,
			-61
		],
		[
			26,
			-77
		],
		[
			15,
			-57
		],
		[
			11,
			-14
		],
		[
			10,
			-69
		],
		[
			13,
			-8
		],
		[
			11,
			-76
		],
		[
			16,
			-54
		],
		[
			59,
			-137
		],
		[
			20,
			-90
		],
		[
			3,
			-90
		],
		[
			8,
			-78
		],
		[
			-9,
			-36
		],
		[
			11,
			-85
		],
		[
			3,
			-65
		],
		[
			22,
			-69
		],
		[
			11,
			7
		],
		[
			11,
			32
		],
		[
			9,
			66
		],
		[
			19,
			4
		],
		[
			27,
			-45
		],
		[
			16,
			-5
		],
		[
			38,
			-82
		],
		[
			-2,
			-60
		],
		[
			-12,
			-29
		],
		[
			-13,
			-59
		],
		[
			10,
			-92
		],
		[
			-2,
			-37
		],
		[
			-22,
			-96
		],
		[
			-6,
			-99
		],
		[
			-17,
			-68
		],
		[
			-7,
			-52
		],
		[
			-1,
			-78
		],
		[
			5,
			-70
		],
		[
			18,
			-50
		],
		[
			20,
			-89
		],
		[
			25,
			-37
		],
		[
			11,
			-54
		],
		[
			8,
			0
		],
		[
			17,
			-60
		],
		[
			16,
			7
		],
		[
			3,
			-27
		],
		[
			-12,
			-24
		],
		[
			6,
			-50
		],
		[
			20,
			-5
		],
		[
			10,
			31
		],
		[
			13,
			-28
		],
		[
			1,
			-29
		],
		[
			15,
			-12
		],
		[
			23,
			-70
		],
		[
			-2,
			-40
		],
		[
			14,
			-3
		],
		[
			9,
			-42
		],
		[
			19,
			-24
		],
		[
			0,
			-57
		],
		[
			11,
			-68
		],
		[
			-13,
			-8
		],
		[
			2,
			-50
		],
		[
			26,
			-161
		],
		[
			-4,
			-62
		],
		[
			-15,
			-12
		],
		[
			-8,
			-56
		],
		[
			17,
			-53
		],
		[
			-1,
			-47
		],
		[
			13,
			-87
		],
		[
			11,
			-46
		],
		[
			-1,
			-53
		],
		[
			24,
			-56
		],
		[
			10,
			27
		],
		[
			-15,
			45
		],
		[
			14,
			12
		],
		[
			17,
			-56
		],
		[
			8,
			-53
		],
		[
			11,
			14
		]
	],
	[
		[
			25079,
			59990
		],
		[
			9,
			-21
		],
		[
			-5,
			-90
		],
		[
			-6,
			-46
		],
		[
			-10,
			-9
		],
		[
			-1,
			-38
		],
		[
			17,
			-37
		],
		[
			-3,
			-28
		],
		[
			-16,
			3
		],
		[
			-4,
			-44
		],
		[
			11,
			-58
		],
		[
			-8,
			-29
		],
		[
			-7,
			-71
		],
		[
			-13,
			-18
		],
		[
			-18,
			78
		],
		[
			-13,
			-13
		],
		[
			-13,
			-142
		]
	],
	[
		[
			24999,
			59427
		],
		[
			-8,
			-40
		],
		[
			-13,
			7
		],
		[
			2,
			31
		]
	],
	[
		[
			24980,
			59425
		],
		[
			6,
			38
		],
		[
			-5,
			49
		],
		[
			-21,
			2
		],
		[
			-4,
			-30
		],
		[
			9,
			-58
		]
	],
	[
		[
			24965,
			59426
		],
		[
			6,
			-22
		],
		[
			-7,
			-64
		],
		[
			10,
			-59
		],
		[
			-5,
			-37
		],
		[
			-24,
			-1
		],
		[
			0,
			-37
		],
		[
			21,
			-39
		],
		[
			1,
			-27
		],
		[
			-15,
			-15
		],
		[
			-30,
			16
		],
		[
			-3,
			-21
		],
		[
			28,
			-74
		],
		[
			1,
			-61
		],
		[
			-22,
			-40
		],
		[
			-3,
			-75
		],
		[
			-12,
			-23
		]
	],
	[
		[
			24911,
			58847
		],
		[
			-179,
			-6
		],
		[
			16,
			110
		],
		[
			23,
			58
		],
		[
			0,
			23
		],
		[
			15,
			53
		],
		[
			16,
			28
		],
		[
			3,
			43
		],
		[
			9,
			7
		],
		[
			5,
			133
		],
		[
			-22,
			44
		],
		[
			3,
			15
		],
		[
			-5,
			71
		],
		[
			-349,
			-1
		],
		[
			-323,
			1
		],
		[
			-141,
			0
		],
		[
			-222,
			1
		],
		[
			-210,
			1
		]
	],
	[
		[
			23358,
			63503
		],
		[
			-31,
			56
		],
		[
			8,
			79
		],
		[
			-24,
			76
		],
		[
			-2,
			77
		],
		[
			-20,
			19
		],
		[
			1,
			32
		],
		[
			-18,
			26
		],
		[
			-12,
			110
		],
		[
			1,
			39
		],
		[
			-11,
			34
		],
		[
			-1,
			40
		],
		[
			13,
			42
		],
		[
			-11,
			18
		],
		[
			-1,
			-33
		],
		[
			-20,
			3
		],
		[
			1,
			63
		]
	],
	[
		[
			26900,
			61666
		],
		[
			18,
			-20
		],
		[
			35,
			40
		],
		[
			23,
			11
		],
		[
			5,
			49
		],
		[
			3,
			98
		],
		[
			12,
			28
		],
		[
			16,
			-7
		],
		[
			6,
			30
		],
		[
			-3,
			101
		],
		[
			-10,
			105
		],
		[
			21,
			52
		],
		[
			0,
			67
		],
		[
			14,
			88
		],
		[
			12,
			27
		],
		[
			6,
			37
		],
		[
			13,
			-40
		],
		[
			11,
			-1
		],
		[
			12,
			-79
		],
		[
			-8,
			-40
		],
		[
			11,
			-20
		],
		[
			9,
			22
		],
		[
			3,
			42
		],
		[
			9,
			20
		],
		[
			9,
			-25
		],
		[
			4,
			111
		],
		[
			-10,
			29
		],
		[
			-3,
			43
		],
		[
			19,
			19
		],
		[
			-3,
			96
		],
		[
			8,
			41
		],
		[
			10,
			12
		],
		[
			3,
			55
		],
		[
			31,
			-7
		],
		[
			3,
			83
		],
		[
			25,
			76
		],
		[
			17,
			-19
		],
		[
			6,
			-52
		],
		[
			11,
			3
		],
		[
			21,
			47
		],
		[
			17,
			8
		],
		[
			11,
			54
		],
		[
			11,
			8
		],
		[
			8,
			48
		],
		[
			16,
			57
		],
		[
			30,
			89
		],
		[
			16,
			9
		],
		[
			4,
			83
		],
		[
			10,
			26
		],
		[
			-11,
			50
		],
		[
			12,
			48
		],
		[
			0,
			57
		],
		[
			10,
			23
		],
		[
			-4,
			60
		],
		[
			13,
			-11
		],
		[
			-2,
			52
		],
		[
			7,
			20
		],
		[
			0,
			122
		],
		[
			9,
			30
		],
		[
			0,
			58
		],
		[
			10,
			48
		],
		[
			5,
			61
		],
		[
			10,
			23
		],
		[
			5,
			65
		],
		[
			-3,
			95
		],
		[
			4,
			71
		],
		[
			-9,
			84
		],
		[
			-11,
			44
		],
		[
			9,
			50
		],
		[
			14,
			-1
		],
		[
			18,
			27
		]
	],
	[
		[
			27769,
			63178
		],
		[
			-3,
			-600
		],
		[
			10,
			7
		],
		[
			33,
			103
		],
		[
			12,
			-1
		],
		[
			10,
			67
		],
		[
			31,
			60
		],
		[
			13,
			75
		],
		[
			11,
			-2
		],
		[
			28,
			-36
		],
		[
			11,
			54
		],
		[
			38,
			158
		],
		[
			13,
			-10
		],
		[
			-13,
			-14
		],
		[
			13,
			-18
		],
		[
			2,
			-26
		],
		[
			20,
			-34
		],
		[
			17,
			1
		],
		[
			7,
			-18
		],
		[
			28,
			-4
		],
		[
			14,
			38
		],
		[
			-7,
			49
		],
		[
			13,
			-1
		],
		[
			-11,
			32
		],
		[
			14,
			-11
		],
		[
			9,
			37
		],
		[
			19,
			-23
		],
		[
			28,
			87
		],
		[
			24,
			-20
		],
		[
			17,
			-49
		],
		[
			8,
			-40
		],
		[
			18,
			20
		],
		[
			17,
			-23
		],
		[
			14,
			4
		],
		[
			0,
			-37
		],
		[
			-16,
			-15
		],
		[
			12,
			-69
		],
		[
			19,
			-41
		],
		[
			-2,
			-33
		],
		[
			9,
			-12
		],
		[
			5,
			-43
		],
		[
			-6,
			-63
		],
		[
			10,
			-14
		]
	],
	[
		[
			28258,
			62713
		],
		[
			-9,
			-45
		],
		[
			-21,
			-175
		],
		[
			-78,
			209
		],
		[
			-66,
			179
		],
		[
			-4,
			-62
		],
		[
			5,
			-28
		],
		[
			-6,
			-36
		],
		[
			7,
			-11
		],
		[
			-23,
			-106
		],
		[
			6,
			-15
		],
		[
			-11,
			-54
		],
		[
			10,
			-36
		],
		[
			-16,
			-62
		],
		[
			-7,
			-7
		],
		[
			-24,
			-88
		],
		[
			6,
			-16
		],
		[
			-14,
			-63
		],
		[
			-7,
			21
		],
		[
			-15,
			-66
		],
		[
			-10,
			-24
		],
		[
			0,
			36
		],
		[
			-23,
			-71
		],
		[
			-20,
			-130
		],
		[
			-35,
			101
		],
		[
			-9,
			-69
		],
		[
			-17,
			-82
		],
		[
			-1,
			-71
		],
		[
			-8,
			1
		],
		[
			-10,
			-57
		],
		[
			-15,
			-138
		],
		[
			-28,
			-94
		],
		[
			-46,
			53
		],
		[
			-17,
			109
		],
		[
			-31,
			47
		],
		[
			-14,
			-121
		],
		[
			3,
			-65
		],
		[
			-12,
			-60
		],
		[
			-22,
			-87
		],
		[
			6,
			-44
		],
		[
			-12,
			-21
		],
		[
			-25,
			-81
		],
		[
			-7,
			-56
		],
		[
			6,
			-29
		],
		[
			-8,
			-30
		],
		[
			-6,
			-60
		],
		[
			-10,
			-51
		],
		[
			-18,
			-51
		],
		[
			-30,
			-104
		],
		[
			-21,
			-112
		],
		[
			2,
			-36
		],
		[
			-12,
			-39
		],
		[
			4,
			-41
		],
		[
			17,
			-34
		],
		[
			-12,
			-40
		],
		[
			-18,
			-34
		],
		[
			-1,
			-32
		],
		[
			13,
			-4
		],
		[
			-4,
			-29
		],
		[
			-49,
			-99
		],
		[
			-10,
			68
		],
		[
			-12,
			-9
		],
		[
			-19,
			-47
		],
		[
			-41,
			-71
		],
		[
			-4,
			26
		],
		[
			-21,
			38
		],
		[
			-7,
			-51
		],
		[
			9,
			-43
		],
		[
			-19,
			-47
		],
		[
			-17,
			-5
		],
		[
			-37,
			-27
		],
		[
			-31,
			-51
		],
		[
			-27,
			75
		],
		[
			-11,
			45
		],
		[
			-8,
			-21
		],
		[
			-8,
			-55
		],
		[
			-23,
			-17
		],
		[
			-2,
			-30
		],
		[
			-13,
			-29
		],
		[
			-34,
			-7
		],
		[
			-19,
			48
		],
		[
			0,
			24
		],
		[
			-12,
			25
		],
		[
			-18,
			3
		],
		[
			-7,
			52
		],
		[
			-14,
			31
		],
		[
			-2,
			90
		],
		[
			-15,
			22
		],
		[
			-1,
			33
		],
		[
			18,
			34
		],
		[
			-11,
			29
		]
	],
	[
		[
			27075,
			60636
		],
		[
			-14,
			-4
		],
		[
			-28,
			30
		],
		[
			-3,
			37
		],
		[
			-8,
			1
		],
		[
			-7,
			40
		],
		[
			-9,
			-2
		],
		[
			-7,
			42
		],
		[
			-15,
			11
		],
		[
			-13,
			134
		],
		[
			-10,
			19
		],
		[
			-13,
			61
		],
		[
			1,
			34
		],
		[
			-15,
			19
		],
		[
			-8,
			39
		],
		[
			11,
			55
		],
		[
			-15,
			22
		],
		[
			-9,
			80
		],
		[
			-10,
			45
		],
		[
			-15,
			37
		],
		[
			0,
			38
		],
		[
			8,
			0
		],
		[
			3,
			55
		],
		[
			-4,
			20
		],
		[
			11,
			33
		],
		[
			1,
			58
		],
		[
			-8,
			36
		],
		[
			1,
			90
		]
	],
	[
		[
			24442,
			63943
		],
		[
			12,
			16
		],
		[
			-2,
			50
		],
		[
			4,
			90
		],
		[
			-11,
			35
		],
		[
			13,
			69
		],
		[
			31,
			43
		],
		[
			18,
			-1
		],
		[
			18,
			41
		],
		[
			1,
			61
		],
		[
			6,
			49
		],
		[
			1,
			67
		],
		[
			10,
			27
		],
		[
			14,
			66
		],
		[
			11,
			19
		],
		[
			6,
			106
		],
		[
			-1,
			98
		],
		[
			-13,
			75
		],
		[
			-13,
			6
		],
		[
			-20,
			85
		],
		[
			11,
			77
		],
		[
			2,
			74
		],
		[
			6,
			55
		],
		[
			19,
			21
		],
		[
			13,
			-15
		],
		[
			23,
			40
		],
		[
			31,
			-6
		],
		[
			24,
			17
		],
		[
			16,
			56
		],
		[
			10,
			13
		],
		[
			26,
			-1
		],
		[
			18,
			57
		],
		[
			16,
			21
		],
		[
			-1,
			66
		],
		[
			9,
			59
		],
		[
			0,
			52
		],
		[
			9,
			29
		],
		[
			28,
			49
		],
		[
			-1,
			41
		],
		[
			8,
			72
		],
		[
			-3,
			58
		],
		[
			7,
			61
		],
		[
			-7,
			37
		],
		[
			1,
			89
		],
		[
			-13,
			41
		],
		[
			-47,
			73
		],
		[
			-15,
			74
		],
		[
			3,
			60
		],
		[
			-16,
			63
		],
		[
			-22,
			37
		],
		[
			-2,
			26
		],
		[
			-22,
			35
		],
		[
			0,
			47
		]
	],
	[
		[
			24658,
			66423
		],
		[
			45,
			-2
		],
		[
			227,
			-2
		],
		[
			51,
			-5
		],
		[
			194,
			-11
		],
		[
			41,
			4
		],
		[
			152,
			1
		],
		[
			82,
			-5
		]
	],
	[
		[
			25450,
			66403
		],
		[
			-2,
			-124
		],
		[
			-8,
			-97
		],
		[
			10,
			-109
		],
		[
			21,
			-117
		],
		[
			12,
			-37
		],
		[
			3,
			-54
		],
		[
			13,
			-139
		],
		[
			4,
			-75
		],
		[
			14,
			-93
		],
		[
			8,
			-20
		],
		[
			2,
			-47
		]
	],
	[
		[
			25386,
			60941
		],
		[
			-8,
			-66
		],
		[
			-17,
			-35
		],
		[
			-11,
			-56
		],
		[
			7,
			-105
		],
		[
			20,
			-68
		],
		[
			-6,
			-50
		],
		[
			-48,
			-19
		],
		[
			-12,
			-11
		],
		[
			-18,
			-52
		],
		[
			-14,
			26
		],
		[
			-18,
			-44
		],
		[
			-2,
			-55
		],
		[
			-9,
			-65
		],
		[
			2,
			-25
		],
		[
			17,
			-65
		],
		[
			7,
			-66
		],
		[
			-10,
			-89
		],
		[
			-15,
			-10
		],
		[
			-13,
			13
		],
		[
			-19,
			52
		],
		[
			-35,
			40
		],
		[
			-14,
			39
		],
		[
			-31,
			42
		],
		[
			-19,
			5
		],
		[
			-13,
			-21
		],
		[
			-13,
			-42
		],
		[
			-9,
			-65
		],
		[
			-16,
			-52
		],
		[
			-4,
			-55
		],
		[
			14,
			-52
		]
	],
	[
		[
			20232,
			53938
		],
		[
			-214,
			0
		],
		[
			-254,
			0
		],
		[
			0,
			-524
		],
		[
			-234,
			-1
		]
	],
	[
		[
			24911,
			58847
		],
		[
			4,
			-38
		],
		[
			18,
			-49
		],
		[
			0,
			-45
		],
		[
			-24,
			23
		],
		[
			-9,
			-49
		],
		[
			20,
			-36
		],
		[
			-11,
			-33
		],
		[
			-11,
			-1
		],
		[
			-9,
			-52
		],
		[
			-17,
			-22
		],
		[
			-9,
			21
		],
		[
			-15,
			-41
		],
		[
			6,
			-68
		],
		[
			9,
			-17
		],
		[
			12,
			23
		],
		[
			3,
			-38
		],
		[
			-26,
			-42
		],
		[
			1,
			-53
		],
		[
			9,
			-10
		],
		[
			-3,
			-40
		],
		[
			-22,
			56
		],
		[
			-9,
			-9
		],
		[
			-5,
			-58
		],
		[
			9,
			-42
		],
		[
			-11,
			-75
		],
		[
			-8,
			88
		],
		[
			-23,
			-67
		],
		[
			-3,
			-46
		],
		[
			12,
			-6
		],
		[
			2,
			43
		],
		[
			15,
			-35
		],
		[
			-9,
			-47
		],
		[
			0,
			-45
		],
		[
			-16,
			-10
		],
		[
			4,
			-47
		],
		[
			15,
			-7
		],
		[
			6,
			-29
		],
		[
			-12,
			-43
		],
		[
			15,
			-58
		],
		[
			-10,
			-25
		],
		[
			-12,
			21
		],
		[
			-9,
			-26
		],
		[
			-9,
			-100
		],
		[
			-25,
			13
		],
		[
			-3,
			-49
		]
	],
	[
		[
			24751,
			57677
		],
		[
			17,
			-55
		],
		[
			0,
			-45
		],
		[
			-18,
			-44
		],
		[
			-31,
			-44
		],
		[
			-4,
			59
		],
		[
			-11,
			2
		],
		[
			-2,
			-29
		],
		[
			8,
			-44
		],
		[
			-5,
			-25
		],
		[
			6,
			-72
		],
		[
			-14,
			-19
		],
		[
			-5,
			34
		],
		[
			2,
			57
		],
		[
			-10,
			-27
		],
		[
			2,
			-35
		],
		[
			-7,
			-14
		],
		[
			6,
			-40
		],
		[
			20,
			-2
		],
		[
			2,
			-31
		],
		[
			-14,
			-50
		],
		[
			-11,
			18
		],
		[
			1,
			49
		],
		[
			-10,
			-21
		],
		[
			0,
			-64
		],
		[
			12,
			-61
		],
		[
			1,
			-27
		],
		[
			-13,
			-51
		],
		[
			6,
			-83
		],
		[
			-25,
			-57
		],
		[
			0,
			-63
		],
		[
			-10,
			1
		],
		[
			3,
			54
		],
		[
			-19,
			-1
		],
		[
			-5,
			-27
		],
		[
			8,
			-45
		],
		[
			-7,
			-30
		],
		[
			-19,
			-15
		],
		[
			-4,
			-71
		],
		[
			-16,
			43
		],
		[
			-9,
			-29
		],
		[
			14,
			-43
		],
		[
			20,
			1
		],
		[
			2,
			-25
		],
		[
			-13,
			-28
		],
		[
			-16,
			33
		],
		[
			-12,
			-32
		],
		[
			9,
			-51
		],
		[
			11,
			3
		],
		[
			3,
			-24
		],
		[
			-8,
			-61
		],
		[
			-24,
			-6
		],
		[
			7,
			-45
		],
		[
			-11,
			-16
		],
		[
			-5,
			43
		],
		[
			-16,
			-23
		],
		[
			-3,
			-29
		],
		[
			22,
			-34
		],
		[
			-18,
			-78
		],
		[
			7,
			-55
		],
		[
			16,
			-26
		],
		[
			-10,
			-34
		],
		[
			-8,
			18
		],
		[
			-24,
			-2
		],
		[
			-1,
			-59
		],
		[
			10,
			-26
		],
		[
			13,
			14
		],
		[
			8,
			-50
		],
		[
			-12,
			-18
		],
		[
			-16,
			22
		],
		[
			-7,
			35
		],
		[
			-17,
			-16
		],
		[
			-2,
			-28
		],
		[
			25,
			-51
		],
		[
			2,
			-33
		],
		[
			-28,
			-41
		],
		[
			13,
			-63
		],
		[
			-14,
			-80
		],
		[
			18,
			16
		],
		[
			-1,
			51
		],
		[
			14,
			-27
		],
		[
			-4,
			-54
		],
		[
			-17,
			-10
		],
		[
			-3,
			-19
		],
		[
			10,
			-24
		],
		[
			17,
			14
		],
		[
			10,
			73
		],
		[
			5,
			-32
		],
		[
			-23,
			-90
		],
		[
			0,
			-64
		],
		[
			12,
			-68
		],
		[
			3,
			42
		],
		[
			10,
			13
		],
		[
			2,
			-23
		],
		[
			-13,
			-52
		],
		[
			2,
			-75
		],
		[
			-3,
			-23
		],
		[
			-14,
			-8
		],
		[
			-11,
			14
		],
		[
			-5,
			-39
		],
		[
			23,
			-62
		],
		[
			-13,
			-59
		]
	],
	[
		[
			24512,
			55359
		],
		[
			-219,
			4
		],
		[
			-154,
			5
		],
		[
			-157,
			7
		],
		[
			-86,
			0
		],
		[
			-185,
			2
		]
	],
	[
		[
			16868,
			55911
		],
		[
			16,
			-5
		],
		[
			28,
			-53
		],
		[
			21,
			-22
		],
		[
			1,
			-25
		],
		[
			16,
			-61
		],
		[
			-5,
			-43
		],
		[
			-13,
			25
		],
		[
			-26,
			7
		],
		[
			-6,
			35
		],
		[
			0,
			74
		],
		[
			-20,
			16
		],
		[
			-12,
			52
		]
	],
	[
		[
			16867,
			55390
		],
		[
			9,
			4
		],
		[
			22,
			-117
		],
		[
			40,
			-130
		],
		[
			-10,
			4
		],
		[
			-11,
			-22
		],
		[
			-17,
			44
		],
		[
			-13,
			72
		],
		[
			-14,
			119
		],
		[
			-6,
			26
		]
	],
	[
		[
			16741,
			55926
		],
		[
			8,
			7
		],
		[
			1,
			-41
		],
		[
			-11,
			7
		],
		[
			2,
			27
		]
	],
	[
		[
			16637,
			56552
		],
		[
			8,
			-17
		],
		[
			11,
			14
		],
		[
			0,
			-30
		],
		[
			-17,
			-4
		],
		[
			-9,
			21
		],
		[
			7,
			16
		]
	],
	[
		[
			16596,
			55679
		],
		[
			14,
			7
		],
		[
			20,
			-35
		],
		[
			8,
			-31
		],
		[
			-13,
			-15
		],
		[
			-20,
			21
		],
		[
			-9,
			53
		]
	],
	[
		[
			16501,
			56608
		],
		[
			18,
			-7
		],
		[
			13,
			-22
		],
		[
			15,
			5
		],
		[
			19,
			-43
		],
		[
			19,
			-4
		],
		[
			7,
			39
		],
		[
			20,
			-20
		],
		[
			-11,
			-43
		],
		[
			-28,
			-11
		],
		[
			-17,
			-31
		],
		[
			-42,
			24
		],
		[
			-1,
			61
		],
		[
			-12,
			52
		]
	],
	[
		[
			16410,
			56520
		],
		[
			22,
			8
		],
		[
			9,
			21
		],
		[
			13,
			-8
		],
		[
			13,
			19
		],
		[
			0,
			-48
		],
		[
			18,
			-13
		],
		[
			1,
			-48
		],
		[
			-41,
			-54
		],
		[
			-16,
			37
		],
		[
			-19,
			86
		]
	],
	[
		[
			16354,
			56562
		],
		[
			16,
			17
		],
		[
			6,
			28
		],
		[
			6,
			-35
		],
		[
			13,
			-26
		],
		[
			-21,
			-6
		],
		[
			-20,
			22
		]
	],
	[
		[
			15305,
			65829
		],
		[
			155,
			-4
		],
		[
			9,
			6
		],
		[
			77,
			-1
		],
		[
			56,
			12
		],
		[
			28,
			-8
		],
		[
			115,
			2
		],
		[
			37,
			5
		],
		[
			95,
			-1
		],
		[
			45,
			-5
		],
		[
			154,
			-8
		],
		[
			114,
			-4
		],
		[
			197,
			0
		],
		[
			92,
			2
		]
	],
	[
		[
			16479,
			65825
		],
		[
			0,
			-1
		]
	],
	[
		[
			16479,
			65824
		],
		[
			0,
			-1448
		],
		[
			1,
			-34
		],
		[
			0,
			-756
		],
		[
			-1,
			-393
		],
		[
			-1,
			-13
		],
		[
			0,
			-457
		],
		[
			-1,
			-122
		],
		[
			2,
			-263
		],
		[
			26,
			-77
		],
		[
			115,
			-330
		],
		[
			114,
			-336
		],
		[
			63,
			-182
		],
		[
			99,
			-298
		],
		[
			125,
			-377
		],
		[
			62,
			-186
		],
		[
			127,
			-394
		],
		[
			313,
			-989
		],
		[
			234,
			-759
		],
		[
			70,
			-234
		],
		[
			147,
			-492
		]
	],
	[
		[
			17950,
			55027
		],
		[
			-416,
			-126
		],
		[
			-254,
			-89
		],
		[
			-3,
			98
		],
		[
			-9,
			62
		],
		[
			-8,
			20
		],
		[
			-14,
			-23
		],
		[
			-3,
			66
		],
		[
			1,
			71
		],
		[
			-8,
			41
		],
		[
			9,
			61
		],
		[
			-9,
			161
		],
		[
			-13,
			127
		],
		[
			-9,
			54
		],
		[
			-40,
			193
		],
		[
			-25,
			61
		],
		[
			-10,
			51
		],
		[
			-15,
			37
		],
		[
			-9,
			-2
		],
		[
			-19,
			95
		],
		[
			-26,
			59
		],
		[
			-14,
			15
		],
		[
			-20,
			57
		],
		[
			-25,
			88
		],
		[
			-24,
			39
		],
		[
			-2,
			-47
		],
		[
			-21,
			-23
		],
		[
			-18,
			14
		],
		[
			-10,
			25
		],
		[
			-15,
			6
		],
		[
			-4,
			38
		],
		[
			9,
			34
		],
		[
			1,
			43
		],
		[
			-14,
			116
		],
		[
			-11,
			64
		],
		[
			-17,
			50
		],
		[
			-35,
			1
		],
		[
			-22,
			-8
		],
		[
			-16,
			-36
		],
		[
			-14,
			38
		],
		[
			-28,
			16
		],
		[
			-37,
			59
		],
		[
			-12,
			2
		],
		[
			-24,
			53
		],
		[
			-17,
			141
		],
		[
			-10,
			10
		],
		[
			-17,
			53
		],
		[
			-4,
			-3
		],
		[
			-20,
			65
		],
		[
			-21,
			25
		],
		[
			-6,
			20
		],
		[
			-32,
			4
		],
		[
			-16,
			-24
		],
		[
			-18,
			25
		],
		[
			-22,
			-10
		],
		[
			-37,
			60
		],
		[
			-23,
			0
		],
		[
			-15,
			15
		],
		[
			-44,
			-7
		],
		[
			-48,
			-22
		],
		[
			-1,
			31
		],
		[
			-13,
			66
		],
		[
			-16,
			30
		],
		[
			-12,
			-4
		],
		[
			-6,
			32
		],
		[
			13,
			143
		],
		[
			-11,
			60
		],
		[
			8,
			119
		],
		[
			-17,
			54
		],
		[
			9,
			115
		],
		[
			1,
			140
		],
		[
			-18,
			56
		],
		[
			-14,
			7
		],
		[
			-3,
			-21
		],
		[
			-27,
			55
		],
		[
			-11,
			48
		],
		[
			10,
			131
		],
		[
			-2,
			50
		],
		[
			-11,
			53
		],
		[
			-27,
			14
		],
		[
			-27,
			102
		],
		[
			-18,
			101
		],
		[
			-24,
			25
		],
		[
			-17,
			66
		],
		[
			-5,
			81
		],
		[
			-16,
			47
		],
		[
			-7,
			37
		],
		[
			-14,
			35
		],
		[
			-6,
			99
		],
		[
			-5,
			35
		],
		[
			-20,
			29
		],
		[
			-15,
			104
		],
		[
			-25,
			94
		],
		[
			-33,
			64
		],
		[
			-11,
			45
		],
		[
			-8,
			80
		],
		[
			1,
			42
		],
		[
			-11,
			101
		],
		[
			2,
			92
		],
		[
			-11,
			16
		],
		[
			10,
			74
		],
		[
			18,
			-38
		],
		[
			9,
			30
		],
		[
			7,
			61
		],
		[
			8,
			141
		],
		[
			-21,
			149
		],
		[
			-12,
			43
		],
		[
			-10,
			11
		],
		[
			-9,
			-28
		],
		[
			-37,
			2
		],
		[
			-28,
			68
		],
		[
			-22,
			102
		],
		[
			-14,
			18
		],
		[
			-2,
			31
		],
		[
			-17,
			60
		],
		[
			-4,
			62
		],
		[
			5,
			129
		],
		[
			-12,
			89
		],
		[
			-2,
			52
		],
		[
			-12,
			14
		],
		[
			-6,
			33
		],
		[
			-1,
			64
		],
		[
			5,
			27
		],
		[
			2,
			77
		],
		[
			-6,
			134
		],
		[
			14,
			28
		],
		[
			16,
			8
		],
		[
			6,
			-24
		],
		[
			7,
			-88
		],
		[
			-9,
			-9
		],
		[
			11,
			-107
		],
		[
			-2,
			-27
		],
		[
			27,
			-23
		],
		[
			27,
			-80
		],
		[
			8,
			5
		],
		[
			14,
			-63
		],
		[
			12,
			3
		],
		[
			-6,
			40
		],
		[
			-12,
			19
		],
		[
			-10,
			87
		],
		[
			-7,
			109
		],
		[
			-21,
			54
		],
		[
			-2,
			46
		],
		[
			-22,
			26
		],
		[
			9,
			74
		],
		[
			-7,
			68
		],
		[
			-15,
			-1
		],
		[
			-14,
			68
		],
		[
			8,
			-9
		],
		[
			9,
			26
		],
		[
			0,
			40
		],
		[
			19,
			-2
		],
		[
			10,
			39
		],
		[
			-10,
			71
		],
		[
			-26,
			44
		],
		[
			-13,
			-30
		],
		[
			-14,
			-6
		],
		[
			2,
			-47
		],
		[
			-5,
			-46
		],
		[
			15,
			-51
		],
		[
			-12,
			-25
		],
		[
			-4,
			-44
		],
		[
			19,
			-56
		],
		[
			-7,
			-14
		],
		[
			-11,
			29
		],
		[
			7,
			-71
		],
		[
			-15,
			-16
		],
		[
			-9,
			38
		],
		[
			-26,
			61
		],
		[
			-13,
			-12
		],
		[
			-23,
			67
		],
		[
			-10,
			53
		],
		[
			-17,
			33
		],
		[
			-16,
			8
		],
		[
			-20,
			-33
		],
		[
			14,
			127
		],
		[
			3,
			48
		],
		[
			-12,
			92
		],
		[
			7,
			20
		],
		[
			-16,
			70
		],
		[
			-11,
			-10
		],
		[
			-1,
			67
		],
		[
			-17,
			106
		],
		[
			-20,
			51
		],
		[
			-14,
			19
		],
		[
			-22,
			64
		],
		[
			-37,
			176
		],
		[
			-14,
			29
		],
		[
			-8,
			41
		],
		[
			-31,
			90
		],
		[
			-24,
			116
		],
		[
			14,
			78
		],
		[
			-1,
			42
		],
		[
			-14,
			126
		],
		[
			-16,
			123
		],
		[
			-7,
			105
		],
		[
			3,
			99
		],
		[
			13,
			132
		],
		[
			-5,
			52
		],
		[
			0,
			65
		],
		[
			-14,
			92
		],
		[
			-4,
			108
		],
		[
			-16,
			36
		],
		[
			-6,
			55
		],
		[
			-35,
			133
		],
		[
			-7,
			6
		],
		[
			0,
			43
		],
		[
			-8,
			43
		],
		[
			-22,
			32
		],
		[
			-49,
			151
		],
		[
			4,
			63
		],
		[
			-4,
			70
		],
		[
			-13,
			74
		],
		[
			9,
			98
		],
		[
			14,
			109
		],
		[
			42,
			265
		],
		[
			11,
			95
		],
		[
			7,
			119
		],
		[
			-12,
			37
		],
		[
			-1,
			97
		],
		[
			4,
			2
		],
		[
			11,
			99
		],
		[
			12,
			244
		],
		[
			-5,
			126
		],
		[
			-15,
			128
		],
		[
			-8,
			96
		],
		[
			-9,
			-4
		],
		[
			-17,
			54
		],
		[
			10,
			74
		],
		[
			5,
			110
		],
		[
			-3,
			67
		]
	],
	[
		[
			28861,
			63044
		],
		[
			-1,
			28
		]
	],
	[
		[
			28874,
			63137
		],
		[
			-6,
			7
		],
		[
			-22,
			-81
		],
		[
			2,
			-39
		],
		[
			11,
			-31
		],
		[
			1,
			-49
		],
		[
			-8,
			-28
		],
		[
			0,
			-41
		],
		[
			14,
			-52
		],
		[
			7,
			-58
		],
		[
			21,
			-62
		],
		[
			10,
			-68
		],
		[
			3,
			-58
		],
		[
			-5,
			-35
		],
		[
			2,
			-126
		],
		[
			16,
			-48
		],
		[
			7,
			-43
		],
		[
			2,
			-74
		],
		[
			34,
			-137
		],
		[
			16,
			-29
		],
		[
			10,
			24
		],
		[
			4,
			-36
		],
		[
			5,
			-129
		],
		[
			4,
			-244
		]
	],
	[
		[
			29002,
			61700
		],
		[
			-105,
			1
		],
		[
			-74,
			9
		],
		[
			-2,
			72
		],
		[
			-25,
			1311
		],
		[
			0,
			86
		]
	],
	[
		[
			28426,
			62262
		],
		[
			21,
			70
		],
		[
			37,
			-118
		],
		[
			-36,
			-118
		]
	],
	[
		[
			28448,
			62096
		],
		[
			0,
			93
		],
		[
			-22,
			73
		]
	],
	[
		[
			6433,
			39922
		],
		[
			2,
			44
		],
		[
			19,
			76
		],
		[
			12,
			7
		],
		[
			13,
			93
		],
		[
			16,
			52
		],
		[
			3,
			58
		],
		[
			-17,
			94
		],
		[
			-4,
			45
		],
		[
			-1,
			105
		],
		[
			8,
			37
		],
		[
			18,
			-9
		],
		[
			18,
			-32
		],
		[
			3,
			-32
		],
		[
			22,
			-44
		],
		[
			15,
			-47
		],
		[
			12,
			6
		],
		[
			25,
			-32
		],
		[
			39,
			-77
		],
		[
			13,
			-19
		],
		[
			22,
			-61
		],
		[
			16,
			-57
		],
		[
			17,
			-76
		],
		[
			-3,
			-47
		],
		[
			1,
			-90
		],
		[
			8,
			-10
		],
		[
			16,
			12
		],
		[
			7,
			-57
		],
		[
			-1,
			-57
		],
		[
			22,
			-82
		],
		[
			22,
			-39
		],
		[
			5,
			-21
		],
		[
			-4,
			-44
		],
		[
			-13,
			-51
		],
		[
			-17,
			-47
		],
		[
			-14,
			-56
		],
		[
			-23,
			-38
		],
		[
			-20,
			-47
		],
		[
			-20,
			-18
		],
		[
			-16,
			15
		],
		[
			-9,
			-9
		],
		[
			-18,
			-66
		],
		[
			-16,
			-25
		],
		[
			-13,
			-48
		],
		[
			-14,
			-16
		],
		[
			-12,
			-59
		],
		[
			1,
			-33
		],
		[
			-8,
			-37
		],
		[
			-5,
			-59
		],
		[
			-20,
			-63
		],
		[
			-15,
			61
		],
		[
			-22,
			52
		],
		[
			-22,
			29
		],
		[
			-10,
			95
		],
		[
			5,
			113
		],
		[
			4,
			151
		],
		[
			-10,
			106
		],
		[
			1,
			46
		],
		[
			-9,
			12
		],
		[
			-5,
			114
		],
		[
			-7,
			66
		],
		[
			-9,
			8
		],
		[
			-8,
			108
		]
	],
	[
		[
			6254,
			41293
		],
		[
			5,
			69
		],
		[
			11,
			56
		],
		[
			14,
			6
		],
		[
			13,
			-33
		],
		[
			10,
			-78
		],
		[
			10,
			-50
		],
		[
			24,
			29
		],
		[
			18,
			35
		],
		[
			26,
			-21
		],
		[
			0,
			-16
		],
		[
			17,
			-51
		],
		[
			10,
			-15
		],
		[
			5,
			-40
		],
		[
			31,
			-37
		],
		[
			5,
			-32
		],
		[
			0,
			-52
		],
		[
			-8,
			-43
		],
		[
			-13,
			-40
		],
		[
			-6,
			3
		],
		[
			-17,
			-36
		],
		[
			-14,
			10
		],
		[
			-30,
			-53
		],
		[
			-21,
			-9
		],
		[
			-17,
			26
		],
		[
			-7,
			210
		],
		[
			-7,
			20
		],
		[
			-14,
			-24
		],
		[
			-26,
			50
		],
		[
			-13,
			58
		],
		[
			-6,
			58
		]
	],
	[
		[
			6253,
			40841
		],
		[
			7,
			29
		],
		[
			28,
			57
		],
		[
			10,
			-30
		],
		[
			-4,
			-44
		],
		[
			5,
			-17
		],
		[
			-13,
			-19
		],
		[
			-5,
			15
		],
		[
			-18,
			-23
		],
		[
			-10,
			32
		]
	],
	[
		[
			6153,
			41274
		],
		[
			7,
			27
		],
		[
			13,
			5
		],
		[
			26,
			-19
		],
		[
			17,
			-60
		],
		[
			8,
			-51
		],
		[
			-9,
			-65
		],
		[
			-19,
			-29
		],
		[
			-17,
			-5
		],
		[
			-7,
			60
		],
		[
			-3,
			73
		],
		[
			-14,
			32
		],
		[
			-2,
			32
		]
	],
	[
		[
			6084,
			41504
		],
		[
			6,
			52
		],
		[
			9,
			29
		],
		[
			-2,
			58
		],
		[
			17,
			-2
		],
		[
			3,
			-14
		],
		[
			54,
			-29
		],
		[
			10,
			34
		],
		[
			4,
			-42
		],
		[
			22,
			-13
		],
		[
			27,
			18
		],
		[
			17,
			-25
		],
		[
			-8,
			-55
		],
		[
			-18,
			-51
		],
		[
			-20,
			-21
		],
		[
			-35,
			32
		],
		[
			-26,
			31
		],
		[
			-15,
			-14
		],
		[
			-29,
			-5
		],
		[
			-16,
			17
		]
	],
	[
		[
			5814,
			42059
		],
		[
			43,
			9
		],
		[
			13,
			49
		],
		[
			4,
			35
		],
		[
			13,
			48
		],
		[
			14,
			15
		],
		[
			6,
			-27
		],
		[
			6,
			-70
		],
		[
			20,
			-84
		],
		[
			4,
			-52
		],
		[
			-4,
			-15
		],
		[
			3,
			-47
		],
		[
			18,
			-55
		],
		[
			3,
			57
		],
		[
			12,
			-2
		],
		[
			-4,
			-64
		],
		[
			8,
			-24
		],
		[
			-1,
			-29
		],
		[
			17,
			-70
		],
		[
			-12,
			-37
		],
		[
			-11,
			18
		],
		[
			-21,
			-29
		],
		[
			-6,
			26
		],
		[
			-17,
			31
		],
		[
			-25,
			11
		],
		[
			-30,
			-20
		],
		[
			-7,
			4
		],
		[
			-7,
			84
		],
		[
			-11,
			34
		],
		[
			-1,
			31
		],
		[
			-14,
			67
		],
		[
			0,
			61
		],
		[
			-13,
			45
		]
	],
	[
		[
			5394,
			42585
		],
		[
			1,
			40
		],
		[
			11,
			38
		],
		[
			4,
			49
		],
		[
			33,
			72
		],
		[
			8,
			26
		],
		[
			23,
			-18
		],
		[
			3,
			25
		],
		[
			16,
			-11
		],
		[
			8,
			14
		],
		[
			15,
			-20
		],
		[
			10,
			-37
		],
		[
			5,
			-45
		],
		[
			0,
			-46
		],
		[
			-11,
			-63
		],
		[
			1,
			-106
		],
		[
			-4,
			-28
		],
		[
			-28,
			-78
		],
		[
			-8,
			15
		],
		[
			-36,
			12
		],
		[
			-18,
			71
		],
		[
			-24,
			29
		],
		[
			-9,
			61
		]
	],
	[
		[
			5266,
			42374
		],
		[
			4,
			43
		],
		[
			12,
			44
		],
		[
			19,
			45
		],
		[
			2,
			38
		],
		[
			11,
			9
		],
		[
			2,
			-31
		],
		[
			-5,
			-57
		],
		[
			2,
			-36
		],
		[
			-20,
			-28
		],
		[
			-16,
			-97
		],
		[
			-12,
			30
		],
		[
			1,
			40
		]
	],
	[
		[
			24498,
			67577
		],
		[
			-5,
			-52
		],
		[
			10,
			-50
		],
		[
			-1,
			-74
		],
		[
			27,
			-41
		],
		[
			13,
			-76
		],
		[
			-18,
			-60
		],
		[
			-6,
			-52
		],
		[
			-9,
			-24
		],
		[
			1,
			-108
		],
		[
			8,
			-88
		],
		[
			0,
			-68
		],
		[
			12,
			-25
		],
		[
			13,
			-169
		],
		[
			33,
			-64
		],
		[
			47,
			-37
		],
		[
			17,
			-20
		],
		[
			18,
			-109
		],
		[
			0,
			-37
		]
	],
	[
		[
			23231,
			64184
		],
		[
			4,
			28
		],
		[
			-10,
			56
		],
		[
			-13,
			16
		],
		[
			-15,
			58
		],
		[
			2,
			37
		],
		[
			13,
			35
		],
		[
			-4,
			83
		],
		[
			10,
			51
		],
		[
			-7,
			27
		],
		[
			2,
			66
		],
		[
			-9,
			20
		],
		[
			1,
			42
		],
		[
			-7,
			30
		],
		[
			5,
			27
		],
		[
			-5,
			93
		],
		[
			12,
			17
		],
		[
			-24,
			24
		],
		[
			4,
			37
		],
		[
			-5,
			63
		],
		[
			13,
			41
		],
		[
			-20,
			27
		],
		[
			7,
			29
		],
		[
			-1,
			116
		],
		[
			-20,
			10
		],
		[
			2,
			77
		],
		[
			-9,
			1
		],
		[
			-2,
			-37
		],
		[
			-15,
			28
		],
		[
			3,
			56
		],
		[
			-11,
			39
		],
		[
			7,
			39
		],
		[
			-8,
			41
		],
		[
			11,
			18
		],
		[
			-6,
			54
		],
		[
			8,
			20
		],
		[
			3,
			46
		],
		[
			-12,
			23
		],
		[
			-1,
			38
		],
		[
			-14,
			61
		],
		[
			6,
			11
		],
		[
			3,
			66
		],
		[
			-16,
			6
		],
		[
			1,
			30
		],
		[
			-15,
			11
		],
		[
			5,
			16
		],
		[
			-15,
			25
		],
		[
			1,
			83
		],
		[
			-22,
			56
		],
		[
			-3,
			48
		],
		[
			10,
			25
		],
		[
			-14,
			103
		],
		[
			-11,
			29
		],
		[
			0,
			76
		],
		[
			9,
			44
		],
		[
			-4,
			44
		],
		[
			-14,
			8
		]
	],
	[
		[
			26280,
			62461
		],
		[
			18,
			48
		],
		[
			7,
			-2
		],
		[
			15,
			-54
		],
		[
			21,
			-28
		],
		[
			14,
			29
		],
		[
			14,
			-3
		],
		[
			8,
			29
		],
		[
			8,
			-8
		],
		[
			4,
			-69
		],
		[
			29,
			-32
		],
		[
			10,
			-84
		],
		[
			16,
			-83
		],
		[
			0,
			-66
		],
		[
			5,
			-26
		],
		[
			40,
			-41
		],
		[
			33,
			19
		],
		[
			29,
			-46
		],
		[
			3,
			-34
		],
		[
			15,
			-26
		],
		[
			5,
			-50
		],
		[
			28,
			-29
		],
		[
			14,
			66
		],
		[
			26,
			22
		],
		[
			15,
			-32
		],
		[
			28,
			-20
		],
		[
			11,
			-24
		],
		[
			5,
			-43
		],
		[
			13,
			24
		],
		[
			30,
			-1
		],
		[
			10,
			53
		],
		[
			18,
			34
		],
		[
			9,
			39
		],
		[
			15,
			0
		],
		[
			21,
			32
		],
		[
			7,
			-33
		],
		[
			-3,
			-44
		],
		[
			9,
			-111
		],
		[
			13,
			-37
		],
		[
			21,
			-6
		],
		[
			21,
			-79
		],
		[
			13,
			-35
		],
		[
			2,
			-44
		]
	],
	[
		[
			27075,
			60636
		],
		[
			-108,
			-317
		],
		[
			-37,
			-39
		],
		[
			-22,
			-41
		],
		[
			-19,
			-49
		],
		[
			-25,
			-45
		],
		[
			0,
			-86
		],
		[
			-16,
			-39
		],
		[
			-12,
			-2
		],
		[
			-12,
			-33
		],
		[
			3,
			-59
		],
		[
			-6,
			-45
		],
		[
			-25,
			-36
		],
		[
			-29,
			-4
		],
		[
			-16,
			-80
		],
		[
			-2,
			-50
		],
		[
			-16,
			-4
		],
		[
			-33,
			-35
		],
		[
			-39,
			-52
		],
		[
			-21,
			2
		],
		[
			-33,
			-49
		],
		[
			-8,
			-27
		]
	],
	[
		[
			26599,
			59546
		],
		[
			-4,
			-21
		],
		[
			-83,
			8
		],
		[
			-79,
			2
		],
		[
			-76,
			5
		],
		[
			-83,
			11
		],
		[
			-51,
			16
		],
		[
			-74,
			9
		],
		[
			-55,
			-14
		],
		[
			-96,
			8
		],
		[
			-56,
			10
		],
		[
			-83,
			22
		],
		[
			-49,
			4
		],
		[
			-16,
			-22
		],
		[
			-7,
			22
		],
		[
			-146,
			-12
		],
		[
			-92,
			-2
		],
		[
			-114,
			-8
		],
		[
			1,
			35
		],
		[
			-61,
			17
		],
		[
			10,
			-147
		],
		[
			-6,
			-64
		],
		[
			-137,
			6
		],
		[
			-126,
			0
		],
		[
			-84,
			6
		],
		[
			-33,
			-10
		]
	],
	[
		[
			24980,
			59425
		],
		[
			-15,
			1
		]
	],
	[
		[
			28739,
			61120
		],
		[
			-14,
			0
		]
	],
	[
		[
			28725,
			61120
		],
		[
			-1,
			72
		],
		[
			8,
			28
		],
		[
			11,
			-40
		],
		[
			-4,
			-60
		]
	],
	[
		[
			28711,
			61320
		],
		[
			2,
			79
		],
		[
			11,
			13
		],
		[
			7,
			-30
		],
		[
			5,
			-118
		],
		[
			-15,
			21
		],
		[
			4,
			27
		],
		[
			-14,
			8
		]
	],
	[
		[
			28627,
			62072
		],
		[
			5,
			20
		],
		[
			5,
			-46
		],
		[
			-10,
			26
		]
	],
	[
		[
			29002,
			61700
		],
		[
			-1,
			-43
		],
		[
			-9,
			-105
		],
		[
			-5,
			-15
		],
		[
			-20,
			-211
		],
		[
			-18,
			-120
		]
	],
	[
		[
			28949,
			61206
		],
		[
			-107,
			-38
		],
		[
			-6,
			-55
		],
		[
			-6,
			4
		]
	],
	[
		[
			28830,
			61117
		],
		[
			-13,
			30
		],
		[
			-19,
			-4
		],
		[
			-22,
			-64
		],
		[
			-9,
			-1
		],
		[
			-1,
			67
		],
		[
			7,
			70
		],
		[
			17,
			28
		],
		[
			-17,
			2
		],
		[
			2,
			45
		],
		[
			11,
			40
		],
		[
			-21,
			9
		],
		[
			-12,
			-33
		],
		[
			-4,
			28
		],
		[
			5,
			58
		],
		[
			26,
			27
		],
		[
			-6,
			39
		],
		[
			-9,
			-13
		],
		[
			-4,
			36
		],
		[
			15,
			112
		],
		[
			-15,
			-24
		],
		[
			-7,
			-47
		],
		[
			0,
			-60
		],
		[
			-8,
			-1
		],
		[
			-11,
			77
		],
		[
			11,
			9
		],
		[
			-1,
			53
		],
		[
			-8,
			10
		],
		[
			-4,
			-49
		],
		[
			-9,
			-33
		],
		[
			6,
			-27
		],
		[
			-9,
			-62
		],
		[
			-4,
			29
		],
		[
			-17,
			-23
		],
		[
			-9,
			12
		],
		[
			-16,
			83
		],
		[
			-9,
			13
		],
		[
			2,
			43
		],
		[
			-24,
			151
		],
		[
			20,
			14
		],
		[
			5,
			39
		],
		[
			-8,
			-7
		],
		[
			-9,
			51
		],
		[
			8,
			40
		],
		[
			12,
			22
		],
		[
			6,
			-25
		],
		[
			12,
			26
		],
		[
			1,
			-36
		],
		[
			22,
			-9
		],
		[
			13,
			-39
		],
		[
			4,
			10
		],
		[
			-16,
			69
		],
		[
			-17,
			14
		],
		[
			-8,
			42
		],
		[
			-7,
			-3
		],
		[
			-16,
			77
		],
		[
			-5,
			-28
		],
		[
			-12,
			20
		],
		[
			-1,
			-59
		],
		[
			-7,
			8
		],
		[
			3,
			101
		],
		[
			18,
			92
		],
		[
			14,
			-45
		],
		[
			8,
			10
		],
		[
			-3,
			124
		],
		[
			-8,
			17
		],
		[
			-17,
			-47
		],
		[
			-12,
			4
		],
		[
			1,
			-48
		],
		[
			-12,
			-17
		],
		[
			4,
			104
		],
		[
			16,
			101
		],
		[
			7,
			-51
		],
		[
			21,
			-11
		],
		[
			11,
			31
		],
		[
			-6,
			54
		],
		[
			11,
			55
		],
		[
			-16,
			-9
		],
		[
			-3,
			-52
		],
		[
			4,
			-31
		],
		[
			-12,
			17
		],
		[
			3,
			63
		],
		[
			-6,
			59
		],
		[
			-7,
			14
		],
		[
			16,
			136
		],
		[
			12,
			42
		],
		[
			-2,
			24
		],
		[
			14,
			25
		],
		[
			7,
			37
		],
		[
			30,
			-6
		],
		[
			-11,
			24
		],
		[
			18,
			70
		],
		[
			-10,
			6
		],
		[
			12,
			122
		],
		[
			-35,
			-24
		],
		[
			-6,
			-48
		],
		[
			12,
			-24
		],
		[
			4,
			-32
		],
		[
			-12,
			-14
		],
		[
			-34,
			-97
		],
		[
			-7,
			31
		],
		[
			7,
			54
		],
		[
			-8,
			28
		],
		[
			0,
			-44
		],
		[
			-9,
			-51
		],
		[
			8,
			-34
		],
		[
			-7,
			-46
		],
		[
			-6,
			96
		],
		[
			-15,
			14
		],
		[
			6,
			-103
		],
		[
			-8,
			8
		],
		[
			-6,
			-42
		],
		[
			12,
			-22
		],
		[
			-21,
			-44
		],
		[
			-7,
			-28
		],
		[
			-13,
			8
		],
		[
			-2,
			26
		],
		[
			-22,
			46
		],
		[
			3,
			-46
		],
		[
			9,
			-13
		],
		[
			2,
			-41
		],
		[
			27,
			-54
		],
		[
			2,
			-67
		],
		[
			-5,
			-25
		],
		[
			13,
			-48
		],
		[
			-23,
			-45
		],
		[
			7,
			-37
		],
		[
			-3,
			-40
		],
		[
			-9,
			4
		],
		[
			-7,
			-55
		],
		[
			6,
			-53
		],
		[
			-17,
			-58
		],
		[
			9,
			-50
		],
		[
			-2,
			-54
		],
		[
			6,
			-73
		],
		[
			-2,
			-89
		],
		[
			7,
			-65
		],
		[
			22,
			-80
		],
		[
			8,
			-62
		],
		[
			-9,
			-45
		],
		[
			-14,
			7
		],
		[
			9,
			-42
		],
		[
			9,
			22
		],
		[
			8,
			-14
		],
		[
			-7,
			-47
		],
		[
			4,
			-48
		],
		[
			18,
			-92
		],
		[
			-5,
			-22
		],
		[
			5,
			-97
		],
		[
			-9,
			19
		],
		[
			-11,
			58
		],
		[
			-8,
			4
		],
		[
			-5,
			64
		],
		[
			-8,
			-9
		],
		[
			-2,
			-57
		],
		[
			-7,
			38
		],
		[
			-8,
			-3
		],
		[
			-5,
			48
		],
		[
			-12,
			45
		],
		[
			-23,
			23
		],
		[
			-35,
			3
		],
		[
			-8,
			129
		],
		[
			-8,
			13
		],
		[
			-4,
			-31
		],
		[
			10,
			-68
		],
		[
			-2,
			-22
		],
		[
			-22,
			43
		],
		[
			-2,
			34
		],
		[
			-13,
			31
		],
		[
			-12,
			114
		],
		[
			-20,
			-44
		],
		[
			-33,
			-56
		],
		[
			-12,
			27
		],
		[
			-7,
			115
		],
		[
			11,
			82
		],
		[
			15,
			57
		],
		[
			20,
			30
		],
		[
			-5,
			10
		]
	],
	[
		[
			28423,
			61914
		],
		[
			-1,
			45
		],
		[
			7,
			27
		],
		[
			18,
			25
		],
		[
			1,
			85
		]
	],
	[
		[
			28426,
			62262
		],
		[
			-9,
			37
		],
		[
			-20,
			6
		],
		[
			-8,
			17
		],
		[
			1,
			48
		],
		[
			-26,
			42
		],
		[
			-34,
			15
		],
		[
			-6,
			39
		],
		[
			-10,
			13
		],
		[
			1,
			58
		],
		[
			9,
			18
		],
		[
			7,
			49
		],
		[
			-23,
			43
		],
		[
			-6,
			45
		],
		[
			-15,
			-1
		],
		[
			-16,
			25
		],
		[
			-13,
			-3
		]
	],
	[
		[
			26327,
			70327
		],
		[
			8,
			17
		],
		[
			9,
			-60
		],
		[
			65,
			-63
		],
		[
			-17,
			-58
		],
		[
			-23,
			18
		],
		[
			-14,
			61
		],
		[
			-28,
			85
		]
	],
	[
		[
			26120,
			70229
		],
		[
			5,
			40
		],
		[
			7,
			-20
		],
		[
			-12,
			-20
		]
	],
	[
		[
			26084,
			70289
		],
		[
			21,
			-39
		],
		[
			-4,
			-36
		],
		[
			-19,
			38
		],
		[
			2,
			37
		]
	],
	[
		[
			26055,
			70019
		],
		[
			7,
			48
		],
		[
			3,
			69
		],
		[
			6,
			15
		],
		[
			1,
			57
		],
		[
			18,
			-7
		],
		[
			-1,
			-85
		],
		[
			4,
			-83
		],
		[
			-19,
			-44
		],
		[
			-19,
			30
		]
	],
	[
		[
			26035,
			70180
		],
		[
			13,
			8
		],
		[
			-5,
			-54
		],
		[
			-7,
			1
		],
		[
			-1,
			45
		]
	],
	[
		[
			25984,
			69839
		],
		[
			13,
			-17
		],
		[
			1,
			-59
		],
		[
			-14,
			76
		]
	],
	[
		[
			25933,
			69486
		],
		[
			6,
			23
		],
		[
			19,
			-25
		],
		[
			-6,
			-96
		],
		[
			-17,
			52
		],
		[
			-2,
			46
		]
	],
	[
		[
			25908,
			69335
		],
		[
			11,
			44
		],
		[
			6,
			-47
		],
		[
			-17,
			3
		]
	],
	[
		[
			25759,
			70041
		],
		[
			20,
			-64
		],
		[
			-8,
			-22
		],
		[
			-4,
			36
		],
		[
			-14,
			43
		],
		[
			6,
			7
		]
	],
	[
		[
			25722,
			65552
		],
		[
			30,
			68
		],
		[
			27,
			87
		],
		[
			37,
			261
		],
		[
			34,
			146
		],
		[
			19,
			134
		],
		[
			10,
			99
		],
		[
			10,
			176
		],
		[
			-1,
			58
		],
		[
			6,
			87
		],
		[
			-1,
			163
		],
		[
			-6,
			182
		],
		[
			-11,
			120
		],
		[
			-35,
			230
		],
		[
			-11,
			94
		],
		[
			-12,
			138
		],
		[
			-17,
			119
		],
		[
			0,
			48
		],
		[
			22,
			102
		],
		[
			7,
			50
		],
		[
			1,
			77
		],
		[
			-9,
			134
		],
		[
			-14,
			90
		],
		[
			4,
			32
		],
		[
			20,
			51
		],
		[
			24,
			151
		],
		[
			21,
			112
		],
		[
			4,
			124
		],
		[
			9,
			134
		],
		[
			-11,
			112
		],
		[
			1,
			33
		],
		[
			27,
			43
		],
		[
			20,
			15
		],
		[
			6,
			93
		],
		[
			-2,
			74
		],
		[
			10,
			36
		],
		[
			13,
			-18
		],
		[
			16,
			80
		],
		[
			18,
			-35
		],
		[
			17,
			13
		],
		[
			8,
			32
		],
		[
			9,
			86
		],
		[
			10,
			16
		],
		[
			15,
			94
		],
		[
			11,
			47
		],
		[
			9,
			-7
		],
		[
			12,
			35
		],
		[
			3,
			-39
		],
		[
			-19,
			-32
		],
		[
			-3,
			-42
		],
		[
			12,
			-81
		],
		[
			-23,
			-81
		],
		[
			13,
			19
		],
		[
			0,
			-74
		],
		[
			-6,
			-7
		],
		[
			-8,
			-84
		],
		[
			7,
			-95
		],
		[
			8,
			-2
		],
		[
			19,
			145
		],
		[
			3,
			98
		],
		[
			13,
			20
		],
		[
			-8,
			-158
		],
		[
			-15,
			-44
		],
		[
			-6,
			-67
		],
		[
			14,
			-14
		],
		[
			8,
			65
		],
		[
			7,
			13
		],
		[
			22,
			135
		],
		[
			5,
			78
		],
		[
			-1,
			56
		],
		[
			4,
			82
		],
		[
			-6,
			85
		],
		[
			5,
			94
		],
		[
			17,
			49
		],
		[
			10,
			3
		],
		[
			18,
			48
		],
		[
			18,
			16
		],
		[
			25,
			-7
		],
		[
			26,
			14
		],
		[
			12,
			20
		],
		[
			-1,
			33
		],
		[
			-33,
			17
		],
		[
			-14,
			47
		],
		[
			-8,
			114
		],
		[
			16,
			75
		],
		[
			13,
			14
		],
		[
			20,
			69
		],
		[
			-2,
			31
		],
		[
			-18,
			27
		],
		[
			60,
			-15
		],
		[
			7,
			49
		],
		[
			61,
			-102
		],
		[
			26,
			-58
		],
		[
			13,
			20
		],
		[
			11,
			-16
		],
		[
			13,
			10
		],
		[
			32,
			-34
		],
		[
			24,
			-85
		],
		[
			3,
			-57
		],
		[
			17,
			-27
		],
		[
			33,
			4
		],
		[
			8,
			-9
		],
		[
			29,
			-77
		],
		[
			23,
			-7
		],
		[
			34,
			-71
		],
		[
			29,
			6
		],
		[
			21,
			-78
		],
		[
			11,
			-25
		],
		[
			-9,
			-27
		],
		[
			15,
			-96
		],
		[
			11,
			-30
		],
		[
			14,
			-133
		],
		[
			-20,
			21
		],
		[
			-16,
			34
		],
		[
			-15,
			-41
		],
		[
			4,
			-110
		],
		[
			12,
			-44
		],
		[
			21,
			-26
		],
		[
			5,
			-59
		],
		[
			1,
			-98
		],
		[
			7,
			-37
		],
		[
			-4,
			-71
		],
		[
			-8,
			-67
		],
		[
			2,
			-65
		],
		[
			-5,
			-111
		],
		[
			-1,
			-121
		],
		[
			-12,
			-15
		],
		[
			-14,
			-64
		],
		[
			-24,
			2
		],
		[
			-8,
			-30
		],
		[
			-8,
			-108
		],
		[
			-4,
			-115
		],
		[
			-19,
			-5
		],
		[
			-8,
			-19
		],
		[
			0,
			-49
		],
		[
			-42,
			-6
		],
		[
			-13,
			-35
		],
		[
			-9,
			-76
		],
		[
			-5,
			-124
		],
		[
			-8,
			-42
		],
		[
			13,
			-91
		],
		[
			16,
			-32
		],
		[
			9,
			33
		],
		[
			5,
			-38
		],
		[
			20,
			-21
		],
		[
			13,
			-38
		],
		[
			10,
			16
		],
		[
			28,
			120
		],
		[
			14,
			0
		],
		[
			7,
			25
		],
		[
			-7,
			51
		],
		[
			9,
			44
		],
		[
			9,
			87
		],
		[
			4,
			-50
		],
		[
			19,
			31
		],
		[
			5,
			29
		],
		[
			-21,
			31
		],
		[
			24,
			-3
		],
		[
			11,
			24
		],
		[
			5,
			41
		],
		[
			23,
			10
		],
		[
			34,
			28
		],
		[
			9,
			45
		],
		[
			31,
			30
		],
		[
			11,
			-30
		],
		[
			23,
			-25
		],
		[
			15,
			-39
		],
		[
			17,
			-123
		],
		[
			10,
			-37
		],
		[
			7,
			-97
		],
		[
			5,
			-208
		],
		[
			17,
			-178
		],
		[
			4,
			-247
		],
		[
			10,
			-143
		],
		[
			18,
			-110
		],
		[
			2,
			-48
		],
		[
			-11,
			-46
		],
		[
			-7,
			-145
		],
		[
			4,
			-47
		],
		[
			-12,
			-113
		],
		[
			-4,
			-67
		],
		[
			-18,
			-66
		],
		[
			-15,
			4
		],
		[
			-12,
			-42
		],
		[
			1,
			66
		],
		[
			-9,
			27
		],
		[
			10,
			16
		],
		[
			15,
			62
		],
		[
			-14,
			26
		],
		[
			-15,
			-5
		],
		[
			-19,
			-34
		],
		[
			-7,
			-32
		],
		[
			9,
			-27
		],
		[
			2,
			-45
		],
		[
			-15,
			4
		],
		[
			-11,
			-52
		],
		[
			1,
			-84
		],
		[
			-7,
			-77
		],
		[
			-17,
			-53
		],
		[
			-30,
			-25
		],
		[
			-18,
			-97
		],
		[
			2,
			-127
		],
		[
			-3,
			-44
		],
		[
			-15,
			-25
		],
		[
			-1,
			-70
		],
		[
			-16,
			-39
		],
		[
			-6,
			-39
		],
		[
			-13,
			-4
		],
		[
			-7,
			-65
		],
		[
			-11,
			-11
		],
		[
			-17,
			-72
		],
		[
			5,
			-79
		],
		[
			-8,
			-9
		]
	],
	[
		[
			26661,
			65520
		],
		[
			-86,
			-11
		],
		[
			-167,
			-20
		],
		[
			-124,
			-12
		]
	],
	[
		[
			25045,
			72671
		],
		[
			21,
			69
		],
		[
			95,
			141
		],
		[
			7,
			-2
		],
		[
			43,
			98
		],
		[
			31,
			42
		],
		[
			6,
			-11
		],
		[
			28,
			29
		],
		[
			-1,
			-28
		],
		[
			-12,
			-16
		],
		[
			-30,
			-80
		],
		[
			0,
			-30
		],
		[
			-25,
			-55
		],
		[
			-51,
			-53
		],
		[
			-42,
			-66
		],
		[
			2,
			-20
		],
		[
			23,
			0
		],
		[
			-59,
			-73
		],
		[
			-18,
			3
		],
		[
			-18,
			52
		]
	],
	[
		[
			24721,
			71146
		],
		[
			19,
			40
		],
		[
			12,
			3
		],
		[
			39,
			49
		],
		[
			38,
			34
		],
		[
			31,
			77
		],
		[
			19,
			64
		],
		[
			16,
			27
		],
		[
			33,
			17
		],
		[
			15,
			-17
		],
		[
			29,
			27
		],
		[
			22,
			-3
		],
		[
			52,
			75
		],
		[
			30,
			94
		],
		[
			22,
			5
		],
		[
			29,
			23
		],
		[
			10,
			39
		],
		[
			5,
			51
		],
		[
			25,
			65
		],
		[
			14,
			16
		],
		[
			30,
			82
		],
		[
			23,
			23
		],
		[
			21,
			56
		],
		[
			11,
			54
		],
		[
			20,
			52
		],
		[
			58,
			85
		],
		[
			56,
			25
		],
		[
			50,
			-7
		],
		[
			23,
			-39
		],
		[
			1,
			-45
		],
		[
			-11,
			5
		],
		[
			-17,
			-24
		],
		[
			-19,
			13
		],
		[
			-21,
			-10
		],
		[
			5,
			-47
		],
		[
			-32,
			-57
		],
		[
			-30,
			-95
		],
		[
			-19,
			-20
		],
		[
			-5,
			-74
		],
		[
			-7,
			9
		],
		[
			-7,
			-52
		],
		[
			-14,
			-26
		],
		[
			-5,
			-67
		],
		[
			-12,
			-48
		],
		[
			-9,
			-6
		],
		[
			-12,
			-164
		],
		[
			6,
			-52
		],
		[
			-9,
			-35
		],
		[
			11,
			3
		],
		[
			20,
			87
		],
		[
			3,
			44
		],
		[
			7,
			-13
		],
		[
			29,
			80
		],
		[
			28,
			43
		],
		[
			-12,
			-55
		],
		[
			-12,
			-24
		],
		[
			-15,
			-77
		],
		[
			30,
			84
		],
		[
			26,
			18
		],
		[
			14,
			-13
		],
		[
			37,
			1
		],
		[
			15,
			-30
		],
		[
			8,
			8
		],
		[
			17,
			-35
		],
		[
			8,
			-39
		],
		[
			15,
			11
		],
		[
			22,
			-63
		],
		[
			3,
			-61
		],
		[
			17,
			-49
		],
		[
			6,
			-47
		],
		[
			14,
			-49
		],
		[
			19,
			-15
		],
		[
			-2,
			-79
		],
		[
			11,
			-28
		],
		[
			26,
			-15
		],
		[
			42,
			10
		],
		[
			25,
			43
		],
		[
			11,
			-8
		],
		[
			14,
			-72
		],
		[
			12,
			-27
		],
		[
			19,
			-4
		],
		[
			8,
			46
		],
		[
			16,
			-7
		],
		[
			9,
			-38
		],
		[
			4,
			69
		],
		[
			-7,
			53
		],
		[
			16,
			20
		],
		[
			7,
			-32
		],
		[
			-6,
			-56
		],
		[
			17,
			-26
		],
		[
			26,
			72
		],
		[
			40,
			62
		],
		[
			59,
			110
		],
		[
			11,
			-21
		],
		[
			61,
			42
		],
		[
			46,
			-16
		],
		[
			35,
			-3
		],
		[
			30,
			7
		],
		[
			62,
			85
		],
		[
			24,
			12
		],
		[
			30,
			-7
		],
		[
			32,
			14
		],
		[
			-22,
			-84
		],
		[
			-2,
			-135
		],
		[
			2,
			-45
		],
		[
			-8,
			-19
		],
		[
			9,
			-51
		],
		[
			16,
			-8
		],
		[
			9,
			16
		],
		[
			6,
			-26
		],
		[
			15,
			3
		],
		[
			17,
			-28
		],
		[
			34,
			49
		],
		[
			13,
			-4
		],
		[
			11,
			-46
		],
		[
			-1,
			-35
		],
		[
			25,
			28
		],
		[
			7,
			-7
		],
		[
			10,
			65
		],
		[
			19,
			24
		],
		[
			23,
			-19
		],
		[
			11,
			9
		],
		[
			8,
			39
		],
		[
			27,
			-5
		],
		[
			5,
			-30
		],
		[
			-10,
			-100
		],
		[
			7,
			-120
		],
		[
			1,
			-95
		],
		[
			-29,
			-2
		],
		[
			-8,
			-65
		],
		[
			15,
			-12
		],
		[
			5,
			21
		],
		[
			15,
			-4
		],
		[
			8,
			-38
		],
		[
			19,
			-19
		],
		[
			-13,
			-40
		],
		[
			24,
			-75
		],
		[
			12,
			-1
		],
		[
			20,
			-45
		],
		[
			8,
			38
		],
		[
			14,
			-35
		],
		[
			8,
			26
		],
		[
			-16,
			100
		],
		[
			14,
			-15
		],
		[
			41,
			13
		],
		[
			12,
			-15
		],
		[
			14,
			-91
		],
		[
			16,
			-31
		],
		[
			-10,
			-64
		],
		[
			-14,
			-20
		],
		[
			-27,
			39
		],
		[
			-31,
			-16
		],
		[
			-31,
			42
		],
		[
			-11,
			-12
		],
		[
			-27,
			1
		],
		[
			-27,
			23
		],
		[
			-60,
			-26
		],
		[
			-13,
			-28
		],
		[
			-37,
			69
		],
		[
			-15,
			48
		],
		[
			-13,
			-7
		],
		[
			-13,
			30
		],
		[
			-10,
			-41
		],
		[
			2,
			-51
		],
		[
			-15,
			-32
		],
		[
			1,
			-45
		],
		[
			9,
			-63
		],
		[
			-12,
			-20
		],
		[
			-24,
			42
		],
		[
			-3,
			31
		],
		[
			-21,
			37
		],
		[
			-5,
			30
		],
		[
			-22,
			64
		],
		[
			-38,
			46
		],
		[
			-13,
			-7
		],
		[
			-33,
			49
		],
		[
			-18,
			-5
		],
		[
			-13,
			23
		],
		[
			-5,
			-20
		],
		[
			-19,
			11
		],
		[
			-25,
			-75
		],
		[
			-17,
			-73
		],
		[
			-9,
			-8
		],
		[
			-32,
			23
		],
		[
			-23,
			-15
		],
		[
			-8,
			-22
		],
		[
			2,
			-34
		],
		[
			-23,
			37
		],
		[
			-21,
			17
		],
		[
			-24,
			-14
		],
		[
			-10,
			11
		],
		[
			-23,
			-24
		],
		[
			-13,
			-42
		],
		[
			-2,
			-63
		],
		[
			-9,
			-72
		],
		[
			-14,
			4
		],
		[
			-7,
			-39
		],
		[
			-22,
			-15
		],
		[
			-6,
			-46
		],
		[
			-13,
			-3
		],
		[
			0,
			-45
		],
		[
			-12,
			-9
		],
		[
			4,
			-61
		],
		[
			-20,
			32
		],
		[
			-9,
			40
		],
		[
			12,
			27
		],
		[
			1,
			34
		],
		[
			11,
			31
		],
		[
			1,
			40
		],
		[
			13,
			-4
		],
		[
			15,
			87
		],
		[
			-3,
			43
		],
		[
			-12,
			10
		],
		[
			-18,
			-75
		],
		[
			-38,
			24
		],
		[
			3,
			-51
		],
		[
			-13,
			-47
		],
		[
			-5,
			-56
		],
		[
			-30,
			-31
		],
		[
			-5,
			-27
		],
		[
			-6,
			39
		],
		[
			3,
			55
		],
		[
			-4,
			67
		],
		[
			-8,
			32
		],
		[
			-10,
			-19
		],
		[
			-5,
			-120
		],
		[
			3,
			-12
		],
		[
			-31,
			-55
		],
		[
			-26,
			-129
		],
		[
			-17,
			-146
		],
		[
			-19,
			-65
		],
		[
			-20,
			-112
		],
		[
			-41,
			-174
		],
		[
			6,
			-33
		]
	],
	[
		[
			25508,
			69434
		],
		[
			-19,
			14
		],
		[
			-8,
			47
		],
		[
			-13,
			28
		],
		[
			-2,
			29
		],
		[
			15,
			118
		],
		[
			11,
			48
		],
		[
			-2,
			34
		],
		[
			-11,
			25
		],
		[
			-16,
			-47
		],
		[
			-27,
			-10
		]
	],
	[
		[
			25436,
			69720
		],
		[
			0,
			0
		]
	],
	[
		[
			25436,
			69720
		],
		[
			-7,
			47
		],
		[
			7,
			24
		],
		[
			-3,
			38
		],
		[
			13,
			34
		],
		[
			6,
			40
		],
		[
			-3,
			47
		],
		[
			8,
			69
		],
		[
			-14,
			75
		],
		[
			12,
			13
		],
		[
			-8,
			44
		],
		[
			-13,
			18
		],
		[
			-6,
			33
		],
		[
			-24,
			4
		],
		[
			-9,
			43
		],
		[
			-21,
			-18
		],
		[
			-18,
			45
		],
		[
			17,
			52
		],
		[
			-7,
			21
		],
		[
			0,
			47
		],
		[
			-40,
			48
		],
		[
			-14,
			-14
		],
		[
			-24,
			47
		],
		[
			-12,
			-15
		],
		[
			-21,
			21
		],
		[
			-2,
			25
		],
		[
			-27,
			-2
		],
		[
			-3,
			-32
		],
		[
			-14,
			0
		],
		[
			-4,
			29
		],
		[
			-17,
			16
		],
		[
			-12,
			-13
		],
		[
			-86,
			142
		],
		[
			-287,
			231
		],
		[
			1,
			27
		],
		[
			-28,
			167
		],
		[
			-27,
			16
		],
		[
			-10,
			24
		]
	],
	[
		[
			24739,
			71113
		],
		[
			0,
			0
		]
	],
	[
		[
			24739,
			71113
		],
		[
			-12,
			-6
		],
		[
			-6,
			39
		]
	],
	[
		[
			25252,
			52115
		],
		[
			30,
			-13
		],
		[
			-14,
			-20
		],
		[
			-12,
			9
		],
		[
			-4,
			24
		]
	],
	[
		[
			25179,
			52148
		],
		[
			16,
			13
		],
		[
			30,
			-29
		],
		[
			6,
			-15
		],
		[
			-24,
			5
		],
		[
			-28,
			26
		]
	],
	[
		[
			25119,
			52114
		],
		[
			15,
			7
		],
		[
			15,
			31
		],
		[
			-4,
			-29
		],
		[
			-21,
			-27
		],
		[
			-5,
			18
		]
	],
	[
		[
			25071,
			52140
		],
		[
			21,
			-1
		],
		[
			8,
			13
		],
		[
			-5,
			-43
		],
		[
			-10,
			-7
		],
		[
			-17,
			26
		],
		[
			3,
			12
		]
	],
	[
		[
			24751,
			57677
		],
		[
			229,
			-2
		],
		[
			156,
			1
		],
		[
			202,
			1
		]
	],
	[
		[
			25284,
			52292
		],
		[
			-4,
			-32
		],
		[
			-7,
			15
		],
		[
			-10,
			-40
		],
		[
			-18,
			27
		],
		[
			-13,
			-15
		],
		[
			-5,
			30
		],
		[
			-18,
			7
		],
		[
			-18,
			-23
		],
		[
			-23,
			49
		],
		[
			-2,
			-28
		],
		[
			-21,
			38
		],
		[
			-22,
			-3
		],
		[
			-31,
			-27
		],
		[
			-28,
			-42
		],
		[
			-30,
			-33
		],
		[
			4,
			54
		],
		[
			-10,
			30
		],
		[
			-14,
			-27
		],
		[
			9,
			-17
		],
		[
			1,
			-40
		],
		[
			-25,
			-57
		],
		[
			-8,
			-80
		],
		[
			-9,
			10
		],
		[
			-13,
			-16
		]
	],
	[
		[
			24969,
			52072
		],
		[
			-12,
			0
		],
		[
			-13,
			50
		],
		[
			-4,
			66
		],
		[
			0,
			69
		],
		[
			-15,
			77
		],
		[
			0,
			54
		],
		[
			-10,
			43
		],
		[
			-11,
			19
		],
		[
			-4,
			39
		],
		[
			-10,
			34
		],
		[
			-4,
			95
		],
		[
			-8,
			14
		],
		[
			10,
			88
		],
		[
			-4,
			36
		],
		[
			7,
			25
		],
		[
			9,
			125
		],
		[
			7,
			19
		],
		[
			-1,
			45
		],
		[
			7,
			22
		],
		[
			-7,
			36
		],
		[
			-165,
			-2
		],
		[
			-134,
			-1
		],
		[
			-226,
			0
		],
		[
			13,
			21
		],
		[
			7,
			58
		],
		[
			-16,
			50
		],
		[
			-1,
			28
		],
		[
			10,
			46
		],
		[
			-3,
			41
		],
		[
			-12,
			30
		],
		[
			1,
			38
		],
		[
			18,
			-7
		],
		[
			17,
			20
		],
		[
			2,
			43
		],
		[
			-12,
			37
		],
		[
			-1,
			45
		],
		[
			-7,
			16
		],
		[
			9,
			39
		],
		[
			4,
			-50
		],
		[
			8,
			-29
		],
		[
			9,
			7
		],
		[
			0,
			29
		],
		[
			-13,
			75
		],
		[
			-1,
			74
		],
		[
			20,
			18
		],
		[
			12,
			35
		],
		[
			-4,
			32
		],
		[
			-18,
			-13
		],
		[
			-9,
			30
		],
		[
			5,
			38
		],
		[
			10,
			-28
		],
		[
			18,
			0
		],
		[
			1,
			106
		],
		[
			11,
			35
		],
		[
			23,
			5
		],
		[
			4,
			18
		],
		[
			-29,
			11
		],
		[
			7,
			94
		],
		[
			12,
			11
		],
		[
			2,
			-43
		],
		[
			7,
			-17
		],
		[
			5,
			28
		],
		[
			-6,
			21
		],
		[
			24,
			78
		],
		[
			-2,
			50
		],
		[
			7,
			25
		],
		[
			19,
			14
		],
		[
			0,
			50
		],
		[
			-19,
			26
		],
		[
			5,
			25
		],
		[
			13,
			-39
		],
		[
			5,
			36
		],
		[
			12,
			22
		],
		[
			9,
			69
		],
		[
			-15,
			24
		],
		[
			2,
			-62
		],
		[
			-32,
			11
		],
		[
			2,
			79
		],
		[
			27,
			20
		],
		[
			7,
			27
		],
		[
			14,
			-31
		],
		[
			5,
			42
		],
		[
			-2,
			53
		],
		[
			12,
			-8
		],
		[
			16,
			79
		],
		[
			-4,
			18
		],
		[
			-6,
			-40
		],
		[
			-23,
			17
		],
		[
			0,
			58
		],
		[
			8,
			20
		],
		[
			-8,
			35
		],
		[
			-10,
			-20
		],
		[
			-23,
			49
		],
		[
			3,
			58
		],
		[
			5,
			1
		],
		[
			17,
			-48
		],
		[
			10,
			7
		],
		[
			-5,
			26
		],
		[
			-21,
			50
		],
		[
			14,
			31
		],
		[
			8,
			37
		],
		[
			-7,
			37
		],
		[
			-6,
			-46
		],
		[
			-20,
			-26
		],
		[
			-6,
			14
		],
		[
			-3,
			52
		],
		[
			9,
			38
		],
		[
			16,
			33
		],
		[
			2,
			27
		],
		[
			-31,
			30
		],
		[
			1,
			71
		],
		[
			5,
			37
		],
		[
			21,
			52
		],
		[
			2,
			39
		],
		[
			-9,
			72
		],
		[
			-11,
			-4
		],
		[
			1,
			-67
		],
		[
			-14,
			-26
		],
		[
			-9,
			22
		],
		[
			3,
			48
		],
		[
			10,
			50
		]
	],
	[
		[
			17580,
			73980
		],
		[
			234,
			-2
		],
		[
			232,
			3
		],
		[
			190,
			-5
		],
		[
			190,
			2
		],
		[
			348,
			-2
		],
		[
			211,
			0
		],
		[
			232,
			2
		],
		[
			328,
			0
		],
		[
			141,
			0
		],
		[
			292,
			0
		],
		[
			227,
			1
		],
		[
			143,
			-1
		],
		[
			294,
			0
		],
		[
			114,
			0
		],
		[
			167,
			1
		]
	],
	[
		[
			18973,
			68711
		],
		[
			-21,
			23
		],
		[
			-6,
			49
		],
		[
			-24,
			59
		],
		[
			2,
			43
		],
		[
			-28,
			117
		],
		[
			-17,
			36
		],
		[
			-8,
			-52
		],
		[
			-20,
			-3
		],
		[
			5,
			-33
		],
		[
			-16,
			-98
		],
		[
			15,
			-64
		],
		[
			-32,
			26
		],
		[
			-9,
			-16
		],
		[
			-24,
			13
		],
		[
			-3,
			-19
		],
		[
			-30,
			-40
		],
		[
			-13,
			63
		],
		[
			-22,
			-8
		],
		[
			-13,
			-25
		],
		[
			-10,
			13
		],
		[
			-21,
			-30
		],
		[
			-8,
			22
		],
		[
			-14,
			-8
		],
		[
			-12,
			35
		],
		[
			-16,
			7
		],
		[
			-9,
			-35
		],
		[
			-9,
			0
		],
		[
			-2,
			-61
		],
		[
			-8,
			-45
		],
		[
			-24,
			38
		],
		[
			-8,
			-20
		],
		[
			-11,
			24
		],
		[
			-33,
			2
		],
		[
			-17,
			22
		],
		[
			-17,
			-23
		],
		[
			-15,
			-72
		],
		[
			6,
			-53
		],
		[
			-9,
			-22
		],
		[
			-11,
			44
		],
		[
			-18,
			24
		],
		[
			-15,
			40
		],
		[
			-6,
			53
		],
		[
			5,
			34
		],
		[
			-21,
			81
		],
		[
			9,
			48
		],
		[
			-5,
			50
		],
		[
			-18,
			109
		],
		[
			-32,
			58
		],
		[
			-26,
			-44
		],
		[
			-4,
			40
		],
		[
			-28,
			53
		],
		[
			-11,
			97
		],
		[
			14,
			13
		],
		[
			2,
			55
		],
		[
			-4,
			61
		],
		[
			-19,
			39
		],
		[
			2,
			26
		],
		[
			-17,
			15
		],
		[
			-7,
			73
		],
		[
			-24,
			73
		],
		[
			-1,
			35
		],
		[
			-14,
			54
		],
		[
			2,
			70
		],
		[
			-8,
			19
		],
		[
			-6,
			57
		],
		[
			6,
			30
		],
		[
			-1,
			46
		],
		[
			-19,
			0
		],
		[
			7,
			95
		],
		[
			-15,
			25
		],
		[
			-12,
			-2
		],
		[
			2,
			26
		],
		[
			-10,
			44
		],
		[
			-15,
			26
		],
		[
			-9,
			-13
		],
		[
			2,
			-41
		],
		[
			-15,
			-35
		],
		[
			-19,
			-82
		],
		[
			-19,
			-26
		],
		[
			-13,
			12
		],
		[
			-3,
			-58
		],
		[
			-24,
			-42
		],
		[
			-5,
			36
		],
		[
			-14,
			22
		],
		[
			-13,
			60
		],
		[
			-25,
			0
		],
		[
			4,
			53
		],
		[
			-8,
			36
		],
		[
			18,
			37
		],
		[
			1,
			48
		],
		[
			-19,
			74
		],
		[
			18,
			89
		],
		[
			25,
			1
		],
		[
			7,
			44
		],
		[
			-13,
			54
		],
		[
			6,
			49
		],
		[
			-19,
			27
		],
		[
			-4,
			54
		],
		[
			9,
			58
		],
		[
			-17,
			33
		],
		[
			2,
			49
		],
		[
			19,
			7
		],
		[
			-1,
			79
		],
		[
			-6,
			30
		],
		[
			13,
			24
		],
		[
			1,
			116
		],
		[
			13,
			65
		],
		[
			-7,
			69
		],
		[
			12,
			3
		],
		[
			10,
			123
		],
		[
			-3,
			58
		],
		[
			-8,
			10
		],
		[
			-26,
			-23
		],
		[
			-4,
			-21
		],
		[
			-22,
			15
		],
		[
			-19,
			-5
		],
		[
			-8,
			39
		],
		[
			6,
			39
		],
		[
			-7,
			30
		],
		[
			-14,
			9
		],
		[
			-4,
			-30
		],
		[
			-15,
			-21
		],
		[
			-6,
			17
		],
		[
			6,
			55
		],
		[
			-34,
			58
		],
		[
			-16,
			59
		],
		[
			4,
			71
		],
		[
			-20,
			60
		],
		[
			-13,
			-1
		],
		[
			-6,
			60
		],
		[
			-19,
			82
		],
		[
			-17,
			54
		],
		[
			-12,
			13
		],
		[
			-5,
			37
		],
		[
			-11,
			7
		],
		[
			2,
			38
		],
		[
			-9,
			41
		],
		[
			-24,
			10
		],
		[
			-32,
			45
		],
		[
			-7,
			54
		],
		[
			-47,
			87
		],
		[
			-11,
			-2
		],
		[
			12,
			36
		],
		[
			22,
			8
		],
		[
			3,
			22
		],
		[
			-16,
			7
		],
		[
			-5,
			57
		],
		[
			-11,
			5
		],
		[
			2,
			34
		],
		[
			13,
			32
		],
		[
			-12,
			55
		],
		[
			2,
			63
		],
		[
			-13,
			24
		],
		[
			-7,
			47
		],
		[
			-8,
			-6
		],
		[
			-8,
			88
		],
		[
			-15,
			21
		],
		[
			-39,
			152
		],
		[
			-1,
			279
		],
		[
			1,
			109
		],
		[
			0,
			804
		]
	],
	[
		[
			29991,
			69339
		],
		[
			3,
			68
		],
		[
			18,
			64
		],
		[
			-3,
			15
		],
		[
			11,
			74
		],
		[
			-13,
			36
		],
		[
			18,
			11
		],
		[
			4,
			26
		],
		[
			22,
			42
		],
		[
			15,
			-61
		],
		[
			28,
			-5
		],
		[
			13,
			70
		]
	],
	[
		[
			30213,
			67064
		],
		[
			-30,
			-174
		],
		[
			-2,
			-44
		]
	],
	[
		[
			29724,
			66677
		],
		[
			-9,
			53
		],
		[
			-6,
			-10
		],
		[
			-12,
			102
		],
		[
			9,
			73
		],
		[
			1,
			57
		],
		[
			13,
			10
		],
		[
			8,
			45
		],
		[
			-6,
			52
		],
		[
			9,
			33
		],
		[
			-5,
			65
		],
		[
			4,
			138
		],
		[
			12,
			64
		],
		[
			-6,
			60
		],
		[
			10,
			135
		],
		[
			-5,
			35
		],
		[
			5,
			74
		],
		[
			15,
			33
		],
		[
			6,
			109
		],
		[
			9,
			44
		],
		[
			19,
			43
		],
		[
			6,
			44
		],
		[
			-1,
			64
		],
		[
			19,
			67
		],
		[
			0,
			85
		],
		[
			12,
			44
		],
		[
			12,
			69
		],
		[
			0,
			47
		],
		[
			-10,
			68
		],
		[
			6,
			57
		],
		[
			-6,
			34
		],
		[
			10,
			61
		],
		[
			35,
			32
		],
		[
			10,
			-13
		],
		[
			16,
			21
		],
		[
			5,
			52
		],
		[
			24,
			14
		],
		[
			14,
			39
		],
		[
			7,
			45
		],
		[
			16,
			22
		],
		[
			-6,
			59
		],
		[
			11,
			13
		],
		[
			2,
			73
		],
		[
			-10,
			38
		],
		[
			-11,
			102
		],
		[
			15,
			52
		],
		[
			4,
			64
		],
		[
			18,
			75
		],
		[
			-13,
			89
		],
		[
			11,
			30
		]
	],
	[
		[
			29842,
			64964
		],
		[
			3,
			18
		],
		[
			27,
			22
		],
		[
			-21,
			-43
		],
		[
			-9,
			3
		]
	],
	[
		[
			29812,
			64781
		],
		[
			5,
			20
		],
		[
			11,
			-16
		],
		[
			0,
			-50
		],
		[
			-6,
			35
		],
		[
			-10,
			11
		]
	],
	[
		[
			29792,
			64880
		],
		[
			16,
			16
		],
		[
			-12,
			-43
		],
		[
			-4,
			27
		]
	],
	[
		[
			29275,
			64272
		],
		[
			5,
			-67
		],
		[
			-9,
			-39
		],
		[
			-38,
			-78
		],
		[
			-11,
			-1
		]
	],
	[
		[
			28633,
			68013
		],
		[
			16,
			50
		],
		[
			-5,
			-45
		],
		[
			-11,
			-5
		]
	],
	[
		[
			28611,
			68032
		],
		[
			12,
			40
		],
		[
			9,
			-5
		],
		[
			-21,
			-35
		]
	],
	[
		[
			27689,
			66145
		],
		[
			33,
			53
		],
		[
			53,
			111
		],
		[
			29,
			91
		],
		[
			30,
			50
		],
		[
			26,
			25
		],
		[
			11,
			70
		],
		[
			13,
			36
		],
		[
			4,
			52
		],
		[
			36,
			56
		],
		[
			19,
			54
		],
		[
			-4,
			80
		],
		[
			-13,
			40
		],
		[
			2,
			43
		],
		[
			-7,
			37
		],
		[
			-23,
			35
		],
		[
			1,
			92
		],
		[
			-18,
			15
		],
		[
			9,
			77
		],
		[
			-5,
			125
		],
		[
			-3,
			13
		],
		[
			28,
			22
		],
		[
			38,
			42
		],
		[
			56,
			47
		],
		[
			40,
			20
		],
		[
			33,
			2
		],
		[
			38,
			-9
		],
		[
			36,
			8
		],
		[
			86,
			-42
		],
		[
			23,
			-19
		],
		[
			15,
			-47
		],
		[
			23,
			-46
		],
		[
			12,
			-10
		],
		[
			40,
			49
		],
		[
			35,
			1
		],
		[
			43,
			12
		],
		[
			21,
			-19
		],
		[
			23,
			-1
		],
		[
			14,
			25
		],
		[
			30,
			20
		],
		[
			18,
			40
		],
		[
			9,
			1
		],
		[
			19,
			80
		],
		[
			30,
			64
		],
		[
			10,
			8
		],
		[
			19,
			54
		],
		[
			14,
			5
		],
		[
			20,
			-15
		],
		[
			17,
			19
		],
		[
			9,
			53
		],
		[
			2,
			87
		],
		[
			-9,
			180
		],
		[
			-20,
			40
		],
		[
			11,
			50
		],
		[
			14,
			11
		],
		[
			2,
			-33
		],
		[
			21,
			41
		],
		[
			-3,
			43
		],
		[
			-19,
			47
		],
		[
			-22,
			-15
		],
		[
			5,
			29
		],
		[
			-15,
			51
		],
		[
			-15,
			1
		],
		[
			1,
			80
		],
		[
			16,
			115
		],
		[
			19,
			5
		],
		[
			23,
			42
		],
		[
			0,
			48
		],
		[
			18,
			22
		],
		[
			27,
			55
		],
		[
			9,
			-5
		],
		[
			16,
			29
		],
		[
			25,
			75
		],
		[
			4,
			46
		],
		[
			12,
			51
		],
		[
			41,
			121
		],
		[
			31,
			100
		],
		[
			56,
			141
		],
		[
			-1,
			12
		],
		[
			68,
			109
		],
		[
			26,
			62
		],
		[
			18,
			0
		],
		[
			22,
			37
		],
		[
			27,
			-29
		],
		[
			19,
			10
		],
		[
			91,
			-8
		],
		[
			53,
			-1
		],
		[
			107,
			14
		],
		[
			24,
			-1
		],
		[
			93,
			10
		]
	],
	[
		[
			29478,
			69336
		],
		[
			1,
			-109
		],
		[
			-7,
			-30
		],
		[
			-4,
			-63
		],
		[
			13,
			-57
		],
		[
			-10,
			-55
		],
		[
			-2,
			-92
		],
		[
			-4,
			-31
		],
		[
			4,
			-70
		],
		[
			19,
			-88
		],
		[
			4,
			-69
		],
		[
			-12,
			-80
		],
		[
			7,
			-114
		],
		[
			-4,
			-36
		],
		[
			-19,
			-63
		],
		[
			-5,
			-89
		],
		[
			-8,
			-79
		],
		[
			9,
			-27
		],
		[
			-1,
			-103
		],
		[
			10,
			-67
		],
		[
			-5,
			-64
		],
		[
			12,
			-57
		],
		[
			-16,
			-97
		],
		[
			-7,
			-114
		],
		[
			10,
			-26
		],
		[
			7,
			66
		],
		[
			19,
			0
		],
		[
			2,
			-53
		],
		[
			13,
			-29
		],
		[
			-2,
			-343
		],
		[
			-6,
			-422
		],
		[
			0,
			-74
		],
		[
			-4,
			-37
		],
		[
			8,
			-65
		]
	],
	[
		[
			29390,
			64649
		],
		[
			-7,
			-42
		],
		[
			-21,
			-42
		],
		[
			-2,
			-79
		],
		[
			-13,
			2
		],
		[
			9,
			-60
		],
		[
			18,
			87
		],
		[
			11,
			-15
		],
		[
			10,
			42
		],
		[
			21,
			27
		],
		[
			18,
			2
		],
		[
			4,
			33
		],
		[
			22,
			-30
		],
		[
			2,
			41
		],
		[
			9,
			-28
		],
		[
			20,
			-8
		],
		[
			18,
			-23
		],
		[
			23,
			28
		],
		[
			2,
			43
		],
		[
			17,
			8
		],
		[
			10,
			-12
		],
		[
			75,
			3
		],
		[
			39,
			20
		],
		[
			14,
			18
		],
		[
			30,
			63
		],
		[
			9,
			40
		],
		[
			12,
			13
		],
		[
			13,
			50
		],
		[
			21,
			21
		],
		[
			12,
			-2
		],
		[
			-18,
			-52
		],
		[
			-9,
			-6
		],
		[
			15,
			-31
		],
		[
			5,
			-44
		],
		[
			17,
			-12
		],
		[
			11,
			25
		],
		[
			16,
			-72
		],
		[
			15,
			17
		],
		[
			23,
			48
		],
		[
			2,
			28
		],
		[
			17,
			11
		],
		[
			12,
			-12
		],
		[
			-5,
			-21
		],
		[
			-67,
			-94
		],
		[
			-78,
			-123
		],
		[
			-50,
			-62
		],
		[
			-81,
			-93
		],
		[
			-53,
			-78
		],
		[
			-43,
			-41
		],
		[
			-27,
			-12
		],
		[
			-6,
			15
		],
		[
			-64,
			-60
		],
		[
			-61,
			10
		],
		[
			-46,
			-55
		],
		[
			3,
			38
		],
		[
			-23,
			-2
		],
		[
			3,
			25
		],
		[
			-11,
			39
		],
		[
			7,
			35
		],
		[
			-8,
			36
		]
	],
	[
		[
			26861,
			65369
		],
		[
			16,
			17
		],
		[
			-2,
			-36
		],
		[
			-14,
			19
		]
	],
	[
		[
			26831,
			65420
		],
		[
			6,
			90
		],
		[
			11,
			-35
		],
		[
			-3,
			-35
		],
		[
			-14,
			-42
		],
		[
			0,
			22
		]
	],
	[
		[
			26661,
			65520
		],
		[
			1,
			-26
		],
		[
			21,
			-28
		],
		[
			13,
			17
		],
		[
			37,
			-82
		],
		[
			25,
			-20
		],
		[
			11,
			-21
		],
		[
			18,
			-66
		],
		[
			19,
			-29
		],
		[
			18,
			23
		],
		[
			2,
			50
		],
		[
			7,
			13
		],
		[
			14,
			-55
		],
		[
			19,
			2
		],
		[
			-1,
			-37
		],
		[
			29,
			-96
		],
		[
			16,
			-33
		],
		[
			22,
			-21
		],
		[
			41,
			57
		],
		[
			22,
			4
		],
		[
			17,
			35
		],
		[
			51,
			60
		],
		[
			37,
			-38
		],
		[
			19,
			15
		],
		[
			20,
			-9
		],
		[
			29,
			61
		],
		[
			29,
			86
		],
		[
			8,
			10
		],
		[
			16,
			58
		],
		[
			44,
			102
		],
		[
			10,
			1
		],
		[
			67,
			108
		],
		[
			30,
			17
		],
		[
			24,
			34
		],
		[
			65,
			69
		],
		[
			17,
			24
		]
	],
	[
		[
			15490,
			70789
		],
		[
			21,
			10
		],
		[
			13,
			-45
		],
		[
			-1,
			-55
		],
		[
			17,
			-42
		],
		[
			25,
			-1
		],
		[
			32,
			51
		],
		[
			14,
			-4
		],
		[
			59,
			-119
		],
		[
			7,
			-61
		],
		[
			18,
			-81
		],
		[
			1,
			-57
		],
		[
			7,
			-52
		],
		[
			-3,
			-67
		],
		[
			10,
			-88
		],
		[
			-4,
			-41
		],
		[
			3,
			-50
		],
		[
			33,
			-54
		],
		[
			46,
			-35
		],
		[
			11,
			-19
		],
		[
			17,
			14
		],
		[
			13,
			-32
		],
		[
			18,
			-5
		],
		[
			23,
			39
		],
		[
			23,
			7
		],
		[
			54,
			83
		],
		[
			12,
			45
		],
		[
			15,
			16
		],
		[
			21,
			-15
		],
		[
			29,
			12
		],
		[
			28,
			26
		],
		[
			19,
			-30
		],
		[
			17,
			-9
		],
		[
			18,
			14
		],
		[
			34,
			-40
		],
		[
			9,
			-75
		],
		[
			14,
			4
		],
		[
			19,
			50
		],
		[
			34,
			4
		],
		[
			13,
			-16
		],
		[
			11,
			34
		],
		[
			47,
			51
		],
		[
			15,
			35
		],
		[
			21,
			-9
		],
		[
			21,
			-51
		],
		[
			22,
			6
		],
		[
			34,
			26
		],
		[
			20,
			5
		],
		[
			11,
			42
		],
		[
			28,
			27
		],
		[
			29,
			46
		],
		[
			46,
			27
		],
		[
			37,
			10
		],
		[
			13,
			57
		],
		[
			14,
			23
		],
		[
			24,
			-22
		],
		[
			64,
			39
		],
		[
			17,
			-14
		],
		[
			19,
			6
		],
		[
			28,
			42
		],
		[
			11,
			36
		],
		[
			163,
			1
		],
		[
			250,
			-3
		],
		[
			164,
			-3
		]
	],
	[
		[
			17338,
			70482
		],
		[
			16,
			-107
		],
		[
			11,
			-27
		],
		[
			16,
			-75
		],
		[
			18,
			5
		],
		[
			10,
			-47
		],
		[
			19,
			-2
		],
		[
			16,
			-48
		],
		[
			0,
			-53
		],
		[
			13,
			-49
		],
		[
			7,
			-54
		],
		[
			-24,
			-108
		],
		[
			-1,
			-55
		],
		[
			-10,
			-23
		],
		[
			-24,
			-150
		],
		[
			1,
			-36
		],
		[
			-9,
			-51
		],
		[
			-7,
			-116
		],
		[
			-13,
			-40
		],
		[
			-6,
			-53
		],
		[
			-14,
			-44
		],
		[
			-3,
			-51
		],
		[
			7,
			-58
		],
		[
			-9,
			-68
		],
		[
			-18,
			-76
		],
		[
			0,
			-21
		],
		[
			-32,
			-49
		],
		[
			-14,
			-93
		],
		[
			-8,
			-97
		],
		[
			-10,
			-66
		],
		[
			-18,
			-48
		],
		[
			3,
			-66
		],
		[
			-8,
			-36
		],
		[
			15,
			-69
		],
		[
			-8,
			-56
		],
		[
			13,
			-35
		],
		[
			19,
			25
		],
		[
			16,
			-59
		],
		[
			20,
			12
		],
		[
			2,
			-53
		],
		[
			18,
			-17
		],
		[
			1,
			-31
		],
		[
			-10,
			-62
		],
		[
			-12,
			-17
		],
		[
			1,
			-42
		],
		[
			11,
			-32
		],
		[
			-1,
			-43
		],
		[
			-12,
			-81
		],
		[
			0,
			-54
		],
		[
			-11,
			-11
		],
		[
			-2,
			-59
		],
		[
			0,
			-2105
		]
	],
	[
		[
			17307,
			65831
		],
		[
			-166,
			-2
		],
		[
			-273,
			-5
		],
		[
			-26,
			-3
		],
		[
			-143,
			2
		],
		[
			-220,
			2
		]
	],
	[
		[
			15305,
			65829
		],
		[
			-21,
			55
		],
		[
			-15,
			55
		],
		[
			-7,
			69
		],
		[
			2,
			33
		],
		[
			-14,
			81
		],
		[
			2,
			32
		],
		[
			-7,
			63
		],
		[
			-2,
			126
		],
		[
			13,
			147
		],
		[
			-7,
			107
		],
		[
			-17,
			87
		],
		[
			-11,
			2
		],
		[
			-11,
			123
		],
		[
			15,
			90
		],
		[
			12,
			96
		],
		[
			6,
			83
		],
		[
			0,
			52
		],
		[
			9,
			80
		],
		[
			6,
			99
		],
		[
			-6,
			42
		],
		[
			17,
			53
		],
		[
			8,
			43
		],
		[
			16,
			132
		],
		[
			15,
			193
		],
		[
			15,
			283
		],
		[
			7,
			225
		],
		[
			4,
			188
		],
		[
			-2,
			8
		],
		[
			10,
			197
		],
		[
			-1,
			69
		],
		[
			7,
			184
		],
		[
			0,
			92
		],
		[
			-5,
			39
		],
		[
			8,
			91
		],
		[
			12,
			227
		],
		[
			8,
			117
		],
		[
			4,
			157
		],
		[
			-3,
			66
		],
		[
			3,
			109
		],
		[
			-4,
			69
		],
		[
			5,
			24
		],
		[
			5,
			176
		],
		[
			-1,
			76
		],
		[
			-11,
			41
		],
		[
			6,
			87
		],
		[
			-2,
			83
		],
		[
			-7,
			45
		],
		[
			16,
			36
		],
		[
			1,
			109
		],
		[
			-19,
			193
		],
		[
			27,
			-79
		],
		[
			14,
			-14
		],
		[
			-3,
			38
		],
		[
			23,
			10
		],
		[
			7,
			17
		],
		[
			11,
			-28
		],
		[
			12,
			31
		],
		[
			15,
			0
		],
		[
			20,
			51
		]
	],
	[
		[
			26599,
			59546
		],
		[
			33,
			-4
		],
		[
			78,
			1
		],
		[
			5,
			-5
		],
		[
			157,
			-1
		],
		[
			61,
			3
		],
		[
			151,
			-2
		],
		[
			3,
			26
		],
		[
			77,
			-5
		],
		[
			-8,
			-28
		]
	],
	[
		[
			18139,
			65823
		],
		[
			61,
			-6
		],
		[
			262,
			13
		],
		[
			192,
			2
		],
		[
			5,
			-5
		],
		[
			196,
			3
		],
		[
			118,
			3
		]
	],
	[
		[
			18136,
			60011
		],
		[
			0,
			880
		],
		[
			1,
			11
		],
		[
			-1,
			272
		],
		[
			1,
			173
		],
		[
			-1,
			298
		],
		[
			1,
			318
		],
		[
			0,
			1661
		],
		[
			1,
			149
		],
		[
			0,
			628
		],
		[
			1,
			266
		],
		[
			0,
			1156
		]
	],
	[
		[
			28738,
			60998
		],
		[
			7,
			-15
		],
		[
			-7,
			-27
		],
		[
			0,
			42
		]
	],
	[
		[
			28949,
			61206
		],
		[
			-16,
			-79
		],
		[
			-15,
			-98
		],
		[
			-8,
			-27
		],
		[
			-5,
			21
		],
		[
			-15,
			-7
		],
		[
			-19,
			-78
		],
		[
			-12,
			-70
		],
		[
			-11,
			-126
		],
		[
			1,
			-64
		],
		[
			-23,
			-128
		],
		[
			7,
			-14
		],
		[
			-18,
			-91
		],
		[
			-12,
			-79
		],
		[
			-9,
			-11
		],
		[
			1,
			-57
		],
		[
			-11,
			-86
		],
		[
			-18,
			-64
		],
		[
			-16,
			2
		],
		[
			4,
			-35
		],
		[
			-9,
			-5
		],
		[
			-1,
			84
		],
		[
			-10,
			55
		],
		[
			-4,
			61
		],
		[
			2,
			70
		],
		[
			9,
			59
		],
		[
			3,
			89
		],
		[
			10,
			105
		],
		[
			4,
			76
		],
		[
			16,
			79
		],
		[
			18,
			110
		],
		[
			-4,
			34
		],
		[
			21,
			17
		],
		[
			15,
			65
		],
		[
			1,
			28
		],
		[
			-20,
			21
		],
		[
			25,
			54
		]
	],
	[
		[
			28739,
			61120
		],
		[
			-11,
			-44
		],
		[
			-3,
			44
		]
	],
	[
		[
			28423,
			61914
		],
		[
			-20,
			-21
		],
		[
			-13,
			21
		],
		[
			0,
			-52
		],
		[
			-18,
			-113
		],
		[
			-4,
			-52
		],
		[
			2,
			-76
		],
		[
			15,
			-59
		],
		[
			29,
			15
		],
		[
			6,
			26
		],
		[
			15,
			0
		],
		[
			12,
			38
		],
		[
			9,
			-30
		],
		[
			-6,
			-74
		],
		[
			19,
			-64
		],
		[
			0,
			-49
		],
		[
			35,
			-59
		],
		[
			25,
			-2
		],
		[
			7,
			-28
		],
		[
			6,
			21
		],
		[
			24,
			-9
		],
		[
			4,
			-44
		],
		[
			16,
			-39
		],
		[
			8,
			-59
		],
		[
			13,
			-15
		],
		[
			15,
			-54
		],
		[
			20,
			-23
		],
		[
			30,
			-68
		],
		[
			-5,
			-65
		],
		[
			-15,
			-24
		],
		[
			-2,
			-107
		],
		[
			4,
			-29
		],
		[
			-11,
			-46
		],
		[
			13,
			-23
		],
		[
			-19,
			-30
		],
		[
			-31,
			64
		],
		[
			-11,
			-27
		],
		[
			-7,
			25
		],
		[
			0,
			41
		],
		[
			-13,
			81
		],
		[
			-19,
			32
		],
		[
			-8,
			35
		],
		[
			-12,
			12
		],
		[
			-21,
			103
		],
		[
			-11,
			11
		],
		[
			-4,
			45
		],
		[
			-13,
			30
		],
		[
			-2,
			-30
		],
		[
			28,
			-89
		],
		[
			20,
			-114
		],
		[
			15,
			-24
		],
		[
			1,
			-25
		],
		[
			16,
			-14
		],
		[
			10,
			-96
		],
		[
			11,
			-53
		],
		[
			30,
			-4
		],
		[
			7,
			-36
		],
		[
			31,
			-24
		],
		[
			-14,
			-29
		],
		[
			-1,
			-37
		],
		[
			13,
			-8
		],
		[
			4,
			22
		],
		[
			8,
			-41
		],
		[
			5,
			-110
		],
		[
			-8,
			-90
		],
		[
			-18,
			63
		],
		[
			-21,
			45
		],
		[
			-9,
			-42
		],
		[
			11,
			-39
		],
		[
			7,
			-55
		],
		[
			9,
			-14
		],
		[
			-22,
			-24
		],
		[
			-18,
			-4
		],
		[
			6,
			-39
		],
		[
			22,
			11
		],
		[
			-2,
			-76
		],
		[
			14,
			12
		],
		[
			4,
			-31
		],
		[
			12,
			-20
		],
		[
			6,
			-49
		],
		[
			-9,
			-97
		],
		[
			-4,
			15
		],
		[
			-16,
			-18
		],
		[
			-15,
			-34
		],
		[
			-10,
			68
		],
		[
			-29,
			61
		],
		[
			-14,
			45
		],
		[
			4,
			48
		],
		[
			-13,
			71
		],
		[
			-22,
			-9
		],
		[
			-8,
			-25
		],
		[
			-10,
			46
		],
		[
			-18,
			11
		],
		[
			-4,
			23
		],
		[
			-21,
			-35
		],
		[
			11,
			-33
		],
		[
			12,
			8
		],
		[
			18,
			-13
		],
		[
			15,
			-55
		],
		[
			9,
			-2
		],
		[
			8,
			58
		],
		[
			8,
			-119
		],
		[
			1,
			-67
		],
		[
			22,
			-19
		],
		[
			25,
			-82
		],
		[
			1,
			-65
		],
		[
			27,
			4
		],
		[
			9,
			27
		],
		[
			1,
			-33
		],
		[
			9,
			-11
		],
		[
			-3,
			86
		],
		[
			17,
			6
		],
		[
			13,
			-29
		],
		[
			35,
			-36
		],
		[
			17,
			27
		],
		[
			11,
			-11
		],
		[
			8,
			-128
		],
		[
			12,
			-140
		],
		[
			9,
			-71
		],
		[
			7,
			-94
		]
	],
	[
		[
			15775,
			72069
		],
		[
			4,
			105
		],
		[
			10,
			72
		],
		[
			12,
			-52
		],
		[
			-2,
			-58
		],
		[
			19,
			-32
		],
		[
			-18,
			-27
		],
		[
			-5,
			-26
		],
		[
			-18,
			-12
		],
		[
			-2,
			30
		]
	],
	[
		[
			15740,
			73454
		],
		[
			0,
			40
		],
		[
			20,
			-41
		],
		[
			-17,
			-26
		],
		[
			-3,
			27
		]
	],
	[
		[
			15720,
			73667
		],
		[
			6,
			14
		],
		[
			26,
			-115
		],
		[
			-18,
			42
		],
		[
			-14,
			59
		]
	],
	[
		[
			15715,
			73495
		],
		[
			8,
			29
		],
		[
			12,
			-47
		],
		[
			-15,
			-33
		],
		[
			-5,
			51
		]
	],
	[
		[
			15707,
			73080
		],
		[
			13,
			89
		],
		[
			14,
			59
		],
		[
			2,
			55
		],
		[
			16,
			11
		],
		[
			7,
			-19
		],
		[
			0,
			-49
		],
		[
			19,
			-38
		],
		[
			3,
			-26
		],
		[
			-15,
			-19
		],
		[
			-17,
			15
		],
		[
			-1,
			-29
		],
		[
			-13,
			-34
		],
		[
			-14,
			-7
		],
		[
			3,
			-24
		],
		[
			23,
			10
		],
		[
			11,
			-42
		],
		[
			8,
			-84
		],
		[
			-4,
			-14
		],
		[
			10,
			-100
		],
		[
			8,
			27
		],
		[
			-5,
			67
		],
		[
			10,
			-3
		],
		[
			16,
			-57
		],
		[
			16,
			-13
		],
		[
			7,
			-94
		],
		[
			-8,
			-58
		],
		[
			-14,
			13
		],
		[
			-12,
			86
		],
		[
			-21,
			-25
		],
		[
			2,
			30
		],
		[
			-19,
			44
		],
		[
			3,
			93
		],
		[
			-5,
			56
		],
		[
			-18,
			-4
		],
		[
			-3,
			30
		],
		[
			-22,
			54
		]
	],
	[
		[
			15649,
			73739
		],
		[
			11,
			-4
		],
		[
			34,
			-53
		],
		[
			-8,
			-8
		],
		[
			-22,
			20
		],
		[
			-15,
			45
		]
	],
	[
		[
			15623,
			73630
		],
		[
			17,
			26
		],
		[
			2,
			-33
		],
		[
			-19,
			7
		]
	],
	[
		[
			15618,
			73982
		],
		[
			15,
			0
		],
		[
			4,
			-29
		],
		[
			-17,
			-2
		],
		[
			-2,
			31
		]
	],
	[
		[
			15586,
			73509
		],
		[
			7,
			30
		],
		[
			20,
			1
		],
		[
			2,
			-29
		],
		[
			15,
			-33
		],
		[
			17,
			-9
		],
		[
			-18,
			69
		],
		[
			37,
			108
		],
		[
			12,
			-2
		],
		[
			37,
			-58
		],
		[
			-19,
			-50
		],
		[
			11,
			-66
		],
		[
			-2,
			-62
		],
		[
			-11,
			-25
		],
		[
			4,
			-69
		],
		[
			-20,
			-12
		],
		[
			-15,
			50
		],
		[
			-9,
			-12
		],
		[
			-22,
			11
		],
		[
			-31,
			62
		],
		[
			-6,
			76
		],
		[
			-9,
			20
		]
	],
	[
		[
			15577,
			73617
		],
		[
			18,
			-10
		],
		[
			18,
			-54
		],
		[
			-30,
			41
		],
		[
			-6,
			23
		]
	],
	[
		[
			17306,
			73978
		],
		[
			-1,
			-290
		],
		[
			0,
			-441
		],
		[
			-2,
			-286
		],
		[
			0,
			-702
		],
		[
			1,
			-52
		],
		[
			0,
			-1247
		],
		[
			-7,
			-48
		],
		[
			20,
			-76
		],
		[
			8,
			-54
		],
		[
			0,
			-63
		],
		[
			12,
			-40
		],
		[
			-17,
			-93
		],
		[
			7,
			-11
		],
		[
			11,
			-93
		]
	],
	[
		[
			15490,
			70789
		],
		[
			-34,
			9
		],
		[
			-3,
			34
		],
		[
			-12,
			6
		],
		[
			-10,
			-31
		],
		[
			-13,
			10
		],
		[
			-19,
			-51
		],
		[
			-9,
			7
		],
		[
			-21,
			74
		],
		[
			-10,
			8
		],
		[
			-7,
			-47
		],
		[
			-10,
			-10
		],
		[
			6,
			139
		],
		[
			1,
			124
		],
		[
			-4,
			165
		],
		[
			13,
			-61
		],
		[
			-2,
			-100
		],
		[
			4,
			-137
		],
		[
			17,
			0
		],
		[
			1,
			37
		],
		[
			-10,
			40
		],
		[
			0,
			61
		],
		[
			12,
			-37
		],
		[
			14,
			83
		],
		[
			-19,
			116
		],
		[
			11,
			42
		],
		[
			25,
			53
		],
		[
			-17,
			37
		],
		[
			-6,
			-27
		],
		[
			-18,
			-2
		],
		[
			4,
			-23
		],
		[
			-16,
			4
		],
		[
			-20,
			44
		],
		[
			-1,
			55
		],
		[
			-11,
			130
		],
		[
			8,
			8
		],
		[
			6,
			-52
		],
		[
			11,
			31
		],
		[
			52,
			63
		],
		[
			-10,
			27
		],
		[
			-34,
			23
		],
		[
			-2,
			45
		],
		[
			-27,
			14
		],
		[
			-8,
			-24
		],
		[
			8,
			-90
		],
		[
			-16,
			-21
		],
		[
			3,
			38
		],
		[
			-4,
			206
		],
		[
			-14,
			176
		],
		[
			-24,
			80
		],
		[
			-9,
			207
		],
		[
			-5,
			77
		],
		[
			-15,
			162
		],
		[
			-14,
			36
		],
		[
			-4,
			55
		],
		[
			-14,
			23
		],
		[
			-5,
			31
		],
		[
			-19,
			29
		],
		[
			-12,
			110
		],
		[
			-8,
			101
		],
		[
			1,
			53
		],
		[
			-11,
			56
		],
		[
			12,
			58
		],
		[
			9,
			138
		],
		[
			-19,
			46
		],
		[
			3,
			22
		],
		[
			17,
			1
		],
		[
			40,
			-55
		],
		[
			32,
			-64
		],
		[
			10,
			-1
		],
		[
			25,
			-39
		],
		[
			6,
			12
		],
		[
			41,
			-55
		],
		[
			-1,
			-20
		],
		[
			35,
			-41
		],
		[
			56,
			-11
		],
		[
			21,
			13
		],
		[
			31,
			-37
		],
		[
			9,
			19
		],
		[
			10,
			-18
		],
		[
			24,
			7
		],
		[
			12,
			-32
		],
		[
			41,
			2
		],
		[
			32,
			71
		],
		[
			-3,
			-24
		],
		[
			22,
			-42
		],
		[
			7,
			-45
		],
		[
			17,
			17
		],
		[
			17,
			-5
		],
		[
			-3,
			-32
		],
		[
			14,
			-20
		],
		[
			1,
			-59
		],
		[
			10,
			6
		],
		[
			3,
			53
		],
		[
			-14,
			34
		],
		[
			0,
			40
		],
		[
			12,
			28
		],
		[
			21,
			10
		],
		[
			3,
			-31
		],
		[
			-15,
			-34
		],
		[
			10,
			-50
		],
		[
			7,
			6
		],
		[
			2,
			48
		],
		[
			10,
			14
		],
		[
			8,
			-100
		],
		[
			-15,
			-10
		],
		[
			11,
			-42
		],
		[
			8,
			-78
		],
		[
			13,
			-21
		],
		[
			-8,
			-25
		],
		[
			-16,
			2
		],
		[
			2,
			-42
		],
		[
			-17,
			-36
		],
		[
			-9,
			-113
		],
		[
			-14,
			-9
		],
		[
			11,
			113
		],
		[
			-6,
			17
		],
		[
			-19,
			-101
		],
		[
			-4,
			-53
		],
		[
			-21,
			-70
		],
		[
			-38,
			-183
		],
		[
			-13,
			-119
		],
		[
			12,
			8
		],
		[
			23,
			-13
		],
		[
			12,
			27
		],
		[
			21,
			17
		],
		[
			3,
			38
		],
		[
			-44,
			-62
		],
		[
			-17,
			27
		],
		[
			42,
			226
		],
		[
			31,
			74
		],
		[
			29,
			28
		],
		[
			3,
			73
		],
		[
			16,
			73
		],
		[
			31,
			68
		],
		[
			-9,
			97
		],
		[
			22,
			-40
		],
		[
			14,
			-187
		],
		[
			-22,
			0
		],
		[
			3,
			-40
		],
		[
			11,
			-14
		],
		[
			-4,
			-56
		],
		[
			7,
			-19
		],
		[
			0,
			-53
		],
		[
			-14,
			-38
		],
		[
			-1,
			-38
		],
		[
			15,
			-16
		],
		[
			-10,
			-48
		],
		[
			-6,
			-87
		],
		[
			4,
			-21
		],
		[
			-10,
			-57
		],
		[
			7,
			-49
		],
		[
			-15,
			-79
		],
		[
			-27,
			78
		],
		[
			8,
			96
		],
		[
			-16,
			-42
		],
		[
			-6,
			-63
		],
		[
			30,
			-83
		],
		[
			-10,
			-16
		],
		[
			1,
			-48
		],
		[
			-11,
			-26
		],
		[
			-16,
			46
		],
		[
			-20,
			105
		],
		[
			12,
			37
		],
		[
			1,
			61
		],
		[
			-7,
			25
		],
		[
			0,
			-51
		],
		[
			-12,
			-57
		],
		[
			7,
			-72
		],
		[
			-6,
			-48
		],
		[
			13,
			14
		],
		[
			11,
			-66
		],
		[
			27,
			-22
		],
		[
			11,
			37
		],
		[
			0,
			33
		],
		[
			13,
			16
		],
		[
			8,
			79
		],
		[
			10,
			53
		],
		[
			-2,
			30
		],
		[
			25,
			-58
		],
		[
			10,
			25
		],
		[
			-4,
			36
		],
		[
			27,
			34
		],
		[
			0,
			50
		],
		[
			-8,
			58
		],
		[
			-8,
			11
		],
		[
			6,
			35
		],
		[
			-10,
			40
		],
		[
			-7,
			71
		],
		[
			22,
			38
		],
		[
			-24,
			58
		],
		[
			16,
			82
		],
		[
			-6,
			91
		],
		[
			15,
			46
		],
		[
			9,
			119
		],
		[
			22,
			25
		],
		[
			-1,
			69
		],
		[
			-14,
			23
		],
		[
			-23,
			86
		],
		[
			1,
			74
		],
		[
			-10,
			49
		],
		[
			-15,
			4
		],
		[
			3,
			-24
		],
		[
			-11,
			-28
		],
		[
			10,
			-67
		],
		[
			18,
			-50
		],
		[
			1,
			-35
		],
		[
			-26,
			85
		],
		[
			-12,
			4
		],
		[
			-7,
			58
		],
		[
			2,
			77
		],
		[
			18,
			24
		],
		[
			16,
			-22
		],
		[
			10,
			42
		],
		[
			-10,
			45
		],
		[
			-28,
			45
		],
		[
			-13,
			48
		],
		[
			1,
			39
		],
		[
			-29,
			-33
		],
		[
			-7,
			33
		],
		[
			4,
			45
		],
		[
			-13,
			-17
		],
		[
			3,
			39
		],
		[
			24,
			28
		],
		[
			13,
			-15
		],
		[
			9,
			-49
		],
		[
			19,
			7
		],
		[
			-10,
			108
		],
		[
			17,
			6
		],
		[
			5,
			34
		],
		[
			-21,
			66
		],
		[
			-5,
			66
		],
		[
			8,
			44
		],
		[
			-13,
			30
		],
		[
			-17,
			-6
		],
		[
			-11,
			-41
		],
		[
			9,
			-44
		],
		[
			-19,
			40
		],
		[
			8,
			57
		],
		[
			-10,
			25
		],
		[
			-9,
			-14
		],
		[
			-1,
			65
		],
		[
			-21,
			54
		],
		[
			11,
			21
		],
		[
			-5,
			36
		],
		[
			-13,
			16
		],
		[
			16,
			54
		],
		[
			184,
			0
		],
		[
			97,
			-6
		],
		[
			145,
			5
		],
		[
			143,
			-2
		],
		[
			190,
			0
		],
		[
			169,
			0
		],
		[
			165,
			1
		],
		[
			178,
			0
		],
		[
			325,
			-2
		]
	],
	[
		[
			25685,
			69733
		],
		[
			6,
			80
		],
		[
			31,
			-17
		],
		[
			-23,
			-128
		],
		[
			-14,
			65
		]
	],
	[
		[
			25568,
			69555
		],
		[
			12,
			14
		],
		[
			2,
			-63
		],
		[
			-14,
			23
		],
		[
			0,
			26
		]
	],
	[
		[
			24707,
			71654
		],
		[
			8,
			83
		],
		[
			12,
			4
		],
		[
			-5,
			-75
		],
		[
			-15,
			-12
		]
	],
	[
		[
			24691,
			71507
		],
		[
			21,
			33
		],
		[
			-14,
			-47
		],
		[
			-7,
			14
		]
	],
	[
		[
			24655,
			71564
		],
		[
			5,
			21
		],
		[
			30,
			29
		],
		[
			5,
			-13
		],
		[
			-11,
			-48
		],
		[
			-24,
			-11
		],
		[
			-5,
			22
		]
	],
	[
		[
			24625,
			71464
		],
		[
			3,
			27
		],
		[
			20,
			41
		],
		[
			1,
			-19
		],
		[
			-24,
			-49
		]
	],
	[
		[
			24631,
			71609
		],
		[
			14,
			-54
		],
		[
			-13,
			-3
		],
		[
			-8,
			37
		],
		[
			7,
			20
		]
	],
	[
		[
			24621,
			71679
		],
		[
			35,
			36
		],
		[
			11,
			-55
		],
		[
			14,
			34
		],
		[
			2,
			-44
		],
		[
			-16,
			-9
		],
		[
			-17,
			-49
		],
		[
			-11,
			42
		],
		[
			-16,
			20
		],
		[
			-2,
			25
		]
	],
	[
		[
			24616,
			71401
		],
		[
			17,
			18
		],
		[
			32,
			86
		],
		[
			14,
			-32
		],
		[
			-30,
			-33
		],
		[
			5,
			-35
		],
		[
			-17,
			-4
		],
		[
			-20,
			-37
		],
		[
			-1,
			37
		]
	],
	[
		[
			24563,
			71635
		],
		[
			15,
			17
		],
		[
			-1,
			-44
		],
		[
			-14,
			27
		]
	],
	[
		[
			24276,
			71309
		],
		[
			20,
			-30
		],
		[
			34,
			11
		],
		[
			49,
			52
		],
		[
			19,
			27
		],
		[
			18,
			0
		],
		[
			48,
			70
		],
		[
			25,
			27
		],
		[
			6,
			26
		],
		[
			17,
			-22
		],
		[
			7,
			33
		],
		[
			25,
			10
		],
		[
			22,
			70
		],
		[
			14,
			-12
		],
		[
			14,
			35
		],
		[
			10,
			-4
		],
		[
			24,
			-81
		],
		[
			-14,
			-76
		],
		[
			-24,
			-78
		],
		[
			9,
			-73
		],
		[
			-16,
			-35
		],
		[
			-11,
			-77
		],
		[
			13,
			-16
		],
		[
			42,
			73
		],
		[
			5,
			54
		],
		[
			42,
			-108
		],
		[
			13,
			-22
		],
		[
			9,
			10
		],
		[
			25,
			-27
		]
	],
	[
		[
			25508,
			69434
		],
		[
			-10,
			-58
		],
		[
			-1,
			-80
		],
		[
			-37,
			-13
		],
		[
			-21,
			-40
		],
		[
			3,
			-47
		],
		[
			-11,
			-59
		],
		[
			-9,
			-15
		],
		[
			-11,
			-83
		],
		[
			-12,
			-42
		],
		[
			-7,
			-104
		],
		[
			3,
			-25
		],
		[
			-13,
			-50
		],
		[
			20,
			-42
		],
		[
			12,
			7
		],
		[
			7,
			53
		],
		[
			26,
			64
		],
		[
			10,
			3
		],
		[
			15,
			63
		],
		[
			0,
			36
		],
		[
			31,
			133
		],
		[
			26,
			36
		],
		[
			11,
			-7
		],
		[
			11,
			34
		],
		[
			15,
			-32
		],
		[
			-6,
			46
		],
		[
			12,
			97
		],
		[
			27,
			109
		],
		[
			7,
			100
		],
		[
			12,
			-5
		],
		[
			21,
			32
		],
		[
			1,
			59
		],
		[
			17,
			60
		],
		[
			22,
			-3
		],
		[
			-2,
			-87
		],
		[
			-16,
			-5
		],
		[
			-2,
			-142
		],
		[
			-12,
			-40
		],
		[
			-8,
			4
		],
		[
			-5,
			-53
		],
		[
			-14,
			-52
		],
		[
			5,
			-43
		],
		[
			-13,
			-39
		],
		[
			4,
			-26
		],
		[
			-18,
			-33
		],
		[
			-13,
			-62
		],
		[
			-8,
			-87
		],
		[
			-17,
			-107
		],
		[
			-9,
			-26
		],
		[
			-9,
			-62
		],
		[
			-21,
			-268
		],
		[
			9,
			-94
		],
		[
			-2,
			-71
		],
		[
			-12,
			-41
		],
		[
			-23,
			-46
		],
		[
			-3,
			-62
		],
		[
			-8,
			-37
		],
		[
			-14,
			-162
		],
		[
			2,
			-82
		],
		[
			8,
			-50
		],
		[
			-2,
			-102
		],
		[
			-21,
			-118
		],
		[
			-7,
			-136
		],
		[
			-20,
			-107
		],
		[
			-9,
			-156
		],
		[
			8,
			-76
		],
		[
			-5,
			-38
		],
		[
			8,
			-85
		],
		[
			-7,
			-57
		],
		[
			14,
			-62
		],
		[
			0,
			-85
		],
		[
			6,
			-63
		],
		[
			16,
			-59
		],
		[
			-4,
			-89
		],
		[
			-11,
			-107
		],
		[
			6,
			-145
		]
	],
	[
		[
			2682,
			386
		],
		[
			26,
			11
		],
		[
			1,
			-51
		],
		[
			-9,
			8
		],
		[
			-8,
			-28
		],
		[
			-10,
			60
		]
	],
	[
		[
			2636,
			452
		],
		[
			21,
			8
		],
		[
			-4,
			-21
		],
		[
			-13,
			-12
		],
		[
			-4,
			25
		]
	],
	[
		[
			2313,
			271
		],
		[
			13,
			35
		],
		[
			16,
			2
		],
		[
			19,
			68
		],
		[
			4,
			-20
		],
		[
			27,
			2
		],
		[
			4,
			-44
		],
		[
			-7,
			13
		],
		[
			-29,
			-30
		],
		[
			-23,
			-89
		],
		[
			-11,
			47
		],
		[
			-13,
			16
		]
	],
	[
		[
			90204,
			32599
		],
		[
			5,
			15
		],
		[
			34,
			16
		],
		[
			21,
			137
		],
		[
			6,
			65
		],
		[
			7,
			-11
		],
		[
			7,
			-43
		],
		[
			14,
			-11
		],
		[
			-10,
			-88
		],
		[
			-32,
			-109
		],
		[
			-9,
			-44
		],
		[
			-2,
			-111
		],
		[
			-12,
			-56
		],
		[
			-18,
			30
		],
		[
			-7,
			101
		],
		[
			8,
			50
		],
		[
			-12,
			59
		]
	],
	[
		[
			90597,
			35570
		],
		[
			10,
			43
		],
		[
			4,
			-16
		],
		[
			-8,
			-45
		],
		[
			-6,
			18
		]
	],
	[
		[
			90537,
			37432
		],
		[
			5,
			20
		],
		[
			1,
			-49
		],
		[
			-6,
			29
		]
	],
	[
		[
			90507,
			37973
		],
		[
			14,
			53
		],
		[
			0,
			59
		],
		[
			11,
			0
		],
		[
			0,
			-66
		],
		[
			-9,
			-13
		],
		[
			-10,
			-55
		],
		[
			-6,
			22
		]
	],
	[
		[
			90501,
			34555
		],
		[
			4,
			28
		],
		[
			2,
			101
		],
		[
			9,
			-12
		],
		[
			20,
			67
		],
		[
			5,
			-22
		],
		[
			-14,
			-80
		],
		[
			4,
			-63
		],
		[
			-13,
			7
		],
		[
			0,
			-73
		],
		[
			-12,
			18
		],
		[
			-5,
			29
		]
	],
	[
		[
			90487,
			38800
		],
		[
			6,
			39
		],
		[
			11,
			-28
		],
		[
			-1,
			-51
		],
		[
			-8,
			-23
		],
		[
			-7,
			25
		],
		[
			-1,
			38
		]
	],
	[
		[
			90486,
			35993
		],
		[
			20,
			2
		],
		[
			3,
			-36
		],
		[
			-19,
			-8
		],
		[
			-4,
			42
		]
	],
	[
		[
			90472,
			34420
		],
		[
			4,
			45
		],
		[
			13,
			54
		],
		[
			5,
			-54
		],
		[
			-4,
			-24
		],
		[
			7,
			-40
		],
		[
			-2,
			-61
		],
		[
			-9,
			-29
		],
		[
			-14,
			109
		]
	],
	[
		[
			90343,
			33382
		],
		[
			11,
			51
		],
		[
			21,
			35
		],
		[
			15,
			-9
		],
		[
			-2,
			-35
		],
		[
			-12,
			-13
		],
		[
			-8,
			-39
		],
		[
			-11,
			-6
		],
		[
			-5,
			23
		],
		[
			-9,
			-7
		]
	],
	[
		[
			28030,
			56345
		],
		[
			-13,
			-8
		],
		[
			-36,
			-51
		],
		[
			-27,
			-66
		],
		[
			-35,
			-121
		],
		[
			-18,
			-79
		],
		[
			-7,
			-45
		],
		[
			-16,
			-58
		],
		[
			-14,
			-93
		],
		[
			-13,
			-174
		],
		[
			3,
			-55
		],
		[
			-7,
			-48
		],
		[
			-14,
			-47
		],
		[
			-23,
			-41
		],
		[
			-9,
			-97
		],
		[
			-17,
			10
		],
		[
			-17,
			-16
		],
		[
			-11,
			39
		],
		[
			-16,
			-33
		],
		[
			-10,
			-63
		],
		[
			3,
			-31
		],
		[
			8,
			10
		],
		[
			0,
			-33
		],
		[
			-15,
			-20
		],
		[
			-18,
			-45
		],
		[
			-9,
			-52
		],
		[
			-34,
			-59
		],
		[
			-10,
			38
		],
		[
			-11,
			-7
		],
		[
			-1,
			-32
		],
		[
			17,
			-22
		],
		[
			-5,
			-59
		],
		[
			-25,
			-52
		],
		[
			-7,
			-40
		],
		[
			-10,
			5
		],
		[
			-24,
			-22
		],
		[
			-17,
			-59
		],
		[
			-6,
			18
		],
		[
			-36,
			-90
		],
		[
			-8,
			21
		],
		[
			-15,
			-28
		],
		[
			-2,
			30
		],
		[
			-13,
			-1
		],
		[
			-4,
			-42
		],
		[
			15,
			-83
		],
		[
			-7,
			-74
		],
		[
			-32,
			-62
		],
		[
			-19,
			-20
		],
		[
			-2,
			41
		],
		[
			-19,
			40
		],
		[
			-11,
			-22
		],
		[
			-2,
			-31
		],
		[
			12,
			-15
		],
		[
			14,
			-59
		],
		[
			-15,
			-65
		],
		[
			-25,
			-59
		],
		[
			-9,
			0
		],
		[
			-17,
			-67
		],
		[
			5,
			-21
		]
	],
	[
		[
			31708,
			38299
		],
		[
			11,
			-21
		],
		[
			12,
			13
		],
		[
			9,
			-36
		],
		[
			-17,
			-36
		],
		[
			-12,
			19
		],
		[
			-3,
			61
		]
	],
	[
		[
			31642,
			38028
		],
		[
			49,
			54
		],
		[
			35,
			-32
		],
		[
			-18,
			-26
		],
		[
			-21,
			-7
		],
		[
			-11,
			-24
		],
		[
			-8,
			12
		],
		[
			-17,
			-17
		],
		[
			-9,
			40
		]
	],
	[
		[
			31637,
			38350
		],
		[
			7,
			-14
		],
		[
			0,
			-44
		],
		[
			-7,
			58
		]
	],
	[
		[
			31170,
			38320
		],
		[
			15,
			18
		],
		[
			17,
			49
		],
		[
			-4,
			63
		],
		[
			7,
			32
		],
		[
			14,
			12
		],
		[
			20,
			-6
		],
		[
			17,
			-25
		],
		[
			50,
			2
		],
		[
			20,
			-22
		],
		[
			24,
			26
		],
		[
			18,
			-5
		],
		[
			25,
			-25
		],
		[
			8,
			20
		],
		[
			28,
			0
		],
		[
			27,
			-20
		],
		[
			16,
			1
		],
		[
			7,
			-19
		],
		[
			6,
			24
		],
		[
			37,
			-35
		],
		[
			4,
			19
		],
		[
			18,
			-18
		],
		[
			6,
			7
		],
		[
			31,
			-33
		],
		[
			14,
			-49
		],
		[
			7,
			13
		],
		[
			5,
			-27
		],
		[
			10,
			-6
		],
		[
			14,
			22
		],
		[
			-5,
			-40
		],
		[
			3,
			-84
		],
		[
			13,
			-30
		],
		[
			-7,
			-43
		],
		[
			-11,
			19
		],
		[
			3,
			-28
		],
		[
			-10,
			2
		],
		[
			-7,
			-32
		],
		[
			-13,
			1
		],
		[
			-11,
			-59
		],
		[
			-7,
			-83
		],
		[
			-8,
			-6
		],
		[
			-1,
			-44
		],
		[
			-25,
			-46
		],
		[
			-15,
			-9
		],
		[
			-12,
			12
		],
		[
			-7,
			-27
		],
		[
			-10,
			13
		],
		[
			-21,
			-43
		],
		[
			-10,
			9
		],
		[
			-9,
			-29
		],
		[
			-8,
			9
		],
		[
			-18,
			66
		],
		[
			-12,
			-10
		],
		[
			-7,
			-34
		],
		[
			-21,
			60
		],
		[
			-8,
			0
		],
		[
			-25,
			-33
		],
		[
			-14,
			24
		],
		[
			-12,
			-19
		],
		[
			-25,
			47
		],
		[
			-7,
			-39
		],
		[
			-14,
			-27
		],
		[
			-21,
			-3
		],
		[
			-12,
			-18
		],
		[
			-8,
			41
		],
		[
			-21,
			8
		],
		[
			-11,
			-32
		],
		[
			-19,
			19
		],
		[
			-12,
			-12
		],
		[
			1,
			53
		],
		[
			10,
			31
		],
		[
			-11,
			12
		],
		[
			3,
			65
		],
		[
			5,
			15
		],
		[
			1,
			75
		],
		[
			7,
			31
		],
		[
			-10,
			101
		],
		[
			-13,
			21
		],
		[
			-9,
			78
		]
	],
	[
		[
			30985,
			38023
		],
		[
			20,
			12
		],
		[
			5,
			-43
		],
		[
			-15,
			-38
		],
		[
			-12,
			32
		],
		[
			2,
			37
		]
	],
	[
		[
			31858,
			38286
		],
		[
			13,
			39
		],
		[
			11,
			-4
		],
		[
			15,
			-28
		],
		[
			-13,
			-4
		],
		[
			1,
			-49
		],
		[
			-9,
			20
		],
		[
			-13,
			-5
		],
		[
			-5,
			31
		]
	],
	[
		[
			31828,
			37522
		],
		[
			7,
			36
		],
		[
			-4,
			40
		],
		[
			7,
			30
		],
		[
			10,
			-13
		],
		[
			8,
			22
		],
		[
			17,
			3
		],
		[
			6,
			-29
		],
		[
			39,
			5
		],
		[
			2,
			-18
		],
		[
			-32,
			-48
		],
		[
			-41,
			-30
		],
		[
			-19,
			2
		]
	],
	[
		[
			31779,
			38288
		],
		[
			6,
			50
		],
		[
			10,
			-23
		],
		[
			12,
			26
		],
		[
			19,
			-21
		],
		[
			33,
			6
		],
		[
			-2,
			-23
		],
		[
			-14,
			-4
		],
		[
			9,
			-42
		],
		[
			-16,
			-11
		],
		[
			-15,
			23
		],
		[
			-7,
			-20
		],
		[
			-12,
			49
		],
		[
			-23,
			-10
		]
	],
	[
		[
			17306,
			73978
		],
		[
			171,
			1
		],
		[
			103,
			1
		]
	],
	[
		[
			18139,
			65823
		],
		[
			-119,
			3
		],
		[
			-36,
			-2
		],
		[
			-58,
			9
		],
		[
			-63,
			-7
		],
		[
			-79,
			0
		],
		[
			-293,
			0
		],
		[
			-184,
			5
		]
	],
	[
		[
			29478,
			69336
		],
		[
			71,
			5
		],
		[
			115,
			0
		],
		[
			40,
			-9
		],
		[
			62,
			-5
		],
		[
			57,
			2
		],
		[
			168,
			10
		]
	],
	[
		[
			25149,
			51924
		],
		[
			13,
			-63
		],
		[
			5,
			-76
		],
		[
			-3,
			-101
		],
		[
			-10,
			-105
		],
		[
			-4,
			3
		],
		[
			8,
			90
		],
		[
			4,
			100
		],
		[
			-1,
			46
		],
		[
			-12,
			106
		]
	],
	[
		[
			25020,
			51931
		],
		[
			11,
			38
		],
		[
			32,
			81
		],
		[
			2,
			-14
		],
		[
			-13,
			-63
		],
		[
			2,
			-28
		],
		[
			13,
			-33
		],
		[
			-15,
			-50
		],
		[
			-3,
			47
		],
		[
			-10,
			-10
		],
		[
			-17,
			10
		],
		[
			-2,
			22
		]
	],
	[
		[
			24941,
			51321
		],
		[
			17,
			10
		],
		[
			-9,
			-42
		],
		[
			-8,
			32
		]
	],
	[
		[
			24732,
			50824
		],
		[
			7,
			27
		],
		[
			13,
			-65
		],
		[
			-8,
			-14
		],
		[
			-12,
			52
		]
	],
	[
		[
			24681,
			50807
		],
		[
			39,
			-33
		],
		[
			-19,
			-8
		],
		[
			-20,
			41
		]
	],
	[
		[
			24628,
			50763
		],
		[
			25,
			19
		],
		[
			2,
			-17
		],
		[
			-26,
			-20
		],
		[
			-1,
			18
		]
	],
	[
		[
			24275,
			51386
		],
		[
			10,
			27
		],
		[
			12,
			-5
		],
		[
			3,
			26
		],
		[
			22,
			-6
		],
		[
			23,
			-61
		],
		[
			9,
			7
		],
		[
			6,
			-29
		],
		[
			-15,
			-36
		],
		[
			-1,
			-40
		],
		[
			-14,
			-19
		],
		[
			-59,
			115
		],
		[
			4,
			21
		]
	],
	[
		[
			24969,
			52072
		],
		[
			-17,
			-35
		],
		[
			-8,
			7
		],
		[
			-17,
			-56
		],
		[
			-2,
			-38
		],
		[
			-12,
			-15
		],
		[
			3,
			-40
		],
		[
			-28,
			17
		],
		[
			-11,
			-45
		],
		[
			5,
			-68
		],
		[
			18,
			-10
		],
		[
			13,
			25
		],
		[
			-4,
			-59
		],
		[
			8,
			-34
		],
		[
			15,
			-19
		],
		[
			13,
			11
		],
		[
			6,
			29
		],
		[
			5,
			101
		],
		[
			-2,
			13
		],
		[
			24,
			54
		],
		[
			3,
			44
		],
		[
			18,
			-34
		],
		[
			13,
			6
		],
		[
			0,
			-21
		],
		[
			-17,
			-34
		],
		[
			0,
			-34
		],
		[
			15,
			-17
		],
		[
			3,
			-61
		],
		[
			15,
			14
		],
		[
			11,
			82
		],
		[
			16,
			-25
		],
		[
			-4,
			-55
		],
		[
			-13,
			0
		],
		[
			-12,
			-44
		],
		[
			22,
			2
		],
		[
			-3,
			-29
		],
		[
			-31,
			-22
		],
		[
			13,
			-66
		],
		[
			11,
			22
		],
		[
			-7,
			-59
		],
		[
			-9,
			26
		],
		[
			-14,
			11
		],
		[
			-12,
			-55
		],
		[
			-1,
			-99
		],
		[
			-9,
			-5
		],
		[
			-6,
			86
		],
		[
			-11,
			1
		],
		[
			-2,
			-66
		],
		[
			13,
			-58
		],
		[
			-13,
			33
		],
		[
			-14,
			5
		],
		[
			-8,
			-17
		],
		[
			-15,
			6
		],
		[
			18,
			-39
		],
		[
			0,
			-32
		],
		[
			-23,
			49
		],
		[
			0,
			-25
		],
		[
			12,
			-32
		],
		[
			-12,
			-14
		],
		[
			1,
			-34
		],
		[
			11,
			-36
		],
		[
			20,
			-11
		],
		[
			-1,
			-22
		],
		[
			12,
			-24
		],
		[
			-1,
			-34
		],
		[
			7,
			-46
		],
		[
			9,
			30
		],
		[
			5,
			-21
		],
		[
			22,
			-2
		],
		[
			16,
			-34
		],
		[
			3,
			30
		],
		[
			20,
			-91
		],
		[
			11,
			44
		],
		[
			24,
			-111
		],
		[
			0,
			-59
		],
		[
			6,
			-13
		],
		[
			18,
			28
		],
		[
			7,
			-41
		],
		[
			-24,
			-15
		],
		[
			-2,
			-33
		],
		[
			16,
			-3
		],
		[
			-8,
			-52
		],
		[
			-11,
			24
		],
		[
			-12,
			-96
		],
		[
			2,
			-44
		],
		[
			-21,
			36
		],
		[
			-2,
			55
		],
		[
			-8,
			16
		],
		[
			-31,
			-138
		],
		[
			-15,
			-41
		],
		[
			7,
			67
		],
		[
			9,
			29
		],
		[
			5,
			48
		],
		[
			9,
			21
		],
		[
			0,
			54
		],
		[
			9,
			23
		],
		[
			-1,
			51
		],
		[
			-10,
			24
		],
		[
			-4,
			-62
		],
		[
			-16,
			-29
		],
		[
			-12,
			29
		],
		[
			-14,
			77
		],
		[
			-34,
			43
		],
		[
			-10,
			45
		],
		[
			-56,
			33
		],
		[
			-12,
			-14
		],
		[
			-48,
			-143
		],
		[
			-46,
			-115
		],
		[
			-7,
			10
		],
		[
			4,
			41
		],
		[
			-12,
			16
		],
		[
			-2,
			41
		],
		[
			6,
			3
		],
		[
			-12,
			100
		],
		[
			-11,
			27
		],
		[
			-9,
			-1
		],
		[
			1,
			-28
		],
		[
			-8,
			-36
		],
		[
			2,
			76
		],
		[
			-10,
			56
		],
		[
			-13,
			-64
		],
		[
			-14,
			14
		],
		[
			-7,
			-22
		],
		[
			-7,
			31
		],
		[
			-6,
			-27
		],
		[
			10,
			-63
		],
		[
			-12,
			4
		],
		[
			-7,
			-27
		],
		[
			-4,
			-54
		],
		[
			-8,
			7
		],
		[
			-5,
			-57
		],
		[
			-8,
			12
		],
		[
			-19,
			-33
		],
		[
			-6,
			-76
		],
		[
			-16,
			16
		],
		[
			5,
			21
		],
		[
			-13,
			67
		],
		[
			-18,
			57
		],
		[
			-11,
			-13
		],
		[
			-26,
			21
		],
		[
			-10,
			33
		],
		[
			-25,
			12
		],
		[
			-16,
			25
		],
		[
			-16,
			60
		],
		[
			12,
			14
		],
		[
			7,
			58
		],
		[
			8,
			-12
		],
		[
			12,
			-52
		],
		[
			7,
			22
		],
		[
			-1,
			-68
		],
		[
			15,
			-17
		],
		[
			-4,
			104
		],
		[
			-23,
			64
		],
		[
			0,
			42
		],
		[
			-11,
			7
		],
		[
			-9,
			-41
		],
		[
			-13,
			-13
		],
		[
			2,
			41
		],
		[
			-10,
			-7
		],
		[
			3,
			39
		],
		[
			9,
			28
		],
		[
			-10,
			40
		],
		[
			-29,
			-50
		],
		[
			-10,
			80
		],
		[
			-10,
			-8
		],
		[
			-6,
			118
		],
		[
			-26,
			1
		],
		[
			6,
			33
		],
		[
			1,
			85
		],
		[
			-32,
			16
		],
		[
			-13,
			-10
		],
		[
			-20,
			-38
		],
		[
			-7,
			57
		],
		[
			8,
			41
		],
		[
			8,
			-3
		],
		[
			-2,
			46
		],
		[
			-16,
			8
		],
		[
			-14,
			-22
		],
		[
			-9,
			20
		],
		[
			-2,
			-40
		],
		[
			-24,
			-36
		],
		[
			-14,
			-34
		],
		[
			-6,
			32
		],
		[
			-18,
			-16
		],
		[
			0,
			-32
		],
		[
			9,
			-30
		],
		[
			18,
			-8
		],
		[
			-9,
			-30
		],
		[
			8,
			-63
		],
		[
			20,
			21
		],
		[
			5,
			-18
		],
		[
			-13,
			-14
		],
		[
			6,
			-20
		],
		[
			-32,
			-6
		],
		[
			-26,
			-49
		],
		[
			-20,
			-9
		],
		[
			-82,
			63
		],
		[
			-35,
			42
		],
		[
			-57,
			101
		],
		[
			-23,
			32
		],
		[
			-41,
			40
		],
		[
			-33,
			5
		],
		[
			-14,
			-14
		],
		[
			-36,
			7
		],
		[
			-58,
			-25
		],
		[
			-17,
			-13
		],
		[
			-26,
			-53
		]
	],
	[
		[
			30097,
			65246
		],
		[
			-20,
			-46
		],
		[
			-6,
			102
		],
		[
			2,
			64
		],
		[
			-10,
			22
		],
		[
			2,
			-159
		],
		[
			-17,
			2
		],
		[
			-2,
			-35
		],
		[
			-10,
			-7
		],
		[
			-1,
			55
		],
		[
			16,
			95
		],
		[
			8,
			68
		],
		[
			17,
			46
		]
	],
	[
		[
			30029,
			65436
		],
		[
			5,
			7
		],
		[
			11,
			-52
		],
		[
			-5,
			-7
		],
		[
			-11,
			52
		]
	],
	[
		[
			30019,
			65203
		],
		[
			6,
			51
		],
		[
			-4,
			23
		],
		[
			5,
			57
		],
		[
			4,
			-20
		],
		[
			0,
			-85
		],
		[
			-11,
			-26
		]
	],
	[
		[
			29960,
			64853
		],
		[
			11,
			80
		],
		[
			5,
			-14
		],
		[
			1,
			-76
		],
		[
			-17,
			10
		]
	],
	[
		[
			30068,
			65494
		],
		[
			-3,
			-45
		],
		[
			-14,
			-41
		],
		[
			-6,
			42
		],
		[
			4,
			35
		],
		[
			-19,
			54
		],
		[
			-8,
			40
		],
		[
			5,
			-129
		],
		[
			-22,
			17
		],
		[
			12,
			-39
		],
		[
			1,
			-75
		],
		[
			-12,
			-11
		],
		[
			8,
			-53
		],
		[
			0,
			-72
		],
		[
			-10,
			-45
		],
		[
			-8,
			-73
		],
		[
			-12,
			6
		],
		[
			-27,
			-18
		],
		[
			-27,
			-34
		],
		[
			-38,
			-30
		],
		[
			-1,
			16
		]
	]
];
var bbox = [
	-179.14733999999999,
	-14.552548999999999,
	179.77847,
	71.352561
];
var objects = {
	nation: {
		geometries: [
			{
				arcs: [
					[
						[
							0
						]
					],
					[
						[
							164,
							4,
							328,
							413,
							236,
							261,
							147,
							276,
							350,
							369,
							403,
							330,
							215,
							196,
							380,
							317,
							381,
							259,
							169,
							314,
							346,
							222,
							341,
							405,
							332,
							185,
							333,
							190,
							414,
							192,
							418,
							243,
							343,
							205,
							338,
							207,
							277,
							201,
							278,
							300,
							355,
							302,
							357,
							212,
							394,
							168
						]
					],
					[
						[
							6
						]
					],
					[
						[
							7
						]
					],
					[
						[
							8
						]
					],
					[
						[
							9
						]
					],
					[
						[
							10
						]
					],
					[
						[
							11
						]
					],
					[
						[
							12
						]
					],
					[
						[
							13
						]
					],
					[
						[
							14
						]
					],
					[
						[
							15
						]
					],
					[
						[
							16
						]
					],
					[
						[
							17
						]
					],
					[
						[
							18
						]
					],
					[
						[
							19
						]
					],
					[
						[
							20
						]
					],
					[
						[
							21
						]
					],
					[
						[
							22
						]
					],
					[
						[
							23
						]
					],
					[
						[
							24
						]
					],
					[
						[
							25
						]
					],
					[
						[
							26
						]
					],
					[
						[
							27
						]
					],
					[
						[
							28
						]
					],
					[
						[
							29
						]
					],
					[
						[
							30
						]
					],
					[
						[
							31
						]
					],
					[
						[
							32
						]
					],
					[
						[
							33
						]
					],
					[
						[
							34
						]
					],
					[
						[
							35
						]
					],
					[
						[
							36
						]
					],
					[
						[
							37
						]
					],
					[
						[
							38
						]
					],
					[
						[
							39
						]
					],
					[
						[
							40
						]
					],
					[
						[
							41
						]
					],
					[
						[
							42
						]
					],
					[
						[
							43
						]
					],
					[
						[
							44
						]
					],
					[
						[
							45
						]
					],
					[
						[
							46
						]
					],
					[
						[
							47
						]
					],
					[
						[
							48
						]
					],
					[
						[
							49
						]
					],
					[
						[
							50
						]
					],
					[
						[
							51
						]
					],
					[
						[
							52
						]
					],
					[
						[
							53
						]
					],
					[
						[
							54
						]
					],
					[
						[
							55
						]
					],
					[
						[
							56
						]
					],
					[
						[
							57
						]
					],
					[
						[
							58
						]
					],
					[
						[
							59
						]
					],
					[
						[
							60
						]
					],
					[
						[
							61
						]
					],
					[
						[
							62
						]
					],
					[
						[
							63
						]
					],
					[
						[
							64
						]
					],
					[
						[
							65
						]
					],
					[
						[
							66
						]
					],
					[
						[
							67
						]
					],
					[
						[
							68
						]
					],
					[
						[
							69
						]
					],
					[
						[
							70
						]
					],
					[
						[
							71
						]
					],
					[
						[
							72
						]
					],
					[
						[
							73
						]
					],
					[
						[
							74
						]
					],
					[
						[
							75
						]
					],
					[
						[
							76
						]
					],
					[
						[
							77
						]
					],
					[
						[
							78
						]
					],
					[
						[
							79
						]
					],
					[
						[
							80
						]
					],
					[
						[
							81
						]
					],
					[
						[
							82
						]
					],
					[
						[
							83
						]
					],
					[
						[
							84
						]
					],
					[
						[
							85
						]
					],
					[
						[
							86
						]
					],
					[
						[
							87
						]
					],
					[
						[
							88
						]
					],
					[
						[
							89
						]
					],
					[
						[
							90
						]
					],
					[
						[
							91
						]
					],
					[
						[
							92
						]
					],
					[
						[
							93
						]
					],
					[
						[
							94
						]
					],
					[
						[
							95
						]
					],
					[
						[
							96
						]
					],
					[
						[
							97
						]
					],
					[
						[
							98
						]
					],
					[
						[
							99
						]
					],
					[
						[
							100
						]
					],
					[
						[
							101
						]
					],
					[
						[
							102
						]
					],
					[
						[
							103
						]
					],
					[
						[
							104
						]
					],
					[
						[
							105
						]
					],
					[
						[
							106
						]
					],
					[
						[
							107
						]
					],
					[
						[
							108
						]
					],
					[
						[
							109
						]
					],
					[
						[
							110
						]
					],
					[
						[
							111
						]
					],
					[
						[
							112
						]
					],
					[
						[
							113
						]
					],
					[
						[
							114
						]
					],
					[
						[
							115
						]
					],
					[
						[
							116
						]
					],
					[
						[
							117
						]
					],
					[
						[
							118
						]
					],
					[
						[
							119
						]
					],
					[
						[
							120
						]
					],
					[
						[
							121
						]
					],
					[
						[
							122
						]
					],
					[
						[
							123
						]
					],
					[
						[
							124
						]
					],
					[
						[
							125
						]
					],
					[
						[
							126
						]
					],
					[
						[
							127
						]
					],
					[
						[
							128
						]
					],
					[
						[
							129
						]
					],
					[
						[
							130
						]
					],
					[
						[
							131
						]
					],
					[
						[
							132
						]
					],
					[
						[
							133
						]
					],
					[
						[
							134
						]
					],
					[
						[
							135
						]
					],
					[
						[
							136
						]
					],
					[
						[
							137
						]
					],
					[
						[
							138
						]
					],
					[
						[
							139
						]
					],
					[
						[
							140
						]
					],
					[
						[
							141
						]
					],
					[
						[
							142
						]
					],
					[
						[
							154
						]
					],
					[
						[
							155
						]
					],
					[
						[
							156
						]
					],
					[
						[
							157
						]
					],
					[
						[
							158
						]
					],
					[
						[
							159
						]
					],
					[
						[
							160
						]
					],
					[
						[
							161
						]
					],
					[
						[
							162
						]
					],
					[
						[
							177
						]
					],
					[
						[
							178
						]
					],
					[
						[
							179
						]
					],
					[
						[
							180
						]
					],
					[
						[
							181
						]
					],
					[
						[
							182
						]
					],
					[
						[
							183
						]
					],
					[
						[
							186
						]
					],
					[
						[
							187
						]
					],
					[
						[
							209
						]
					],
					[
						[
							210
						]
					],
					[
						[
							265
						]
					],
					[
						[
							266
						]
					],
					[
						[
							267
						]
					],
					[
						[
							268
						]
					],
					[
						[
							269
						]
					],
					[
						[
							270
						]
					],
					[
						[
							271
						]
					],
					[
						[
							272
						]
					],
					[
						[
							282
						]
					],
					[
						[
							283
						]
					],
					[
						[
							284
						]
					],
					[
						[
							285
						]
					],
					[
						[
							286
						]
					],
					[
						[
							287
						]
					],
					[
						[
							288
						]
					],
					[
						[
							289
						]
					],
					[
						[
							297,
							356
						]
					],
					[
						[
							298
						]
					],
					[
						[
							299
						]
					],
					[
						[
							305
						]
					],
					[
						[
							306
						]
					],
					[
						[
							307
						]
					],
					[
						[
							308
						]
					],
					[
						[
							309
						]
					],
					[
						[
							310
						]
					],
					[
						[
							311
						]
					],
					[
						[
							312
						]
					],
					[
						[
							313
						]
					],
					[
						[
							316
						]
					],
					[
						[
							323
						]
					],
					[
						[
							324
						]
					],
					[
						[
							325
						]
					],
					[
						[
							326
						]
					],
					[
						[
							335
						]
					],
					[
						[
							336
						]
					],
					[
						[
							337
						]
					],
					[
						[
							339
						]
					],
					[
						[
							340
						]
					],
					[
						[
							344
						]
					],
					[
						[
							345
						]
					],
					[
						[
							354
						]
					],
					[
						[
							358
						]
					],
					[
						[
							359
						]
					],
					[
						[
							360
						]
					],
					[
						[
							361
						]
					],
					[
						[
							362
						]
					],
					[
						[
							363
						]
					],
					[
						[
							364
						]
					],
					[
						[
							365
						]
					],
					[
						[
							366
						]
					],
					[
						[
							367
						]
					],
					[
						[
							370
						]
					],
					[
						[
							371
						]
					],
					[
						[
							372
						]
					],
					[
						[
							373
						]
					],
					[
						[
							374
						]
					],
					[
						[
							375
						]
					],
					[
						[
							376
						]
					],
					[
						[
							377
						]
					],
					[
						[
							378
						]
					],
					[
						[
							379
						]
					],
					[
						[
							382
						]
					],
					[
						[
							383
						]
					],
					[
						[
							384
						]
					],
					[
						[
							385
						]
					],
					[
						[
							386
						]
					],
					[
						[
							387
						]
					],
					[
						[
							388
						]
					],
					[
						[
							389
						]
					],
					[
						[
							390
						]
					],
					[
						[
							391
						]
					],
					[
						[
							392
						]
					],
					[
						[
							393
						]
					],
					[
						[
							395
						]
					],
					[
						[
							396
						]
					],
					[
						[
							397
						]
					],
					[
						[
							398
						]
					],
					[
						[
							399
						]
					],
					[
						[
							400
						]
					],
					[
						[
							401
						]
					],
					[
						[
							402
						]
					],
					[
						[
							406
						]
					],
					[
						[
							407
						]
					],
					[
						[
							408
						]
					],
					[
						[
							409
						]
					],
					[
						[
							410
						]
					],
					[
						[
							411
						]
					],
					[
						[
							412
						]
					],
					[
						[
							415
						]
					],
					[
						[
							416
						]
					],
					[
						[
							417
						]
					]
				],
				type: "MultiPolygon"
			}
		],
		type: "GeometryCollection"
	},
	states: {
		geometries: [
			{
				arcs: [
					[
						[
							0
						]
					],
					[
						[
							1,
							2,
							3,
							4,
							5
						]
					]
				],
				id: "01",
				properties: {
					name: "Alabama"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							6
						]
					],
					[
						[
							7
						]
					],
					[
						[
							8
						]
					],
					[
						[
							9
						]
					],
					[
						[
							10
						]
					],
					[
						[
							11
						]
					],
					[
						[
							12
						]
					],
					[
						[
							13
						]
					],
					[
						[
							14
						]
					],
					[
						[
							15
						]
					],
					[
						[
							16
						]
					],
					[
						[
							17
						]
					],
					[
						[
							18
						]
					],
					[
						[
							19
						]
					],
					[
						[
							20
						]
					],
					[
						[
							21
						]
					],
					[
						[
							22
						]
					],
					[
						[
							23
						]
					],
					[
						[
							24
						]
					],
					[
						[
							25
						]
					],
					[
						[
							26
						]
					],
					[
						[
							27
						]
					],
					[
						[
							28
						]
					],
					[
						[
							29
						]
					],
					[
						[
							30
						]
					],
					[
						[
							31
						]
					],
					[
						[
							32
						]
					],
					[
						[
							33
						]
					],
					[
						[
							34
						]
					],
					[
						[
							35
						]
					],
					[
						[
							36
						]
					],
					[
						[
							37
						]
					],
					[
						[
							38
						]
					],
					[
						[
							39
						]
					],
					[
						[
							40
						]
					],
					[
						[
							41
						]
					],
					[
						[
							42
						]
					],
					[
						[
							43
						]
					],
					[
						[
							44
						]
					],
					[
						[
							45
						]
					],
					[
						[
							46
						]
					],
					[
						[
							47
						]
					],
					[
						[
							48
						]
					],
					[
						[
							49
						]
					],
					[
						[
							50
						]
					],
					[
						[
							51
						]
					],
					[
						[
							52
						]
					],
					[
						[
							53
						]
					],
					[
						[
							54
						]
					],
					[
						[
							55
						]
					],
					[
						[
							56
						]
					],
					[
						[
							57
						]
					],
					[
						[
							58
						]
					],
					[
						[
							59
						]
					],
					[
						[
							60
						]
					],
					[
						[
							61
						]
					],
					[
						[
							62
						]
					],
					[
						[
							63
						]
					],
					[
						[
							64
						]
					],
					[
						[
							65
						]
					],
					[
						[
							66
						]
					],
					[
						[
							67
						]
					],
					[
						[
							68
						]
					],
					[
						[
							69
						]
					],
					[
						[
							70
						]
					],
					[
						[
							71
						]
					],
					[
						[
							72
						]
					],
					[
						[
							73
						]
					],
					[
						[
							74
						]
					],
					[
						[
							75
						]
					],
					[
						[
							76
						]
					],
					[
						[
							77
						]
					],
					[
						[
							78
						]
					],
					[
						[
							79
						]
					],
					[
						[
							80
						]
					],
					[
						[
							81
						]
					],
					[
						[
							82
						]
					],
					[
						[
							83
						]
					],
					[
						[
							84
						]
					],
					[
						[
							85
						]
					],
					[
						[
							86
						]
					],
					[
						[
							87
						]
					],
					[
						[
							88
						]
					],
					[
						[
							89
						]
					],
					[
						[
							90
						]
					],
					[
						[
							91
						]
					],
					[
						[
							92
						]
					],
					[
						[
							93
						]
					],
					[
						[
							94
						]
					],
					[
						[
							95
						]
					],
					[
						[
							96
						]
					],
					[
						[
							97
						]
					],
					[
						[
							98
						]
					],
					[
						[
							99
						]
					],
					[
						[
							100
						]
					],
					[
						[
							101
						]
					],
					[
						[
							102
						]
					],
					[
						[
							103
						]
					],
					[
						[
							104
						]
					],
					[
						[
							105
						]
					],
					[
						[
							106
						]
					],
					[
						[
							107
						]
					],
					[
						[
							108
						]
					],
					[
						[
							109
						]
					],
					[
						[
							110
						]
					],
					[
						[
							111
						]
					],
					[
						[
							112
						]
					],
					[
						[
							113
						]
					],
					[
						[
							114
						]
					],
					[
						[
							115
						]
					],
					[
						[
							116
						]
					],
					[
						[
							117
						]
					],
					[
						[
							118
						]
					],
					[
						[
							119
						]
					],
					[
						[
							120
						]
					],
					[
						[
							121
						]
					],
					[
						[
							122
						]
					],
					[
						[
							123
						]
					],
					[
						[
							124
						]
					],
					[
						[
							125
						]
					],
					[
						[
							126
						]
					],
					[
						[
							127
						]
					],
					[
						[
							128
						]
					],
					[
						[
							129
						]
					],
					[
						[
							130
						]
					],
					[
						[
							131
						]
					],
					[
						[
							132
						]
					],
					[
						[
							133
						]
					],
					[
						[
							134
						]
					],
					[
						[
							135
						]
					],
					[
						[
							136
						]
					],
					[
						[
							137
						]
					],
					[
						[
							138
						]
					],
					[
						[
							139
						]
					],
					[
						[
							140
						]
					],
					[
						[
							141
						]
					],
					[
						[
							142
						]
					]
				],
				id: "02",
				properties: {
					name: "Alaska"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						143,
						144,
						145,
						146,
						147
					]
				],
				id: "04",
				properties: {
					name: "Arizona"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						148,
						149,
						150,
						151,
						152,
						153
					]
				],
				id: "08",
				properties: {
					name: "Colorado"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							154
						]
					],
					[
						[
							155
						]
					],
					[
						[
							156
						]
					],
					[
						[
							157
						]
					],
					[
						[
							158
						]
					],
					[
						[
							159
						]
					],
					[
						[
							160
						]
					],
					[
						[
							161
						]
					],
					[
						[
							162
						]
					],
					[
						[
							163,
							164,
							-4
						]
					]
				],
				id: "12",
				properties: {
					name: "Florida"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						165,
						166,
						167,
						168,
						-164,
						-3
					]
				],
				id: "13",
				properties: {
					name: "Georgia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						169,
						170,
						171,
						172,
						173
					]
				],
				id: "18",
				properties: {
					name: "Indiana"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						174,
						175,
						176,
						-151
					]
				],
				id: "20",
				properties: {
					name: "Kansas"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							177
						]
					],
					[
						[
							178
						]
					],
					[
						[
							179
						]
					],
					[
						[
							180
						]
					],
					[
						[
							181
						]
					],
					[
						[
							182
						]
					],
					[
						[
							183
						]
					],
					[
						[
							184,
							185
						]
					]
				],
				id: "23",
				properties: {
					name: "Maine"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							186
						]
					],
					[
						[
							187
						]
					],
					[
						[
							188,
							189,
							190,
							191,
							192,
							193,
							194,
							195
						]
					]
				],
				id: "25",
				properties: {
					name: "Massachusetts"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						196,
						197,
						198,
						199,
						200
					]
				],
				id: "27",
				properties: {
					name: "Minnesota"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						201,
						202,
						203,
						204,
						205,
						206,
						207,
						208
					]
				],
				id: "34",
				properties: {
					name: "New Jersey"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							209
						]
					],
					[
						[
							210
						]
					],
					[
						[
							211,
							212,
							213,
							-167,
							214
						]
					]
				],
				id: "37",
				properties: {
					name: "North Carolina"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						215,
						-201,
						216,
						217
					]
				],
				id: "38",
				properties: {
					name: "North Dakota"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-152,
						-177,
						218,
						219,
						220,
						221
					]
				],
				id: "40",
				properties: {
					name: "Oklahoma"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						222,
						223,
						-204,
						224,
						225,
						226,
						227
					]
				],
				id: "42",
				properties: {
					name: "Pennsylvania"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						228,
						-217,
						-200,
						229,
						230,
						231
					]
				],
				id: "46",
				properties: {
					name: "South Dakota"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-221,
						232,
						233,
						234,
						235,
						236,
						237
					]
				],
				id: "48",
				properties: {
					name: "Texas"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-232,
						238,
						-149,
						239,
						240,
						241
					]
				],
				id: "56",
				properties: {
					name: "Wyoming"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-195,
						242,
						243,
						244
					]
				],
				id: "09",
				properties: {
					name: "Connecticut"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						245,
						246,
						247,
						248,
						249,
						250,
						251,
						-219,
						-176,
						252
					]
				],
				id: "29",
				properties: {
					name: "Missouri"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						253,
						-227,
						254,
						255,
						256
					]
				],
				id: "54",
				properties: {
					name: "West Virginia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						257,
						258,
						259,
						-174,
						260,
						-247
					]
				],
				id: "17",
				properties: {
					name: "Illinois"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-153,
						-222,
						-238,
						261,
						-147
					]
				],
				id: "35",
				properties: {
					name: "New Mexico"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-252,
						262,
						263,
						264,
						-235,
						233,
						-233,
						-220
					]
				],
				id: "05",
				properties: {
					name: "Arkansas"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							265
						]
					],
					[
						[
							266
						]
					],
					[
						[
							267
						]
					],
					[
						[
							268
						]
					],
					[
						[
							269
						]
					],
					[
						[
							270
						]
					],
					[
						[
							271
						]
					],
					[
						[
							272
						]
					],
					[
						[
							273,
							274,
							275,
							-144,
							276
						]
					]
				],
				id: "06",
				properties: {
					name: "California"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-209,
							277
						]
					],
					[
						[
							-225,
							-203,
							278,
							279
						]
					]
				],
				id: "10",
				properties: {
					name: "Delaware"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						280,
						281
					]
				],
				id: "11",
				properties: {
					name: "District of Columbia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							282
						]
					],
					[
						[
							283
						]
					],
					[
						[
							284
						]
					],
					[
						[
							285
						]
					],
					[
						[
							286
						]
					],
					[
						[
							287
						]
					],
					[
						[
							288
						]
					],
					[
						[
							289
						]
					]
				],
				id: "15",
				properties: {
					name: "Hawaii"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-199,
						290,
						-258,
						-246,
						291,
						-230
					]
				],
				id: "19",
				properties: {
					name: "Iowa"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							-261,
							-173,
							292,
							-257,
							293,
							294,
							-248
						]
					],
					[
						[
							295,
							-250
						]
					]
				],
				id: "21",
				properties: {
					name: "Kentucky"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							296,
							297
						]
					],
					[
						[
							298
						]
					],
					[
						[
							299
						]
					],
					[
						[
							-226,
							-280,
							300,
							301,
							302,
							303,
							-281,
							304,
							-255
						]
					]
				],
				id: "24",
				properties: {
					name: "Maryland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							305
						]
					],
					[
						[
							306
						]
					],
					[
						[
							307
						]
					],
					[
						[
							308
						]
					],
					[
						[
							309
						]
					],
					[
						[
							310
						]
					],
					[
						[
							311
						]
					],
					[
						[
							312
						]
					],
					[
						[
							313
						]
					],
					[
						[
							314,
							315,
							-171
						]
					],
					[
						[
							316
						]
					],
					[
						[
							317,
							318,
							319,
							320,
							321,
							322
						]
					]
				],
				id: "26",
				properties: {
					name: "Michigan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							323
						]
					],
					[
						[
							324
						]
					],
					[
						[
							325
						]
					],
					[
						[
							326
						]
					],
					[
						[
							-264,
							327,
							-6,
							328,
							329
						]
					]
				],
				id: "28",
				properties: {
					name: "Mississippi"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						330,
						-218,
						-229,
						-242,
						331
					]
				],
				id: "30",
				properties: {
					name: "Montana"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						332,
						-185,
						333,
						-190,
						334
					]
				],
				id: "33",
				properties: {
					name: "New Hampshire"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							335
						]
					],
					[
						[
							336
						]
					],
					[
						[
							337
						]
					],
					[
						[
							338,
							-207
						]
					],
					[
						[
							339
						]
					],
					[
						[
							340
						]
					],
					[
						[
							341,
							342,
							-196,
							-245,
							343,
							-205,
							-224
						]
					]
				],
				id: "36",
				properties: {
					name: "New York"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							344
						]
					],
					[
						[
							345
						]
					],
					[
						[
							-316,
							346,
							-228,
							-254,
							-293,
							-172
						]
					]
				],
				id: "39",
				properties: {
					name: "Ohio"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						347,
						348,
						349,
						274,
						-275,
						-274,
						350
					]
				],
				id: "41",
				properties: {
					name: "Oregon"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-251,
						-296,
						-249,
						-295,
						351,
						-215,
						-166,
						-2,
						-328,
						-263
					]
				],
				id: "47",
				properties: {
					name: "Tennessee"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						352,
						-240,
						-154,
						-146,
						353
					]
				],
				id: "49",
				properties: {
					name: "Utah"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							354
						]
					],
					[
						[
							-302,
							355
						]
					],
					[
						[
							356,
							-297
						]
					],
					[
						[
							-256,
							-305,
							-282,
							-304,
							357,
							-212,
							-352,
							-294
						]
					]
				],
				id: "51",
				properties: {
					name: "Virginia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							358
						]
					],
					[
						[
							359
						]
					],
					[
						[
							360
						]
					],
					[
						[
							361
						]
					],
					[
						[
							362
						]
					],
					[
						[
							363
						]
					],
					[
						[
							364
						]
					],
					[
						[
							365
						]
					],
					[
						[
							366
						]
					],
					[
						[
							367
						]
					],
					[
						[
							368,
							-348,
							369
						]
					]
				],
				id: "53",
				properties: {
					name: "Washington"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							370
						]
					],
					[
						[
							371
						]
					],
					[
						[
							372
						]
					],
					[
						[
							373
						]
					],
					[
						[
							374
						]
					],
					[
						[
							375
						]
					],
					[
						[
							376
						]
					],
					[
						[
							377
						]
					],
					[
						[
							378
						]
					],
					[
						[
							379
						]
					],
					[
						[
							380,
							-323,
							321,
							-321,
							319,
							-319,
							381,
							-259,
							-291,
							-198
						]
					]
				],
				id: "55",
				properties: {
					name: "Wisconsin"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							382
						]
					],
					[
						[
							383
						]
					],
					[
						[
							384
						]
					]
				],
				id: "60",
				properties: {
					name: "American Samoa"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							385
						]
					]
				],
				id: "66",
				properties: {
					name: "Guam"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							386
						]
					],
					[
						[
							387
						]
					],
					[
						[
							388
						]
					],
					[
						[
							389
						]
					],
					[
						[
							390
						]
					],
					[
						[
							391
						]
					],
					[
						[
							392
						]
					],
					[
						[
							393
						]
					]
				],
				id: "69",
				properties: {
					name: "Commonwealth of the Northern Mariana Islands"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-231,
						-292,
						-253,
						-175,
						-150,
						-239
					]
				],
				id: "31",
				properties: {
					name: "Nebraska"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-214,
						394,
						-168
					]
				],
				id: "45",
				properties: {
					name: "South Carolina"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							395
						]
					],
					[
						[
							396
						]
					],
					[
						[
							397
						]
					],
					[
						[
							398
						]
					],
					[
						[
							399
						]
					]
				],
				id: "72",
				properties: {
					name: "Puerto Rico"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							400
						]
					],
					[
						[
							401
						]
					],
					[
						[
							402
						]
					]
				],
				id: "78",
				properties: {
					name: "United States Virgin Islands"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-369,
						403,
						-332,
						-241,
						-353,
						404,
						-349
					]
				],
				id: "16",
				properties: {
					name: "Idaho"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-275,
						-350,
						-405,
						-354,
						-145,
						-276
					]
				],
				id: "32",
				properties: {
					name: "Nevada"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						405,
						-335,
						-189,
						-343
					]
				],
				id: "50",
				properties: {
					name: "Vermont"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							406
						]
					],
					[
						[
							407
						]
					],
					[
						[
							408
						]
					],
					[
						[
							409
						]
					],
					[
						[
							410
						]
					],
					[
						[
							411
						]
					],
					[
						[
							412
						]
					],
					[
						[
							-265,
							-330,
							413,
							-236
						]
					]
				],
				id: "22",
				properties: {
					name: "Louisiana"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-192,
							414
						]
					],
					[
						[
							415
						]
					],
					[
						[
							416
						]
					],
					[
						[
							417
						]
					],
					[
						[
							-243,
							-194,
							418
						]
					]
				],
				id: "44",
				properties: {
					name: "Rhode Island"
				},
				type: "MultiPolygon"
			}
		],
		type: "GeometryCollection"
	}
};
var transform = {
	scale: [
		0.003589293992939929,
		0.0008590596905969058
	],
	translate: [
		-179.14733999999999,
		-14.552548999999999
	]
};
var type = "Topology";
var topology = {
	arcs: arcs,
	bbox: bbox,
	objects: objects,
	transform: transform,
	type: type
};

var abbeville_la = {
	name: "Abbeville, LA",
	value: {
		lat: 29.9746502,
		lng: -92.13429210000001
	}
};
var aberdeen_sd = {
	name: "Aberdeen, SD",
	value: {
		lat: 45.4646985,
		lng: -98.4864829
	}
};
var aberdeen_wa = {
	name: "Aberdeen, WA",
	value: {
		lat: 46.9753708,
		lng: -123.8157218
	}
};
var abilene_tx = {
	name: "Abilene, TX",
	value: {
		lat: 32.4487364,
		lng: -99.73314390000002
	}
};
var ada_ok = {
	name: "Ada, OK",
	value: {
		lat: 34.774531,
		lng: -96.6783449
	}
};
var adrian_mi = {
	name: "Adrian, MI",
	value: {
		lat: 41.8975471,
		lng: -84.03716589999999
	}
};
var aguadilla_isabela_san_sebastian_pr = {
	name: "Aguadilla-Isabela-San Sebastian, PR",
	value: {
		lat: 18.4274454,
		lng: -67.1540698
	}
};
var akron_oh = {
	name: "Akron, OH",
	value: {
		lat: 41.0814447,
		lng: -81.51900529999999
	}
};
var alamogordo_nm = {
	name: "Alamogordo, NM",
	value: {
		lat: 32.8995325,
		lng: -105.960265
	}
};
var albany_ga = {
	name: "Albany, GA",
	value: {
		lat: 31.5785074,
		lng: -84.15574099999999
	}
};
var albany_lebanon_or = {
	name: "Albany-Lebanon, OR",
	value: {
		lat: 44.6365107,
		lng: -123.1059282
	}
};
var albany_schenectady_troy_ny = {
	name: "Albany-Schenectady-Troy, NY",
	value: {
		lat: 42.6525793,
		lng: -73.7562317
	}
};
var albemarle_nc = {
	name: "Albemarle, NC",
	value: {
		lat: 35.3501426,
		lng: -80.2000578
	}
};
var albert_lea_mn = {
	name: "Albert Lea, MN",
	value: {
		lat: 43.6478006,
		lng: -93.3686555
	}
};
var albertville_al = {
	name: "Albertville, AL",
	value: {
		lat: 34.2675937,
		lng: -86.20886689999999
	}
};
var albuquerque_nm = {
	name: "Albuquerque, NM",
	value: {
		lat: 35.0853336,
		lng: -106.6055534
	}
};
var alexander_city_al = {
	name: "Alexander City, AL",
	value: {
		lat: 32.944012,
		lng: -85.9538532
	}
};
var alexandria_la = {
	name: "Alexandria, LA",
	value: {
		lat: 31.3112936,
		lng: -92.4451371
	}
};
var alexandria_mn = {
	name: "Alexandria, MN",
	value: {
		lat: 45.8848164,
		lng: -95.3776663
	}
};
var alice_tx = {
	name: "Alice, TX",
	value: {
		lat: 27.7522487,
		lng: -98.0697249
	}
};
var allegan_mi = {
	name: "Allegan, MI",
	value: {
		lat: 42.5291989,
		lng: -85.8553031
	}
};
var allentown_bethlehem_easton_pa_nj = {
	name: "Allentown-Bethlehem-Easton, PA-NJ",
	value: {
		lat: 40.6084305,
		lng: -75.4901833
	}
};
var alma_mi = {
	name: "Alma, MI",
	value: {
		lat: 43.3789199,
		lng: -84.6597274
	}
};
var alpena_mi = {
	name: "Alpena, MI",
	value: {
		lat: 45.0616794,
		lng: -83.4327528
	}
};
var altoona_pa = {
	name: "Altoona, PA",
	value: {
		lat: 40.5186809,
		lng: -78.3947359
	}
};
var altus_ok = {
	name: "Altus, OK",
	value: {
		lat: 34.637765,
		lng: -99.3340442
	}
};
var amarillo_tx = {
	name: "Amarillo, TX",
	value: {
		lat: 35.2219971,
		lng: -101.8312969
	}
};
var americus_ga = {
	name: "Americus, GA",
	value: {
		lat: 32.0723861,
		lng: -84.23268759999999
	}
};
var ames_ia = {
	name: "Ames, IA",
	value: {
		lat: 42.0307812,
		lng: -93.63191309999999
	}
};
var amsterdam_ny = {
	name: "Amsterdam, NY",
	value: {
		lat: 42.9377453,
		lng: -74.190356
	}
};
var anchorage_ak = {
	name: "Anchorage, AK",
	value: {
		lat: 61.2180556,
		lng: -149.9002778
	}
};
var anderson_in = {
	name: "Anderson, IN",
	value: {
		lat: 40.1053196,
		lng: -85.6802541
	}
};
var anderson_sc = {
	name: "Anderson, SC",
	value: {
		lat: 34.5034394,
		lng: -82.6501332
	}
};
var andrews_tx = {
	name: "Andrews, TX",
	value: {
		lat: 32.31871580000001,
		lng: -102.5457155
	}
};
var angola_in = {
	name: "Angola, IN",
	value: {
		lat: 41.6347726,
		lng: -84.9994088
	}
};
var ann_arbor_mi = {
	name: "Ann Arbor, MI",
	value: {
		lat: 42.2808256,
		lng: -83.7430378
	}
};
var anniston_oxford_al = {
	name: "Anniston-Oxford, AL",
	value: {
		lat: 33.6598257,
		lng: -85.8316318
	}
};
var appleton_wi = {
	name: "Appleton, WI",
	value: {
		lat: 44.2619309,
		lng: -88.41538469999999
	}
};
var arcadia_fl = {
	name: "Arcadia, FL",
	value: {
		lat: 27.2158826,
		lng: -81.8584164
	}
};
var ardmore_ok = {
	name: "Ardmore, OK",
	value: {
		lat: 34.1742611,
		lng: -97.14362539999999
	}
};
var arkadelphia_ar = {
	name: "Arkadelphia, AR",
	value: {
		lat: 34.1209292,
		lng: -93.0537839
	}
};
var asheville_nc = {
	name: "Asheville, NC",
	value: {
		lat: 35.5950581,
		lng: -82.5514869
	}
};
var ashland_oh = {
	name: "Ashland, OH",
	value: {
		lat: 40.8686675,
		lng: -82.3182178
	}
};
var ashtabula_oh = {
	name: "Ashtabula, OH",
	value: {
		lat: 41.8650534,
		lng: -80.7898089
	}
};
var astoria_or = {
	name: "Astoria, OR",
	value: {
		lat: 46.1878841,
		lng: -123.8312534
	}
};
var atchison_ks = {
	name: "Atchison, KS",
	value: {
		lat: 39.5630521,
		lng: -95.12163559999999
	}
};
var athens_oh = {
	name: "Athens, OH",
	value: {
		lat: 39.3292396,
		lng: -82.1012554
	}
};
var athens_tn = {
	name: "Athens, TN",
	value: {
		lat: 35.4428512,
		lng: -84.5929898
	}
};
var athens_tx = {
	name: "Athens, TX",
	value: {
		lat: 32.2048735,
		lng: -95.8555207
	}
};
var athens_clarke_county_ga = {
	name: "Athens-Clarke County, GA",
	value: {
		lat: 33.9519347,
		lng: -83.357567
	}
};
var atlanta_sandy_springs_marietta_ga = {
	name: "Atlanta-Sandy Springs-Marietta, GA",
	value: {
		lat: 33.7489954,
		lng: -84.3879824
	}
};
var atlantic_city_nj = {
	name: "Atlantic City, NJ",
	value: {
		lat: 39.3642834,
		lng: -74.4229266
	}
};
var auburn_in = {
	name: "Auburn, IN",
	value: {
		lat: 41.3669942,
		lng: -85.0588575
	}
};
var auburn_ny = {
	name: "Auburn, NY",
	value: {
		lat: 42.9317335,
		lng: -76.5660529
	}
};
var auburn_opelika_al = {
	name: "Auburn-Opelika, AL",
	value: {
		lat: 32.6098566,
		lng: -85.48078249999999
	}
};
var augusta_richmond_county_ga_sc = {
	name: "Augusta-Richmond County, GA-SC",
	value: {
		lat: 33.4734978,
		lng: -82.0105148
	}
};
var augusta_waterville_me = {
	name: "Augusta-Waterville, ME",
	value: {
		lat: 44.3106241,
		lng: -69.7794897
	}
};
var austin_mn = {
	name: "Austin, MN",
	value: {
		lat: 43.6666296,
		lng: -92.97463669999999
	}
};
var austin_round_rock_tx = {
	name: "Austin-Round Rock, TX",
	value: {
		lat: 30.267153,
		lng: -97.7430608
	}
};
var bainbridge_ga = {
	name: "Bainbridge, GA",
	value: {
		lat: 30.9037995,
		lng: -84.57546990000002
	}
};
var bakersfield_ca = {
	name: "Bakersfield, CA",
	value: {
		lat: 35.3732921,
		lng: -119.0187125
	}
};
var baltimore_towson_md = {
	name: "Baltimore-Towson, MD",
	value: {
		lat: 39.2903848,
		lng: -76.6121893
	}
};
var bangor_me = {
	name: "Bangor, ME",
	value: {
		lat: 44.80118210000001,
		lng: -68.77781379999999
	}
};
var baraboo_wi = {
	name: "Baraboo, WI",
	value: {
		lat: 43.4710944,
		lng: -89.74429060000001
	}
};
var barnstable_town_ma = {
	name: "Barnstable Town, MA",
	value: {
		lat: 41.7003208,
		lng: -70.3002024
	}
};
var barre_vt = {
	name: "Barre, VT",
	value: {
		lat: 44.1767937,
		lng: -72.4687538
	}
};
var bartlesville_ok = {
	name: "Bartlesville, OK",
	value: {
		lat: 36.7473114,
		lng: -95.98081789999999
	}
};
var bastrop_la = {
	name: "Bastrop, LA",
	value: {
		lat: 32.7562463,
		lng: -91.8723497
	}
};
var batavia_ny = {
	name: "Batavia, NY",
	value: {
		lat: 42.9981156,
		lng: -78.1875167
	}
};
var batesville_ar = {
	name: "Batesville, AR",
	value: {
		lat: 35.769799,
		lng: -91.6409721
	}
};
var baton_rouge_la = {
	name: "Baton Rouge, LA",
	value: {
		lat: 30.4582829,
		lng: -91.1403196
	}
};
var battle_creek_mi = {
	name: "Battle Creek, MI",
	value: {
		lat: 42.3211522,
		lng: -85.17971419999999
	}
};
var bay_city_mi = {
	name: "Bay City, MI",
	value: {
		lat: 43.5944677,
		lng: -83.8888647
	}
};
var bay_city_tx = {
	name: "Bay City, TX",
	value: {
		lat: 28.9827565,
		lng: -95.969402
	}
};
var beatrice_ne = {
	name: "Beatrice, NE",
	value: {
		lat: 40.2659269,
		lng: -96.7466913
	}
};
var beaumont_port_arthur_tx = {
	name: "Beaumont-Port Arthur, TX",
	value: {
		lat: 30.080174,
		lng: -94.1265562
	}
};
var beaver_dam_wi = {
	name: "Beaver Dam, WI",
	value: {
		lat: 43.4577692,
		lng: -88.837329
	}
};
var beckley_wv = {
	name: "Beckley, WV",
	value: {
		lat: 37.7781702,
		lng: -81.1881557
	}
};
var bedford_in = {
	name: "Bedford, IN",
	value: {
		lat: 38.8611619,
		lng: -86.4872149
	}
};
var beeville_tx = {
	name: "Beeville, TX",
	value: {
		lat: 28.4008319,
		lng: -97.7483312
	}
};
var bellefontaine_oh = {
	name: "Bellefontaine, OH",
	value: {
		lat: 40.3611643,
		lng: -83.7596557
	}
};
var bellingham_wa = {
	name: "Bellingham, WA",
	value: {
		lat: 48.74908,
		lng: -122.4781473
	}
};
var bemidji_mn = {
	name: "Bemidji, MN",
	value: {
		lat: 47.4875361,
		lng: -94.8858492
	}
};
var bend_or = {
	name: "Bend, OR",
	value: {
		lat: 44.0581728,
		lng: -121.3153096
	}
};
var bennettsville_sc = {
	name: "Bennettsville, SC",
	value: {
		lat: 34.6173803,
		lng: -79.68478139999999
	}
};
var bennington_vt = {
	name: "Bennington, VT",
	value: {
		lat: 42.8781345,
		lng: -73.1967741
	}
};
var berlin_nh_vt = {
	name: "Berlin, NH-VT",
	value: {
		lat: 44.4686696,
		lng: -71.18507679999999
	}
};
var big_rapids_mi = {
	name: "Big Rapids, MI",
	value: {
		lat: 43.6980782,
		lng: -85.4836557
	}
};
var big_spring_tx = {
	name: "Big Spring, TX",
	value: {
		lat: 32.2503979,
		lng: -101.4787355
	}
};
var billings_mt = {
	name: "Billings, MT",
	value: {
		lat: 45.7832856,
		lng: -108.5006904
	}
};
var binghamton_ny = {
	name: "Binghamton, NY",
	value: {
		lat: 42.09868669999999,
		lng: -75.91797380000001
	}
};
var birmingham_hoover_al = {
	name: "Birmingham-Hoover, AL",
	value: {
		lat: 33.5206608,
		lng: -86.80248999999999
	}
};
var bishop_ca = {
	name: "Bishop, CA",
	value: {
		lat: 37.3614238,
		lng: -118.3996636
	}
};
var bismarck_nd = {
	name: "Bismarck, ND",
	value: {
		lat: 46.8083268,
		lng: -100.7837392
	}
};
var blackfoot_id = {
	name: "Blackfoot, ID",
	value: {
		lat: 43.19047090000001,
		lng: -112.3449773
	}
};
var blacksburg_christiansburg_radford_va = {
	name: "Blacksburg-Christiansburg-Radford, VA",
	value: {
		lat: 37.2295733,
		lng: -80.4139393
	}
};
var bloomington_in = {
	name: "Bloomington, IN",
	value: {
		lat: 39.165325,
		lng: -86.52638569999999
	}
};
var bloomington_normal_il = {
	name: "Bloomington-Normal, IL",
	value: {
		lat: 40.4842027,
		lng: -88.99368729999999
	}
};
var bloomsburg_berwick_pa = {
	name: "Bloomsburg-Berwick, PA",
	value: {
		lat: 41.003698,
		lng: -76.4549457
	}
};
var bluefield_wv_va = {
	name: "Bluefield, WV-VA",
	value: {
		lat: 37.2698395,
		lng: -81.2223195
	}
};
var blytheville_ar = {
	name: "Blytheville, AR",
	value: {
		lat: 35.9272953,
		lng: -89.9189753
	}
};
var bogalusa_la = {
	name: "Bogalusa, LA",
	value: {
		lat: 30.7910204,
		lng: -89.8486858
	}
};
var boise_city_nampa_id = {
	name: "Boise City-Nampa, ID",
	value: {
		lat: 43.6187102,
		lng: -116.2146068
	}
};
var bonham_tx = {
	name: "Bonham, TX",
	value: {
		lat: 33.5773275,
		lng: -96.1783111
	}
};
var boone_ia = {
	name: "Boone, IA",
	value: {
		lat: 42.0597047,
		lng: -93.8802273
	}
};
var boone_nc = {
	name: "Boone, NC",
	value: {
		lat: 36.216795,
		lng: -81.6745517
	}
};
var borger_tx = {
	name: "Borger, TX",
	value: {
		lat: 35.6678203,
		lng: -101.3973876
	}
};
var boston_cambridge_quincy_ma_nh = {
	name: "Boston-Cambridge-Quincy, MA-NH",
	value: {
		lat: 42.3600825,
		lng: -71.0588801
	}
};
var boulder_co = {
	name: "Boulder, CO",
	value: {
		lat: 40.0149856,
		lng: -105.2705456
	}
};
var bowling_green_ky = {
	name: "Bowling Green, KY",
	value: {
		lat: 36.9685219,
		lng: -86.4808043
	}
};
var bozeman_mt = {
	name: "Bozeman, MT",
	value: {
		lat: 45.6769979,
		lng: -111.0429339
	}
};
var bradford_pa = {
	name: "Bradford, PA",
	value: {
		lat: 41.9564953,
		lng: -78.649163
	}
};
var brainerd_mn = {
	name: "Brainerd, MN",
	value: {
		lat: 46.3526733,
		lng: -94.2020084
	}
};
var branson_mo = {
	name: "Branson, MO",
	value: {
		lat: 36.6436731,
		lng: -93.21851439999999
	}
};
var bremerton_silverdale_wa = {
	name: "Bremerton-Silverdale, WA",
	value: {
		lat: 47.5673202,
		lng: -122.6329356
	}
};
var brenham_tx = {
	name: "Brenham, TX",
	value: {
		lat: 30.1668828,
		lng: -96.39774419999999
	}
};
var brevard_nc = {
	name: "Brevard, NC",
	value: {
		lat: 35.2334472,
		lng: -82.7342919
	}
};
var bridgeport_stamford_norwalk_ct = {
	name: "Bridgeport-Stamford-Norwalk, CT",
	value: {
		lat: 41.1865478,
		lng: -73.19517669999999
	}
};
var brigham_city_ut = {
	name: "Brigham City, UT",
	value: {
		lat: 41.5102129,
		lng: -112.0155015
	}
};
var brookhaven_ms = {
	name: "Brookhaven, MS",
	value: {
		lat: 31.5790588,
		lng: -90.4406506
	}
};
var brookings_or = {
	name: "Brookings, OR",
	value: {
		lat: 42.0526114,
		lng: -124.2839819
	}
};
var brookings_sd = {
	name: "Brookings, SD",
	value: {
		lat: 44.3113573,
		lng: -96.79838769999999
	}
};
var brownsville_tn = {
	name: "Brownsville, TN",
	value: {
		lat: 35.5939671,
		lng: -89.26229099999999
	}
};
var brownsville_harlingen_tx = {
	name: "Brownsville-Harlingen, TX",
	value: {
		lat: 25.9017472,
		lng: -97.4974838
	}
};
var brownwood_tx = {
	name: "Brownwood, TX",
	value: {
		lat: 31.7093197,
		lng: -98.9911611
	}
};
var brunswick_ga = {
	name: "Brunswick, GA",
	value: {
		lat: 31.1499528,
		lng: -81.49148939999999
	}
};
var bucyrus_oh = {
	name: "Bucyrus, OH",
	value: {
		lat: 40.8083909,
		lng: -82.97546489999999
	}
};
var buffalo_niagara_falls_ny = {
	name: "Buffalo-Niagara Falls, NY",
	value: {
		lat: 42.88644679999999,
		lng: -78.8783689
	}
};
var burley_id = {
	name: "Burley, ID",
	value: {
		lat: 42.5357428,
		lng: -113.7927948
	}
};
var burlington_ia_il = {
	name: "Burlington, IA-IL",
	value: {
		lat: 40.8076529,
		lng: -91.1128901
	}
};
var burlington_nc = {
	name: "Burlington, NC",
	value: {
		lat: 36.0956918,
		lng: -79.43779909999999
	}
};
var burlington_south_burlington_vt = {
	name: "Burlington-South Burlington, VT",
	value: {
		lat: 44.4758825,
		lng: -73.21207199999999
	}
};
var butte_silver_bow_mt = {
	name: "Butte-Silver Bow, MT",
	value: {
		lat: 46.0038232,
		lng: -112.5347776
	}
};
var cadillac_mi = {
	name: "Cadillac, MI",
	value: {
		lat: 44.2519526,
		lng: -85.40116189999999
	}
};
var calhoun_ga = {
	name: "Calhoun, GA",
	value: {
		lat: 34.502587,
		lng: -84.9510542
	}
};
var cambridge_md = {
	name: "Cambridge, MD",
	value: {
		lat: 38.5631744,
		lng: -76.0788292
	}
};
var cambridge_oh = {
	name: "Cambridge, OH",
	value: {
		lat: 40.031183,
		lng: -81.5884561
	}
};
var camden_ar = {
	name: "Camden, AR",
	value: {
		lat: 33.5845581,
		lng: -92.8343294
	}
};
var campbellsville_ky = {
	name: "Campbellsville, KY",
	value: {
		lat: 37.3433974,
		lng: -85.3419069
	}
};
var canon_city_co = {
	name: "Canon City, CO",
	value: {
		lat: 38.4494063,
		lng: -105.2253316
	}
};
var canton_il = {
	name: "Canton, IL",
	value: {
		lat: 40.5580945,
		lng: -90.03511669999999
	}
};
var canton_massillon_oh = {
	name: "Canton-Massillon, OH",
	value: {
		lat: 40.79894729999999,
		lng: -81.378447
	}
};
var cape_coral_fort_myers_fl = {
	name: "Cape Coral-Fort Myers, FL",
	value: {
		lat: 26.5628537,
		lng: -81.9495331
	}
};
var cape_girardeau_jackson_mo_il = {
	name: "Cape Girardeau-Jackson, MO-IL",
	value: {
		lat: 37.3058839,
		lng: -89.51814759999999
	}
};
var carbondale_il = {
	name: "Carbondale, IL",
	value: {
		lat: 37.7272727,
		lng: -89.2167501
	}
};
var carlsbad_artesia_nm = {
	name: "Carlsbad-Artesia, NM",
	value: {
		lat: 32.4206736,
		lng: -104.2288375
	}
};
var carson_city_nv = {
	name: "Carson City, NV",
	value: {
		lat: 39.1637984,
		lng: -119.7674034
	}
};
var casper_wy = {
	name: "Casper, WY",
	value: {
		lat: 42.866632,
		lng: -106.313081
	}
};
var cedar_city_ut = {
	name: "Cedar City, UT",
	value: {
		lat: 37.67747689999999,
		lng: -113.0618931
	}
};
var cedar_rapids_ia = {
	name: "Cedar Rapids, IA",
	value: {
		lat: 41.9778795,
		lng: -91.6656232
	}
};
var cedartown_ga = {
	name: "Cedartown, GA",
	value: {
		lat: 34.0112715,
		lng: -85.25658229999999
	}
};
var celina_oh = {
	name: "Celina, OH",
	value: {
		lat: 40.5489358,
		lng: -84.5702338
	}
};
var central_city_ky = {
	name: "Central City, KY",
	value: {
		lat: 37.2939322,
		lng: -87.1233292
	}
};
var centralia_il = {
	name: "Centralia, IL",
	value: {
		lat: 38.5285169,
		lng: -89.1316944
	}
};
var centralia_wa = {
	name: "Centralia, WA",
	value: {
		lat: 46.7162136,
		lng: -122.9542972
	}
};
var chambersburg_pa = {
	name: "Chambersburg, PA",
	value: {
		lat: 39.9375911,
		lng: -77.6611022
	}
};
var champaign_urbana_il = {
	name: "Champaign-Urbana, IL",
	value: {
		lat: 40.1164204,
		lng: -88.2433829
	}
};
var charleston_wv = {
	name: "Charleston, WV",
	value: {
		lat: 38.3498195,
		lng: -81.6326234
	}
};
var charleston_mattoon_il = {
	name: "Charleston-Mattoon, IL",
	value: {
		lat: 39.4961458,
		lng: -88.1761521
	}
};
var charleston_north_charleston_sc = {
	name: "Charleston-North Charleston, SC",
	value: {
		lat: 32.7764749,
		lng: -79.93105120000001
	}
};
var charlotte_gastonia_concord_nc_sc = {
	name: "Charlotte-Gastonia-Concord, NC-SC",
	value: {
		lat: 35.2270869,
		lng: -80.8431267
	}
};
var charlottesville_va = {
	name: "Charlottesville, VA",
	value: {
		lat: 38.0293059,
		lng: -78.47667810000002
	}
};
var chattanooga_tn_ga = {
	name: "Chattanooga, TN-GA",
	value: {
		lat: 35.0456297,
		lng: -85.3096801
	}
};
var chester_sc = {
	name: "Chester, SC",
	value: {
		lat: 34.7048613,
		lng: -81.2142561
	}
};
var cheyenne_wy = {
	name: "Cheyenne, WY",
	value: {
		lat: 41.1399814,
		lng: -104.8202462
	}
};
var chicago_naperville_joliet_il_in_wi = {
	name: "Chicago-Naperville-Joliet, IL-IN-WI",
	value: {
		lat: 41.8781136,
		lng: -87.6297982
	}
};
var chico_ca = {
	name: "Chico, CA",
	value: {
		lat: 39.7284944,
		lng: -121.8374777
	}
};
var chillicothe_oh = {
	name: "Chillicothe, OH",
	value: {
		lat: 39.3331197,
		lng: -82.9824019
	}
};
var cincinnati_middletown_oh_ky_in = {
	name: "Cincinnati-Middletown, OH-KY-IN",
	value: {
		lat: 39.1031182,
		lng: -84.5120196
	}
};
var city_of_the_dalles_or = {
	name: "City of The Dalles, OR",
	value: {
		lat: 45.5945645,
		lng: -121.1786823
	}
};
var claremont_nh = {
	name: "Claremont, NH",
	value: {
		lat: 43.3728635,
		lng: -72.33787439999999
	}
};
var clarksburg_wv = {
	name: "Clarksburg, WV",
	value: {
		lat: 39.2806451,
		lng: -80.34453409999999
	}
};
var clarksdale_ms = {
	name: "Clarksdale, MS",
	value: {
		lat: 34.2001086,
		lng: -90.5709323
	}
};
var clarksville_tn_ky = {
	name: "Clarksville, TN-KY",
	value: {
		lat: 36.5297706,
		lng: -87.3594528
	}
};
var clearlake_ca = {
	name: "Clearlake, CA",
	value: {
		lat: 38.9582307,
		lng: -122.6263728
	}
};
var cleveland_ms = {
	name: "Cleveland, MS",
	value: {
		lat: 33.7440023,
		lng: -90.7248187
	}
};
var cleveland_tn = {
	name: "Cleveland, TN",
	value: {
		lat: 35.1595182,
		lng: -84.8766115
	}
};
var cleveland_elyria_mentor_oh = {
	name: "Cleveland-Elyria-Mentor, OH",
	value: {
		lat: 41.49932,
		lng: -81.6943605
	}
};
var clewiston_fl = {
	name: "Clewiston, FL",
	value: {
		lat: 26.7542312,
		lng: -80.93367529999999
	}
};
var clinton_ia = {
	name: "Clinton, IA",
	value: {
		lat: 41.8444735,
		lng: -90.1887379
	}
};
var clovis_nm = {
	name: "Clovis, NM",
	value: {
		lat: 34.4047987,
		lng: -103.2052272
	}
};
var coffeyville_ks = {
	name: "Coffeyville, KS",
	value: {
		lat: 37.0373005,
		lng: -95.6163665
	}
};
var coldwater_mi = {
	name: "Coldwater, MI",
	value: {
		lat: 41.9403263,
		lng: -85.00052149999999
	}
};
var college_station_bryan_tx = {
	name: "College Station-Bryan, TX",
	value: {
		lat: 30.627977,
		lng: -96.3344068
	}
};
var colorado_springs_co = {
	name: "Colorado Springs, CO",
	value: {
		lat: 38.8338816,
		lng: -104.8213634
	}
};
var columbia_mo = {
	name: "Columbia, MO",
	value: {
		lat: 38.9517053,
		lng: -92.3340724
	}
};
var columbia_sc = {
	name: "Columbia, SC",
	value: {
		lat: 34.0007104,
		lng: -81.0348144
	}
};
var columbia_tn = {
	name: "Columbia, TN",
	value: {
		lat: 35.6150716,
		lng: -87.0352831
	}
};
var columbus_ga_al = {
	name: "Columbus, GA-AL",
	value: {
		lat: 32.4609764,
		lng: -84.9877094
	}
};
var columbus_in = {
	name: "Columbus, IN",
	value: {
		lat: 39.2014404,
		lng: -85.9213796
	}
};
var columbus_ms = {
	name: "Columbus, MS",
	value: {
		lat: 33.4956744,
		lng: -88.4272627
	}
};
var columbus_ne = {
	name: "Columbus, NE",
	value: {
		lat: 41.43029730000001,
		lng: -97.3593904
	}
};
var columbus_oh = {
	name: "Columbus, OH",
	value: {
		lat: 39.9611755,
		lng: -82.99879419999999
	}
};
var concord_nh = {
	name: "Concord, NH",
	value: {
		lat: 43.2081366,
		lng: -71.5375718
	}
};
var connersville_in = {
	name: "Connersville, IN",
	value: {
		lat: 39.6411589,
		lng: -85.1410748
	}
};
var cookeville_tn = {
	name: "Cookeville, TN",
	value: {
		lat: 36.162839,
		lng: -85.5016423
	}
};
var coos_bay_or = {
	name: "Coos Bay, OR",
	value: {
		lat: 43.3665007,
		lng: -124.2178903
	}
};
var corbin_ky = {
	name: "Corbin, KY",
	value: {
		lat: 36.9486986,
		lng: -84.0968761
	}
};
var cordele_ga = {
	name: "Cordele, GA",
	value: {
		lat: 31.9635074,
		lng: -83.7823938
	}
};
var corinth_ms = {
	name: "Corinth, MS",
	value: {
		lat: 34.9342548,
		lng: -88.5222702
	}
};
var cornelia_ga = {
	name: "Cornelia, GA",
	value: {
		lat: 34.5114883,
		lng: -83.5271166
	}
};
var corning_ny = {
	name: "Corning, NY",
	value: {
		lat: 42.1428521,
		lng: -77.05469029999999
	}
};
var corpus_christi_tx = {
	name: "Corpus Christi, TX",
	value: {
		lat: 27.8005828,
		lng: -97.39638099999999
	}
};
var corsicana_tx = {
	name: "Corsicana, TX",
	value: {
		lat: 32.0954304,
		lng: -96.46887269999999
	}
};
var cortland_ny = {
	name: "Cortland, NY",
	value: {
		lat: 42.6011813,
		lng: -76.1804843
	}
};
var corvallis_or = {
	name: "Corvallis, OR",
	value: {
		lat: 44.5645659,
		lng: -123.2620435
	}
};
var coshocton_oh = {
	name: "Coshocton, OH",
	value: {
		lat: 40.2720151,
		lng: -81.8595756
	}
};
var crawfordsville_in = {
	name: "Crawfordsville, IN",
	value: {
		lat: 40.0411536,
		lng: -86.87445160000001
	}
};
var crescent_city_ca = {
	name: "Crescent City, CA",
	value: {
		lat: 41.7557501,
		lng: -124.2025913
	}
};
var crossville_tn = {
	name: "Crossville, TN",
	value: {
		lat: 35.9489566,
		lng: -85.0269014
	}
};
var crowley_la = {
	name: "Crowley, LA",
	value: {
		lat: 30.2140928,
		lng: -92.3745761
	}
};
var cullman_al = {
	name: "Cullman, AL",
	value: {
		lat: 34.1748208,
		lng: -86.8436124
	}
};
var culpeper_va = {
	name: "Culpeper, VA",
	value: {
		lat: 38.4729632,
		lng: -77.9962512
	}
};
var cumberland_md_wv = {
	name: "Cumberland, MD-WV",
	value: {
		lat: 39.6528654,
		lng: -78.7625185
	}
};
var dallas_fort_worth_arlington_tx = {
	name: "Dallas-Fort Worth-Arlington, TX",
	value: {
		lat: 32.7766642,
		lng: -96.79698789999999
	}
};
var dalton_ga = {
	name: "Dalton, GA",
	value: {
		lat: 34.7698021,
		lng: -84.9702228
	}
};
var danville_il = {
	name: "Danville, IL",
	value: {
		lat: 40.124481,
		lng: -87.6300207
	}
};
var danville_ky = {
	name: "Danville, KY",
	value: {
		lat: 37.6456329,
		lng: -84.77217019999999
	}
};
var danville_va = {
	name: "Danville, VA",
	value: {
		lat: 36.5859718,
		lng: -79.39502279999999
	}
};
var daphne_fairhope_foley_al = {
	name: "Daphne-Fairhope-Foley, AL",
	value: {
		lat: 30.6035255,
		lng: -87.9036047
	}
};
var davenport_moline_rock_island_ia_il = {
	name: "Davenport-Moline-Rock Island, IA-IL",
	value: {
		lat: 41.5236437,
		lng: -90.5776367
	}
};
var dayton_oh = {
	name: "Dayton, OH",
	value: {
		lat: 39.7589478,
		lng: -84.1916069
	}
};
var de_ridder_la = {
	name: "De Ridder, LA",
	value: {
		lat: 30.8463055,
		lng: -93.2890527
	}
};
var decatur_al = {
	name: "Decatur, AL",
	value: {
		lat: 34.6059253,
		lng: -86.9833417
	}
};
var decatur_il = {
	name: "Decatur, IL",
	value: {
		lat: 39.8403147,
		lng: -88.9548001
	}
};
var decatur_in = {
	name: "Decatur, IN",
	value: {
		lat: 40.830603,
		lng: -84.9291329
	}
};
var defiance_oh = {
	name: "Defiance, OH",
	value: {
		lat: 41.2844933,
		lng: -84.3557802
	}
};
var del_rio_tx = {
	name: "Del Rio, TX",
	value: {
		lat: 29.3708857,
		lng: -100.8958674
	}
};
var deltona_daytona_beach_ormond_beach_fl = {
	name: "Deltona-Daytona Beach-Ormond Beach, FL",
	value: {
		lat: 28.9005446,
		lng: -81.26367379999999
	}
};
var deming_nm = {
	name: "Deming, NM",
	value: {
		lat: 32.2686981,
		lng: -107.7586404
	}
};
var denver_aurora_co = {
	name: "Denver-Aurora, CO",
	value: {
		lat: 39.7392358,
		lng: -104.990251
	}
};
var des_moines_west_des_moines_ia = {
	name: "Des Moines-West Des Moines, IA",
	value: {
		lat: 41.6005448,
		lng: -93.6091064
	}
};
var detroit_warren_livonia_mi = {
	name: "Detroit-Warren-Livonia, MI",
	value: {
		lat: 42.331427,
		lng: -83.0457538
	}
};
var dickinson_nd = {
	name: "Dickinson, ND",
	value: {
		lat: 46.8791756,
		lng: -102.7896242
	}
};
var dillon_sc = {
	name: "Dillon, SC",
	value: {
		lat: 34.4165505,
		lng: -79.3711579
	}
};
var dixon_il = {
	name: "Dixon, IL",
	value: {
		lat: 41.8389213,
		lng: -89.47954779999999
	}
};
var dodge_city_ks = {
	name: "Dodge City, KS",
	value: {
		lat: 37.7527982,
		lng: -100.0170787
	}
};
var dothan_al = {
	name: "Dothan, AL",
	value: {
		lat: 31.2232313,
		lng: -85.3904888
	}
};
var douglas_ga = {
	name: "Douglas, GA",
	value: {
		lat: 31.5088073,
		lng: -82.8498654
	}
};
var dover_de = {
	name: "Dover, DE",
	value: {
		lat: 39.158168,
		lng: -75.5243682
	}
};
var dubois_pa = {
	name: "DuBois, PA",
	value: {
		lat: 41.1210115,
		lng: -78.7583257
	}
};
var dublin_ga = {
	name: "Dublin, GA",
	value: {
		lat: 32.5404447,
		lng: -82.90375399999999
	}
};
var dubuque_ia = {
	name: "Dubuque, IA",
	value: {
		lat: 42.5005583,
		lng: -90.66457179999999
	}
};
var duluth_mn_wi = {
	name: "Duluth, MN-WI",
	value: {
		lat: 46.78667189999999,
		lng: -92.1004852
	}
};
var dumas_tx = {
	name: "Dumas, TX",
	value: {
		lat: 35.8653789,
		lng: -101.9732236
	}
};
var duncan_ok = {
	name: "Duncan, OK",
	value: {
		lat: 34.5023028,
		lng: -97.9578128
	}
};
var dunn_nc = {
	name: "Dunn, NC",
	value: {
		lat: 35.3062743,
		lng: -78.6089028
	}
};
var durango_co = {
	name: "Durango, CO",
	value: {
		lat: 37.27528,
		lng: -107.8800667
	}
};
var durant_ok = {
	name: "Durant, OK",
	value: {
		lat: 33.9924186,
		lng: -96.39712329999999
	}
};
var durham_nc = {
	name: "Durham, NC",
	value: {
		lat: 35.9940329,
		lng: -78.898619
	}
};
var dyersburg_tn = {
	name: "Dyersburg, TN",
	value: {
		lat: 36.0345159,
		lng: -89.38562809999999
	}
};
var eagle_pass_tx = {
	name: "Eagle Pass, TX",
	value: {
		lat: 28.7091433,
		lng: -100.4995214
	}
};
var east_liverpool_salem_oh = {
	name: "East Liverpool-Salem, OH",
	value: {
		lat: 40.6186756,
		lng: -80.5772928
	}
};
var east_stroudsburg_pa = {
	name: "East Stroudsburg, PA",
	value: {
		lat: 40.9995386,
		lng: -75.1812913
	}
};
var easton_md = {
	name: "Easton, MD",
	value: {
		lat: 38.7742826,
		lng: -76.0763305
	}
};
var eau_claire_wi = {
	name: "Eau Claire, WI",
	value: {
		lat: 44.811349,
		lng: -91.4984941
	}
};
var edwards_co = {
	name: "Edwards, CO",
	value: {
		lat: 39.644986,
		lng: -106.5942
	}
};
var effingham_il = {
	name: "Effingham, IL",
	value: {
		lat: 39.1200418,
		lng: -88.5433829
	}
};
var el_campo_tx = {
	name: "El Campo, TX",
	value: {
		lat: 29.19664049999999,
		lng: -96.2696867
	}
};
var el_centro_ca = {
	name: "El Centro, CA",
	value: {
		lat: 32.792,
		lng: -115.5630514
	}
};
var el_dorado_ar = {
	name: "El Dorado, AR",
	value: {
		lat: 33.20763,
		lng: -92.6662674
	}
};
var el_paso_tx = {
	name: "El Paso, TX",
	value: {
		lat: 31.7618778,
		lng: -106.4850217
	}
};
var elizabeth_city_nc = {
	name: "Elizabeth City, NC",
	value: {
		lat: 36.2946008,
		lng: -76.2510461
	}
};
var elizabethtown_ky = {
	name: "Elizabethtown, KY",
	value: {
		lat: 37.7030646,
		lng: -85.8649408
	}
};
var elk_city_ok = {
	name: "Elk City, OK",
	value: {
		lat: 35.4119944,
		lng: -99.4042592
	}
};
var elkhart_goshen_in = {
	name: "Elkhart-Goshen, IN",
	value: {
		lat: 41.6819935,
		lng: -85.9766671
	}
};
var elko_nv = {
	name: "Elko, NV",
	value: {
		lat: 40.8324211,
		lng: -115.7631232
	}
};
var ellensburg_wa = {
	name: "Ellensburg, WA",
	value: {
		lat: 46.9965144,
		lng: -120.5478474
	}
};
var elmira_ny = {
	name: "Elmira, NY",
	value: {
		lat: 42.0897965,
		lng: -76.8077338
	}
};
var emporia_ks = {
	name: "Emporia, KS",
	value: {
		lat: 38.403903,
		lng: -96.18166260000001
	}
};
var enid_ok = {
	name: "Enid, OK",
	value: {
		lat: 36.3955891,
		lng: -97.8783911
	}
};
var enterprise_ozark_al = {
	name: "Enterprise-Ozark, AL",
	value: {
		lat: 31.3151708,
		lng: -85.85521609999999
	}
};
var erie_pa = {
	name: "Erie, PA",
	value: {
		lat: 42.12922409999999,
		lng: -80.085059
	}
};
var escanaba_mi = {
	name: "Escanaba, MI",
	value: {
		lat: 45.74524659999999,
		lng: -87.06458010000001
	}
};
var espanola_nm = {
	name: "Espanola, NM",
	value: {
		lat: 35.9910383,
		lng: -106.0818233
	}
};
var eufaula_al_ga = {
	name: "Eufaula, AL-GA",
	value: {
		lat: 31.8912717,
		lng: -85.1454876
	}
};
var eugene_springfield_or = {
	name: "Eugene-Springfield, OR",
	value: {
		lat: 44.0520691,
		lng: -123.0867536
	}
};
var eureka_arcata_fortuna_ca = {
	name: "Eureka-Arcata-Fortuna, CA",
	value: {
		lat: 40.8020712,
		lng: -124.1636729
	}
};
var evanston_wy = {
	name: "Evanston, WY",
	value: {
		lat: 41.2682794,
		lng: -110.9632373
	}
};
var evansville_in_ky = {
	name: "Evansville, IN-KY",
	value: {
		lat: 37.9715592,
		lng: -87.5710898
	}
};
var fairbanks_ak = {
	name: "Fairbanks, AK",
	value: {
		lat: 64.8377778,
		lng: -147.7163889
	}
};
var fairmont_mn = {
	name: "Fairmont, MN",
	value: {
		lat: 43.65217750000001,
		lng: -94.46108319999999
	}
};
var fairmont_wv = {
	name: "Fairmont, WV",
	value: {
		lat: 39.4850848,
		lng: -80.1425781
	}
};
var fajardo_pr = {
	name: "Fajardo, PR",
	value: {
		lat: 18.2065872,
		lng: -65.64879080000001
	}
};
var fallon_nv = {
	name: "Fallon, NV",
	value: {
		lat: 39.4748693,
		lng: -118.7770407
	}
};
var fargo_nd_mn = {
	name: "Fargo, ND-MN",
	value: {
		lat: 46.8771863,
		lng: -96.7898034
	}
};
var faribault_northfield_mn = {
	name: "Faribault-Northfield, MN",
	value: {
		lat: 44.2949636,
		lng: -93.268827
	}
};
var farmington_mo = {
	name: "Farmington, MO",
	value: {
		lat: 37.7808846,
		lng: -90.4217895
	}
};
var farmington_nm = {
	name: "Farmington, NM",
	value: {
		lat: 36.72805830000001,
		lng: -108.2186856
	}
};
var fayetteville_nc = {
	name: "Fayetteville, NC",
	value: {
		lat: 35.0526641,
		lng: -78.87835849999999
	}
};
var fayetteville_springdale_rogers_ar_mo = {
	name: "Fayetteville-Springdale-Rogers, AR-MO",
	value: {
		lat: 36.0625795,
		lng: -94.1574263
	}
};
var fergus_falls_mn = {
	name: "Fergus Falls, MN",
	value: {
		lat: 46.2835212,
		lng: -96.0777887
	}
};
var fernley_nv = {
	name: "Fernley, NV",
	value: {
		lat: 39.6079683,
		lng: -119.2518349
	}
};
var findlay_oh = {
	name: "Findlay, OH",
	value: {
		lat: 41.04422,
		lng: -83.6499321
	}
};
var fitzgerald_ga = {
	name: "Fitzgerald, GA",
	value: {
		lat: 31.7149082,
		lng: -83.25265449999999
	}
};
var flagstaff_az = {
	name: "Flagstaff, AZ",
	value: {
		lat: 35.1982836,
		lng: -111.651302
	}
};
var flint_mi = {
	name: "Flint, MI",
	value: {
		lat: 43.0125274,
		lng: -83.6874562
	}
};
var florence_sc = {
	name: "Florence, SC",
	value: {
		lat: 34.1954331,
		lng: -79.7625625
	}
};
var florence_muscle_shoals_al = {
	name: "Florence-Muscle Shoals, AL",
	value: {
		lat: 34.79981,
		lng: -87.677251
	}
};
var fond_du_lac_wi = {
	name: "Fond du Lac, WI",
	value: {
		lat: 43.7730448,
		lng: -88.4470508
	}
};
var forest_city_nc = {
	name: "Forest City, NC",
	value: {
		lat: 35.3340108,
		lng: -81.8651028
	}
};
var forrest_city_ar = {
	name: "Forrest City, AR",
	value: {
		lat: 35.0081474,
		lng: -90.7898342
	}
};
var fort_collins_loveland_co = {
	name: "Fort Collins-Loveland, CO",
	value: {
		lat: 40.5852602,
		lng: -105.084423
	}
};
var fort_dodge_ia = {
	name: "Fort Dodge, IA",
	value: {
		lat: 42.4974694,
		lng: -94.16801579999999
	}
};
var fort_leonard_wood_mo = {
	name: "Fort Leonard Wood, MO",
	value: {
		lat: 37.7252315,
		lng: -92.1646722
	}
};
var fort_madison_keokuk_ia_mo = {
	name: "Fort Madison-Keokuk, IA-MO",
	value: {
		lat: 40.6297634,
		lng: -91.31453499999999
	}
};
var fort_morgan_co = {
	name: "Fort Morgan, CO",
	value: {
		lat: 40.2502582,
		lng: -103.7999509
	}
};
var fort_payne_al = {
	name: "Fort Payne, AL",
	value: {
		lat: 34.4442547,
		lng: -85.7196893
	}
};
var fort_polk_south_la = {
	name: "Fort Polk South, LA",
	value: {
		lat: 31.0567117,
		lng: -93.2131232
	}
};
var fort_smith_ar_ok = {
	name: "Fort Smith, AR-OK",
	value: {
		lat: 35.3859242,
		lng: -94.39854749999999
	}
};
var fort_valley_ga = {
	name: "Fort Valley, GA",
	value: {
		lat: 32.5537585,
		lng: -83.8874084
	}
};
var fort_walton_beach_crestview_destin_fl = {
	name: "Fort Walton Beach-Crestview-Destin, FL",
	value: {
		lat: 30.42007079999999,
		lng: -86.6170308
	}
};
var fort_wayne_in = {
	name: "Fort Wayne, IN",
	value: {
		lat: 41.079273,
		lng: -85.1393513
	}
};
var frankfort_in = {
	name: "Frankfort, IN",
	value: {
		lat: 40.2794809,
		lng: -86.5108355
	}
};
var frankfort_ky = {
	name: "Frankfort, KY",
	value: {
		lat: 38.2009055,
		lng: -84.87328350000001
	}
};
var fredericksburg_tx = {
	name: "Fredericksburg, TX",
	value: {
		lat: 30.2752011,
		lng: -98.8719843
	}
};
var freeport_il = {
	name: "Freeport, IL",
	value: {
		lat: 42.2966861,
		lng: -89.6212271
	}
};
var fremont_ne = {
	name: "Fremont, NE",
	value: {
		lat: 41.4333909,
		lng: -96.49814669999999
	}
};
var fremont_oh = {
	name: "Fremont, OH",
	value: {
		lat: 41.3503303,
		lng: -83.1218634
	}
};
var fresno_ca = {
	name: "Fresno, CA",
	value: {
		lat: 36.7468422,
		lng: -119.7725868
	}
};
var gadsden_al = {
	name: "Gadsden, AL",
	value: {
		lat: 34.014264,
		lng: -86.0066386
	}
};
var gaffney_sc = {
	name: "Gaffney, SC",
	value: {
		lat: 35.0717945,
		lng: -81.64981949999999
	}
};
var gainesville_fl = {
	name: "Gainesville, FL",
	value: {
		lat: 29.6516344,
		lng: -82.32482619999999
	}
};
var gainesville_ga = {
	name: "Gainesville, GA",
	value: {
		lat: 34.2978794,
		lng: -83.8240663
	}
};
var gainesville_tx = {
	name: "Gainesville, TX",
	value: {
		lat: 33.62594139999999,
		lng: -97.1333453
	}
};
var galesburg_il = {
	name: "Galesburg, IL",
	value: {
		lat: 40.94781580000001,
		lng: -90.3712395
	}
};
var gallup_nm = {
	name: "Gallup, NM",
	value: {
		lat: 35.5280783,
		lng: -108.7425843
	}
};
var garden_city_ks = {
	name: "Garden City, KS",
	value: {
		lat: 37.9716898,
		lng: -100.8726618
	}
};
var gardnerville_ranchos_nv = {
	name: "Gardnerville Ranchos, NV",
	value: {
		lat: 38.8882398,
		lng: -119.7412875
	}
};
var georgetown_sc = {
	name: "Georgetown, SC",
	value: {
		lat: 33.376834,
		lng: -79.2944964
	}
};
var gettysburg_pa = {
	name: "Gettysburg, PA",
	value: {
		lat: 39.8309293,
		lng: -77.2310955
	}
};
var gillette_wy = {
	name: "Gillette, WY",
	value: {
		lat: 44.2910915,
		lng: -105.5022205
	}
};
var glasgow_ky = {
	name: "Glasgow, KY",
	value: {
		lat: 36.9958839,
		lng: -85.91192149999999
	}
};
var glens_falls_ny = {
	name: "Glens Falls, NY",
	value: {
		lat: 43.3095164,
		lng: -73.6440058
	}
};
var gloversville_ny = {
	name: "Gloversville, NY",
	value: {
		lat: 43.0528506,
		lng: -74.3437467
	}
};
var goldsboro_nc = {
	name: "Goldsboro, NC",
	value: {
		lat: 35.3848841,
		lng: -77.9927651
	}
};
var granbury_tx = {
	name: "Granbury, TX",
	value: {
		lat: 32.4420826,
		lng: -97.7941967
	}
};
var grand_forks_nd_mn = {
	name: "Grand Forks, ND-MN",
	value: {
		lat: 47.9252568,
		lng: -97.0328547
	}
};
var grand_island_ne = {
	name: "Grand Island, NE",
	value: {
		lat: 40.9263957,
		lng: -98.3420118
	}
};
var grand_junction_co = {
	name: "Grand Junction, CO",
	value: {
		lat: 39.0638705,
		lng: -108.5506486
	}
};
var grand_rapids_wyoming_mi = {
	name: "Grand Rapids-Wyoming, MI",
	value: {
		lat: 42.9633599,
		lng: -85.6680863
	}
};
var grants_pass_or = {
	name: "Grants Pass, OR",
	value: {
		lat: 42.4390069,
		lng: -123.3283925
	}
};
var grants_nm = {
	name: "Grants, NM",
	value: {
		lat: 35.14726,
		lng: -107.8514466
	}
};
var great_bend_ks = {
	name: "Great Bend, KS",
	value: {
		lat: 38.3644567,
		lng: -98.7648073
	}
};
var great_falls_mt = {
	name: "Great Falls, MT",
	value: {
		lat: 47.4941836,
		lng: -111.2833449
	}
};
var greeley_co = {
	name: "Greeley, CO",
	value: {
		lat: 40.4233142,
		lng: -104.7091322
	}
};
var green_bay_wi = {
	name: "Green Bay, WI",
	value: {
		lat: 44.51915899999999,
		lng: -88.019826
	}
};
var greeneville_tn = {
	name: "Greeneville, TN",
	value: {
		lat: 36.1631574,
		lng: -82.83098609999999
	}
};
var greensboro_high_point_nc = {
	name: "Greensboro-High Point, NC",
	value: {
		lat: 36.0726354,
		lng: -79.7919754
	}
};
var greensburg_in = {
	name: "Greensburg, IN",
	value: {
		lat: 39.3372722,
		lng: -85.483581
	}
};
var greenville_ms = {
	name: "Greenville, MS",
	value: {
		lat: 33.399661,
		lng: -91.0377029
	}
};
var greenville_nc = {
	name: "Greenville, NC",
	value: {
		lat: 35.612661,
		lng: -77.3663538
	}
};
var greenville_oh = {
	name: "Greenville, OH",
	value: {
		lat: 40.1028264,
		lng: -84.63301150000001
	}
};
var greenville_mauldin_easley_sc = {
	name: "Greenville-Mauldin-Easley, SC",
	value: {
		lat: 34.85261759999999,
		lng: -82.3940104
	}
};
var greenwood_ms = {
	name: "Greenwood, MS",
	value: {
		lat: 33.5162315,
		lng: -90.1795281
	}
};
var greenwood_sc = {
	name: "Greenwood, SC",
	value: {
		lat: 34.1954001,
		lng: -82.1617883
	}
};
var grenada_ms = {
	name: "Grenada, MS",
	value: {
		lat: 33.7690049,
		lng: -89.8084192
	}
};
var guayama_pr = {
	name: "Guayama, PR",
	value: {
		lat: 17.98413,
		lng: -66.11378
	}
};
var gulfport_biloxi_ms = {
	name: "Gulfport-Biloxi, MS",
	value: {
		lat: 30.3674198,
		lng: -89.0928155
	}
};
var guymon_ok = {
	name: "Guymon, OK",
	value: {
		lat: 36.6828041,
		lng: -101.4815493
	}
};
var hagerstown_martinsburg_md_wv = {
	name: "Hagerstown-Martinsburg, MD-WV",
	value: {
		lat: 39.6417629,
		lng: -77.71999319999999
	}
};
var hammond_la = {
	name: "Hammond, LA",
	value: {
		lat: 30.5043583,
		lng: -90.46119949999999
	}
};
var hanford_corcoran_ca = {
	name: "Hanford-Corcoran, CA",
	value: {
		lat: 36.3274502,
		lng: -119.6456844
	}
};
var hannibal_mo = {
	name: "Hannibal, MO",
	value: {
		lat: 39.7083789,
		lng: -91.35848159999999
	}
};
var harriman_tn = {
	name: "Harriman, TN",
	value: {
		lat: 35.9339638,
		lng: -84.5524358
	}
};
var harrisburg_il = {
	name: "Harrisburg, IL",
	value: {
		lat: 37.7383812,
		lng: -88.540607
	}
};
var harrisburg_carlisle_pa = {
	name: "Harrisburg-Carlisle, PA",
	value: {
		lat: 40.2731911,
		lng: -76.8867008
	}
};
var harrison_ar = {
	name: "Harrison, AR",
	value: {
		lat: 36.2297936,
		lng: -93.1076765
	}
};
var harrisonburg_va = {
	name: "Harrisonburg, VA",
	value: {
		lat: 38.4495688,
		lng: -78.8689155
	}
};
var hartford_west_hartford_east_hartford_ct = {
	name: "Hartford-West Hartford-East Hartford, CT",
	value: {
		lat: 41.76371109999999,
		lng: -72.6850932
	}
};
var hastings_ne = {
	name: "Hastings, NE",
	value: {
		lat: 40.5862583,
		lng: -98.38987259999999
	}
};
var hattiesburg_ms = {
	name: "Hattiesburg, MS",
	value: {
		lat: 31.3271189,
		lng: -89.29033919999999
	}
};
var havre_mt = {
	name: "Havre, MT",
	value: {
		lat: 48.549999,
		lng: -109.6840887
	}
};
var hays_ks = {
	name: "Hays, KS",
	value: {
		lat: 38.8791783,
		lng: -99.3267702
	}
};
var heber_ut = {
	name: "Heber, UT",
	value: {
		lat: 40.5070087,
		lng: -111.4133234
	}
};
var helena_mt = {
	name: "Helena, MT",
	value: {
		lat: 46.5883707,
		lng: -112.0245054
	}
};
var henderson_nc = {
	name: "Henderson, NC",
	value: {
		lat: 36.3295905,
		lng: -78.3991638
	}
};
var hereford_tx = {
	name: "Hereford, TX",
	value: {
		lat: 34.8150622,
		lng: -102.3977036
	}
};
var hickory_lenoir_morganton_nc = {
	name: "Hickory-Lenoir-Morganton, NC",
	value: {
		lat: 35.7344538,
		lng: -81.3444573
	}
};
var hilo_hi = {
	name: "Hilo, HI",
	value: {
		lat: 19.7297222,
		lng: -155.09
	}
};
var hilton_head_island_beaufort_sc = {
	name: "Hilton Head Island-Beaufort, SC",
	value: {
		lat: 32.216316,
		lng: -80.752608
	}
};
var hinesville_fort_stewart_ga = {
	name: "Hinesville-Fort Stewart, GA",
	value: {
		lat: 31.846877,
		lng: -81.5959453
	}
};
var hobbs_nm = {
	name: "Hobbs, NM",
	value: {
		lat: 32.7026116,
		lng: -103.1360403
	}
};
var holland_grand_haven_mi = {
	name: "Holland-Grand Haven, MI",
	value: {
		lat: 42.7875235,
		lng: -86.1089301
	}
};
var homosassa_springs_fl = {
	name: "Homosassa Springs, FL",
	value: {
		lat: 28.8037059,
		lng: -82.5761369
	}
};
var honolulu_hi = {
	name: "Honolulu, HI",
	value: {
		lat: 21.3069444,
		lng: -157.8583333
	}
};
var hood_river_or = {
	name: "Hood River, OR",
	value: {
		lat: 45.7053966,
		lng: -121.5214623
	}
};
var hope_ar = {
	name: "Hope, AR",
	value: {
		lat: 33.6670615,
		lng: -93.5915665
	}
};
var hot_springs_ar = {
	name: "Hot Springs, AR",
	value: {
		lat: 34.5037004,
		lng: -93.0551795
	}
};
var houghton_mi = {
	name: "Houghton, MI",
	value: {
		lat: 47.12113309999999,
		lng: -88.5694182
	}
};
var houma_bayou_cane_thibodaux_la = {
	name: "Houma-Bayou Cane-Thibodaux, LA",
	value: {
		lat: 29.5957696,
		lng: -90.71953479999999
	}
};
var houston_sugar_land_baytown_tx = {
	name: "Houston-Sugar Land-Baytown, TX",
	value: {
		lat: 29.7604267,
		lng: -95.3698028
	}
};
var hudson_ny = {
	name: "Hudson, NY",
	value: {
		lat: 42.2528649,
		lng: -73.790959
	}
};
var humboldt_tn = {
	name: "Humboldt, TN",
	value: {
		lat: 35.8197917,
		lng: -88.9158953
	}
};
var huntingdon_pa = {
	name: "Huntingdon, PA",
	value: {
		lat: 40.48479589999999,
		lng: -78.0102813
	}
};
var huntington_in = {
	name: "Huntington, IN",
	value: {
		lat: 40.8831011,
		lng: -85.49747599999999
	}
};
var huntington_ashland_wv_ky_oh = {
	name: "Huntington-Ashland, WV-KY-OH",
	value: {
		lat: 38.4192496,
		lng: -82.44515400000002
	}
};
var huntsville_al = {
	name: "Huntsville, AL",
	value: {
		lat: 34.7303688,
		lng: -86.5861037
	}
};
var huntsville_tx = {
	name: "Huntsville, TX",
	value: {
		lat: 30.7235263,
		lng: -95.55077709999999
	}
};
var huron_sd = {
	name: "Huron, SD",
	value: {
		lat: 44.3633173,
		lng: -98.21425719999999
	}
};
var hutchinson_ks = {
	name: "Hutchinson, KS",
	value: {
		lat: 38.0608445,
		lng: -97.92977429999999
	}
};
var hutchinson_mn = {
	name: "Hutchinson, MN",
	value: {
		lat: 44.89254830000001,
		lng: -94.3692926
	}
};
var idaho_falls_id = {
	name: "Idaho Falls, ID",
	value: {
		lat: 43.49165139999999,
		lng: -112.0339645
	}
};
var indiana_pa = {
	name: "Indiana, PA",
	value: {
		lat: 40.6214551,
		lng: -79.15253489999999
	}
};
var indianapolis_carmel_in = {
	name: "Indianapolis-Carmel, IN",
	value: {
		lat: 39.768403,
		lng: -86.158068
	}
};
var indianola_ms = {
	name: "Indianola, MS",
	value: {
		lat: 33.4509513,
		lng: -90.6550917
	}
};
var iowa_city_ia = {
	name: "Iowa City, IA",
	value: {
		lat: 41.6611277,
		lng: -91.5301683
	}
};
var iron_mountain_mi_wi = {
	name: "Iron Mountain, MI-WI",
	value: {
		lat: 45.8202334,
		lng: -88.0659603
	}
};
var ithaca_ny = {
	name: "Ithaca, NY",
	value: {
		lat: 42.4439614,
		lng: -76.5018807
	}
};
var jackson_mi = {
	name: "Jackson, MI",
	value: {
		lat: 42.245869,
		lng: -84.40134619999999
	}
};
var jackson_ms = {
	name: "Jackson, MS",
	value: {
		lat: 32.2987573,
		lng: -90.1848103
	}
};
var jackson_tn = {
	name: "Jackson, TN",
	value: {
		lat: 35.6145169,
		lng: -88.81394689999999
	}
};
var jackson_wy_id = {
	name: "Jackson, WY-ID",
	value: {
		lat: 43.4799291,
		lng: -110.7624282
	}
};
var jacksonville_fl = {
	name: "Jacksonville, FL",
	value: {
		lat: 30.3321838,
		lng: -81.65565099999999
	}
};
var jacksonville_il = {
	name: "Jacksonville, IL",
	value: {
		lat: 39.733936,
		lng: -90.2290098
	}
};
var jacksonville_nc = {
	name: "Jacksonville, NC",
	value: {
		lat: 34.7540524,
		lng: -77.4302414
	}
};
var jacksonville_tx = {
	name: "Jacksonville, TX",
	value: {
		lat: 31.963778,
		lng: -95.27050419999999
	}
};
var jamestown_nd = {
	name: "Jamestown, ND",
	value: {
		lat: 46.9105438,
		lng: -98.7084357
	}
};
var jamestown_dunkirk_fredonia_ny = {
	name: "Jamestown-Dunkirk-Fredonia, NY",
	value: {
		lat: 42.0970023,
		lng: -79.23532589999999
	}
};
var janesville_wi = {
	name: "Janesville, WI",
	value: {
		lat: 42.6827885,
		lng: -89.0187222
	}
};
var jasper_in = {
	name: "Jasper, IN",
	value: {
		lat: 38.3914418,
		lng: -86.9311094
	}
};
var jefferson_city_mo = {
	name: "Jefferson City, MO",
	value: {
		lat: 38.57670170000001,
		lng: -92.1735164
	}
};
var jennings_la = {
	name: "Jennings, LA",
	value: {
		lat: 30.22242839999999,
		lng: -92.657085
	}
};
var jesup_ga = {
	name: "Jesup, GA",
	value: {
		lat: 31.6074365,
		lng: -81.8853924
	}
};
var johnson_city_tn = {
	name: "Johnson City, TN",
	value: {
		lat: 36.3134397,
		lng: -82.3534727
	}
};
var johnstown_pa = {
	name: "Johnstown, PA",
	value: {
		lat: 40.32674069999999,
		lng: -78.9219698
	}
};
var jonesboro_ar = {
	name: "Jonesboro, AR",
	value: {
		lat: 35.84229670000001,
		lng: -90.704279
	}
};
var joplin_mo = {
	name: "Joplin, MO",
	value: {
		lat: 37.08422710000001,
		lng: -94.51328099999999
	}
};
var juneau_ak = {
	name: "Juneau, AK",
	value: {
		lat: 58.3019444,
		lng: -134.4197222
	}
};
var kahului_wailuku_hi = {
	name: "Kahului-Wailuku, HI",
	value: {
		lat: 20.8893351,
		lng: -156.4729469
	}
};
var kalamazoo_portage_mi = {
	name: "Kalamazoo-Portage, MI",
	value: {
		lat: 42.2917069,
		lng: -85.5872286
	}
};
var kalispell_mt = {
	name: "Kalispell, MT",
	value: {
		lat: 48.1919889,
		lng: -114.3168131
	}
};
var kankakee_bradley_il = {
	name: "Kankakee-Bradley, IL",
	value: {
		lat: 41.1200325,
		lng: -87.8611531
	}
};
var kansas_city_mo_ks = {
	name: "Kansas City, MO-KS",
	value: {
		lat: 39.0997265,
		lng: -94.5785667
	}
};
var kapaa_hi = {
	name: "Kapaa, HI",
	value: {
		lat: 22.0881391,
		lng: -159.3379818
	}
};
var kearney_ne = {
	name: "Kearney, NE",
	value: {
		lat: 40.69933030000001,
		lng: -99.0816784
	}
};
var keene_nh = {
	name: "Keene, NH",
	value: {
		lat: 42.933692,
		lng: -72.2781409
	}
};
var kendallville_in = {
	name: "Kendallville, IN",
	value: {
		lat: 41.4414384,
		lng: -85.2649754
	}
};
var kennett_mo = {
	name: "Kennett, MO",
	value: {
		lat: 36.2361762,
		lng: -90.0556493
	}
};
var kennewick_richland_pasco_wa = {
	name: "Kennewick-Richland-Pasco, WA",
	value: {
		lat: 46.2112458,
		lng: -119.1372338
	}
};
var kerrville_tx = {
	name: "Kerrville, TX",
	value: {
		lat: 30.0474332,
		lng: -99.1403189
	}
};
var ketchikan_ak = {
	name: "Ketchikan, AK",
	value: {
		lat: 55.34222219999999,
		lng: -131.6461111
	}
};
var key_west_fl = {
	name: "Key West, FL",
	value: {
		lat: 24.5550593,
		lng: -81.7799871
	}
};
var kill_devil_hills_nc = {
	name: "Kill Devil Hills, NC",
	value: {
		lat: 36.0307226,
		lng: -75.6760101
	}
};
var killeen_temple_fort_hood_tx = {
	name: "Killeen-Temple-Fort Hood, TX",
	value: {
		lat: 31.1171194,
		lng: -97.72779589999999
	}
};
var kingsport_bristol_bristol_tn_va = {
	name: "Kingsport-Bristol-Bristol, TN-VA",
	value: {
		lat: 36.548434,
		lng: -82.5618186
	}
};
var kingston_ny = {
	name: "Kingston, NY",
	value: {
		lat: 41.9270367,
		lng: -73.9973608
	}
};
var kingsville_tx = {
	name: "Kingsville, TX",
	value: {
		lat: 27.5158689,
		lng: -97.85610899999999
	}
};
var kinston_nc = {
	name: "Kinston, NC",
	value: {
		lat: 35.2626635,
		lng: -77.5816353
	}
};
var kirksville_mo = {
	name: "Kirksville, MO",
	value: {
		lat: 40.19475389999999,
		lng: -92.5832496
	}
};
var klamath_falls_or = {
	name: "Klamath Falls, OR",
	value: {
		lat: 42.224867,
		lng: -121.7816704
	}
};
var knoxville_tn = {
	name: "Knoxville, TN",
	value: {
		lat: 35.9606384,
		lng: -83.9207392
	}
};
var kodiak_ak = {
	name: "Kodiak, AK",
	value: {
		lat: 57.79000000000001,
		lng: -152.4072222
	}
};
var kokomo_in = {
	name: "Kokomo, IN",
	value: {
		lat: 40.486427,
		lng: -86.13360329999999
	}
};
var la_crosse_wi_mn = {
	name: "La Crosse, WI-MN",
	value: {
		lat: 43.8013556,
		lng: -91.23958069999999
	}
};
var la_follette_tn = {
	name: "La Follette, TN",
	value: {
		lat: 36.3828852,
		lng: -84.1199472
	}
};
var la_grande_or = {
	name: "La Grande, OR",
	value: {
		lat: 45.3245771,
		lng: -118.0877188
	}
};
var lagrange_ga = {
	name: "LaGrange, GA",
	value: {
		lat: 33.0362218,
		lng: -85.0322444
	}
};
var laconia_nh = {
	name: "Laconia, NH",
	value: {
		lat: 43.5278546,
		lng: -71.4703509
	}
};
var lafayette_in = {
	name: "Lafayette, IN",
	value: {
		lat: 40.4167022,
		lng: -86.87528689999999
	}
};
var lafayette_la = {
	name: "Lafayette, LA",
	value: {
		lat: 30.2240897,
		lng: -92.0198427
	}
};
var lake_charles_la = {
	name: "Lake Charles, LA",
	value: {
		lat: 30.2265949,
		lng: -93.2173758
	}
};
var lake_city_fl = {
	name: "Lake City, FL",
	value: {
		lat: 30.1896756,
		lng: -82.6392899
	}
};
var lake_havasu_city_kingman_az = {
	name: "Lake Havasu City-Kingman, AZ",
	value: {
		lat: 34.483901,
		lng: -114.3224548
	}
};
var lakeland_fl = {
	name: "Lakeland, FL",
	value: {
		lat: 28.0394654,
		lng: -81.9498042
	}
};
var lamesa_tx = {
	name: "Lamesa, TX",
	value: {
		lat: 32.7376001,
		lng: -101.950992
	}
};
var lancaster_pa = {
	name: "Lancaster, PA",
	value: {
		lat: 40.0378755,
		lng: -76.3055144
	}
};
var lancaster_sc = {
	name: "Lancaster, SC",
	value: {
		lat: 34.7204257,
		lng: -80.7709014
	}
};
var lansing_east_lansing_mi = {
	name: "Lansing-East Lansing, MI",
	value: {
		lat: 42.732535,
		lng: -84.5555347
	}
};
var laramie_wy = {
	name: "Laramie, WY",
	value: {
		lat: 41.3113669,
		lng: -105.5911007
	}
};
var laredo_tx = {
	name: "Laredo, TX",
	value: {
		lat: 27.5305671,
		lng: -99.48032409999999
	}
};
var las_cruces_nm = {
	name: "Las Cruces, NM",
	value: {
		lat: 32.3199396,
		lng: -106.7636538
	}
};
var las_vegas_nm = {
	name: "Las Vegas, NM",
	value: {
		lat: 35.5942137,
		lng: -105.2227978
	}
};
var las_vegas_paradise_nv = {
	name: "Las Vegas-Paradise, NV",
	value: {
		lat: 36.1699412,
		lng: -115.1398296
	}
};
var laurel_ms = {
	name: "Laurel, MS",
	value: {
		lat: 31.6940509,
		lng: -89.1306124
	}
};
var laurinburg_nc = {
	name: "Laurinburg, NC",
	value: {
		lat: 34.7740494,
		lng: -79.46282479999999
	}
};
var lawrence_ks = {
	name: "Lawrence, KS",
	value: {
		lat: 38.9716689,
		lng: -95.2352501
	}
};
var lawrenceburg_tn = {
	name: "Lawrenceburg, TN",
	value: {
		lat: 35.2423023,
		lng: -87.33473889999999
	}
};
var lawton_ok = {
	name: "Lawton, OK",
	value: {
		lat: 34.6035669,
		lng: -98.39592909999999
	}
};
var lebanon_mo = {
	name: "Lebanon, MO",
	value: {
		lat: 37.6805967,
		lng: -92.6637865
	}
};
var lebanon_nh_vt = {
	name: "Lebanon, NH-VT",
	value: {
		lat: 43.6422934,
		lng: -72.2517569
	}
};
var lebanon_pa = {
	name: "Lebanon, PA",
	value: {
		lat: 40.3409251,
		lng: -76.4113497
	}
};
var levelland_tx = {
	name: "Levelland, TX",
	value: {
		lat: 33.5873164,
		lng: -102.37796
	}
};
var lewisburg_pa = {
	name: "Lewisburg, PA",
	value: {
		lat: 40.9645293,
		lng: -76.8844101
	}
};
var lewisburg_tn = {
	name: "Lewisburg, TN",
	value: {
		lat: 35.4492404,
		lng: -86.7888887
	}
};
var lewiston_id_wa = {
	name: "Lewiston, ID-WA",
	value: {
		lat: 46.4004089,
		lng: -117.0011889
	}
};
var lewiston_auburn_me = {
	name: "Lewiston-Auburn, ME",
	value: {
		lat: 44.100351,
		lng: -70.21477639999999
	}
};
var lewistown_pa = {
	name: "Lewistown, PA",
	value: {
		lat: 40.5992395,
		lng: -77.571382
	}
};
var lexington_park_md = {
	name: "Lexington Park, MD",
	value: {
		lat: 38.2575517,
		lng: -76.4620928
	}
};
var lexington_ne = {
	name: "Lexington, NE",
	value: {
		lat: 40.7808398,
		lng: -99.74150449999999
	}
};
var lexington_fayette_ky = {
	name: "Lexington-Fayette, KY",
	value: {
		lat: 38.0405837,
		lng: -84.5037164
	}
};
var liberal_ks = {
	name: "Liberal, KS",
	value: {
		lat: 37.0430812,
		lng: -100.920999
	}
};
var lima_oh = {
	name: "Lima, OH",
	value: {
		lat: 40.742551,
		lng: -84.1052256
	}
};
var lincoln_il = {
	name: "Lincoln, IL",
	value: {
		lat: 40.1483768,
		lng: -89.3648183
	}
};
var lincoln_ne = {
	name: "Lincoln, NE",
	value: {
		lat: 40.8257625,
		lng: -96.6851982
	}
};
var lincolnton_nc = {
	name: "Lincolnton, NC",
	value: {
		lat: 35.473745,
		lng: -81.2545251
	}
};
var little_rock_north_little_rock_conway_ar = {
	name: "Little Rock-North Little Rock-Conway, AR",
	value: {
		lat: 34.7464809,
		lng: -92.28959479999999
	}
};
var lock_haven_pa = {
	name: "Lock Haven, PA",
	value: {
		lat: 41.1370133,
		lng: -77.4469263
	}
};
var logan_ut_id = {
	name: "Logan, UT-ID",
	value: {
		lat: 41.7369803,
		lng: -111.8338359
	}
};
var logansport_in = {
	name: "Logansport, IN",
	value: {
		lat: 40.7544843,
		lng: -86.3566659
	}
};
var london_ky = {
	name: "London, KY",
	value: {
		lat: 37.1289771,
		lng: -84.08326459999999
	}
};
var longview_tx = {
	name: "Longview, TX",
	value: {
		lat: 32.5007037,
		lng: -94.74048909999999
	}
};
var longview_wa = {
	name: "Longview, WA",
	value: {
		lat: 46.1381676,
		lng: -122.9381672
	}
};
var los_alamos_nm = {
	name: "Los Alamos, NM",
	value: {
		lat: 35.8800364,
		lng: -106.3031138
	}
};
var los_angeles_long_beach_santa_ana_ca = {
	name: "Los Angeles-Long Beach-Santa Ana, CA",
	value: {
		lat: 34.0522342,
		lng: -118.2436849
	}
};
var lubbock_tx = {
	name: "Lubbock, TX",
	value: {
		lat: 33.5778631,
		lng: -101.8551665
	}
};
var lufkin_tx = {
	name: "Lufkin, TX",
	value: {
		lat: 31.3382406,
		lng: -94.729097
	}
};
var lumberton_nc = {
	name: "Lumberton, NC",
	value: {
		lat: 34.6182199,
		lng: -79.0086424
	}
};
var lynchburg_va = {
	name: "Lynchburg, VA",
	value: {
		lat: 37.4137536,
		lng: -79.14224639999999
	}
};
var macomb_il = {
	name: "Macomb, IL",
	value: {
		lat: 40.4592076,
		lng: -90.67179709999999
	}
};
var macon_ga = {
	name: "Macon, GA",
	value: {
		lat: 32.8406946,
		lng: -83.6324022
	}
};
var madera_ca = {
	name: "Madera, CA",
	value: {
		lat: 36.9613356,
		lng: -120.0607176
	}
};
var madison_in = {
	name: "Madison, IN",
	value: {
		lat: 38.7358933,
		lng: -85.37995769999999
	}
};
var madison_wi = {
	name: "Madison, WI",
	value: {
		lat: 43.0730517,
		lng: -89.4012302
	}
};
var madisonville_ky = {
	name: "Madisonville, KY",
	value: {
		lat: 37.32810050000001,
		lng: -87.4988882
	}
};
var magnolia_ar = {
	name: "Magnolia, AR",
	value: {
		lat: 33.2670725,
		lng: -93.239334
	}
};
var malone_ny = {
	name: "Malone, NY",
	value: {
		lat: 44.8486596,
		lng: -74.29489830000001
	}
};
var manchester_nashua_nh = {
	name: "Manchester-Nashua, NH",
	value: {
		lat: 42.9956397,
		lng: -71.4547891
	}
};
var manhattan_ks = {
	name: "Manhattan, KS",
	value: {
		lat: 39.18360819999999,
		lng: -96.57166939999999
	}
};
var manitowoc_wi = {
	name: "Manitowoc, WI",
	value: {
		lat: 44.0886059,
		lng: -87.657584
	}
};
var mankato_north_mankato_mn = {
	name: "Mankato-North Mankato, MN",
	value: {
		lat: 44.1635775,
		lng: -93.99939959999999
	}
};
var mansfield_oh = {
	name: "Mansfield, OH",
	value: {
		lat: 40.75839,
		lng: -82.5154471
	}
};
var marinette_wi_mi = {
	name: "Marinette, WI-MI",
	value: {
		lat: 45.0999849,
		lng: -87.6306623
	}
};
var marion_in = {
	name: "Marion, IN",
	value: {
		lat: 40.5583739,
		lng: -85.6591442
	}
};
var marion_oh = {
	name: "Marion, OH",
	value: {
		lat: 40.5886699,
		lng: -83.1285242
	}
};
var marion_herrin_il = {
	name: "Marion-Herrin, IL",
	value: {
		lat: 37.7306054,
		lng: -88.9331256
	}
};
var marquette_mi = {
	name: "Marquette, MI",
	value: {
		lat: 46.5475825,
		lng: -87.39559539999999
	}
};
var marshall_mn = {
	name: "Marshall, MN",
	value: {
		lat: 44.448423,
		lng: -95.79119159999999
	}
};
var marshall_mo = {
	name: "Marshall, MO",
	value: {
		lat: 39.1230777,
		lng: -93.1968704
	}
};
var marshall_tx = {
	name: "Marshall, TX",
	value: {
		lat: 32.5448714,
		lng: -94.36741839999999
	}
};
var marshalltown_ia = {
	name: "Marshalltown, IA",
	value: {
		lat: 42.0494674,
		lng: -92.90803749999999
	}
};
var marshfield_wisconsin_rapids_wi = {
	name: "Marshfield-Wisconsin Rapids, WI",
	value: {
		lat: 44.6688524,
		lng: -90.1717987
	}
};
var martin_tn = {
	name: "Martin, TN",
	value: {
		lat: 36.3433965,
		lng: -88.8503379
	}
};
var martinsville_va = {
	name: "Martinsville, VA",
	value: {
		lat: 36.6915262,
		lng: -79.8725386
	}
};
var maryville_mo = {
	name: "Maryville, MO",
	value: {
		lat: 40.3461017,
		lng: -94.8724706
	}
};
var mason_city_ia = {
	name: "Mason City, IA",
	value: {
		lat: 43.1535728,
		lng: -93.20103669999999
	}
};
var mayaguez_pr = {
	name: "Mayaguez, PR",
	value: {
		lat: 18.1534243863,
		lng: -67.13833944669
	}
};
var mayfield_ky = {
	name: "Mayfield, KY",
	value: {
		lat: 36.7417235,
		lng: -88.6367154
	}
};
var maysville_ky = {
	name: "Maysville, KY",
	value: {
		lat: 38.6411854,
		lng: -83.744365
	}
};
var mcalester_ok = {
	name: "McAlester, OK",
	value: {
		lat: 34.9334298,
		lng: -95.76971309999999
	}
};
var mcallen_edinburg_mission_tx = {
	name: "McAllen-Edinburg-Mission, TX",
	value: {
		lat: 26.2034071,
		lng: -98.23001239999999
	}
};
var mccomb_ms = {
	name: "McComb, MS",
	value: {
		lat: 31.2437872,
		lng: -90.4531535
	}
};
var mcminnville_tn = {
	name: "McMinnville, TN",
	value: {
		lat: 35.6865889,
		lng: -85.7801453
	}
};
var mcpherson_ks = {
	name: "McPherson, KS",
	value: {
		lat: 38.3708415,
		lng: -97.66420869999999
	}
};
var meadville_pa = {
	name: "Meadville, PA",
	value: {
		lat: 41.6414438,
		lng: -80.15144839999999
	}
};
var medford_or = {
	name: "Medford, OR",
	value: {
		lat: 42.3265152,
		lng: -122.8755949
	}
};
var memphis_tn_ms_ar = {
	name: "Memphis, TN-MS-AR",
	value: {
		lat: 35.1495343,
		lng: -90.0489801
	}
};
var menomonie_wi = {
	name: "Menomonie, WI",
	value: {
		lat: 44.8755183,
		lng: -91.9193422
	}
};
var merced_ca = {
	name: "Merced, CA",
	value: {
		lat: 37.3021632,
		lng: -120.4829677
	}
};
var meridian_ms = {
	name: "Meridian, MS",
	value: {
		lat: 32.3643098,
		lng: -88.703656
	}
};
var merrill_wi = {
	name: "Merrill, WI",
	value: {
		lat: 45.1805223,
		lng: -89.683459
	}
};
var mexico_mo = {
	name: "Mexico, MO",
	value: {
		lat: 39.1730652,
		lng: -91.887271
	}
};
var miami_ok = {
	name: "Miami, OK",
	value: {
		lat: 36.8745146,
		lng: -94.8774554
	}
};
var miami_fort_lauderdale_pompano_beach_fl = {
	name: "Miami-Fort Lauderdale-Pompano Beach, FL",
	value: {
		lat: 25.7616798,
		lng: -80.1917902
	}
};
var michigan_city_la_porte_in = {
	name: "Michigan City-La Porte, IN",
	value: {
		lat: 41.70753939999999,
		lng: -86.8950297
	}
};
var middlesborough_ky = {
	name: "Middlesborough, KY",
	value: {
		lat: 36.6072567,
		lng: -83.7142848
	}
};
var midland_mi = {
	name: "Midland, MI",
	value: {
		lat: 43.6155825,
		lng: -84.2472116
	}
};
var midland_tx = {
	name: "Midland, TX",
	value: {
		lat: 31.9973456,
		lng: -102.0779146
	}
};
var milledgeville_ga = {
	name: "Milledgeville, GA",
	value: {
		lat: 33.0801429,
		lng: -83.2320991
	}
};
var milwaukee_waukesha_west_allis_wi = {
	name: "Milwaukee-Waukesha-West Allis, WI",
	value: {
		lat: 43.0389025,
		lng: -87.9064736
	}
};
var minden_la = {
	name: "Minden, LA",
	value: {
		lat: 32.6154278,
		lng: -93.2868354
	}
};
var mineral_wells_tx = {
	name: "Mineral Wells, TX",
	value: {
		lat: 32.8084605,
		lng: -98.1128223
	}
};
var minneapolis_st_paul_bloomington_mn_wi = {
	name: "Minneapolis-St. Paul-Bloomington, MN-WI",
	value: {
		lat: 44.977753,
		lng: -93.2650108
	}
};
var minot_nd = {
	name: "Minot, ND",
	value: {
		lat: 48.2329668,
		lng: -101.2922906
	}
};
var missoula_mt = {
	name: "Missoula, MT",
	value: {
		lat: 46.87871759999999,
		lng: -113.996586
	}
};
var mitchell_sd = {
	name: "Mitchell, SD",
	value: {
		lat: 43.7094283,
		lng: -98.0297992
	}
};
var moberly_mo = {
	name: "Moberly, MO",
	value: {
		lat: 39.4183689,
		lng: -92.43823669999999
	}
};
var mobile_al = {
	name: "Mobile, AL",
	value: {
		lat: 30.6953657,
		lng: -88.0398912
	}
};
var modesto_ca = {
	name: "Modesto, CA",
	value: {
		lat: 37.63909719999999,
		lng: -120.9968782
	}
};
var monroe_la = {
	name: "Monroe, LA",
	value: {
		lat: 32.5093109,
		lng: -92.1193012
	}
};
var monroe_mi = {
	name: "Monroe, MI",
	value: {
		lat: 41.9164343,
		lng: -83.3977101
	}
};
var monroe_wi = {
	name: "Monroe, WI",
	value: {
		lat: 42.60111939999999,
		lng: -89.6384532
	}
};
var montgomery_al = {
	name: "Montgomery, AL",
	value: {
		lat: 32.3668052,
		lng: -86.2999689
	}
};
var montrose_co = {
	name: "Montrose, CO",
	value: {
		lat: 38.4783198,
		lng: -107.8761738
	}
};
var morehead_city_nc = {
	name: "Morehead City, NC",
	value: {
		lat: 34.7229391,
		lng: -76.7260436
	}
};
var morgan_city_la = {
	name: "Morgan City, LA",
	value: {
		lat: 29.6993748,
		lng: -91.20676999999999
	}
};
var morgantown_wv = {
	name: "Morgantown, WV",
	value: {
		lat: 39.629526,
		lng: -79.95589679999999
	}
};
var morristown_tn = {
	name: "Morristown, TN",
	value: {
		lat: 36.2139814,
		lng: -83.29489219999999
	}
};
var moscow_id = {
	name: "Moscow, ID",
	value: {
		lat: 46.73238749999999,
		lng: -117.0001651
	}
};
var moses_lake_wa = {
	name: "Moses Lake, WA",
	value: {
		lat: 47.1301417,
		lng: -119.2780771
	}
};
var moultrie_ga = {
	name: "Moultrie, GA",
	value: {
		lat: 31.1799407,
		lng: -83.7888387
	}
};
var mount_airy_nc = {
	name: "Mount Airy, NC",
	value: {
		lat: 36.4993007,
		lng: -80.6072858
	}
};
var mount_pleasant_mi = {
	name: "Mount Pleasant, MI",
	value: {
		lat: 43.59780749999999,
		lng: -84.7675139
	}
};
var mount_pleasant_tx = {
	name: "Mount Pleasant, TX",
	value: {
		lat: 33.1567863,
		lng: -94.96826899999999
	}
};
var mount_sterling_ky = {
	name: "Mount Sterling, KY",
	value: {
		lat: 38.0564679,
		lng: -83.9432556
	}
};
var mount_vernon_il = {
	name: "Mount Vernon, IL",
	value: {
		lat: 38.3172714,
		lng: -88.9031201
	}
};
var mount_vernon_oh = {
	name: "Mount Vernon, OH",
	value: {
		lat: 40.3933956,
		lng: -82.4857181
	}
};
var mount_vernon_anacortes_wa = {
	name: "Mount Vernon-Anacortes, WA",
	value: {
		lat: 48.421216,
		lng: -122.3340474
	}
};
var mountain_home_ar = {
	name: "Mountain Home, AR",
	value: {
		lat: 36.3353949,
		lng: -92.381346
	}
};
var mountain_home_id = {
	name: "Mountain Home, ID",
	value: {
		lat: 43.1329504,
		lng: -115.6911975
	}
};
var muncie_in = {
	name: "Muncie, IN",
	value: {
		lat: 40.1933767,
		lng: -85.3863599
	}
};
var murray_ky = {
	name: "Murray, KY",
	value: {
		lat: 36.6103334,
		lng: -88.31476099999999
	}
};
var muscatine_ia = {
	name: "Muscatine, IA",
	value: {
		lat: 41.424473,
		lng: -91.0432051
	}
};
var muskegon_norton_shores_mi = {
	name: "Muskegon-Norton Shores, MI",
	value: {
		lat: 43.2341813,
		lng: -86.24839209999999
	}
};
var muskogee_ok = {
	name: "Muskogee, OK",
	value: {
		lat: 35.7478769,
		lng: -95.3696909
	}
};
var myrtle_beach_conway_north_myrtle_beach_sc = {
	name: "Myrtle Beach-Conway-North Myrtle Beach, SC",
	value: {
		lat: 33.6890603,
		lng: -78.8866943
	}
};
var nacogdoches_tx = {
	name: "Nacogdoches, TX",
	value: {
		lat: 31.6035129,
		lng: -94.6554874
	}
};
var napa_ca = {
	name: "Napa, CA",
	value: {
		lat: 38.2975381,
		lng: -122.286865
	}
};
var naples_marco_island_fl = {
	name: "Naples-Marco Island, FL",
	value: {
		lat: 26.1420358,
		lng: -81.7948103
	}
};
var nashville_davidson_murfreesboro_franklin_tn = {
	name: "Nashville-Davidson--Murfreesboro--Franklin, TN",
	value: {
		lat: 36.1626638,
		lng: -86.7816016
	}
};
var natchez_ms_la = {
	name: "Natchez, MS-LA",
	value: {
		lat: 31.5604442,
		lng: -91.40317100000001
	}
};
var natchitoches_la = {
	name: "Natchitoches, LA",
	value: {
		lat: 31.7607195,
		lng: -93.08627489999999
	}
};
var new_bern_nc = {
	name: "New Bern, NC",
	value: {
		lat: 35.108493,
		lng: -77.04411429999999
	}
};
var new_castle_in = {
	name: "New Castle, IN",
	value: {
		lat: 39.928935,
		lng: -85.3702476
	}
};
var new_castle_pa = {
	name: "New Castle, PA",
	value: {
		lat: 41.0036719,
		lng: -80.34700900000001
	}
};
var new_haven_milford_ct = {
	name: "New Haven-Milford, CT",
	value: {
		lat: 41.308274,
		lng: -72.9278835
	}
};
var new_iberia_la = {
	name: "New Iberia, LA",
	value: {
		lat: 30.0035365,
		lng: -91.81872849999999
	}
};
var new_orleans_metairie_kenner_la = {
	name: "New Orleans-Metairie-Kenner, LA",
	value: {
		lat: 29.95106579999999,
		lng: -90.0715323
	}
};
var new_philadelphia_dover_oh = {
	name: "New Philadelphia-Dover, OH",
	value: {
		lat: 40.4897871,
		lng: -81.4456706
	}
};
var new_ulm_mn = {
	name: "New Ulm, MN",
	value: {
		lat: 44.3144394,
		lng: -94.45930179999999
	}
};
var new_york_northern_new_jersey_long_island_ny_nj_pa = {
	name: "New York-Northern New Jersey-Long Island, NY-NJ-PA",
	value: {
		lat: 40.7127837,
		lng: -74.0059413
	}
};
var newberry_sc = {
	name: "Newberry, SC",
	value: {
		lat: 34.2745833,
		lng: -81.6187178
	}
};
var newport_tn = {
	name: "Newport, TN",
	value: {
		lat: 35.9670412,
		lng: -83.1876578
	}
};
var newton_ia = {
	name: "Newton, IA",
	value: {
		lat: 41.7033177,
		lng: -93.05735330000002
	}
};
var niles_benton_harbor_mi = {
	name: "Niles-Benton Harbor, MI",
	value: {
		lat: 41.8297694,
		lng: -86.2541768
	}
};
var nogales_az = {
	name: "Nogales, AZ",
	value: {
		lat: 31.3403775,
		lng: -110.9342532
	}
};
var norfolk_ne = {
	name: "Norfolk, NE",
	value: {
		lat: 42.03272339999999,
		lng: -97.41375529999999
	}
};
var north_platte_ne = {
	name: "North Platte, NE",
	value: {
		lat: 41.1402759,
		lng: -100.7601454
	}
};
var north_vernon_in = {
	name: "North Vernon, IN",
	value: {
		lat: 39.006165,
		lng: -85.6235796
	}
};
var north_wilkesboro_nc = {
	name: "North Wilkesboro, NC",
	value: {
		lat: 36.1584651,
		lng: -81.1475841
	}
};
var norwalk_oh = {
	name: "Norwalk, OH",
	value: {
		lat: 41.24255309999999,
		lng: -82.6157331
	}
};
var norwich_new_london_ct = {
	name: "Norwich-New London, CT",
	value: {
		lat: 41.5242649,
		lng: -72.07591049999999
	}
};
var oak_harbor_wa = {
	name: "Oak Harbor, WA",
	value: {
		lat: 48.2931559,
		lng: -122.6432245
	}
};
var oak_hill_wv = {
	name: "Oak Hill, WV",
	value: {
		lat: 37.9723339,
		lng: -81.1487135
	}
};
var ocala_fl = {
	name: "Ocala, FL",
	value: {
		lat: 29.1871986,
		lng: -82.14009229999999
	}
};
var ocean_city_nj = {
	name: "Ocean City, NJ",
	value: {
		lat: 39.2776156,
		lng: -74.5746001
	}
};
var ocean_pines_md = {
	name: "Ocean Pines, MD",
	value: {
		lat: 38.395392,
		lng: -75.15574149999999
	}
};
var odessa_tx = {
	name: "Odessa, TX",
	value: {
		lat: 31.8456816,
		lng: -102.3676431
	}
};
var ogden_clearfield_ut = {
	name: "Ogden-Clearfield, UT",
	value: {
		lat: 41.223,
		lng: -111.9738304
	}
};
var ogdensburg_massena_ny = {
	name: "Ogdensburg-Massena, NY",
	value: {
		lat: 44.6942291,
		lng: -75.48633640000001
	}
};
var oil_city_pa = {
	name: "Oil City, PA",
	value: {
		lat: 41.4339484,
		lng: -79.7064413
	}
};
var okeechobee_fl = {
	name: "Okeechobee, FL",
	value: {
		lat: 27.2439349,
		lng: -80.82978279999999
	}
};
var oklahoma_city_ok = {
	name: "Oklahoma City, OK",
	value: {
		lat: 35.4675602,
		lng: -97.5164276
	}
};
var olean_ny = {
	name: "Olean, NY",
	value: {
		lat: 42.083639,
		lng: -78.42992699999999
	}
};
var olympia_wa = {
	name: "Olympia, WA",
	value: {
		lat: 47.0378741,
		lng: -122.9006951
	}
};
var omaha_council_bluffs_ne_ia = {
	name: "Omaha-Council Bluffs, NE-IA",
	value: {
		lat: 41.2523634,
		lng: -95.99798829999999
	}
};
var oneonta_ny = {
	name: "Oneonta, NY",
	value: {
		lat: 42.4528571,
		lng: -75.0637746
	}
};
var ontario_or_id = {
	name: "Ontario, OR-ID",
	value: {
		lat: 44.0265525,
		lng: -116.9629378
	}
};
var opelousas_eunice_la = {
	name: "Opelousas-Eunice, LA",
	value: {
		lat: 30.5335302,
		lng: -92.081509
	}
};
var orangeburg_sc = {
	name: "Orangeburg, SC",
	value: {
		lat: 33.4918203,
		lng: -80.8556476
	}
};
var orlando_kissimmee_fl = {
	name: "Orlando-Kissimmee, FL",
	value: {
		lat: 28.5383355,
		lng: -81.3792365
	}
};
var oshkosh_neenah_wi = {
	name: "Oshkosh-Neenah, WI",
	value: {
		lat: 44.0247062,
		lng: -88.5426136
	}
};
var oskaloosa_ia = {
	name: "Oskaloosa, IA",
	value: {
		lat: 41.2916728,
		lng: -92.6493595
	}
};
var ottawa_streator_il = {
	name: "Ottawa-Streator, IL",
	value: {
		lat: 41.3455892,
		lng: -88.8425769
	}
};
var ottumwa_ia = {
	name: "Ottumwa, IA",
	value: {
		lat: 41.01602930000001,
		lng: -92.40830220000001
	}
};
var owatonna_mn = {
	name: "Owatonna, MN",
	value: {
		lat: 44.0855572,
		lng: -93.2259349
	}
};
var owensboro_ky = {
	name: "Owensboro, KY",
	value: {
		lat: 37.7719074,
		lng: -87.1111676
	}
};
var owosso_mi = {
	name: "Owosso, MI",
	value: {
		lat: 42.9978049,
		lng: -84.1766358
	}
};
var oxford_ms = {
	name: "Oxford, MS",
	value: {
		lat: 34.3664951,
		lng: -89.5192484
	}
};
var oxnard_thousand_oaks_ventura_ca = {
	name: "Oxnard-Thousand Oaks-Ventura, CA",
	value: {
		lat: 34.1975048,
		lng: -119.1770516
	}
};
var paducah_ky_il = {
	name: "Paducah, KY-IL",
	value: {
		lat: 37.0833893,
		lng: -88.6000478
	}
};
var pahrump_nv = {
	name: "Pahrump, NV",
	value: {
		lat: 36.2082943,
		lng: -115.9839147
	}
};
var palatka_fl = {
	name: "Palatka, FL",
	value: {
		lat: 29.6485801,
		lng: -81.6375819
	}
};
var palestine_tx = {
	name: "Palestine, TX",
	value: {
		lat: 31.7621153,
		lng: -95.6307891
	}
};
var palm_bay_melbourne_titusville_fl = {
	name: "Palm Bay-Melbourne-Titusville, FL",
	value: {
		lat: 28.0344621,
		lng: -80.5886646
	}
};
var palm_coast_fl = {
	name: "Palm Coast, FL",
	value: {
		lat: 29.5844524,
		lng: -81.20786989999999
	}
};
var pampa_tx = {
	name: "Pampa, TX",
	value: {
		lat: 35.5361559,
		lng: -100.9598709
	}
};
var panama_city_lynn_haven_fl = {
	name: "Panama City-Lynn Haven, FL",
	value: {
		lat: 30.1588129,
		lng: -85.6602058
	}
};
var paragould_ar = {
	name: "Paragould, AR",
	value: {
		lat: 36.0584021,
		lng: -90.4973286
	}
};
var paris_tn = {
	name: "Paris, TN",
	value: {
		lat: 36.3020023,
		lng: -88.32671069999999
	}
};
var paris_tx = {
	name: "Paris, TX",
	value: {
		lat: 33.6609389,
		lng: -95.55551299999999
	}
};
var parkersburg_marietta_vienna_wv_oh = {
	name: "Parkersburg-Marietta-Vienna, WV-OH",
	value: {
		lat: 39.2667418,
		lng: -81.56151349999999
	}
};
var parsons_ks = {
	name: "Parsons, KS",
	value: {
		lat: 37.34033840000001,
		lng: -95.2610838
	}
};
var pascagoula_ms = {
	name: "Pascagoula, MS",
	value: {
		lat: 30.3657552,
		lng: -88.5561272
	}
};
var payson_az = {
	name: "Payson, AZ",
	value: {
		lat: 34.2308684,
		lng: -111.3251355
	}
};
var pecos_tx = {
	name: "Pecos, TX",
	value: {
		lat: 31.4229124,
		lng: -103.4932293
	}
};
var pella_ia = {
	name: "Pella, IA",
	value: {
		lat: 41.4080327,
		lng: -92.91640500000001
	}
};
var pendleton_hermiston_or = {
	name: "Pendleton-Hermiston, OR",
	value: {
		lat: 45.672075,
		lng: -118.7885967
	}
};
var pensacola_ferry_pass_brent_fl = {
	name: "Pensacola-Ferry Pass-Brent, FL",
	value: {
		lat: 30.42130899999999,
		lng: -87.2169149
	}
};
var peoria_il = {
	name: "Peoria, IL",
	value: {
		lat: 40.6936488,
		lng: -89.5889864
	}
};
var peru_in = {
	name: "Peru, IN",
	value: {
		lat: 40.7536528,
		lng: -86.0688811
	}
};
var philadelphia_camden_wilmington_pa_nj_de_md = {
	name: "Philadelphia-Camden-Wilmington, PA-NJ-DE-MD",
	value: {
		lat: 39.9525839,
		lng: -75.1652215
	}
};
var phoenix_lake_cedar_ridge_ca = {
	name: "Phoenix Lake-Cedar Ridge, CA",
	value: {
		lat: 39.3754055,
		lng: -120.5225122
	}
};
var phoenix_mesa_scottsdale_az = {
	name: "Phoenix-Mesa-Scottsdale, AZ",
	value: {
		lat: 33.4483771,
		lng: -112.0740373
	}
};
var picayune_ms = {
	name: "Picayune, MS",
	value: {
		lat: 30.5254692,
		lng: -89.67950839999999
	}
};
var pierre_part_la = {
	name: "Pierre Part, LA",
	value: {
		lat: 29.9652016,
		lng: -91.2031593
	}
};
var pierre_sd = {
	name: "Pierre, SD",
	value: {
		lat: 44.3683156,
		lng: -100.3509665
	}
};
var pine_bluff_ar = {
	name: "Pine Bluff, AR",
	value: {
		lat: 34.2284312,
		lng: -92.00319549999999
	}
};
var pittsburg_ks = {
	name: "Pittsburg, KS",
	value: {
		lat: 37.410884,
		lng: -94.70496
	}
};
var pittsburgh_pa = {
	name: "Pittsburgh, PA",
	value: {
		lat: 40.44062479999999,
		lng: -79.9958864
	}
};
var pittsfield_ma = {
	name: "Pittsfield, MA",
	value: {
		lat: 42.4500845,
		lng: -73.2453824
	}
};
var plainview_tx = {
	name: "Plainview, TX",
	value: {
		lat: 34.1847936,
		lng: -101.7068417
	}
};
var platteville_wi = {
	name: "Platteville, WI",
	value: {
		lat: 42.73416,
		lng: -90.4784621
	}
};
var plattsburgh_ny = {
	name: "Plattsburgh, NY",
	value: {
		lat: 44.6994873,
		lng: -73.4529124
	}
};
var plymouth_in = {
	name: "Plymouth, IN",
	value: {
		lat: 41.3436554,
		lng: -86.3097278
	}
};
var pocatello_id = {
	name: "Pocatello, ID",
	value: {
		lat: 42.8713032,
		lng: -112.4455344
	}
};
var point_pleasant_wv_oh = {
	name: "Point Pleasant, WV-OH",
	value: {
		lat: 38.8445251,
		lng: -82.1370889
	}
};
var ponca_city_ok = {
	name: "Ponca City, OK",
	value: {
		lat: 36.706981,
		lng: -97.0855948
	}
};
var ponce_pr = {
	name: "Ponce, PR",
	value: {
		lat: 18.01108,
		lng: -66.61406
	}
};
var pontiac_il = {
	name: "Pontiac, IL",
	value: {
		lat: 40.8808666,
		lng: -88.62978389999999
	}
};
var poplar_bluff_mo = {
	name: "Poplar Bluff, MO",
	value: {
		lat: 36.7569994,
		lng: -90.392888
	}
};
var port_angeles_wa = {
	name: "Port Angeles, WA",
	value: {
		lat: 48.118146,
		lng: -123.4307413
	}
};
var port_st_lucie_fl = {
	name: "Port St. Lucie, FL",
	value: {
		lat: 27.2730492,
		lng: -80.3582261
	}
};
var portales_nm = {
	name: "Portales, NM",
	value: {
		lat: 34.1861922,
		lng: -103.3343978
	}
};
var portland_south_portland_biddeford_me = {
	name: "Portland-South Portland-Biddeford, ME",
	value: {
		lat: 43.66147100000001,
		lng: -70.2553259
	}
};
var portland_vancouver_beaverton_or_wa = {
	name: "Portland-Vancouver-Beaverton, OR-WA",
	value: {
		lat: 45.5230622,
		lng: -122.6764816
	}
};
var portsmouth_oh = {
	name: "Portsmouth, OH",
	value: {
		lat: 38.7317431,
		lng: -82.9976742
	}
};
var pottsville_pa = {
	name: "Pottsville, PA",
	value: {
		lat: 40.6856456,
		lng: -76.195499
	}
};
var poughkeepsie_newburgh_middletown_ny = {
	name: "Poughkeepsie-Newburgh-Middletown, NY",
	value: {
		lat: 41.7003713,
		lng: -73.9209701
	}
};
var prescott_az = {
	name: "Prescott, AZ",
	value: {
		lat: 34.5400242,
		lng: -112.4685025
	}
};
var price_ut = {
	name: "Price, UT",
	value: {
		lat: 39.5994095,
		lng: -110.8107148
	}
};
var prineville_or = {
	name: "Prineville, OR",
	value: {
		lat: 44.2998485,
		lng: -120.8344664
	}
};
var providence_new_bedford_fall_river_ri_ma = {
	name: "Providence-New Bedford-Fall River, RI-MA",
	value: {
		lat: 41.8239891,
		lng: -71.4128343
	}
};
var provo_orem_ut = {
	name: "Provo-Orem, UT",
	value: {
		lat: 40.2338438,
		lng: -111.6585337
	}
};
var pueblo_co = {
	name: "Pueblo, CO",
	value: {
		lat: 38.2544472,
		lng: -104.6091409
	}
};
var pullman_wa = {
	name: "Pullman, WA",
	value: {
		lat: 46.7297771,
		lng: -117.1817377
	}
};
var punta_gorda_fl = {
	name: "Punta Gorda, FL",
	value: {
		lat: 26.9297836,
		lng: -82.0453664
	}
};
var quincy_il_mo = {
	name: "Quincy, IL-MO",
	value: {
		lat: 39.9356016,
		lng: -91.4098726
	}
};
var racine_wi = {
	name: "Racine, WI",
	value: {
		lat: 42.7261309,
		lng: -87.78285230000002
	}
};
var raleigh_cary_nc = {
	name: "Raleigh-Cary, NC",
	value: {
		lat: 35.7795897,
		lng: -78.6381787
	}
};
var rapid_city_sd = {
	name: "Rapid City, SD",
	value: {
		lat: 44.0805434,
		lng: -103.2310149
	}
};
var raymondville_tx = {
	name: "Raymondville, TX",
	value: {
		lat: 26.4814565,
		lng: -97.783051
	}
};
var reading_pa = {
	name: "Reading, PA",
	value: {
		lat: 40.3356483,
		lng: -75.9268747
	}
};
var red_bluff_ca = {
	name: "Red Bluff, CA",
	value: {
		lat: 40.1784886,
		lng: -122.2358302
	}
};
var red_wing_mn = {
	name: "Red Wing, MN",
	value: {
		lat: 44.5660691,
		lng: -92.5369563
	}
};
var redding_ca = {
	name: "Redding, CA",
	value: {
		lat: 40.5865396,
		lng: -122.3916754
	}
};
var reno_sparks_nv = {
	name: "Reno-Sparks, NV",
	value: {
		lat: 39.5296329,
		lng: -119.8138027
	}
};
var rexburg_id = {
	name: "Rexburg, ID",
	value: {
		lat: 43.8231096,
		lng: -111.7924237
	}
};
var richmond_in = {
	name: "Richmond, IN",
	value: {
		lat: 39.8289369,
		lng: -84.8902382
	}
};
var richmond_va = {
	name: "Richmond, VA",
	value: {
		lat: 37.5407246,
		lng: -77.4360481
	}
};
var richmond_berea_ky = {
	name: "Richmond Berea, KY",
	value: {
		lat: 37.6921707,
		lng: -84.2594969
	}
};
var rio_grande_city_roma_tx = {
	name: "Rio Grande City-Roma, TX",
	value: {
		lat: 26.3797874,
		lng: -98.8203046
	}
};
var riverside_san_bernardino_ontario_ca = {
	name: "Riverside-San Bernardino-Ontario, CA",
	value: {
		lat: 33.9533487,
		lng: -117.3961564
	}
};
var riverton_wy = {
	name: "Riverton, WY",
	value: {
		lat: 43.0249592,
		lng: -108.3801036
	}
};
var roanoke_rapids_nc = {
	name: "Roanoke Rapids, NC",
	value: {
		lat: 36.4615395,
		lng: -77.6541464
	}
};
var roanoke_va = {
	name: "Roanoke, VA",
	value: {
		lat: 37.2709704,
		lng: -79.9414266
	}
};
var rochelle_il = {
	name: "Rochelle, IL",
	value: {
		lat: 41.9239178,
		lng: -89.0687073
	}
};
var rochester_mn = {
	name: "Rochester, MN",
	value: {
		lat: 44.0121221,
		lng: -92.4801989
	}
};
var rochester_ny = {
	name: "Rochester, NY",
	value: {
		lat: 43.16103,
		lng: -77.6109219
	}
};
var rock_springs_wy = {
	name: "Rock Springs, WY",
	value: {
		lat: 41.58746439999999,
		lng: -109.2029043
	}
};
var rockford_il = {
	name: "Rockford, IL",
	value: {
		lat: 42.2711311,
		lng: -89.0939952
	}
};
var rockingham_nc = {
	name: "Rockingham, NC",
	value: {
		lat: 34.9393201,
		lng: -79.7739457
	}
};
var rockland_me = {
	name: "Rockland, ME",
	value: {
		lat: 44.1036914,
		lng: -69.1089293
	}
};
var rocky_mount_nc = {
	name: "Rocky Mount, NC",
	value: {
		lat: 35.9382103,
		lng: -77.7905339
	}
};
var rolla_mo = {
	name: "Rolla, MO",
	value: {
		lat: 37.948544,
		lng: -91.7715303
	}
};
var rome_ga = {
	name: "Rome, GA",
	value: {
		lat: 34.257038,
		lng: -85.1646726
	}
};
var roseburg_or = {
	name: "Roseburg, OR",
	value: {
		lat: 43.216505,
		lng: -123.3417381
	}
};
var roswell_nm = {
	name: "Roswell, NM",
	value: {
		lat: 33.3942655,
		lng: -104.5230242
	}
};
var ruidoso_nm = {
	name: "Ruidoso, NM",
	value: {
		lat: 33.3672525,
		lng: -105.6588485
	}
};
var russellville_ar = {
	name: "Russellville, AR",
	value: {
		lat: 35.2784173,
		lng: -93.1337856
	}
};
var ruston_la = {
	name: "Ruston, LA",
	value: {
		lat: 32.5232053,
		lng: -92.63792699999999
	}
};
var rutland_vt = {
	name: "Rutland, VT",
	value: {
		lat: 43.6106237,
		lng: -72.9726065
	}
};
var sacramento_arden_arcade_roseville_ca = {
	name: "Sacramento--Arden-Arcade--Roseville, CA",
	value: {
		lat: 38.5815719,
		lng: -121.4943996
	}
};
var safford_az = {
	name: "Safford, AZ",
	value: {
		lat: 32.8339546,
		lng: -109.70758
	}
};
var saginaw_saginaw_township_north_mi = {
	name: "Saginaw-Saginaw Township North, MI",
	value: {
		lat: 43.4194699,
		lng: -83.9508068
	}
};
var salem_or = {
	name: "Salem, OR",
	value: {
		lat: 44.9428975,
		lng: -123.0350963
	}
};
var salina_ks = {
	name: "Salina, KS",
	value: {
		lat: 38.8402805,
		lng: -97.61142369999999
	}
};
var salinas_ca = {
	name: "Salinas, CA",
	value: {
		lat: 36.6777372,
		lng: -121.6555013
	}
};
var salisbury_md = {
	name: "Salisbury, MD",
	value: {
		lat: 38.3606736,
		lng: -75.5993692
	}
};
var salisbury_nc = {
	name: "Salisbury, NC",
	value: {
		lat: 35.6709727,
		lng: -80.4742261
	}
};
var salt_lake_city_ut = {
	name: "Salt Lake City, UT",
	value: {
		lat: 40.7607793,
		lng: -111.8910474
	}
};
var san_angelo_tx = {
	name: "San Angelo, TX",
	value: {
		lat: 31.4637723,
		lng: -100.4370375
	}
};
var san_antonio_tx = {
	name: "San Antonio, TX",
	value: {
		lat: 29.4241219,
		lng: -98.49362819999999
	}
};
var san_diego_carlsbad_san_marcos_ca = {
	name: "San Diego-Carlsbad-San Marcos, CA",
	value: {
		lat: 32.715738,
		lng: -117.1610838
	}
};
var san_francisco_oakland_fremont_ca = {
	name: "San Francisco-Oakland-Fremont, CA",
	value: {
		lat: 37.7749295,
		lng: -122.4194155
	}
};
var san_german_cabo_rojo_pr = {
	name: "San German-Cabo Rojo, PR",
	value: {
		lat: 18.080708,
		lng: -67.041107
	}
};
var san_jose_sunnyvale_santa_clara_ca = {
	name: "San Jose-Sunnyvale-Santa Clara, CA",
	value: {
		lat: 37.3382082,
		lng: -121.8863286
	}
};
var san_juan_caguas_guaynabo_pr = {
	name: "San Juan-Caguas-Guaynabo, PR",
	value: {
		lat: 18.466333,
		lng: -66.105721
	}
};
var san_luis_obispo_paso_robles_ca = {
	name: "San Luis Obispo-Paso Robles, CA",
	value: {
		lat: 35.2827524,
		lng: -120.6596156
	}
};
var sandusky_oh = {
	name: "Sandusky, OH",
	value: {
		lat: 41.4489396,
		lng: -82.7079605
	}
};
var sanford_nc = {
	name: "Sanford, NC",
	value: {
		lat: 35.4798757,
		lng: -79.1802994
	}
};
var santa_barbara_santa_maria_goleta_ca = {
	name: "Santa Barbara-Santa Maria-Goleta, CA",
	value: {
		lat: 34.4208305,
		lng: -119.6981901
	}
};
var santa_cruz_watsonville_ca = {
	name: "Santa Cruz-Watsonville, CA",
	value: {
		lat: 36.9741171,
		lng: -122.0307963
	}
};
var santa_fe_nm = {
	name: "Santa Fe, NM",
	value: {
		lat: 35.6869752,
		lng: -105.937799
	}
};
var santa_isabel_pr = {
	name: "Santa Isabel, PR",
	value: {
		lat: 17.985792,
		lng: -66.391441
	}
};
var santa_rosa_petaluma_ca = {
	name: "Santa Rosa-Petaluma, CA",
	value: {
		lat: 38.440429,
		lng: -122.7140548
	}
};
var sarasota_bradenton_venice_fl = {
	name: "Sarasota-Bradenton-Venice, FL",
	value: {
		lat: 27.3364347,
		lng: -82.53065269999999
	}
};
var sault_ste_marie_mi = {
	name: "Sault Ste. Marie, MI",
	value: {
		lat: 46.4952996,
		lng: -84.3453169
	}
};
var savannah_ga = {
	name: "Savannah, GA",
	value: {
		lat: 32.0835407,
		lng: -81.09983419999999
	}
};
var sayre_pa = {
	name: "Sayre, PA",
	value: {
		lat: 41.9789631,
		lng: -76.51549899999999
	}
};
var scottsbluff_ne = {
	name: "Scottsbluff, NE",
	value: {
		lat: 41.8666341,
		lng: -103.6671662
	}
};
var scottsboro_al = {
	name: "Scottsboro, AL",
	value: {
		lat: 34.6723069,
		lng: -86.03414629999999
	}
};
var scottsburg_in = {
	name: "Scottsburg, IN",
	value: {
		lat: 38.685614,
		lng: -85.7702451
	}
};
var scranton_wilkes_barre_pa = {
	name: "Scranton--Wilkes-Barre, PA",
	value: {
		lat: 41.408969,
		lng: -75.66241219999999
	}
};
var seaford_de = {
	name: "Seaford, DE",
	value: {
		lat: 38.6412256,
		lng: -75.6110381
	}
};
var searcy_ar = {
	name: "Searcy, AR",
	value: {
		lat: 35.2468204,
		lng: -91.73368459999999
	}
};
var seattle_tacoma_bellevue_wa = {
	name: "Seattle-Tacoma-Bellevue, WA",
	value: {
		lat: 47.6062095,
		lng: -122.3320708
	}
};
var sebastian_vero_beach_fl = {
	name: "Sebastian-Vero Beach, FL",
	value: {
		lat: 27.816415,
		lng: -80.4706078
	}
};
var sebring_fl = {
	name: "Sebring, FL",
	value: {
		lat: 27.495592,
		lng: -81.440907
	}
};
var sedalia_mo = {
	name: "Sedalia, MO",
	value: {
		lat: 38.7044609,
		lng: -93.2282613
	}
};
var selinsgrove_pa = {
	name: "Selinsgrove, PA",
	value: {
		lat: 40.7989735,
		lng: -76.8621935
	}
};
var selma_al = {
	name: "Selma, AL",
	value: {
		lat: 32.4073589,
		lng: -87.02110069999999
	}
};
var seneca_falls_ny = {
	name: "Seneca Falls, NY",
	value: {
		lat: 42.9106219,
		lng: -76.7966215
	}
};
var seneca_sc = {
	name: "Seneca, SC",
	value: {
		lat: 34.6856555,
		lng: -82.9532036
	}
};
var sevierville_tn = {
	name: "Sevierville, TN",
	value: {
		lat: 35.8681455,
		lng: -83.56183500000002
	}
};
var seymour_in = {
	name: "Seymour, IN",
	value: {
		lat: 38.9592201,
		lng: -85.8902547
	}
};
var shawnee_ok = {
	name: "Shawnee, OK",
	value: {
		lat: 35.3272928,
		lng: -96.9253004
	}
};
var sheboygan_wi = {
	name: "Sheboygan, WI",
	value: {
		lat: 43.7508284,
		lng: -87.71453
	}
};
var shelby_nc = {
	name: "Shelby, NC",
	value: {
		lat: 35.2923513,
		lng: -81.5356463
	}
};
var shelbyville_tn = {
	name: "Shelbyville, TN",
	value: {
		lat: 35.483406,
		lng: -86.46027169999999
	}
};
var shelton_wa = {
	name: "Shelton, WA",
	value: {
		lat: 47.2150945,
		lng: -123.1007066
	}
};
var sheridan_wy = {
	name: "Sheridan, WY",
	value: {
		lat: 44.7971939,
		lng: -106.9561791
	}
};
var sherman_denison_tx = {
	name: "Sherman-Denison, TX",
	value: {
		lat: 33.6356618,
		lng: -96.6088805
	}
};
var shreveport_bossier_city_la = {
	name: "Shreveport-Bossier City, LA",
	value: {
		lat: 32.5251516,
		lng: -93.7501789
	}
};
var sidney_oh = {
	name: "Sidney, OH",
	value: {
		lat: 40.2842164,
		lng: -84.1554987
	}
};
var sierra_vista_douglas_az = {
	name: "Sierra Vista-Douglas, AZ",
	value: {
		lat: 31.5455001,
		lng: -110.2772856
	}
};
var sikeston_mo = {
	name: "Sikeston, MO",
	value: {
		lat: 36.876719,
		lng: -89.5878579
	}
};
var silver_city_nm = {
	name: "Silver City, NM",
	value: {
		lat: 32.770075,
		lng: -108.280326
	}
};
var silverthorne_co = {
	name: "Silverthorne, CO",
	value: {
		lat: 39.6296191,
		lng: -106.0712941
	}
};
var sioux_city_ia_ne_sd = {
	name: "Sioux City, IA-NE-SD",
	value: {
		lat: 42.4999942,
		lng: -96.40030689999999
	}
};
var sioux_falls_sd = {
	name: "Sioux Falls, SD",
	value: {
		lat: 43.5445959,
		lng: -96.73110340000001
	}
};
var snyder_tx = {
	name: "Snyder, TX",
	value: {
		lat: 32.7178862,
		lng: -100.9176184
	}
};
var somerset_ky = {
	name: "Somerset, KY",
	value: {
		lat: 37.0920222,
		lng: -84.6041084
	}
};
var somerset_pa = {
	name: "Somerset, PA",
	value: {
		lat: 40.008411,
		lng: -79.0780831
	}
};
var south_bend_mishawaka_in_mi = {
	name: "South Bend-Mishawaka, IN-MI",
	value: {
		lat: 41.6763545,
		lng: -86.25198979999999
	}
};
var southern_pines_pinehurst_nc = {
	name: "Southern Pines-Pinehurst, NC",
	value: {
		lat: 35.1740471,
		lng: -79.3922539
	}
};
var spartanburg_sc = {
	name: "Spartanburg, SC",
	value: {
		lat: 34.9495672,
		lng: -81.9320482
	}
};
var spearfish_sd = {
	name: "Spearfish, SD",
	value: {
		lat: 44.4908172,
		lng: -103.8593698
	}
};
var spencer_ia = {
	name: "Spencer, IA",
	value: {
		lat: 43.1450748,
		lng: -95.144318
	}
};
var spirit_lake_ia = {
	name: "Spirit Lake, IA",
	value: {
		lat: 43.4226192,
		lng: -95.1022313
	}
};
var spokane_wa = {
	name: "Spokane, WA",
	value: {
		lat: 47.6587802,
		lng: -117.4260466
	}
};
var springfield_il = {
	name: "Springfield, IL",
	value: {
		lat: 39.78172130000001,
		lng: -89.6501481
	}
};
var springfield_ma = {
	name: "Springfield, MA",
	value: {
		lat: 42.1014831,
		lng: -72.589811
	}
};
var springfield_mo = {
	name: "Springfield, MO",
	value: {
		lat: 37.2089572,
		lng: -93.29229889999999
	}
};
var springfield_oh = {
	name: "Springfield, OH",
	value: {
		lat: 39.9242266,
		lng: -83.8088171
	}
};
var st_cloud_mn = {
	name: "St. Cloud, MN",
	value: {
		lat: 45.5579451,
		lng: -94.16324039999999
	}
};
var st_george_ut = {
	name: "St. George, UT",
	value: {
		lat: 37.0965278,
		lng: -113.5684164
	}
};
var st_joseph_mo_ks = {
	name: "St. Joseph, MO-KS",
	value: {
		lat: 39.7674578,
		lng: -94.84668099999999
	}
};
var st_louis_mo_il = {
	name: "St. Louis, MO-IL",
	value: {
		lat: 38.6270025,
		lng: -90.19940419999999
	}
};
var st_marys_ga = {
	name: "St. Marys, GA",
	value: {
		lat: 30.7478954,
		lng: -81.57061089999999
	}
};
var st_marys_pa = {
	name: "St. Marys, PA",
	value: {
		lat: 41.42737380000001,
		lng: -78.5609398
	}
};
var starkville_ms = {
	name: "Starkville, MS",
	value: {
		lat: 33.4503998,
		lng: -88.81838719999999
	}
};
var state_college_pa = {
	name: "State College, PA",
	value: {
		lat: 40.7933949,
		lng: -77.8600012
	}
};
var statesboro_ga = {
	name: "Statesboro, GA",
	value: {
		lat: 32.4487876,
		lng: -81.7831674
	}
};
var statesville_mooresville_nc = {
	name: "Statesville-Mooresville, NC",
	value: {
		lat: 35.7826363,
		lng: -80.8872959
	}
};
var staunton_waynesboro_va = {
	name: "Staunton-Waynesboro, VA",
	value: {
		lat: 38.149576,
		lng: -79.0716958
	}
};
var stephenville_tx = {
	name: "Stephenville, TX",
	value: {
		lat: 32.2206958,
		lng: -98.2022633
	}
};
var sterling_co = {
	name: "Sterling, CO",
	value: {
		lat: 40.6255415,
		lng: -103.207709
	}
};
var sterling_il = {
	name: "Sterling, IL",
	value: {
		lat: 41.788642,
		lng: -89.69621939999999
	}
};
var stevens_point_wi = {
	name: "Stevens Point, WI",
	value: {
		lat: 44.52357920000001,
		lng: -89.574563
	}
};
var stillwater_ok = {
	name: "Stillwater, OK",
	value: {
		lat: 36.1156071,
		lng: -97.0583681
	}
};
var stockton_ca = {
	name: "Stockton, CA",
	value: {
		lat: 37.9577016,
		lng: -121.2907796
	}
};
var storm_lake_ia = {
	name: "Storm Lake, IA",
	value: {
		lat: 42.6430359,
		lng: -95.2019399
	}
};
var sturgis_mi = {
	name: "Sturgis, MI",
	value: {
		lat: 41.799217,
		lng: -85.41914820000001
	}
};
var sulphur_springs_tx = {
	name: "Sulphur Springs, TX",
	value: {
		lat: 33.1384479,
		lng: -95.6010668
	}
};
var summerville_ga = {
	name: "Summerville, GA",
	value: {
		lat: 34.480642,
		lng: -85.3477343
	}
};
var sumter_sc = {
	name: "Sumter, SC",
	value: {
		lat: 33.9204354,
		lng: -80.3414693
	}
};
var sunbury_pa = {
	name: "Sunbury, PA",
	value: {
		lat: 40.862585,
		lng: -76.79441039999999
	}
};
var susanville_ca = {
	name: "Susanville, CA",
	value: {
		lat: 40.4162842,
		lng: -120.6530063
	}
};
var sweetwater_tx = {
	name: "Sweetwater, TX",
	value: {
		lat: 32.4709519,
		lng: -100.4059384
	}
};
var syracuse_ny = {
	name: "Syracuse, NY",
	value: {
		lat: 43.0481221,
		lng: -76.14742439999999
	}
};
var tahlequah_ok = {
	name: "Tahlequah, OK",
	value: {
		lat: 35.91537,
		lng: -94.969956
	}
};
var talladega_sylacauga_al = {
	name: "Talladega-Sylacauga, AL",
	value: {
		lat: 33.4359416,
		lng: -86.1058048
	}
};
var tallahassee_fl = {
	name: "Tallahassee, FL",
	value: {
		lat: 30.4382559,
		lng: -84.28073289999999
	}
};
var tallulah_la = {
	name: "Tallulah, LA",
	value: {
		lat: 32.4084765,
		lng: -91.1867771
	}
};
var tampa_st_petersburg_clearwater_fl = {
	name: "Tampa-St. Petersburg-Clearwater, FL",
	value: {
		lat: 27.950575,
		lng: -82.4571776
	}
};
var taos_nm = {
	name: "Taos, NM",
	value: {
		lat: 36.4072485,
		lng: -105.5730665
	}
};
var taylorville_il = {
	name: "Taylorville, IL",
	value: {
		lat: 39.548935,
		lng: -89.294533
	}
};
var terre_haute_in = {
	name: "Terre Haute, IN",
	value: {
		lat: 39.4667034,
		lng: -87.41390919999999
	}
};
var texarkana_tx_texarkana_ar = {
	name: "Texarkana, TX-Texarkana, AR",
	value: {
		lat: 33.425125,
		lng: -94.04768820000001
	}
};
var the_villages_fl = {
	name: "The Villages, FL",
	value: {
		lat: 28.927019,
		lng: -82.0037608
	}
};
var thomaston_ga = {
	name: "Thomaston, GA",
	value: {
		lat: 32.8881879,
		lng: -84.3265854
	}
};
var thomasville_ga = {
	name: "Thomasville, GA",
	value: {
		lat: 30.8365815,
		lng: -83.9787808
	}
};
var thomasville_lexington_nc = {
	name: "Thomasville-Lexington, NC",
	value: {
		lat: 35.8826369,
		lng: -80.0819879
	}
};
var tiffin_oh = {
	name: "Tiffin, OH",
	value: {
		lat: 41.1144992,
		lng: -83.1779746
	}
};
var tifton_ga = {
	name: "Tifton, GA",
	value: {
		lat: 31.4504629,
		lng: -83.5084973
	}
};
var toccoa_ga = {
	name: "Toccoa, GA",
	value: {
		lat: 34.5773206,
		lng: -83.3323851
	}
};
var toledo_oh = {
	name: "Toledo, OH",
	value: {
		lat: 41.6639383,
		lng: -83.55521200000001
	}
};
var topeka_ks = {
	name: "Topeka, KS",
	value: {
		lat: 39.0558235,
		lng: -95.68901849999999
	}
};
var torrington_ct = {
	name: "Torrington, CT",
	value: {
		lat: 41.8003049,
		lng: -73.1211715
	}
};
var traverse_city_mi = {
	name: "Traverse City, MI",
	value: {
		lat: 44.7630567,
		lng: -85.62063169999999
	}
};
var trenton_ewing_nj = {
	name: "Trenton-Ewing, NJ",
	value: {
		lat: 40.2170534,
		lng: -74.7429384
	}
};
var troy_al = {
	name: "Troy, AL",
	value: {
		lat: 31.8087678,
		lng: -85.969951
	}
};
var truckee_grass_valley_ca = {
	name: "Truckee-Grass Valley, CA",
	value: {
		lat: 39.327962,
		lng: -120.1832533
	}
};
var tucson_az = {
	name: "Tucson, AZ",
	value: {
		lat: 32.2217429,
		lng: -110.926479
	}
};
var tullahoma_tn = {
	name: "Tullahoma, TN",
	value: {
		lat: 35.3620235,
		lng: -86.20943419999999
	}
};
var tulsa_ok = {
	name: "Tulsa, OK",
	value: {
		lat: 36.1539816,
		lng: -95.99277500000001
	}
};
var tupelo_ms = {
	name: "Tupelo, MS",
	value: {
		lat: 34.2576066,
		lng: -88.7033859
	}
};
var tuscaloosa_al = {
	name: "Tuscaloosa, AL",
	value: {
		lat: 33.2098407,
		lng: -87.56917349999999
	}
};
var tuskegee_al = {
	name: "Tuskegee, AL",
	value: {
		lat: 32.430237,
		lng: -85.7077266
	}
};
var twin_falls_id = {
	name: "Twin Falls, ID",
	value: {
		lat: 42.5629668,
		lng: -114.4608711
	}
};
var tyler_tx = {
	name: "Tyler, TX",
	value: {
		lat: 32.3512601,
		lng: -95.30106239999999
	}
};
var ukiah_ca = {
	name: "Ukiah, CA",
	value: {
		lat: 39.1501709,
		lng: -123.2077831
	}
};
var union_city_tn_ky = {
	name: "Union City, TN-KY",
	value: {
		lat: 36.4242303,
		lng: -89.0570096
	}
};
var union_sc = {
	name: "Union, SC",
	value: {
		lat: 34.7154122,
		lng: -81.623711
	}
};
var urbana_oh = {
	name: "Urbana, OH",
	value: {
		lat: 40.1083912,
		lng: -83.7524298
	}
};
var utica_rome_ny = {
	name: "Utica-Rome, NY",
	value: {
		lat: 43.100903,
		lng: -75.232664
	}
};
var uvalde_tx = {
	name: "Uvalde, TX",
	value: {
		lat: 29.20968359999999,
		lng: -99.7861679
	}
};
var valdosta_ga = {
	name: "Valdosta, GA",
	value: {
		lat: 30.8327022,
		lng: -83.2784851
	}
};
var vallejo_fairfield_ca = {
	name: "Vallejo-Fairfield, CA",
	value: {
		lat: 38.1040864,
		lng: -122.2566367
	}
};
var valley_al = {
	name: "Valley, AL",
	value: {
		lat: 32.8187406,
		lng: -85.1793852
	}
};
var van_wert_oh = {
	name: "Van Wert, OH",
	value: {
		lat: 40.8694927,
		lng: -84.58412229999999
	}
};
var vermillion_sd = {
	name: "Vermillion, SD",
	value: {
		lat: 42.7794417,
		lng: -96.9292104
	}
};
var vernal_ut = {
	name: "Vernal, UT",
	value: {
		lat: 40.4555157,
		lng: -109.5287479
	}
};
var vernon_tx = {
	name: "Vernon, TX",
	value: {
		lat: 34.1545306,
		lng: -99.2650804
	}
};
var vicksburg_ms = {
	name: "Vicksburg, MS",
	value: {
		lat: 32.3526456,
		lng: -90.877882
	}
};
var victoria_tx = {
	name: "Victoria, TX",
	value: {
		lat: 28.8052674,
		lng: -97.0035982
	}
};
var vidalia_ga = {
	name: "Vidalia, GA",
	value: {
		lat: 32.2176855,
		lng: -82.4134614
	}
};
var vincennes_in = {
	name: "Vincennes, IN",
	value: {
		lat: 38.677269,
		lng: -87.5286325
	}
};
var vineland_millville_bridgeton_nj = {
	name: "Vineland-Millville-Bridgeton, NJ",
	value: {
		lat: 39.4863773,
		lng: -75.02596369999999
	}
};
var virginia_beach_norfolk_newport_news_va_nc = {
	name: "Virginia Beach-Norfolk-Newport News, VA-NC",
	value: {
		lat: 36.8529263,
		lng: -75.97798499999999
	}
};
var visalia_porterville_ca = {
	name: "Visalia-Porterville, CA",
	value: {
		lat: 36.3302284,
		lng: -119.2920585
	}
};
var wabash_in = {
	name: "Wabash, IN",
	value: {
		lat: 40.797821,
		lng: -85.8205411
	}
};
var waco_tx = {
	name: "Waco, TX",
	value: {
		lat: 31.549333,
		lng: -97.1466695
	}
};
var wahpeton_nd_mn = {
	name: "Wahpeton, ND-MN",
	value: {
		lat: 46.2652367,
		lng: -96.60590719999999
	}
};
var walla_walla_wa = {
	name: "Walla Walla, WA",
	value: {
		lat: 46.0645809,
		lng: -118.3430209
	}
};
var walterboro_sc = {
	name: "Walterboro, SC",
	value: {
		lat: 32.9051704,
		lng: -80.6667688
	}
};
var wapakoneta_oh = {
	name: "Wapakoneta, OH",
	value: {
		lat: 40.5678265,
		lng: -84.1935594
	}
};
var warner_robins_ga = {
	name: "Warner Robins, GA",
	value: {
		lat: 32.6130007,
		lng: -83.624201
	}
};
var warren_pa = {
	name: "Warren, PA",
	value: {
		lat: 41.8439486,
		lng: -79.1450445
	}
};
var warrensburg_mo = {
	name: "Warrensburg, MO",
	value: {
		lat: 38.7627893,
		lng: -93.73604979999999
	}
};
var warsaw_in = {
	name: "Warsaw, IN",
	value: {
		lat: 41.2381,
		lng: -85.8530469
	}
};
var washington_in = {
	name: "Washington, IN",
	value: {
		lat: 38.65921520000001,
		lng: -87.172789
	}
};
var washington_nc = {
	name: "Washington, NC",
	value: {
		lat: 35.54655169999999,
		lng: -77.0521742
	}
};
var washington_oh = {
	name: "Washington, OH",
	value: {
		lat: 39.5364511,
		lng: -83.4390843
	}
};
var washington_arlington_alexandria_dc_va_md_wv = {
	name: "Washington-Arlington-Alexandria, DC-VA-MD-WV",
	value: {
		lat: 38.9071923,
		lng: -77.0368707
	}
};
var waterloo_cedar_falls_ia = {
	name: "Waterloo-Cedar Falls, IA",
	value: {
		lat: 42.492786,
		lng: -92.34257749999999
	}
};
var watertown_sd = {
	name: "Watertown, SD",
	value: {
		lat: 44.8994088,
		lng: -97.1150732
	}
};
var watertown_fort_atkinson_wi = {
	name: "Watertown-Fort Atkinson, WI",
	value: {
		lat: 43.1947211,
		lng: -88.7289918
	}
};
var watertown_fort_drum_ny = {
	name: "Watertown-Fort Drum, NY",
	value: {
		lat: 43.9747838,
		lng: -75.91075649999999
	}
};
var wauchula_fl = {
	name: "Wauchula, FL",
	value: {
		lat: 27.5472589,
		lng: -81.8114715
	}
};
var wausau_wi = {
	name: "Wausau, WI",
	value: {
		lat: 44.9591352,
		lng: -89.6301221
	}
};
var waycross_ga = {
	name: "Waycross, GA",
	value: {
		lat: 31.2135511,
		lng: -82.3540178
	}
};
var weirton_steubenville_wv_oh = {
	name: "Weirton-Steubenville, WV-OH",
	value: {
		lat: 40.41895660000001,
		lng: -80.58951669999999
	}
};
var wenatchee_wa = {
	name: "Wenatchee, WA",
	value: {
		lat: 47.4234599,
		lng: -120.3103494
	}
};
var west_helena_ar = {
	name: "West Helena, AR",
	value: {
		lat: 34.550177,
		lng: -90.6413226
	}
};
var west_plains_mo = {
	name: "West Plains, MO",
	value: {
		lat: 36.7281154,
		lng: -91.8523711
	}
};
var west_point_ms = {
	name: "West Point, MS",
	value: {
		lat: 33.6076186,
		lng: -88.6503254
	}
};
var wheeling_wv_oh = {
	name: "Wheeling, WV-OH",
	value: {
		lat: 40.0639616,
		lng: -80.7209149
	}
};
var whitewater_wi = {
	name: "Whitewater, WI",
	value: {
		lat: 42.83362049999999,
		lng: -88.7323272
	}
};
var wichita_falls_tx = {
	name: "Wichita Falls, TX",
	value: {
		lat: 33.9137085,
		lng: -98.4933873
	}
};
var wichita_ks = {
	name: "Wichita, KS",
	value: {
		lat: 37.68717609999999,
		lng: -97.33005299999999
	}
};
var williamsport_pa = {
	name: "Williamsport, PA",
	value: {
		lat: 41.2411897,
		lng: -77.00107860000001
	}
};
var willimantic_ct = {
	name: "Willimantic, CT",
	value: {
		lat: 41.7106543,
		lng: -72.2081338
	}
};
var williston_nd = {
	name: "Williston, ND",
	value: {
		lat: 48.1469683,
		lng: -103.6179745
	}
};
var willmar_mn = {
	name: "Willmar, MN",
	value: {
		lat: 45.1223711,
		lng: -95.048659
	}
};
var wilmington_nc = {
	name: "Wilmington, NC",
	value: {
		lat: 34.2257255,
		lng: -77.9447102
	}
};
var wilmington_oh = {
	name: "Wilmington, OH",
	value: {
		lat: 39.4453393,
		lng: -83.8285375
	}
};
var wilson_nc = {
	name: "Wilson, NC",
	value: {
		lat: 35.7212689,
		lng: -77.9155395
	}
};
var winchester_va_wv = {
	name: "Winchester, VA-WV",
	value: {
		lat: 39.1856597,
		lng: -78.1633341
	}
};
var winfield_ks = {
	name: "Winfield, KS",
	value: {
		lat: 37.2397486,
		lng: -96.9955918
	}
};
var winona_mn = {
	name: "Winona, MN",
	value: {
		lat: 44.0553908,
		lng: -91.6663523
	}
};
var winston_salem_nc = {
	name: "Winston-Salem, NC",
	value: {
		lat: 36.1039642,
		lng: -80.254435
	}
};
var woodward_ok = {
	name: "Woodward, OK",
	value: {
		lat: 36.4336481,
		lng: -99.3903862
	}
};
var wooster_oh = {
	name: "Wooster, OH",
	value: {
		lat: 40.8050565,
		lng: -81.935143
	}
};
var worcester_ma = {
	name: "Worcester, MA",
	value: {
		lat: 42.2625932,
		lng: -71.8022934
	}
};
var worthington_mn = {
	name: "Worthington, MN",
	value: {
		lat: 43.6210985,
		lng: -95.59414360000001
	}
};
var yakima_wa = {
	name: "Yakima, WA",
	value: {
		lat: 46.6020711,
		lng: -120.5058987
	}
};
var yankton_sd = {
	name: "Yankton, SD",
	value: {
		lat: 42.87110879999999,
		lng: -97.39728129999999
	}
};
var yazoo_city_ms = {
	name: "Yazoo City, MS",
	value: {
		lat: 32.8551326,
		lng: -90.4056468
	}
};
var york_hanover_pa = {
	name: "York-Hanover, PA",
	value: {
		lat: 39.9625984,
		lng: -76.727745
	}
};
var youngstown_warren_boardman_oh_pa = {
	name: "Youngstown-Warren-Boardman, OH-PA",
	value: {
		lat: 41.0997803,
		lng: -80.6495194
	}
};
var yuba_city_ca = {
	name: "Yuba City, CA",
	value: {
		lat: 39.1404477,
		lng: -121.6169108
	}
};
var yuma_az = {
	name: "Yuma, AZ",
	value: {
		lat: 32.6926512,
		lng: -114.6276916
	}
};
var zanesville_oh = {
	name: "Zanesville, OH",
	value: {
		lat: 39.9403453,
		lng: -82.0131924
	}
};
var usaCounties = {
	abbeville_la: abbeville_la,
	aberdeen_sd: aberdeen_sd,
	aberdeen_wa: aberdeen_wa,
	abilene_tx: abilene_tx,
	ada_ok: ada_ok,
	adrian_mi: adrian_mi,
	aguadilla_isabela_san_sebastian_pr: aguadilla_isabela_san_sebastian_pr,
	akron_oh: akron_oh,
	alamogordo_nm: alamogordo_nm,
	albany_ga: albany_ga,
	albany_lebanon_or: albany_lebanon_or,
	albany_schenectady_troy_ny: albany_schenectady_troy_ny,
	albemarle_nc: albemarle_nc,
	albert_lea_mn: albert_lea_mn,
	albertville_al: albertville_al,
	albuquerque_nm: albuquerque_nm,
	alexander_city_al: alexander_city_al,
	alexandria_la: alexandria_la,
	alexandria_mn: alexandria_mn,
	alice_tx: alice_tx,
	allegan_mi: allegan_mi,
	allentown_bethlehem_easton_pa_nj: allentown_bethlehem_easton_pa_nj,
	alma_mi: alma_mi,
	alpena_mi: alpena_mi,
	altoona_pa: altoona_pa,
	altus_ok: altus_ok,
	amarillo_tx: amarillo_tx,
	americus_ga: americus_ga,
	ames_ia: ames_ia,
	amsterdam_ny: amsterdam_ny,
	anchorage_ak: anchorage_ak,
	anderson_in: anderson_in,
	anderson_sc: anderson_sc,
	andrews_tx: andrews_tx,
	angola_in: angola_in,
	ann_arbor_mi: ann_arbor_mi,
	anniston_oxford_al: anniston_oxford_al,
	appleton_wi: appleton_wi,
	arcadia_fl: arcadia_fl,
	ardmore_ok: ardmore_ok,
	arkadelphia_ar: arkadelphia_ar,
	asheville_nc: asheville_nc,
	ashland_oh: ashland_oh,
	ashtabula_oh: ashtabula_oh,
	astoria_or: astoria_or,
	atchison_ks: atchison_ks,
	athens_oh: athens_oh,
	athens_tn: athens_tn,
	athens_tx: athens_tx,
	athens_clarke_county_ga: athens_clarke_county_ga,
	atlanta_sandy_springs_marietta_ga: atlanta_sandy_springs_marietta_ga,
	atlantic_city_nj: atlantic_city_nj,
	auburn_in: auburn_in,
	auburn_ny: auburn_ny,
	auburn_opelika_al: auburn_opelika_al,
	augusta_richmond_county_ga_sc: augusta_richmond_county_ga_sc,
	augusta_waterville_me: augusta_waterville_me,
	austin_mn: austin_mn,
	austin_round_rock_tx: austin_round_rock_tx,
	bainbridge_ga: bainbridge_ga,
	bakersfield_ca: bakersfield_ca,
	baltimore_towson_md: baltimore_towson_md,
	bangor_me: bangor_me,
	baraboo_wi: baraboo_wi,
	barnstable_town_ma: barnstable_town_ma,
	barre_vt: barre_vt,
	bartlesville_ok: bartlesville_ok,
	bastrop_la: bastrop_la,
	batavia_ny: batavia_ny,
	batesville_ar: batesville_ar,
	baton_rouge_la: baton_rouge_la,
	battle_creek_mi: battle_creek_mi,
	bay_city_mi: bay_city_mi,
	bay_city_tx: bay_city_tx,
	beatrice_ne: beatrice_ne,
	beaumont_port_arthur_tx: beaumont_port_arthur_tx,
	beaver_dam_wi: beaver_dam_wi,
	beckley_wv: beckley_wv,
	bedford_in: bedford_in,
	beeville_tx: beeville_tx,
	bellefontaine_oh: bellefontaine_oh,
	bellingham_wa: bellingham_wa,
	bemidji_mn: bemidji_mn,
	bend_or: bend_or,
	bennettsville_sc: bennettsville_sc,
	bennington_vt: bennington_vt,
	berlin_nh_vt: berlin_nh_vt,
	big_rapids_mi: big_rapids_mi,
	big_spring_tx: big_spring_tx,
	billings_mt: billings_mt,
	binghamton_ny: binghamton_ny,
	birmingham_hoover_al: birmingham_hoover_al,
	bishop_ca: bishop_ca,
	bismarck_nd: bismarck_nd,
	blackfoot_id: blackfoot_id,
	blacksburg_christiansburg_radford_va: blacksburg_christiansburg_radford_va,
	bloomington_in: bloomington_in,
	bloomington_normal_il: bloomington_normal_il,
	bloomsburg_berwick_pa: bloomsburg_berwick_pa,
	bluefield_wv_va: bluefield_wv_va,
	blytheville_ar: blytheville_ar,
	bogalusa_la: bogalusa_la,
	boise_city_nampa_id: boise_city_nampa_id,
	bonham_tx: bonham_tx,
	boone_ia: boone_ia,
	boone_nc: boone_nc,
	borger_tx: borger_tx,
	boston_cambridge_quincy_ma_nh: boston_cambridge_quincy_ma_nh,
	boulder_co: boulder_co,
	bowling_green_ky: bowling_green_ky,
	bozeman_mt: bozeman_mt,
	bradford_pa: bradford_pa,
	brainerd_mn: brainerd_mn,
	branson_mo: branson_mo,
	bremerton_silverdale_wa: bremerton_silverdale_wa,
	brenham_tx: brenham_tx,
	brevard_nc: brevard_nc,
	bridgeport_stamford_norwalk_ct: bridgeport_stamford_norwalk_ct,
	brigham_city_ut: brigham_city_ut,
	brookhaven_ms: brookhaven_ms,
	brookings_or: brookings_or,
	brookings_sd: brookings_sd,
	brownsville_tn: brownsville_tn,
	brownsville_harlingen_tx: brownsville_harlingen_tx,
	brownwood_tx: brownwood_tx,
	brunswick_ga: brunswick_ga,
	bucyrus_oh: bucyrus_oh,
	buffalo_niagara_falls_ny: buffalo_niagara_falls_ny,
	burley_id: burley_id,
	burlington_ia_il: burlington_ia_il,
	burlington_nc: burlington_nc,
	burlington_south_burlington_vt: burlington_south_burlington_vt,
	butte_silver_bow_mt: butte_silver_bow_mt,
	cadillac_mi: cadillac_mi,
	calhoun_ga: calhoun_ga,
	cambridge_md: cambridge_md,
	cambridge_oh: cambridge_oh,
	camden_ar: camden_ar,
	campbellsville_ky: campbellsville_ky,
	canon_city_co: canon_city_co,
	canton_il: canton_il,
	canton_massillon_oh: canton_massillon_oh,
	cape_coral_fort_myers_fl: cape_coral_fort_myers_fl,
	cape_girardeau_jackson_mo_il: cape_girardeau_jackson_mo_il,
	carbondale_il: carbondale_il,
	carlsbad_artesia_nm: carlsbad_artesia_nm,
	carson_city_nv: carson_city_nv,
	casper_wy: casper_wy,
	cedar_city_ut: cedar_city_ut,
	cedar_rapids_ia: cedar_rapids_ia,
	cedartown_ga: cedartown_ga,
	celina_oh: celina_oh,
	central_city_ky: central_city_ky,
	centralia_il: centralia_il,
	centralia_wa: centralia_wa,
	chambersburg_pa: chambersburg_pa,
	champaign_urbana_il: champaign_urbana_il,
	charleston_wv: charleston_wv,
	charleston_mattoon_il: charleston_mattoon_il,
	charleston_north_charleston_sc: charleston_north_charleston_sc,
	charlotte_gastonia_concord_nc_sc: charlotte_gastonia_concord_nc_sc,
	charlottesville_va: charlottesville_va,
	chattanooga_tn_ga: chattanooga_tn_ga,
	chester_sc: chester_sc,
	cheyenne_wy: cheyenne_wy,
	chicago_naperville_joliet_il_in_wi: chicago_naperville_joliet_il_in_wi,
	chico_ca: chico_ca,
	chillicothe_oh: chillicothe_oh,
	cincinnati_middletown_oh_ky_in: cincinnati_middletown_oh_ky_in,
	city_of_the_dalles_or: city_of_the_dalles_or,
	claremont_nh: claremont_nh,
	clarksburg_wv: clarksburg_wv,
	clarksdale_ms: clarksdale_ms,
	clarksville_tn_ky: clarksville_tn_ky,
	clearlake_ca: clearlake_ca,
	cleveland_ms: cleveland_ms,
	cleveland_tn: cleveland_tn,
	cleveland_elyria_mentor_oh: cleveland_elyria_mentor_oh,
	clewiston_fl: clewiston_fl,
	clinton_ia: clinton_ia,
	clovis_nm: clovis_nm,
	"coeur_d'alene_id": {
	name: "Coeur d'Alene, ID",
	value: {
		lat: 47.6776832,
		lng: -116.7804664
	}
},
	coffeyville_ks: coffeyville_ks,
	coldwater_mi: coldwater_mi,
	college_station_bryan_tx: college_station_bryan_tx,
	colorado_springs_co: colorado_springs_co,
	columbia_mo: columbia_mo,
	columbia_sc: columbia_sc,
	columbia_tn: columbia_tn,
	columbus_ga_al: columbus_ga_al,
	columbus_in: columbus_in,
	columbus_ms: columbus_ms,
	columbus_ne: columbus_ne,
	columbus_oh: columbus_oh,
	concord_nh: concord_nh,
	connersville_in: connersville_in,
	cookeville_tn: cookeville_tn,
	coos_bay_or: coos_bay_or,
	corbin_ky: corbin_ky,
	cordele_ga: cordele_ga,
	corinth_ms: corinth_ms,
	cornelia_ga: cornelia_ga,
	corning_ny: corning_ny,
	corpus_christi_tx: corpus_christi_tx,
	corsicana_tx: corsicana_tx,
	cortland_ny: cortland_ny,
	corvallis_or: corvallis_or,
	coshocton_oh: coshocton_oh,
	crawfordsville_in: crawfordsville_in,
	crescent_city_ca: crescent_city_ca,
	crossville_tn: crossville_tn,
	crowley_la: crowley_la,
	cullman_al: cullman_al,
	culpeper_va: culpeper_va,
	cumberland_md_wv: cumberland_md_wv,
	dallas_fort_worth_arlington_tx: dallas_fort_worth_arlington_tx,
	dalton_ga: dalton_ga,
	danville_il: danville_il,
	danville_ky: danville_ky,
	danville_va: danville_va,
	daphne_fairhope_foley_al: daphne_fairhope_foley_al,
	davenport_moline_rock_island_ia_il: davenport_moline_rock_island_ia_il,
	dayton_oh: dayton_oh,
	de_ridder_la: de_ridder_la,
	decatur_al: decatur_al,
	decatur_il: decatur_il,
	decatur_in: decatur_in,
	defiance_oh: defiance_oh,
	del_rio_tx: del_rio_tx,
	deltona_daytona_beach_ormond_beach_fl: deltona_daytona_beach_ormond_beach_fl,
	deming_nm: deming_nm,
	denver_aurora_co: denver_aurora_co,
	des_moines_west_des_moines_ia: des_moines_west_des_moines_ia,
	detroit_warren_livonia_mi: detroit_warren_livonia_mi,
	dickinson_nd: dickinson_nd,
	dillon_sc: dillon_sc,
	dixon_il: dixon_il,
	dodge_city_ks: dodge_city_ks,
	dothan_al: dothan_al,
	douglas_ga: douglas_ga,
	dover_de: dover_de,
	dubois_pa: dubois_pa,
	dublin_ga: dublin_ga,
	dubuque_ia: dubuque_ia,
	duluth_mn_wi: duluth_mn_wi,
	dumas_tx: dumas_tx,
	duncan_ok: duncan_ok,
	dunn_nc: dunn_nc,
	durango_co: durango_co,
	durant_ok: durant_ok,
	durham_nc: durham_nc,
	dyersburg_tn: dyersburg_tn,
	eagle_pass_tx: eagle_pass_tx,
	east_liverpool_salem_oh: east_liverpool_salem_oh,
	east_stroudsburg_pa: east_stroudsburg_pa,
	easton_md: easton_md,
	eau_claire_wi: eau_claire_wi,
	edwards_co: edwards_co,
	effingham_il: effingham_il,
	el_campo_tx: el_campo_tx,
	el_centro_ca: el_centro_ca,
	el_dorado_ar: el_dorado_ar,
	el_paso_tx: el_paso_tx,
	elizabeth_city_nc: elizabeth_city_nc,
	elizabethtown_ky: elizabethtown_ky,
	elk_city_ok: elk_city_ok,
	elkhart_goshen_in: elkhart_goshen_in,
	elko_nv: elko_nv,
	ellensburg_wa: ellensburg_wa,
	elmira_ny: elmira_ny,
	emporia_ks: emporia_ks,
	enid_ok: enid_ok,
	enterprise_ozark_al: enterprise_ozark_al,
	erie_pa: erie_pa,
	escanaba_mi: escanaba_mi,
	espanola_nm: espanola_nm,
	eufaula_al_ga: eufaula_al_ga,
	eugene_springfield_or: eugene_springfield_or,
	eureka_arcata_fortuna_ca: eureka_arcata_fortuna_ca,
	evanston_wy: evanston_wy,
	evansville_in_ky: evansville_in_ky,
	fairbanks_ak: fairbanks_ak,
	fairmont_mn: fairmont_mn,
	fairmont_wv: fairmont_wv,
	fajardo_pr: fajardo_pr,
	fallon_nv: fallon_nv,
	fargo_nd_mn: fargo_nd_mn,
	faribault_northfield_mn: faribault_northfield_mn,
	farmington_mo: farmington_mo,
	farmington_nm: farmington_nm,
	fayetteville_nc: fayetteville_nc,
	fayetteville_springdale_rogers_ar_mo: fayetteville_springdale_rogers_ar_mo,
	fergus_falls_mn: fergus_falls_mn,
	fernley_nv: fernley_nv,
	findlay_oh: findlay_oh,
	fitzgerald_ga: fitzgerald_ga,
	flagstaff_az: flagstaff_az,
	flint_mi: flint_mi,
	florence_sc: florence_sc,
	florence_muscle_shoals_al: florence_muscle_shoals_al,
	fond_du_lac_wi: fond_du_lac_wi,
	forest_city_nc: forest_city_nc,
	forrest_city_ar: forrest_city_ar,
	fort_collins_loveland_co: fort_collins_loveland_co,
	fort_dodge_ia: fort_dodge_ia,
	fort_leonard_wood_mo: fort_leonard_wood_mo,
	fort_madison_keokuk_ia_mo: fort_madison_keokuk_ia_mo,
	fort_morgan_co: fort_morgan_co,
	fort_payne_al: fort_payne_al,
	fort_polk_south_la: fort_polk_south_la,
	fort_smith_ar_ok: fort_smith_ar_ok,
	fort_valley_ga: fort_valley_ga,
	fort_walton_beach_crestview_destin_fl: fort_walton_beach_crestview_destin_fl,
	fort_wayne_in: fort_wayne_in,
	frankfort_in: frankfort_in,
	frankfort_ky: frankfort_ky,
	fredericksburg_tx: fredericksburg_tx,
	freeport_il: freeport_il,
	fremont_ne: fremont_ne,
	fremont_oh: fremont_oh,
	fresno_ca: fresno_ca,
	gadsden_al: gadsden_al,
	gaffney_sc: gaffney_sc,
	gainesville_fl: gainesville_fl,
	gainesville_ga: gainesville_ga,
	gainesville_tx: gainesville_tx,
	galesburg_il: galesburg_il,
	gallup_nm: gallup_nm,
	garden_city_ks: garden_city_ks,
	gardnerville_ranchos_nv: gardnerville_ranchos_nv,
	georgetown_sc: georgetown_sc,
	gettysburg_pa: gettysburg_pa,
	gillette_wy: gillette_wy,
	glasgow_ky: glasgow_ky,
	glens_falls_ny: glens_falls_ny,
	gloversville_ny: gloversville_ny,
	goldsboro_nc: goldsboro_nc,
	granbury_tx: granbury_tx,
	grand_forks_nd_mn: grand_forks_nd_mn,
	grand_island_ne: grand_island_ne,
	grand_junction_co: grand_junction_co,
	grand_rapids_wyoming_mi: grand_rapids_wyoming_mi,
	grants_pass_or: grants_pass_or,
	grants_nm: grants_nm,
	great_bend_ks: great_bend_ks,
	great_falls_mt: great_falls_mt,
	greeley_co: greeley_co,
	green_bay_wi: green_bay_wi,
	greeneville_tn: greeneville_tn,
	greensboro_high_point_nc: greensboro_high_point_nc,
	greensburg_in: greensburg_in,
	greenville_ms: greenville_ms,
	greenville_nc: greenville_nc,
	greenville_oh: greenville_oh,
	greenville_mauldin_easley_sc: greenville_mauldin_easley_sc,
	greenwood_ms: greenwood_ms,
	greenwood_sc: greenwood_sc,
	grenada_ms: grenada_ms,
	guayama_pr: guayama_pr,
	gulfport_biloxi_ms: gulfport_biloxi_ms,
	guymon_ok: guymon_ok,
	hagerstown_martinsburg_md_wv: hagerstown_martinsburg_md_wv,
	hammond_la: hammond_la,
	hanford_corcoran_ca: hanford_corcoran_ca,
	hannibal_mo: hannibal_mo,
	harriman_tn: harriman_tn,
	harrisburg_il: harrisburg_il,
	harrisburg_carlisle_pa: harrisburg_carlisle_pa,
	harrison_ar: harrison_ar,
	harrisonburg_va: harrisonburg_va,
	hartford_west_hartford_east_hartford_ct: hartford_west_hartford_east_hartford_ct,
	hastings_ne: hastings_ne,
	hattiesburg_ms: hattiesburg_ms,
	havre_mt: havre_mt,
	hays_ks: hays_ks,
	heber_ut: heber_ut,
	helena_mt: helena_mt,
	henderson_nc: henderson_nc,
	hereford_tx: hereford_tx,
	hickory_lenoir_morganton_nc: hickory_lenoir_morganton_nc,
	hilo_hi: hilo_hi,
	hilton_head_island_beaufort_sc: hilton_head_island_beaufort_sc,
	hinesville_fort_stewart_ga: hinesville_fort_stewart_ga,
	hobbs_nm: hobbs_nm,
	holland_grand_haven_mi: holland_grand_haven_mi,
	homosassa_springs_fl: homosassa_springs_fl,
	honolulu_hi: honolulu_hi,
	hood_river_or: hood_river_or,
	hope_ar: hope_ar,
	hot_springs_ar: hot_springs_ar,
	houghton_mi: houghton_mi,
	houma_bayou_cane_thibodaux_la: houma_bayou_cane_thibodaux_la,
	houston_sugar_land_baytown_tx: houston_sugar_land_baytown_tx,
	hudson_ny: hudson_ny,
	humboldt_tn: humboldt_tn,
	huntingdon_pa: huntingdon_pa,
	huntington_in: huntington_in,
	huntington_ashland_wv_ky_oh: huntington_ashland_wv_ky_oh,
	huntsville_al: huntsville_al,
	huntsville_tx: huntsville_tx,
	huron_sd: huron_sd,
	hutchinson_ks: hutchinson_ks,
	hutchinson_mn: hutchinson_mn,
	idaho_falls_id: idaho_falls_id,
	indiana_pa: indiana_pa,
	indianapolis_carmel_in: indianapolis_carmel_in,
	indianola_ms: indianola_ms,
	iowa_city_ia: iowa_city_ia,
	iron_mountain_mi_wi: iron_mountain_mi_wi,
	ithaca_ny: ithaca_ny,
	jackson_mi: jackson_mi,
	jackson_ms: jackson_ms,
	jackson_tn: jackson_tn,
	jackson_wy_id: jackson_wy_id,
	jacksonville_fl: jacksonville_fl,
	jacksonville_il: jacksonville_il,
	jacksonville_nc: jacksonville_nc,
	jacksonville_tx: jacksonville_tx,
	jamestown_nd: jamestown_nd,
	jamestown_dunkirk_fredonia_ny: jamestown_dunkirk_fredonia_ny,
	janesville_wi: janesville_wi,
	jasper_in: jasper_in,
	jefferson_city_mo: jefferson_city_mo,
	jennings_la: jennings_la,
	jesup_ga: jesup_ga,
	johnson_city_tn: johnson_city_tn,
	johnstown_pa: johnstown_pa,
	jonesboro_ar: jonesboro_ar,
	joplin_mo: joplin_mo,
	juneau_ak: juneau_ak,
	kahului_wailuku_hi: kahului_wailuku_hi,
	kalamazoo_portage_mi: kalamazoo_portage_mi,
	kalispell_mt: kalispell_mt,
	kankakee_bradley_il: kankakee_bradley_il,
	kansas_city_mo_ks: kansas_city_mo_ks,
	kapaa_hi: kapaa_hi,
	kearney_ne: kearney_ne,
	keene_nh: keene_nh,
	kendallville_in: kendallville_in,
	kennett_mo: kennett_mo,
	kennewick_richland_pasco_wa: kennewick_richland_pasco_wa,
	kerrville_tx: kerrville_tx,
	ketchikan_ak: ketchikan_ak,
	key_west_fl: key_west_fl,
	kill_devil_hills_nc: kill_devil_hills_nc,
	killeen_temple_fort_hood_tx: killeen_temple_fort_hood_tx,
	kingsport_bristol_bristol_tn_va: kingsport_bristol_bristol_tn_va,
	kingston_ny: kingston_ny,
	kingsville_tx: kingsville_tx,
	kinston_nc: kinston_nc,
	kirksville_mo: kirksville_mo,
	klamath_falls_or: klamath_falls_or,
	knoxville_tn: knoxville_tn,
	kodiak_ak: kodiak_ak,
	kokomo_in: kokomo_in,
	la_crosse_wi_mn: la_crosse_wi_mn,
	la_follette_tn: la_follette_tn,
	la_grande_or: la_grande_or,
	lagrange_ga: lagrange_ga,
	laconia_nh: laconia_nh,
	lafayette_in: lafayette_in,
	lafayette_la: lafayette_la,
	lake_charles_la: lake_charles_la,
	lake_city_fl: lake_city_fl,
	lake_havasu_city_kingman_az: lake_havasu_city_kingman_az,
	lakeland_fl: lakeland_fl,
	lamesa_tx: lamesa_tx,
	lancaster_pa: lancaster_pa,
	lancaster_sc: lancaster_sc,
	lansing_east_lansing_mi: lansing_east_lansing_mi,
	laramie_wy: laramie_wy,
	laredo_tx: laredo_tx,
	las_cruces_nm: las_cruces_nm,
	las_vegas_nm: las_vegas_nm,
	las_vegas_paradise_nv: las_vegas_paradise_nv,
	laurel_ms: laurel_ms,
	laurinburg_nc: laurinburg_nc,
	lawrence_ks: lawrence_ks,
	lawrenceburg_tn: lawrenceburg_tn,
	lawton_ok: lawton_ok,
	lebanon_mo: lebanon_mo,
	lebanon_nh_vt: lebanon_nh_vt,
	lebanon_pa: lebanon_pa,
	levelland_tx: levelland_tx,
	lewisburg_pa: lewisburg_pa,
	lewisburg_tn: lewisburg_tn,
	lewiston_id_wa: lewiston_id_wa,
	lewiston_auburn_me: lewiston_auburn_me,
	lewistown_pa: lewistown_pa,
	lexington_park_md: lexington_park_md,
	lexington_ne: lexington_ne,
	lexington_fayette_ky: lexington_fayette_ky,
	liberal_ks: liberal_ks,
	lima_oh: lima_oh,
	lincoln_il: lincoln_il,
	lincoln_ne: lincoln_ne,
	lincolnton_nc: lincolnton_nc,
	little_rock_north_little_rock_conway_ar: little_rock_north_little_rock_conway_ar,
	lock_haven_pa: lock_haven_pa,
	logan_ut_id: logan_ut_id,
	logansport_in: logansport_in,
	london_ky: london_ky,
	longview_tx: longview_tx,
	longview_wa: longview_wa,
	los_alamos_nm: los_alamos_nm,
	los_angeles_long_beach_santa_ana_ca: los_angeles_long_beach_santa_ana_ca,
	"louisville/jefferson_county_ky_in": {
	name: "Louisville/Jefferson County, KY-IN",
	value: {
		lat: 38.2526647,
		lng: -85.7584557
	}
},
	lubbock_tx: lubbock_tx,
	lufkin_tx: lufkin_tx,
	lumberton_nc: lumberton_nc,
	lynchburg_va: lynchburg_va,
	macomb_il: macomb_il,
	macon_ga: macon_ga,
	madera_ca: madera_ca,
	madison_in: madison_in,
	madison_wi: madison_wi,
	madisonville_ky: madisonville_ky,
	magnolia_ar: magnolia_ar,
	malone_ny: malone_ny,
	manchester_nashua_nh: manchester_nashua_nh,
	manhattan_ks: manhattan_ks,
	manitowoc_wi: manitowoc_wi,
	mankato_north_mankato_mn: mankato_north_mankato_mn,
	mansfield_oh: mansfield_oh,
	marinette_wi_mi: marinette_wi_mi,
	marion_in: marion_in,
	marion_oh: marion_oh,
	marion_herrin_il: marion_herrin_il,
	marquette_mi: marquette_mi,
	marshall_mn: marshall_mn,
	marshall_mo: marshall_mo,
	marshall_tx: marshall_tx,
	marshalltown_ia: marshalltown_ia,
	marshfield_wisconsin_rapids_wi: marshfield_wisconsin_rapids_wi,
	martin_tn: martin_tn,
	martinsville_va: martinsville_va,
	maryville_mo: maryville_mo,
	mason_city_ia: mason_city_ia,
	mayaguez_pr: mayaguez_pr,
	mayfield_ky: mayfield_ky,
	maysville_ky: maysville_ky,
	mcalester_ok: mcalester_ok,
	mcallen_edinburg_mission_tx: mcallen_edinburg_mission_tx,
	mccomb_ms: mccomb_ms,
	mcminnville_tn: mcminnville_tn,
	mcpherson_ks: mcpherson_ks,
	meadville_pa: meadville_pa,
	medford_or: medford_or,
	memphis_tn_ms_ar: memphis_tn_ms_ar,
	menomonie_wi: menomonie_wi,
	merced_ca: merced_ca,
	meridian_ms: meridian_ms,
	merrill_wi: merrill_wi,
	mexico_mo: mexico_mo,
	miami_ok: miami_ok,
	miami_fort_lauderdale_pompano_beach_fl: miami_fort_lauderdale_pompano_beach_fl,
	michigan_city_la_porte_in: michigan_city_la_porte_in,
	middlesborough_ky: middlesborough_ky,
	midland_mi: midland_mi,
	midland_tx: midland_tx,
	milledgeville_ga: milledgeville_ga,
	milwaukee_waukesha_west_allis_wi: milwaukee_waukesha_west_allis_wi,
	minden_la: minden_la,
	mineral_wells_tx: mineral_wells_tx,
	minneapolis_st_paul_bloomington_mn_wi: minneapolis_st_paul_bloomington_mn_wi,
	minot_nd: minot_nd,
	missoula_mt: missoula_mt,
	mitchell_sd: mitchell_sd,
	moberly_mo: moberly_mo,
	mobile_al: mobile_al,
	modesto_ca: modesto_ca,
	monroe_la: monroe_la,
	monroe_mi: monroe_mi,
	monroe_wi: monroe_wi,
	montgomery_al: montgomery_al,
	montrose_co: montrose_co,
	morehead_city_nc: morehead_city_nc,
	morgan_city_la: morgan_city_la,
	morgantown_wv: morgantown_wv,
	morristown_tn: morristown_tn,
	moscow_id: moscow_id,
	moses_lake_wa: moses_lake_wa,
	moultrie_ga: moultrie_ga,
	mount_airy_nc: mount_airy_nc,
	mount_pleasant_mi: mount_pleasant_mi,
	mount_pleasant_tx: mount_pleasant_tx,
	mount_sterling_ky: mount_sterling_ky,
	mount_vernon_il: mount_vernon_il,
	mount_vernon_oh: mount_vernon_oh,
	mount_vernon_anacortes_wa: mount_vernon_anacortes_wa,
	mountain_home_ar: mountain_home_ar,
	mountain_home_id: mountain_home_id,
	muncie_in: muncie_in,
	murray_ky: murray_ky,
	muscatine_ia: muscatine_ia,
	muskegon_norton_shores_mi: muskegon_norton_shores_mi,
	muskogee_ok: muskogee_ok,
	myrtle_beach_conway_north_myrtle_beach_sc: myrtle_beach_conway_north_myrtle_beach_sc,
	nacogdoches_tx: nacogdoches_tx,
	napa_ca: napa_ca,
	naples_marco_island_fl: naples_marco_island_fl,
	nashville_davidson_murfreesboro_franklin_tn: nashville_davidson_murfreesboro_franklin_tn,
	natchez_ms_la: natchez_ms_la,
	natchitoches_la: natchitoches_la,
	new_bern_nc: new_bern_nc,
	new_castle_in: new_castle_in,
	new_castle_pa: new_castle_pa,
	new_haven_milford_ct: new_haven_milford_ct,
	new_iberia_la: new_iberia_la,
	new_orleans_metairie_kenner_la: new_orleans_metairie_kenner_la,
	new_philadelphia_dover_oh: new_philadelphia_dover_oh,
	new_ulm_mn: new_ulm_mn,
	new_york_northern_new_jersey_long_island_ny_nj_pa: new_york_northern_new_jersey_long_island_ny_nj_pa,
	newberry_sc: newberry_sc,
	newport_tn: newport_tn,
	newton_ia: newton_ia,
	niles_benton_harbor_mi: niles_benton_harbor_mi,
	nogales_az: nogales_az,
	norfolk_ne: norfolk_ne,
	north_platte_ne: north_platte_ne,
	north_vernon_in: north_vernon_in,
	north_wilkesboro_nc: north_wilkesboro_nc,
	norwalk_oh: norwalk_oh,
	norwich_new_london_ct: norwich_new_london_ct,
	oak_harbor_wa: oak_harbor_wa,
	oak_hill_wv: oak_hill_wv,
	ocala_fl: ocala_fl,
	ocean_city_nj: ocean_city_nj,
	ocean_pines_md: ocean_pines_md,
	odessa_tx: odessa_tx,
	ogden_clearfield_ut: ogden_clearfield_ut,
	ogdensburg_massena_ny: ogdensburg_massena_ny,
	oil_city_pa: oil_city_pa,
	okeechobee_fl: okeechobee_fl,
	oklahoma_city_ok: oklahoma_city_ok,
	olean_ny: olean_ny,
	olympia_wa: olympia_wa,
	omaha_council_bluffs_ne_ia: omaha_council_bluffs_ne_ia,
	oneonta_ny: oneonta_ny,
	ontario_or_id: ontario_or_id,
	opelousas_eunice_la: opelousas_eunice_la,
	orangeburg_sc: orangeburg_sc,
	orlando_kissimmee_fl: orlando_kissimmee_fl,
	oshkosh_neenah_wi: oshkosh_neenah_wi,
	oskaloosa_ia: oskaloosa_ia,
	ottawa_streator_il: ottawa_streator_il,
	ottumwa_ia: ottumwa_ia,
	owatonna_mn: owatonna_mn,
	owensboro_ky: owensboro_ky,
	owosso_mi: owosso_mi,
	oxford_ms: oxford_ms,
	oxnard_thousand_oaks_ventura_ca: oxnard_thousand_oaks_ventura_ca,
	paducah_ky_il: paducah_ky_il,
	pahrump_nv: pahrump_nv,
	palatka_fl: palatka_fl,
	palestine_tx: palestine_tx,
	palm_bay_melbourne_titusville_fl: palm_bay_melbourne_titusville_fl,
	palm_coast_fl: palm_coast_fl,
	pampa_tx: pampa_tx,
	panama_city_lynn_haven_fl: panama_city_lynn_haven_fl,
	paragould_ar: paragould_ar,
	paris_tn: paris_tn,
	paris_tx: paris_tx,
	parkersburg_marietta_vienna_wv_oh: parkersburg_marietta_vienna_wv_oh,
	parsons_ks: parsons_ks,
	pascagoula_ms: pascagoula_ms,
	payson_az: payson_az,
	pecos_tx: pecos_tx,
	pella_ia: pella_ia,
	pendleton_hermiston_or: pendleton_hermiston_or,
	pensacola_ferry_pass_brent_fl: pensacola_ferry_pass_brent_fl,
	peoria_il: peoria_il,
	peru_in: peru_in,
	philadelphia_camden_wilmington_pa_nj_de_md: philadelphia_camden_wilmington_pa_nj_de_md,
	phoenix_lake_cedar_ridge_ca: phoenix_lake_cedar_ridge_ca,
	phoenix_mesa_scottsdale_az: phoenix_mesa_scottsdale_az,
	picayune_ms: picayune_ms,
	pierre_part_la: pierre_part_la,
	pierre_sd: pierre_sd,
	pine_bluff_ar: pine_bluff_ar,
	pittsburg_ks: pittsburg_ks,
	pittsburgh_pa: pittsburgh_pa,
	pittsfield_ma: pittsfield_ma,
	plainview_tx: plainview_tx,
	platteville_wi: platteville_wi,
	plattsburgh_ny: plattsburgh_ny,
	plymouth_in: plymouth_in,
	pocatello_id: pocatello_id,
	point_pleasant_wv_oh: point_pleasant_wv_oh,
	ponca_city_ok: ponca_city_ok,
	ponce_pr: ponce_pr,
	pontiac_il: pontiac_il,
	poplar_bluff_mo: poplar_bluff_mo,
	port_angeles_wa: port_angeles_wa,
	port_st_lucie_fl: port_st_lucie_fl,
	portales_nm: portales_nm,
	portland_south_portland_biddeford_me: portland_south_portland_biddeford_me,
	portland_vancouver_beaverton_or_wa: portland_vancouver_beaverton_or_wa,
	portsmouth_oh: portsmouth_oh,
	pottsville_pa: pottsville_pa,
	poughkeepsie_newburgh_middletown_ny: poughkeepsie_newburgh_middletown_ny,
	prescott_az: prescott_az,
	price_ut: price_ut,
	prineville_or: prineville_or,
	providence_new_bedford_fall_river_ri_ma: providence_new_bedford_fall_river_ri_ma,
	provo_orem_ut: provo_orem_ut,
	pueblo_co: pueblo_co,
	pullman_wa: pullman_wa,
	punta_gorda_fl: punta_gorda_fl,
	quincy_il_mo: quincy_il_mo,
	racine_wi: racine_wi,
	raleigh_cary_nc: raleigh_cary_nc,
	rapid_city_sd: rapid_city_sd,
	raymondville_tx: raymondville_tx,
	reading_pa: reading_pa,
	red_bluff_ca: red_bluff_ca,
	red_wing_mn: red_wing_mn,
	redding_ca: redding_ca,
	reno_sparks_nv: reno_sparks_nv,
	rexburg_id: rexburg_id,
	richmond_in: richmond_in,
	richmond_va: richmond_va,
	richmond_berea_ky: richmond_berea_ky,
	rio_grande_city_roma_tx: rio_grande_city_roma_tx,
	riverside_san_bernardino_ontario_ca: riverside_san_bernardino_ontario_ca,
	riverton_wy: riverton_wy,
	roanoke_rapids_nc: roanoke_rapids_nc,
	roanoke_va: roanoke_va,
	rochelle_il: rochelle_il,
	rochester_mn: rochester_mn,
	rochester_ny: rochester_ny,
	rock_springs_wy: rock_springs_wy,
	rockford_il: rockford_il,
	rockingham_nc: rockingham_nc,
	rockland_me: rockland_me,
	rocky_mount_nc: rocky_mount_nc,
	rolla_mo: rolla_mo,
	rome_ga: rome_ga,
	roseburg_or: roseburg_or,
	roswell_nm: roswell_nm,
	ruidoso_nm: ruidoso_nm,
	russellville_ar: russellville_ar,
	ruston_la: ruston_la,
	rutland_vt: rutland_vt,
	sacramento_arden_arcade_roseville_ca: sacramento_arden_arcade_roseville_ca,
	safford_az: safford_az,
	saginaw_saginaw_township_north_mi: saginaw_saginaw_township_north_mi,
	salem_or: salem_or,
	salina_ks: salina_ks,
	salinas_ca: salinas_ca,
	salisbury_md: salisbury_md,
	salisbury_nc: salisbury_nc,
	salt_lake_city_ut: salt_lake_city_ut,
	san_angelo_tx: san_angelo_tx,
	san_antonio_tx: san_antonio_tx,
	san_diego_carlsbad_san_marcos_ca: san_diego_carlsbad_san_marcos_ca,
	san_francisco_oakland_fremont_ca: san_francisco_oakland_fremont_ca,
	san_german_cabo_rojo_pr: san_german_cabo_rojo_pr,
	san_jose_sunnyvale_santa_clara_ca: san_jose_sunnyvale_santa_clara_ca,
	san_juan_caguas_guaynabo_pr: san_juan_caguas_guaynabo_pr,
	san_luis_obispo_paso_robles_ca: san_luis_obispo_paso_robles_ca,
	sandusky_oh: sandusky_oh,
	sanford_nc: sanford_nc,
	santa_barbara_santa_maria_goleta_ca: santa_barbara_santa_maria_goleta_ca,
	santa_cruz_watsonville_ca: santa_cruz_watsonville_ca,
	santa_fe_nm: santa_fe_nm,
	santa_isabel_pr: santa_isabel_pr,
	santa_rosa_petaluma_ca: santa_rosa_petaluma_ca,
	sarasota_bradenton_venice_fl: sarasota_bradenton_venice_fl,
	sault_ste_marie_mi: sault_ste_marie_mi,
	savannah_ga: savannah_ga,
	sayre_pa: sayre_pa,
	scottsbluff_ne: scottsbluff_ne,
	scottsboro_al: scottsboro_al,
	scottsburg_in: scottsburg_in,
	scranton_wilkes_barre_pa: scranton_wilkes_barre_pa,
	seaford_de: seaford_de,
	searcy_ar: searcy_ar,
	seattle_tacoma_bellevue_wa: seattle_tacoma_bellevue_wa,
	sebastian_vero_beach_fl: sebastian_vero_beach_fl,
	sebring_fl: sebring_fl,
	sedalia_mo: sedalia_mo,
	selinsgrove_pa: selinsgrove_pa,
	selma_al: selma_al,
	seneca_falls_ny: seneca_falls_ny,
	seneca_sc: seneca_sc,
	sevierville_tn: sevierville_tn,
	seymour_in: seymour_in,
	shawnee_ok: shawnee_ok,
	sheboygan_wi: sheboygan_wi,
	shelby_nc: shelby_nc,
	shelbyville_tn: shelbyville_tn,
	shelton_wa: shelton_wa,
	sheridan_wy: sheridan_wy,
	sherman_denison_tx: sherman_denison_tx,
	shreveport_bossier_city_la: shreveport_bossier_city_la,
	sidney_oh: sidney_oh,
	sierra_vista_douglas_az: sierra_vista_douglas_az,
	sikeston_mo: sikeston_mo,
	silver_city_nm: silver_city_nm,
	silverthorne_co: silverthorne_co,
	sioux_city_ia_ne_sd: sioux_city_ia_ne_sd,
	sioux_falls_sd: sioux_falls_sd,
	snyder_tx: snyder_tx,
	somerset_ky: somerset_ky,
	somerset_pa: somerset_pa,
	south_bend_mishawaka_in_mi: south_bend_mishawaka_in_mi,
	southern_pines_pinehurst_nc: southern_pines_pinehurst_nc,
	spartanburg_sc: spartanburg_sc,
	spearfish_sd: spearfish_sd,
	spencer_ia: spencer_ia,
	spirit_lake_ia: spirit_lake_ia,
	spokane_wa: spokane_wa,
	springfield_il: springfield_il,
	springfield_ma: springfield_ma,
	springfield_mo: springfield_mo,
	springfield_oh: springfield_oh,
	st_cloud_mn: st_cloud_mn,
	st_george_ut: st_george_ut,
	st_joseph_mo_ks: st_joseph_mo_ks,
	st_louis_mo_il: st_louis_mo_il,
	st_marys_ga: st_marys_ga,
	st_marys_pa: st_marys_pa,
	starkville_ms: starkville_ms,
	state_college_pa: state_college_pa,
	statesboro_ga: statesboro_ga,
	statesville_mooresville_nc: statesville_mooresville_nc,
	staunton_waynesboro_va: staunton_waynesboro_va,
	stephenville_tx: stephenville_tx,
	sterling_co: sterling_co,
	sterling_il: sterling_il,
	stevens_point_wi: stevens_point_wi,
	stillwater_ok: stillwater_ok,
	stockton_ca: stockton_ca,
	storm_lake_ia: storm_lake_ia,
	sturgis_mi: sturgis_mi,
	sulphur_springs_tx: sulphur_springs_tx,
	summerville_ga: summerville_ga,
	sumter_sc: sumter_sc,
	sunbury_pa: sunbury_pa,
	susanville_ca: susanville_ca,
	sweetwater_tx: sweetwater_tx,
	syracuse_ny: syracuse_ny,
	tahlequah_ok: tahlequah_ok,
	talladega_sylacauga_al: talladega_sylacauga_al,
	tallahassee_fl: tallahassee_fl,
	tallulah_la: tallulah_la,
	tampa_st_petersburg_clearwater_fl: tampa_st_petersburg_clearwater_fl,
	taos_nm: taos_nm,
	taylorville_il: taylorville_il,
	terre_haute_in: terre_haute_in,
	texarkana_tx_texarkana_ar: texarkana_tx_texarkana_ar,
	the_villages_fl: the_villages_fl,
	thomaston_ga: thomaston_ga,
	thomasville_ga: thomasville_ga,
	thomasville_lexington_nc: thomasville_lexington_nc,
	tiffin_oh: tiffin_oh,
	tifton_ga: tifton_ga,
	toccoa_ga: toccoa_ga,
	toledo_oh: toledo_oh,
	topeka_ks: topeka_ks,
	torrington_ct: torrington_ct,
	traverse_city_mi: traverse_city_mi,
	trenton_ewing_nj: trenton_ewing_nj,
	troy_al: troy_al,
	truckee_grass_valley_ca: truckee_grass_valley_ca,
	tucson_az: tucson_az,
	tullahoma_tn: tullahoma_tn,
	tulsa_ok: tulsa_ok,
	tupelo_ms: tupelo_ms,
	tuscaloosa_al: tuscaloosa_al,
	tuskegee_al: tuskegee_al,
	twin_falls_id: twin_falls_id,
	tyler_tx: tyler_tx,
	ukiah_ca: ukiah_ca,
	union_city_tn_ky: union_city_tn_ky,
	union_sc: union_sc,
	urbana_oh: urbana_oh,
	utica_rome_ny: utica_rome_ny,
	uvalde_tx: uvalde_tx,
	valdosta_ga: valdosta_ga,
	vallejo_fairfield_ca: vallejo_fairfield_ca,
	valley_al: valley_al,
	van_wert_oh: van_wert_oh,
	vermillion_sd: vermillion_sd,
	vernal_ut: vernal_ut,
	vernon_tx: vernon_tx,
	vicksburg_ms: vicksburg_ms,
	victoria_tx: victoria_tx,
	vidalia_ga: vidalia_ga,
	vincennes_in: vincennes_in,
	vineland_millville_bridgeton_nj: vineland_millville_bridgeton_nj,
	virginia_beach_norfolk_newport_news_va_nc: virginia_beach_norfolk_newport_news_va_nc,
	visalia_porterville_ca: visalia_porterville_ca,
	wabash_in: wabash_in,
	waco_tx: waco_tx,
	wahpeton_nd_mn: wahpeton_nd_mn,
	walla_walla_wa: walla_walla_wa,
	walterboro_sc: walterboro_sc,
	wapakoneta_oh: wapakoneta_oh,
	warner_robins_ga: warner_robins_ga,
	warren_pa: warren_pa,
	warrensburg_mo: warrensburg_mo,
	warsaw_in: warsaw_in,
	washington_in: washington_in,
	washington_nc: washington_nc,
	washington_oh: washington_oh,
	washington_arlington_alexandria_dc_va_md_wv: washington_arlington_alexandria_dc_va_md_wv,
	waterloo_cedar_falls_ia: waterloo_cedar_falls_ia,
	watertown_sd: watertown_sd,
	watertown_fort_atkinson_wi: watertown_fort_atkinson_wi,
	watertown_fort_drum_ny: watertown_fort_drum_ny,
	wauchula_fl: wauchula_fl,
	wausau_wi: wausau_wi,
	waycross_ga: waycross_ga,
	weirton_steubenville_wv_oh: weirton_steubenville_wv_oh,
	wenatchee_wa: wenatchee_wa,
	west_helena_ar: west_helena_ar,
	west_plains_mo: west_plains_mo,
	west_point_ms: west_point_ms,
	wheeling_wv_oh: wheeling_wv_oh,
	whitewater_wi: whitewater_wi,
	wichita_falls_tx: wichita_falls_tx,
	wichita_ks: wichita_ks,
	williamsport_pa: williamsport_pa,
	willimantic_ct: willimantic_ct,
	williston_nd: williston_nd,
	willmar_mn: willmar_mn,
	wilmington_nc: wilmington_nc,
	wilmington_oh: wilmington_oh,
	wilson_nc: wilson_nc,
	winchester_va_wv: winchester_va_wv,
	winfield_ks: winfield_ks,
	winona_mn: winona_mn,
	winston_salem_nc: winston_salem_nc,
	woodward_ok: woodward_ok,
	wooster_oh: wooster_oh,
	worcester_ma: worcester_ma,
	worthington_mn: worthington_mn,
	yakima_wa: yakima_wa,
	yankton_sd: yankton_sd,
	yazoo_city_ms: yazoo_city_ms,
	york_hanover_pa: york_hanover_pa,
	youngstown_warren_boardman_oh_pa: youngstown_warren_boardman_oh_pa,
	yuba_city_ca: yuba_city_ca,
	yuma_az: yuma_az,
	zanesville_oh: zanesville_oh
};

var tooltipTimeout$5;

var _topojson$feature = topojson.feature(topology, topology.objects.states),
    states = _topojson$feature.features;

var UsaMapChart = function UsaMapChart(_ref) {
  var _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'states' : _ref$type,
      data = _ref.data,
      metric = _ref.metric,
      showMoreDetail = _ref.showMoreDetail,
      onItemClick = _ref.onItemClick,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var yMax = height;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var counties = Object.keys(usaCounties).map(function (county) {
    return {
      id: county,
      abbr: county.substring(county.length - 2, county.length).toUpperCase(),
      label: usaCounties[county].name,
      lat: usaCounties[county].value.lat,
      lng: usaCounties[county].value.lng
    };
  });
  var handleMouseMove = React.useCallback(function (event$1, feature, color) {
    if (color === void 0) {
      color = '#000000';
    }

    if (tooltipTimeout$5) clearTimeout(tooltipTimeout$5);
    if (!svgRef.current) return;
    var point = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, feature, {
        color: color
      }),
      tooltipTop: point === null || point === void 0 ? void 0 : point.y,
      tooltipLeft: point === null || point === void 0 ? void 0 : point.x
    });
  }, [svgRef, showTooltip]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$5 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var tooltipContent = React.useMemo(function () {
    if (showMoreDetail) {
      return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
        opened: tooltipOpen,
        top: tooltipTop || 0,
        left: tooltipLeft || 0,
        data: tooltipData
      }, metric === METRICS.REACH && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), metric === METRICS.AFFINITY && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), metric === METRICS.BASE && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE, 1))));
    }

    return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(StyledUsaMapChartTooltip, {
      top: tooltipTop,
      left: tooltipLeft
    }, /*#__PURE__*/React__default.createElement("div", null, tooltipData && tooltipData.label)));
  }, [showMoreDetail, tooltipLeft, tooltipTop, tooltipData, metric, tooltipOpen]);
  var scale$1 = (width + height) / 1.55;
  var centerX = width / 2;
  var centerY = height / 2;
  var max = data && Math.max.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;
  var min = data && Math.min.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;
  var colorsRange = getMapColors(color);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [metric === METRICS.AFFINITY ? min : min * 100, metric === METRICS.AFFINITY ? max : max * 100],
      range: colorsRange
    });
  }, [metric, min, max, color]);
  var getFillColor = React.useCallback(function (item) {
    if (!metric) {
      return '#d8d7ea';
    }

    var value = item[metric] || 0;

    if (metric !== METRICS.AFFINITY) {
      value = value * 100;
    }

    return colorScale(value);
  }, [metric, colorScale]);
  var rScale = React.useMemo(function () {
    return scale.scaleSqrt({
      domain: [min, max],
      range: [0, 20],
      nice: true
    });
  }, [min, max]);
  var getCircles = React.useCallback(function (abbr, projection) {
    var stateCounties = counties.filter(function (county) {
      return abbr === county.abbr;
    });
    return stateCounties.map(function (county) {
      var countyData = data && data.find(function (item) {
        return item.id === county.id;
      });
      return {
        id: county.id,
        radius: metric && countyData && rScale(countyData[metric]) || 0,
        position: projection([county.lng, county.lat]),
        data: countyData
      };
    });
  }, [data, metric, rScale]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledUsaMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledUsaMapChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement(geo.AlbersUsa, {
    data: states,
    scale: scale$1,
    translate: [centerX, centerY - 25]
  }, function (_ref2) {
    var features = _ref2.features;
    return features.map(function (_ref3, i) {
      var feature = _ref3.feature,
          path = _ref3.path,
          projection = _ref3.projection;
      var abbr = statesAbbr.find(function (abbr) {
        return abbr.id === feature.id;
      });
      var abbrLabel = abbr && abbr.label || '';
      var included = data && data.find(function (item) {
        return item.id === abbrLabel;
      });
      var circles = getCircles(abbrLabel, projection);

      if (!included || type === 'counties') {
        return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
          key: "map-" + chartId.current + "-feature-fragment-" + i
        }, /*#__PURE__*/React__default.createElement(StyledMapFeatureSvg, {
          key: "map-" + chartId.current + "-feature-svg-" + i,
          selectable: false
        }, /*#__PURE__*/React__default.createElement("path", {
          key: "map-" + chartId.current + "-feature-" + i,
          d: path || '',
          fill: type === 'counties' ? '#e6ebee' : '#d8d7ea',
          stroke: type === 'counties' ? '#afb3b4' : '#ffffff',
          strokeWidth: 1
        }), type === 'counties' && circles && circles.map(function (circle, indx) {
          return /*#__PURE__*/React__default.createElement(shape.Circle, {
            key: "county-" + chartId.current + "-feature-" + i + "-" + indx,
            r: circle.radius,
            cx: circle.position && circle.position[0] || 0,
            cy: circle.position && circle.position[1] || 0,
            fill: "#41b6a8",
            fillOpacity: 0.5,
            onMouseOver: function onMouseOver(event) {
              return handleMouseMove(event, circle.data);
            },
            onMouseMove: function onMouseMove(event) {
              return handleMouseMove(event, circle.data);
            },
            onMouseLeave: function onMouseLeave(event) {
              return handleMouseLeave(event);
            }
          });
        })));
      }

      return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
        key: "map-" + chartId.current + "-feature-fragment-" + i
      }, /*#__PURE__*/React__default.createElement(StyledMapFeatureSvg, {
        key: "map-" + chartId.current + "-feature-svg-" + i,
        metric: metric,
        selectable: true
      }, /*#__PURE__*/React__default.createElement("path", {
        key: "map-" + chartId.current + "-feature-" + i,
        d: path || '',
        fill: getFillColor(included),
        stroke: "#ffffff",
        strokeWidth: 1,
        onMouseOver: function onMouseOver(event) {
          return handleMouseMove(event, included, getFillColor(included));
        },
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, included, getFillColor(included));
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        onClick: function onClick() {
          onItemClick && onItemClick(included);
        }
      })));
    });
  }), metric && type !== 'counties' && /*#__PURE__*/React__default.createElement(group.Group, {
    top: yMax - 40,
    left: centerX - 100
  }, /*#__PURE__*/React__default.createElement(gradient.LinearGradient, {
    from: colorsRange[0],
    to: colorsRange[1],
    id: "legend-gradient",
    vertical: false
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 0,
    y: -10
  }, FormatUtils.formattedValue(min, metric, metric !== METRICS.AFFINITY ? 1 : 2)), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 200,
    y: -10
  }, "" + FormatUtils.formattedValue(max, metric, metric !== METRICS.AFFINITY ? 1 : 2)), /*#__PURE__*/React__default.createElement("rect", {
    width: 200,
    height: 20,
    fill: "url(#legend-gradient)"
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 100,
    y: 30
  }, MAP_CHART_FIELDS_LABEL[metric]))), tooltipContent);
};

var BubbleImage = function BubbleImage(_ref) {
  var item = _ref.item,
      x = _ref.x,
      y = _ref.y,
      radius = _ref.radius,
      color = _ref.color,
      showItemsPreview = _ref.showItemsPreview,
      onMouseMove = _ref.onMouseMove,
      onMouseLeave = _ref.onMouseLeave,
      chartId = _ref.chartId;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [item.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (!item.pic || !showItemsPreview || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement(shape.Circle, {
      r: radius,
      cx: x,
      cy: y,
      fill: color,
      onMouseMove: onMouseMove,
      onMouseLeave: onMouseLeave,
      onTouchMove: onMouseMove,
      onTouchEnd: onMouseLeave
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      height: radius * 2,
      width: radius * 2,
      x: x,
      y: y,
      fontSize: "10px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000"
    }, item.label.toUpperCase())));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: item.pic,
    height: radius * 2,
    width: radius * 2,
    clipPath: "url(#icon-" + chartId + "-" + item.id + ")",
    x: x - radius,
    y: y - radius,
    onMouseMove: onMouseMove,
    onMouseLeave: onMouseLeave,
    onTouchMove: onMouseMove,
    onTouchEnd: onMouseLeave,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "icon-" + chartId + "-" + item.id,
    key: "icon-" + chartId + "-" + item.id,
    className: "dot",
    r: radius,
    cx: x,
    cy: y
  }), /*#__PURE__*/React__default.createElement(shape.Circle, {
    r: radius,
    cx: x,
    cy: y,
    fill: "none",
    stroke: color,
    strokeWidth: "2"
  }));
};

function _templateObject$c() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$c = function _templateObject() {
    return data;
  };

  return data;
}
var StyledBubbleChartWrapper = styled__default.div(_templateObject$c());
var tooltipTimeout$6;
var defaultMargin$7 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var BubbleChart = function BubbleChart(_ref) {
  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$7 : _ref$margin,
      xAxis = _ref.xAxis,
      yAxis = _ref.yAxis,
      zAxis = _ref.zAxis,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      showItemsPreview = _ref.showItemsPreview;
  var isEmpty = !data || data.length === 0;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var filteredData = React.useMemo(function () {
    if (isEmpty) {
      return [];
    }

    return limit !== 'auto' ? data.slice(0, limit) : data;
  }, [isEmpty, data, limit]);

  var _ref2 = filteredData && filteredData.reduce(function (_ref3, item) {
    var xList = _ref3[0],
        yList = _ref3[1],
        rList = _ref3[2];
    xList.push(item[xAxis]);
    yList.push(item[yAxis]);
    rList.push(zAxis === METRICS.BASE ? item[zAxis] * 100 : item[zAxis]);
    return [xList, yList, rList];
  }, [[], [], []]) || [[], [], []],
      xValues = _ref2[0],
      yValues = _ref2[1],
      rValues = _ref2[2];

  var minMaxValues = React.useMemo(function () {
    return {
      xMin: Math.min.apply(Math, xValues),
      xMax: Math.max.apply(Math, xValues),
      yMin: Math.min.apply(Math, yValues),
      yMax: Math.max.apply(Math, yValues),
      rMin: Math.min.apply(Math, rValues),
      rMax: Math.max.apply(Math, rValues)
    };
  }, [xValues, yValues, rValues]);
  var xDiff = Math.max(minMaxValues.xMax - minMaxValues.xMin, 0);
  var yDiff = Math.max(minMaxValues.yMax - minMaxValues.yMin, 0);
  var yDomain = React.useMemo(function () {
    return [minMaxValues.yMin - yDiff / 3, minMaxValues.yMax + yDiff / 3];
  }, [minMaxValues, yDiff]);
  var xDomain = React.useMemo(function () {
    return [minMaxValues.xMin - xDiff / 10 < 0 ? 0 : minMaxValues.xMin - xDiff / 10, minMaxValues.xMax + xDiff / 10];
  }, [minMaxValues, xDiff]);
  var xScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: xDomain,
      range: [0, minMaxValues.xMax],
      nice: true
    });
  }, [minMaxValues, xDomain]);
  var yScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: yDomain,
      range: [minMaxValues.yMax, 0],
      nice: true
    });
  }, [minMaxValues, yDomain]);
  var rScale = React.useMemo(function () {
    return scale.scaleSqrt({
      domain: [minMaxValues.rMin, minMaxValues.rMax],
      range: [10, 50],
      nice: true
    });
  }, [minMaxValues]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : filteredData.length / 2, isEmpty ? 0 : filteredData.length],
      range: getColors(color)
    });
  }, [isEmpty, filteredData, color]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  xScale.rangeRound([0, xMax]);
  yScale.rangeRound([yMax, 0]);
  var yTicks = Math.min(yAxis === METRICS.AFFINITY ? yDiff : yDiff <= 0.01 ? 1 : yDiff * 100, 10);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$6 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, item, indx) {
    if (tooltipTimeout$6) clearTimeout(tooltipTimeout$6);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, item, {
        color: colorScale(indx)
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, colorScale]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledBubbleChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledBubbleChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(grid.Grid, {
    top: margin.top,
    left: margin.left,
    xScale: xScale,
    yScale: yScale,
    width: xMax,
    height: yMax,
    numTicksRows: yTicks
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, filteredData.map(function (item, indx) {
    var radius = rScale(zAxis === METRICS.BASE ? item[zAxis] * 100 : item[zAxis]);
    var bubbleX = xScale(item[xAxis]);
    var bubbleY = yScale(item[yAxis]);

    if (bubbleX && bubbleY) {
      return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
        key: "bubble-" + chartId.current + "-" + item.id
      }, /*#__PURE__*/React__default.createElement(BubbleImage, {
        item: item,
        x: bubbleX,
        y: bubbleY,
        radius: radius,
        color: colorScale(indx),
        onMouseMove: function onMouseMove(event) {
          return handleMouseMove(event, item, indx);
        },
        onMouseLeave: function onMouseLeave(event) {
          return handleMouseLeave(event);
        },
        chartId: chartId.current,
        showItemsPreview: showItemsPreview
      }));
    }

    return null;
  }), /*#__PURE__*/React__default.createElement(axis.AxisLeft, {
    label: MAP_CHART_FIELDS_LABEL[yAxis],
    scale: yScale,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, yAxis, yAxis === METRICS.REACH ? 1 : 2);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'end',
        dy: '0.33em',
        dx: '-0.33em',
        fontWeight: 'bold'
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold',
      dx: '-1.2em'
    },
    numTicks: yTicks
  }), /*#__PURE__*/React__default.createElement(axis.AxisBottom, {
    label: MAP_CHART_FIELDS_LABEL[xAxis],
    top: yMax,
    scale: xScale,
    stroke: "#9493A6",
    tickStroke: "#9493A6",
    tickFormat: function tickFormat(d) {
      return FormatUtils.formattedValue(d, xAxis, xAxis === METRICS.REACH ? 1 : 2);
    },
    tickLabelProps: function tickLabelProps() {
      return {
        fill: '#9493A6',
        fontSize: 11,
        textAnchor: 'middle',
        fontWeight: 'bold'
      };
    },
    labelProps: {
      fill: 'black',
      textAnchor: 'middle',
      fontSize: 14,
      fontWeight: 'bold'
    }
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE, 1))));
};

function _templateObject2$7() {
  var data = _taggedTemplateLiteralLoose(["\nposition: absolute;\n    border-radius: 50%;\n    background-size: cover;\n    border: 1px solid rgba(205, 205, 205, 0.7);\n    cursor: pointer;\n    transition: all 0.4s;\n\n&.bubble-0 {\n  width: 36%;\n  padding-top: 36%;\n  left: 64%;\n  top: 14%;\n}\n&.bubble-1 {\n  width: 33%;\n  padding-top: 33%;\n  left: 3%;\n  top: 0;\n}\n&.bubble-2 {\n  width: 28%;\n  padding-top: 28%;\n  left: 1%;\n  top: 35%;\n}\n&.bubble-3 {\n  width: 25%;\n  padding-top: 25%;\n  left: 45%;\n  top: 0%;\n}\n&.bubble-4 {\n  width: 26%;\n  padding-top: 26%;\n  left: 29%;\n  top: 26%;\n}\n&.bubble-5 {\n  width: 23%;\n  padding-top: 23%;\n  left: 60%;\n  top: 52%;\n}\n&.bubble-6 {\n  width: 20%;\n  padding-top: 20%;\n  left: 30%;\n  top: 60%;\n}\n&.bubble-7 {\n  width: 18%;\n  padding-top: 18%;\n  left: 80%;\n  top: 70%;\n}\n&.bubble-8 {\n  width: 16%;\n  padding-top: 16%;\n  left: 60%;\n  top: 80%;\n}\n&.bubble-9 {\n  width: 14%;\n  padding-top: 14%;\n  left: 5%;\n  top: 66%;\n}\n&.bubble-10 {\n  width: 12%;\n  padding-top: 12%;\n  left: 85%;\n  top: 2%;\n}\n&.bubble-11 {\n  width: 10%;\n  padding-top: 10%;\n  left: 56%;\n  top: 43%;\n}\n&.bubble-12 {\n  width: 9.5%;\n  padding-top: 9.5%;\n  left: 20%;\n  top: 75%;\n}\n&.bubble-13 {\n  width: 9%;\n  padding-top: 9%;\n  left: 54%;\n  top: 26%;\n}\n&.bubble-14 {\n  width: 8.5%;\n  padding-top: 8.5%;\n  left: 47%;\n  top: 53%;\n}\n&.bubble-15 {\n  width: 8%;\n  padding-top: 8%;\n  left: 53%;\n  top: 72%;\n}\n&.bubble-16 {\n  width: 8%;\n  padding-top: 8%;\n  left: 35%;\n  top: 3%;\n}\n&.bubble-17 {\n\twidth: 7.5%;\n\tpadding-top: 7.5%;\n  left: 33%;\n  top: 84%;\n}\n&.bubble-18 {\n  width: 7.5%;\n  padding-top: 7.5%;\n  left: 87%;\n  top: 53%;\n}\n&.bubble-19 {\n  width: 7%;\n  padding-top: 7%;\n  left: 45%;\n  top: 85%;\n}\n"]);

  _templateObject2$7 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$d() {
  var data = _taggedTemplateLiteralLoose(["\n  \n  position: relative;\n\twidth: 100%;\n\theight: 100%;\n"]);

  _templateObject$d = function _templateObject() {
    return data;
  };

  return data;
}
var StyledCloudChartWrapper = styled__default.div(_templateObject$d());
var StyledCloudChartItem = styled__default.div(_templateObject2$7());

var CloudChartImage = function CloudChartImage(_ref) {
  var item = _ref.item,
      x = _ref.x,
      y = _ref.y,
      radius = _ref.radius,
      color = _ref.color,
      onMouseMove = _ref.onMouseMove,
      onMouseLeave = _ref.onMouseLeave,
      chartId = _ref.chartId;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [item.pic]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (!item.pic || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("svg", {
      overflow: "visible"
    }, /*#__PURE__*/React__default.createElement(group.Group, null, /*#__PURE__*/React__default.createElement(shape.Circle, {
      r: radius,
      cx: x,
      cy: y,
      fill: color,
      onMouseMove: onMouseMove,
      onMouseLeave: onMouseLeave,
      onTouchMove: onMouseMove,
      onTouchEnd: onMouseLeave
    }), /*#__PURE__*/React__default.createElement(text.Text, {
      height: radius * 2,
      width: radius * 2,
      x: x,
      y: y,
      fontSize: "10px",
      fontWeight: "bold",
      textAnchor: "middle",
      verticalAnchor: "middle",
      fill: "#000000"
    }, item.label.toUpperCase())));
  }

  return /*#__PURE__*/React__default.createElement("svg", {
    overflow: "visible"
  }, /*#__PURE__*/React__default.createElement("image", {
    href: item.pic,
    height: radius * 2,
    width: radius * 2,
    clipPath: "url(#icon-" + chartId + "-" + item.id + ")",
    x: x - radius,
    y: y - radius,
    onMouseMove: onMouseMove,
    onMouseLeave: onMouseLeave,
    onTouchMove: onMouseMove,
    onTouchEnd: onMouseLeave,
    onError: onErrorLoadingImage
  }), /*#__PURE__*/React__default.createElement(clipPath.CircleClipPath, {
    id: "icon-" + chartId + "-" + item.id,
    key: "icon-" + chartId + "-" + item.id,
    className: "dot",
    r: radius,
    cx: x,
    cy: y
  }), /*#__PURE__*/React__default.createElement(shape.Circle, {
    r: radius,
    cx: x,
    cy: y,
    fill: "none",
    stroke: color,
    strokeWidth: "2"
  }));
};

var tooltipTimeout$7;
var defaultMargin$8 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 50
};

var CloudChart = function CloudChart(_ref) {
  var _pack;

  var data = _ref.data,
      _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$8 : _ref$margin,
      metric = _ref.metric,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var isEmpty = !data || data.length === 0;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var xMax = width - margin.left - margin.right;
  var yMax = height - margin.top - margin.bottom;
  var values = React.useMemo(function () {
    return data && data.map(function (item) {
      return metric === METRICS.BASE ? item[metric] * 100 : item[metric];
    }) || [];
  }, [data, metric]);
  var minMaxValues = React.useMemo(function () {
    return {
      rMin: Math.min.apply(Math, values),
      rMax: Math.max.apply(Math, values)
    };
  }, [values]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : data.length / 2, isEmpty ? 0 : data.length],
      range: getColors(color)
    });
  }, [isEmpty, data, color]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$7 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, item, indx) {
    if (tooltipTimeout$7) clearTimeout(tooltipTimeout$7);
    var eventSvgCoords = event.localPoint(event$1);
    showTooltip({
      tooltipData: _extends({}, item, {
        color: colorScale(indx)
      }),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip, colorScale]);
  var pack = (_pack = {
    children: data,
    name: 'root',
    radius: 0,
    distance: 0
  }, _pack[metric] = 0, _pack);
  var root = hierarchy.hierarchy(pack).sum(function (d) {
    return d[metric];
  });

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledCloudChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledCloudChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "white",
    width: width,
    height: height,
    rx: 14
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: margin.top,
    left: margin.left,
    key: "group-" + chartId.current
  }, /*#__PURE__*/React__default.createElement(hierarchy.Pack, {
    root: root,
    size: [xMax, yMax]
  }, function (packData) {
    var circles = packData.descendants().slice(1);
    return /*#__PURE__*/React__default.createElement(group.Group, null, circles.map(function (circle, i) {
      if (circle.x >= 0 && circle.y >= 0 && circle.r) {
        return /*#__PURE__*/React__default.createElement(React__default.Fragment, {
          key: "cloud-" + chartId.current + "-item-" + i
        }, /*#__PURE__*/React__default.createElement(CloudChartImage, {
          item: circle.data,
          x: circle.x,
          y: circle.y,
          radius: circle.r,
          color: colorScale(i),
          onMouseMove: function onMouseMove(event) {
            return handleMouseMove(event, circle.data, i);
          },
          onMouseLeave: function onMouseLeave(event) {
            return handleMouseLeave(event);
          },
          chartId: chartId.current
        }));
      }

      return null;
    }));
  }))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE))));
};

function _templateObject$e() {
  var data = _taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: row;\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$e = function _templateObject() {
    return data;
  };

  return data;
}
var StyledDoubleChartWrapper = styled__default.div(_templateObject$e());
var defaultMargin$9 = {
  top: 50,
  right: 50,
  bottom: 50,
  left: 100
};

var DoubleChart = function DoubleChart(_ref) {
  var _ref$margin = _ref.margin,
      margin = _ref$margin === void 0 ? defaultMargin$9 : _ref$margin,
      data = _ref.data,
      x1Axis = _ref.x1Axis,
      x2Axis = _ref.x2Axis,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage,
      _ref$limit = _ref.limit,
      limit = _ref$limit === void 0 ? 'auto' : _ref$limit,
      showItemsPreview = _ref.showItemsPreview;
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledDoubleChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  return /*#__PURE__*/React__default.createElement(StyledDoubleChartWrapper, null, /*#__PURE__*/React__default.createElement("div", {
    style: {
      width: '50%',
      height: '100%'
    }
  }, /*#__PURE__*/React__default.createElement(StackedChart, {
    key: "stacked-bar-left-" + chartId.current,
    limit: limit,
    xAxis: x1Axis,
    data: data,
    color: color,
    margin: margin,
    showItemsPreview: showItemsPreview
  })), /*#__PURE__*/React__default.createElement("div", {
    style: {
      width: '50%',
      height: '100%'
    }
  }, /*#__PURE__*/React__default.createElement(StackedChart, {
    key: "stacked-bar-right-" + chartId.current,
    limit: limit,
    xAxis: x2Axis,
    data: data,
    color: color,
    margin: {
      top: 50,
      right: 50,
      bottom: 50,
      left: 20
    },
    showAxisLeft: false
  })));
};

function _templateObject12() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 14px;\n  font-weight: 500;\n  color: rgb(148, 147, 166);\n  margin-right: 10px;\n  text-align: end;\n"]);

  _templateObject12 = function _templateObject12() {
    return data;
  };

  return data;
}

function _templateObject11() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 14px;\n  font-weight: 400;\n  color: rgb(148, 147, 166);\n  margin-right: 10px;\n"]);

  _templateObject11 = function _templateObject11() {
    return data;
  };

  return data;
}

function _templateObject10$1() {
  var data = _taggedTemplateLiteralLoose(["\n  padding-top: 10px;\n  font-size: 11px;\n  font-weight: 300;\n  color: rgb(148, 147, 166);\n"]);

  _templateObject10$1 = function _templateObject10() {
    return data;
  };

  return data;
}

function _templateObject9$1() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 16px;\n  font-weight: 500;\n  color: rgb(148, 147, 166);\n"]);

  _templateObject9$1 = function _templateObject9() {
    return data;
  };

  return data;
}

function _templateObject8$1() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 83%;\n  display: flex;\n  align-items: left;\n  flex-direction: column;\n  padding-left: 10px;\n"]);

  _templateObject8$1 = function _templateObject8() {
    return data;
  };

  return data;
}

function _templateObject7$1() {
  var data = _taggedTemplateLiteralLoose(["\n  font-size: 12px;\n  padding: 1px 1px 0 0;\n  background-color: #cdcdcd;\n  color: white;\n  width: 18px;\n  height: 18px;\n  border-radius: 50%;\n  text-align: center;\n  z-index: 1;\n  position: absolute;\n  left: 10px;\n"]);

  _templateObject7$1 = function _templateObject7() {
    return data;
  };

  return data;
}

function _templateObject6$2() {
  var data = _taggedTemplateLiteralLoose(["\n  margin-left: 10px;\n  width: 50px;\n  height: 50px;\n  border: 1px solid rgba(148, 147, 166, 0.5);\n  border-radius: 50%;\n"]);

  _templateObject6$2 = function _templateObject6() {
    return data;
  };

  return data;
}

function _templateObject5$2() {
  var data = _taggedTemplateLiteralLoose(["\n  margin-left: 10px;\n  width: 50px;\n  height: 50px;\n  border: 1px solid rgba(148, 147, 166, 0.5);\n  border-radius: 50%;\n  background-color: ", ";\n"]);

  _templateObject5$2 = function _templateObject5() {
    return data;
  };

  return data;
}

function _templateObject4$4() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 86px;\n  border-bottom: 1px solid #cdcdcd;\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  flex-direction: row;\n  position: relative;\n"]);

  _templateObject4$4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3$6() {
  var data = _taggedTemplateLiteralLoose(["\n  height: 100%;\n  overflow: hidden auto;\n"]);

  _templateObject3$6 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$8() {
  var data = _taggedTemplateLiteralLoose(["\n  z-index: 1;\n"]);

  _templateObject2$8 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$f() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$f = function _templateObject() {
    return data;
  };

  return data;
}
var StyledListChartWrapper = styled__default.div(_templateObject$f());
var StyledListChartSvg = styled__default.svg(_templateObject2$8());
var StyledListChartContent = styled__default.div(_templateObject3$6());
var StyledListItem = styled__default.div(_templateObject4$4());
var StyledListItemPreview = styled__default.div(_templateObject5$2(), function (props) {
  return props.color;
});
var StyledListItemPreviewImg = styled__default.img(_templateObject6$2());
var StyledListItemNumber = styled__default.div(_templateObject7$1());
var StyledListItemContent = styled__default.div(_templateObject8$1());
var StyledListItemTitle = styled__default.div(_templateObject9$1());
var StyledListItemSubTitle = styled__default.div(_templateObject10$1());
var StyledListItemValue = styled__default.div(_templateObject11());
var StyledListChartMetric = styled__default.div(_templateObject12());

var ListChartImage = function ListChartImage(_ref) {
  var index = _ref.index,
      color = _ref.color,
      image = _ref.image;

  var _useState = React.useState(false),
      errorLoadingImage = _useState[0],
      setErrorLoadingImage = _useState[1];

  React.useEffect(function () {
    setErrorLoadingImage(false);
  }, [image]);
  var onErrorLoadingImage = React.useCallback(function () {
    setErrorLoadingImage(true);
  }, []);

  if (!image || errorLoadingImage) {
    return /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement(StyledListItemNumber, null, index + 1), /*#__PURE__*/React__default.createElement(StyledListItemPreview, {
      color: color
    }));
  }

  return /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement(StyledListItemNumber, null, index + 1), /*#__PURE__*/React__default.createElement(StyledListItemPreviewImg, {
    src: image,
    onError: onErrorLoadingImage
  }));
};

var tooltipTimeout$8;

var ListChart = function ListChart(_ref) {
  var data = _ref.data,
      metric = _ref.metric,
      color = _ref.color;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$8 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);
  var handleMouseMove = React.useCallback(function (event$1, item) {
    if (tooltipTimeout$8) clearTimeout(tooltipTimeout$8);
    if (!svgRef.current) return;
    var eventSvgCoords = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, item),
      tooltipTop: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.y,
      tooltipLeft: eventSvgCoords === null || eventSvgCoords === void 0 ? void 0 : eventSvgCoords.x
    });
  }, [showTooltip]);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [0, isEmpty ? 0 : data.length / 2, isEmpty ? 0 : data.length],
      range: getColors(color)
    });
  }, [isEmpty, data, color]);
  return /*#__PURE__*/React__default.createElement(StyledListChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement(StyledListChartSvg, {
    ref: svgRef,
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement("rect", {
    width: width,
    height: height,
    fill: "#ffffff"
  }), /*#__PURE__*/React__default.createElement(group.Group, {
    top: 0,
    left: 0,
    key: "group-" + chartId.current
  }, /*#__PURE__*/React__default.createElement("rect", {
    fill: "#ffffff",
    width: width,
    height: height
  }), /*#__PURE__*/React__default.createElement("foreignObject", {
    x: "0",
    y: "0",
    width: width,
    height: height
  }, /*#__PURE__*/React__default.createElement(StyledListChartContent, null, /*#__PURE__*/React__default.createElement(StyledListChartMetric, null, MAP_CHART_FIELDS_LABEL[metric]), data && data.map(function (item, index) {
    return /*#__PURE__*/React__default.createElement(StyledListItem, {
      key: "list-chart-item-" + item.id,
      onMouseMove: function onMouseMove(event) {
        return handleMouseMove(event, item);
      },
      onMouseLeave: function onMouseLeave(event) {
        return handleMouseLeave(event);
      }
    }, /*#__PURE__*/React__default.createElement(ListChartImage, {
      image: item.pic,
      color: colorScale(index),
      index: index
    }), /*#__PURE__*/React__default.createElement(StyledListItemContent, null, /*#__PURE__*/React__default.createElement(StyledListItemTitle, null, item.label), /*#__PURE__*/React__default.createElement(StyledListItemSubTitle, null, item.taxonomy)), /*#__PURE__*/React__default.createElement(StyledListItemValue, null, metric === METRICS.REACH && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(item.target_audience_perc, METRICS.REACH, 1)), metric === METRICS.AFFINITY && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(item.target_audience_affinity, METRICS.AFFINITY, 2)), metric === METRICS.BASE && /*#__PURE__*/React__default.createElement("div", null, FormatUtils.formattedValue(item.base_population_perc, METRICS.BASE, 1))));
  }))))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE))));
};

var arcs$1 = [
	[
		[
			7080,
			7327
		],
		[
			-5,
			4
		],
		[
			-10,
			-10
		],
		[
			5,
			-6
		]
	],
	[
		[
			7070,
			7315
		],
		[
			-16,
			-12
		],
		[
			-9,
			5
		],
		[
			-28,
			-4
		],
		[
			-12,
			-6
		],
		[
			-1,
			-5
		],
		[
			-17,
			-18
		],
		[
			-11,
			-16
		],
		[
			6,
			-10
		],
		[
			6,
			-18
		],
		[
			-2,
			-15
		],
		[
			3,
			-8
		],
		[
			-18,
			-35
		],
		[
			4,
			-12
		],
		[
			-2,
			-18
		],
		[
			-7,
			-5
		],
		[
			-13,
			0
		],
		[
			-13,
			4
		],
		[
			3,
			-16
		],
		[
			6,
			-6
		],
		[
			-1,
			-9
		],
		[
			4,
			-9
		],
		[
			-12,
			-14
		],
		[
			-8,
			0
		],
		[
			-6,
			-18
		],
		[
			2,
			-7
		],
		[
			-6,
			-11
		],
		[
			2,
			-30
		],
		[
			-8,
			-17
		],
		[
			-6,
			-1
		],
		[
			-2,
			8
		],
		[
			-15,
			4
		],
		[
			-3,
			-8
		],
		[
			-14,
			-12
		],
		[
			6,
			-9
		],
		[
			-11,
			-7
		],
		[
			-13,
			6
		],
		[
			-7,
			-15
		],
		[
			-8,
			-7
		],
		[
			-3,
			-19
		],
		[
			2,
			-9
		],
		[
			-4,
			-35
		],
		[
			-32,
			-17
		],
		[
			-16,
			2
		],
		[
			-11,
			-11
		],
		[
			-14,
			6
		],
		[
			-30,
			-5
		],
		[
			-46,
			26
		]
	],
	[
		[
			6689,
			6902
		],
		[
			27,
			56
		],
		[
			1,
			10
		],
		[
			-4,
			21
		],
		[
			-24,
			7
		],
		[
			-1,
			9
		],
		[
			1,
			35
		],
		[
			-7,
			43
		],
		[
			0,
			9
		],
		[
			7,
			14
		],
		[
			1,
			9
		],
		[
			-10,
			5
		],
		[
			0,
			31
		],
		[
			11,
			8
		],
		[
			-5,
			13
		],
		[
			7,
			6
		],
		[
			5,
			26
		],
		[
			-1,
			11
		],
		[
			4,
			19
		]
	],
	[
		[
			6701,
			7234
		],
		[
			8,
			-10
		],
		[
			13,
			-1
		],
		[
			6,
			-7
		],
		[
			1,
			-9
		],
		[
			5,
			8
		],
		[
			5,
			-4
		],
		[
			13,
			13
		],
		[
			0,
			24
		],
		[
			9,
			0
		],
		[
			4,
			6
		],
		[
			20,
			11
		],
		[
			9,
			15
		],
		[
			0,
			16
		],
		[
			5,
			14
		],
		[
			-1,
			9
		],
		[
			9,
			8
		],
		[
			12,
			0
		],
		[
			4,
			16
		],
		[
			4,
			3
		],
		[
			15,
			-14
		],
		[
			5,
			2
		]
	],
	[
		[
			6847,
			7334
		],
		[
			14,
			2
		],
		[
			7,
			-12
		],
		[
			6,
			6
		],
		[
			8,
			-6
		]
	],
	[
		[
			6882,
			7324
		],
		[
			7,
			-15
		],
		[
			7,
			10
		],
		[
			15,
			9
		],
		[
			2,
			5
		],
		[
			10,
			-14
		],
		[
			5,
			7
		],
		[
			-2,
			13
		],
		[
			4,
			8
		],
		[
			21,
			2
		],
		[
			-3,
			18
		],
		[
			5,
			4
		],
		[
			12,
			26
		],
		[
			9,
			-2
		],
		[
			7,
			-9
		],
		[
			-1,
			-21
		],
		[
			6,
			3
		],
		[
			2,
			-8
		],
		[
			-3,
			-14
		],
		[
			-1,
			-35
		],
		[
			3,
			-12
		],
		[
			7,
			-4
		],
		[
			15,
			19
		],
		[
			9,
			1
		],
		[
			3,
			11
		],
		[
			14,
			14
		],
		[
			13,
			-2
		],
		[
			-1,
			-12
		],
		[
			14,
			8
		],
		[
			12,
			2
		],
		[
			7,
			-9
		]
	],
	[
		[
			5665,
			4557
		],
		[
			3,
			-32
		],
		[
			-3,
			-9
		],
		[
			0,
			-36
		],
		[
			2,
			-12
		],
		[
			-5,
			-22
		],
		[
			4,
			-12
		],
		[
			-56,
			0
		],
		[
			0,
			-182
		],
		[
			3,
			-21
		],
		[
			6,
			-7
		],
		[
			15,
			-33
		],
		[
			6,
			-7
		],
		[
			3,
			-10
		],
		[
			6,
			-7
		]
	],
	[
		[
			5649,
			4167
		],
		[
			-53,
			-21
		],
		[
			-11,
			4
		],
		[
			-8,
			-4
		],
		[
			-13,
			9
		],
		[
			-8,
			-3
		],
		[
			-17,
			2
		],
		[
			-5,
			4
		],
		[
			-10,
			0
		],
		[
			-7,
			9
		],
		[
			-5,
			14
		],
		[
			-52,
			0
		],
		[
			-66,
			0
		],
		[
			-7,
			-1
		],
		[
			-12,
			17
		],
		[
			-4,
			9
		],
		[
			-6,
			1
		],
		[
			-18,
			-16
		],
		[
			-15,
			4
		],
		[
			-6,
			-6
		]
	],
	[
		[
			5326,
			4189
		],
		[
			0,
			28
		],
		[
			2,
			-1
		],
		[
			-2,
			58
		],
		[
			7,
			9
		],
		[
			1,
			23
		],
		[
			6,
			24
		],
		[
			2,
			20
		],
		[
			0,
			23
		],
		[
			5,
			12
		],
		[
			0,
			26
		],
		[
			4,
			4
		],
		[
			8,
			20
		],
		[
			0,
			10
		],
		[
			6,
			12
		],
		[
			5,
			0
		],
		[
			8,
			20
		],
		[
			5,
			28
		],
		[
			-1,
			20
		],
		[
			2,
			29
		],
		[
			-2,
			15
		],
		[
			-7,
			15
		],
		[
			-8,
			46
		],
		[
			-7,
			29
		],
		[
			6,
			16
		],
		[
			6,
			7
		],
		[
			-1,
			21
		],
		[
			-3,
			9
		],
		[
			-10,
			48
		],
		[
			-2,
			4
		],
		[
			0,
			21
		],
		[
			-8,
			16
		],
		[
			-8,
			30
		],
		[
			16,
			4
		],
		[
			10,
			11
		]
	],
	[
		[
			5366,
			4846
		],
		[
			4,
			-2
		],
		[
			18,
			2
		],
		[
			12,
			-3
		],
		[
			21,
			2
		],
		[
			32,
			1
		],
		[
			7,
			-4
		],
		[
			4,
			-15
		],
		[
			0,
			-22
		],
		[
			3,
			-16
		],
		[
			3,
			-3
		],
		[
			0,
			-19
		],
		[
			10,
			-23
		],
		[
			0,
			-8
		],
		[
			9,
			-20
		],
		[
			7,
			4
		],
		[
			6,
			-4
		],
		[
			2,
			6
		],
		[
			33,
			0
		],
		[
			1,
			20
		],
		[
			4,
			12
		],
		[
			-2,
			8
		],
		[
			2,
			18
		],
		[
			21,
			0
		],
		[
			9,
			5
		],
		[
			-3,
			-22
		],
		[
			36,
			0
		],
		[
			1,
			-22
		],
		[
			-2,
			-20
		],
		[
			5,
			-23
		],
		[
			-4,
			-53
		],
		[
			1,
			-14
		],
		[
			6,
			-17
		],
		[
			3,
			-2
		],
		[
			4,
			-23
		],
		[
			0,
			-22
		],
		[
			-4,
			-9
		],
		[
			3,
			-18
		],
		[
			6,
			7
		],
		[
			13,
			-4
		],
		[
			14,
			9
		],
		[
			12,
			-3
		],
		[
			2,
			8
		]
	],
	[
		[
			5363,
			4916
		],
		[
			-7,
			-5
		],
		[
			-8,
			-18
		],
		[
			-1,
			-40
		],
		[
			-8,
			-2
		]
	],
	[
		[
			5339,
			4851
		],
		[
			-2,
			5
		],
		[
			2,
			14
		],
		[
			-6,
			24
		]
	],
	[
		[
			5333,
			4894
		],
		[
			10,
			23
		],
		[
			7,
			3
		],
		[
			4,
			10
		],
		[
			9,
			-14
		]
	],
	[
		[
			5582,
			7537
		],
		[
			-1,
			0
		]
	],
	[
		[
			5581,
			7537
		],
		[
			1,
			0
		]
	],
	[
		[
			5537,
			7617
		],
		[
			1,
			0
		]
	],
	[
		[
			5538,
			7617
		],
		[
			-1,
			0
		]
	],
	[
		[
			5557,
			7633
		],
		[
			4,
			-13
		],
		[
			7,
			-4
		],
		[
			3,
			-22
		]
	],
	[
		[
			5571,
			7594
		],
		[
			-4,
			-21
		],
		[
			6,
			-24
		]
	],
	[
		[
			5573,
			7549
		],
		[
			2,
			-10
		]
	],
	[
		[
			5575,
			7539
		],
		[
			6,
			-2
		]
	],
	[
		[
			5581,
			7537
		],
		[
			1,
			-1
		]
	],
	[
		[
			5582,
			7536
		],
		[
			0,
			0
		]
	],
	[
		[
			5582,
			7536
		],
		[
			0,
			-5
		]
	],
	[
		[
			5582,
			7531
		],
		[
			1,
			-5
		]
	],
	[
		[
			5583,
			7526
		],
		[
			0,
			0
		]
	],
	[
		[
			5583,
			7526
		],
		[
			-2,
			-13
		],
		[
			-5,
			-2
		],
		[
			-2,
			-17
		],
		[
			-11,
			-8
		],
		[
			3,
			-12
		],
		[
			-6,
			-8
		],
		[
			-5,
			3
		]
	],
	[
		[
			5555,
			7469
		],
		[
			-3,
			19
		],
		[
			-11,
			9
		],
		[
			-1,
			22
		],
		[
			-4,
			4
		],
		[
			4,
			16
		],
		[
			-1,
			29
		],
		[
			5,
			23
		],
		[
			-7,
			2
		]
	],
	[
		[
			5537,
			7593
		],
		[
			1,
			14
		]
	],
	[
		[
			5538,
			7607
		],
		[
			0,
			13
		]
	],
	[
		[
			5538,
			7620
		],
		[
			9,
			19
		],
		[
			3,
			-11
		],
		[
			7,
			5
		]
	],
	[
		[
			5553,
			8659
		],
		[
			10,
			-5
		],
		[
			-7,
			-11
		],
		[
			-10,
			6
		],
		[
			7,
			10
		]
	],
	[
		[
			5047,
			7630
		],
		[
			-7,
			-5
		],
		[
			-1,
			11
		]
	],
	[
		[
			5039,
			7636
		],
		[
			8,
			1
		],
		[
			0,
			-7
		]
	],
	[
		[
			6563,
			6637
		],
		[
			0,
			0
		]
	],
	[
		[
			6563,
			6659
		],
		[
			2,
			-2
		],
		[
			1,
			-36
		]
	],
	[
		[
			6566,
			6621
		],
		[
			-8,
			-14
		],
		[
			-3,
			13
		],
		[
			-6,
			-4
		],
		[
			-1,
			-38
		],
		[
			7,
			-9
		],
		[
			-11,
			-3
		],
		[
			-4,
			-6
		],
		[
			2,
			-9
		],
		[
			-10,
			-44
		],
		[
			0,
			-17
		]
	],
	[
		[
			6532,
			6490
		],
		[
			-2,
			-5
		],
		[
			-70,
			18
		],
		[
			-3,
			5
		],
		[
			-25,
			63
		],
		[
			0,
			9
		]
	],
	[
		[
			6432,
			6580
		],
		[
			6,
			-1
		],
		[
			0,
			-13
		],
		[
			12,
			-3
		],
		[
			10,
			11
		],
		[
			24,
			-2
		],
		[
			11,
			-4
		],
		[
			15,
			12
		],
		[
			6,
			14
		],
		[
			1,
			15
		],
		[
			11,
			12
		],
		[
			13,
			31
		],
		[
			11,
			13
		],
		[
			5,
			19
		]
	],
	[
		[
			6557,
			6684
		],
		[
			3,
			-2
		],
		[
			-1,
			-22
		],
		[
			4,
			-1
		]
	],
	[
		[
			6562,
			6642
		],
		[
			0,
			0
		]
	],
	[
		[
			3093,
			2021
		],
		[
			0,
			6
		]
	],
	[
		[
			3093,
			2027
		],
		[
			0,
			-6
		]
	],
	[
		[
			3093,
			2028
		],
		[
			0,
			123
		]
	],
	[
		[
			3093,
			2151
		],
		[
			10,
			-17
		],
		[
			-8,
			-15
		],
		[
			11,
			-6
		],
		[
			5,
			-17
		],
		[
			12,
			-13
		],
		[
			7,
			-13
		],
		[
			17,
			-13
		],
		[
			11,
			-14
		],
		[
			12,
			-7
		],
		[
			20,
			0
		],
		[
			-5,
			-16
		],
		[
			-18,
			1
		],
		[
			-11,
			-8
		],
		[
			-12,
			6
		],
		[
			-51,
			9
		]
	],
	[
		[
			3259,
			3902
		],
		[
			11,
			-14
		],
		[
			7,
			-29
		],
		[
			9,
			-17
		],
		[
			15,
			-17
		],
		[
			3,
			-11
		],
		[
			17,
			-13
		],
		[
			11,
			-1
		],
		[
			15,
			-18
		],
		[
			4,
			-9
		],
		[
			15,
			-17
		],
		[
			9,
			-5
		],
		[
			5,
			-8
		],
		[
			13,
			-5
		],
		[
			8,
			-20
		],
		[
			-6,
			-14
		],
		[
			-3,
			-19
		],
		[
			-8,
			-10
		],
		[
			-1,
			-25
		],
		[
			-3,
			-14
		],
		[
			-5,
			-4
		],
		[
			-5,
			-15
		],
		[
			4,
			-5
		],
		[
			13,
			1
		],
		[
			19,
			-8
		],
		[
			5,
			-5
		],
		[
			7,
			4
		],
		[
			5,
			-5
		],
		[
			6,
			3
		],
		[
			4,
			-8
		],
		[
			3,
			12
		],
		[
			5,
			5
		],
		[
			10,
			-9
		],
		[
			5,
			8
		],
		[
			-1,
			8
		],
		[
			6,
			12
		],
		[
			6,
			0
		],
		[
			11,
			18
		],
		[
			5,
			40
		],
		[
			0,
			22
		]
	],
	[
		[
			3483,
			3710
		],
		[
			5,
			-4
		],
		[
			6,
			7
		],
		[
			9,
			-9
		],
		[
			1,
			-17
		],
		[
			5,
			-14
		],
		[
			-2,
			-9
		],
		[
			0,
			-25
		],
		[
			-2,
			-17
		],
		[
			-13,
			-19
		],
		[
			-15,
			-5
		],
		[
			-6,
			-19
		],
		[
			-8,
			-4
		],
		[
			-6,
			-13
		],
		[
			-7,
			-5
		],
		[
			3,
			-10
		],
		[
			-6,
			-4
		],
		[
			-20,
			-39
		],
		[
			-2,
			-11
		],
		[
			-12,
			-25
		],
		[
			-5,
			-2
		],
		[
			-1,
			-10
		],
		[
			-8,
			-11
		]
	],
	[
		[
			3399,
			3445
		],
		[
			0,
			-7
		],
		[
			-7,
			-12
		],
		[
			2,
			-23
		],
		[
			-3,
			-20
		],
		[
			-5,
			-13
		],
		[
			3,
			-4
		],
		[
			-2,
			-14
		],
		[
			-4,
			-5
		],
		[
			3,
			-25
		],
		[
			-3,
			-8
		]
	],
	[
		[
			3383,
			3314
		],
		[
			2,
			-25
		],
		[
			-2,
			-12
		],
		[
			-6,
			0
		],
		[
			-4,
			-34
		],
		[
			5,
			-29
		],
		[
			-4,
			-14
		],
		[
			5,
			-12
		],
		[
			23,
			-21
		],
		[
			11,
			-25
		],
		[
			-7,
			-19
		],
		[
			0,
			-13
		],
		[
			7,
			-17
		],
		[
			12,
			-6
		],
		[
			1,
			-29
		],
		[
			-11,
			-30
		],
		[
			-13,
			-26
		],
		[
			-2,
			-16
		],
		[
			-27,
			-24
		],
		[
			-37,
			-16
		],
		[
			-27,
			-8
		],
		[
			-27,
			0
		],
		[
			-15,
			11
		],
		[
			3,
			-32
		],
		[
			5,
			-9
		],
		[
			-2,
			-21
		],
		[
			-4,
			3
		],
		[
			-1,
			-21
		],
		[
			-4,
			-5
		],
		[
			6,
			-17
		],
		[
			-2,
			-18
		],
		[
			-20,
			-16
		],
		[
			-21,
			0
		],
		[
			-26,
			20
		],
		[
			-8,
			2
		],
		[
			-4,
			-10
		],
		[
			5,
			-32
		],
		[
			-2,
			-24
		],
		[
			6,
			-16
		],
		[
			11,
			-4
		],
		[
			-4,
			-10
		],
		[
			13,
			0
		],
		[
			2,
			10
		],
		[
			-6,
			0
		],
		[
			14,
			11
		],
		[
			5,
			-13
		],
		[
			1,
			-17
		],
		[
			-3,
			-12
		],
		[
			-12,
			-5
		],
		[
			-3,
			16
		],
		[
			-13,
			5
		],
		[
			-9,
			-15
		],
		[
			19,
			-13
		],
		[
			-20,
			-17
		],
		[
			-8,
			-19
		],
		[
			3,
			-43
		],
		[
			-4,
			-11
		],
		[
			-9,
			-7
		],
		[
			0,
			-20
		],
		[
			-14,
			3
		],
		[
			-8,
			-5
		],
		[
			-1,
			-8
		],
		[
			-14,
			-5
		],
		[
			-9,
			-18
		],
		[
			0,
			-9
		],
		[
			-6,
			-9
		],
		[
			-2,
			-14
		],
		[
			7,
			-25
		],
		[
			7,
			-6
		],
		[
			8,
			-16
		],
		[
			6,
			-4
		],
		[
			17,
			0
		],
		[
			6,
			-6
		],
		[
			2,
			-20
		],
		[
			-5,
			-33
		],
		[
			-6,
			-2
		],
		[
			-12,
			-18
		],
		[
			-16,
			-14
		],
		[
			-3,
			-10
		],
		[
			-9,
			-10
		],
		[
			-6,
			-22
		],
		[
			2,
			-16
		],
		[
			-5,
			-18
		],
		[
			-5,
			-6
		],
		[
			-23,
			-14
		],
		[
			-5,
			-12
		],
		[
			-2,
			-21
		],
		[
			2,
			-24
		],
		[
			9,
			-34
		],
		[
			11,
			-24
		],
		[
			-3,
			-1
		]
	],
	[
		[
			3098,
			2168
		],
		[
			-15,
			10
		],
		[
			-26,
			10
		],
		[
			-55,
			1
		],
		[
			-4,
			12
		],
		[
			-11,
			13
		],
		[
			6,
			19
		],
		[
			-5,
			7
		],
		[
			5,
			13
		],
		[
			-2,
			14
		],
		[
			-13,
			1
		],
		[
			-11,
			-8
		],
		[
			-3,
			26
		],
		[
			-7,
			9
		],
		[
			2,
			22
		],
		[
			-3,
			11
		],
		[
			3,
			15
		],
		[
			9,
			1
		],
		[
			3,
			17
		],
		[
			12,
			10
		],
		[
			1,
			22
		],
		[
			7,
			7
		],
		[
			-1,
			15
		],
		[
			-5,
			7
		],
		[
			6,
			30
		],
		[
			8,
			13
		],
		[
			2,
			22
		],
		[
			8,
			9
		],
		[
			-3,
			32
		],
		[
			4,
			11
		],
		[
			-4,
			4
		],
		[
			0,
			15
		],
		[
			8,
			5
		],
		[
			5,
			13
		],
		[
			-8,
			17
		],
		[
			-14,
			5
		],
		[
			7,
			5
		],
		[
			17,
			3
		],
		[
			2,
			17
		],
		[
			-18,
			3
		],
		[
			-1,
			18
		],
		[
			5,
			7
		],
		[
			-4,
			14
		],
		[
			3,
			7
		],
		[
			-6,
			16
		],
		[
			5,
			9
		],
		[
			-11,
			7
		],
		[
			0,
			45
		],
		[
			3,
			8
		],
		[
			8,
			1
		],
		[
			-5,
			26
		],
		[
			2,
			43
		],
		[
			-3,
			11
		],
		[
			4,
			27
		],
		[
			5,
			21
		],
		[
			-2,
			18
		],
		[
			8,
			13
		],
		[
			0,
			25
		],
		[
			15,
			13
		],
		[
			-3,
			15
		],
		[
			-1,
			21
		],
		[
			-5,
			20
		],
		[
			3,
			35
		],
		[
			-2,
			24
		],
		[
			3,
			12
		],
		[
			10,
			4
		],
		[
			-1,
			8
		],
		[
			10,
			14
		],
		[
			-2,
			40
		],
		[
			-4,
			4
		],
		[
			6,
			6
		],
		[
			0,
			12
		],
		[
			9,
			39
		],
		[
			6,
			2
		],
		[
			-2,
			34
		],
		[
			3,
			18
		],
		[
			-9,
			9
		],
		[
			3,
			18
		],
		[
			-4,
			6
		],
		[
			0,
			16
		],
		[
			-5,
			12
		],
		[
			-2,
			14
		],
		[
			3,
			9
		],
		[
			-5,
			2
		],
		[
			-3,
			15
		],
		[
			1,
			24
		],
		[
			6,
			8
		],
		[
			0,
			13
		],
		[
			5,
			19
		],
		[
			7,
			8
		],
		[
			2,
			10
		],
		[
			-4,
			4
		],
		[
			2,
			16
		],
		[
			-4,
			31
		],
		[
			7,
			10
		],
		[
			1,
			26
		],
		[
			4,
			17
		],
		[
			13,
			33
		],
		[
			9,
			38
		],
		[
			6,
			-3
		],
		[
			8,
			7
		],
		[
			0,
			10
		],
		[
			-8,
			21
		],
		[
			0,
			10
		],
		[
			5,
			9
		],
		[
			-2,
			26
		],
		[
			-3,
			17
		],
		[
			2,
			15
		],
		[
			5,
			4
		],
		[
			-6,
			14
		],
		[
			2,
			14
		],
		[
			7,
			13
		],
		[
			25,
			20
		],
		[
			9,
			54
		],
		[
			-5,
			17
		]
	],
	[
		[
			3133,
			3869
		],
		[
			5,
			9
		],
		[
			0,
			8
		],
		[
			7,
			6
		],
		[
			2,
			12
		],
		[
			9,
			5
		],
		[
			4,
			19
		],
		[
			3,
			-2
		],
		[
			10,
			-17
		],
		[
			21,
			0
		],
		[
			12,
			-5
		],
		[
			6,
			-38
		],
		[
			3,
			20
		],
		[
			8,
			29
		],
		[
			32,
			1
		],
		[
			4,
			-14
		]
	],
	[
		[
			6265,
			7522
		],
		[
			0,
			0
		]
	],
	[
		[
			6249,
			7560
		],
		[
			2,
			-10
		],
		[
			15,
			-14
		],
		[
			-6,
			-16
		],
		[
			6,
			-11
		],
		[
			11,
			-10
		],
		[
			-3,
			-13
		],
		[
			-7,
			2
		],
		[
			15,
			-25
		],
		[
			9,
			-1
		],
		[
			-3,
			-13
		],
		[
			5,
			-7
		],
		[
			-5,
			-5
		],
		[
			3,
			-15
		]
	],
	[
		[
			6291,
			7422
		],
		[
			-10,
			-2
		]
	],
	[
		[
			6281,
			7420
		],
		[
			-4,
			23
		],
		[
			-7,
			7
		],
		[
			1,
			10
		],
		[
			-13,
			-1
		],
		[
			-8,
			14
		],
		[
			-7,
			-4
		]
	],
	[
		[
			6243,
			7469
		],
		[
			-8,
			16
		],
		[
			-12,
			1
		],
		[
			-11,
			7
		],
		[
			-3,
			20
		],
		[
			5,
			12
		],
		[
			-3,
			17
		],
		[
			-5,
			8
		]
	],
	[
		[
			6206,
			7550
		],
		[
			9,
			0
		],
		[
			11,
			7
		],
		[
			10,
			-3
		],
		[
			13,
			6
		]
	],
	[
		[
			6249,
			7546
		],
		[
			0,
			0
		]
	],
	[
		[
			6255,
			7542
		],
		[
			0,
			0
		]
	],
	[
		[
			488,
			408
		],
		[
			24,
			-7
		],
		[
			-48,
			-4
		],
		[
			-13,
			16
		],
		[
			37,
			-5
		]
	],
	[
		[
			542,
			484
		],
		[
			-90,
			7
		],
		[
			20,
			11
		],
		[
			65,
			-10
		],
		[
			5,
			-8
		]
	],
	[
		[
			3331,
			592
		],
		[
			8,
			-3
		],
		[
			-1,
			-57
		],
		[
			-23,
			-11
		],
		[
			-52,
			4
		],
		[
			-17,
			17
		],
		[
			-32,
			-10
		],
		[
			-67,
			20
		],
		[
			3,
			10
		],
		[
			19,
			-10
		],
		[
			115,
			3
		],
		[
			8,
			27
		],
		[
			39,
			10
		]
	],
	[
		[
			4135,
			588
		],
		[
			34,
			-2
		],
		[
			-10,
			-10
		],
		[
			-44,
			8
		],
		[
			-5,
			11
		],
		[
			25,
			-7
		]
	],
	[
		[
			3120,
			602
		],
		[
			25,
			-4
		],
		[
			35,
			-20
		],
		[
			-20,
			-7
		],
		[
			-40,
			31
		]
	],
	[
		[
			3137,
			618
		],
		[
			-11,
			-15
		],
		[
			-30,
			6
		],
		[
			41,
			9
		]
	],
	[
		[
			4054,
			618
		],
		[
			1,
			-6
		],
		[
			-76,
			3
		],
		[
			30,
			13
		],
		[
			45,
			-10
		]
	],
	[
		[
			547,
			618
		],
		[
			21,
			-9
		],
		[
			14,
			-23
		],
		[
			-47,
			-2
		],
		[
			-90,
			25
		],
		[
			-10,
			7
		],
		[
			5,
			17
		],
		[
			24,
			15
		],
		[
			25,
			0
		],
		[
			58,
			-30
		]
	],
	[
		[
			3143,
			666
		],
		[
			-58,
			-38
		],
		[
			-39,
			-36
		],
		[
			-31,
			3
		],
		[
			-10,
			10
		],
		[
			11,
			23
		],
		[
			23,
			11
		],
		[
			92,
			33
		],
		[
			12,
			-6
		]
	],
	[
		[
			9654,
			680
		],
		[
			-35,
			-8
		],
		[
			-8,
			14
		],
		[
			21,
			-7
		],
		[
			22,
			11
		],
		[
			0,
			-10
		]
	],
	[
		[
			3740,
			650
		],
		[
			1,
			-7
		],
		[
			44,
			2
		],
		[
			21,
			-39
		],
		[
			-7,
			-30
		],
		[
			-18,
			-1
		],
		[
			9,
			-11
		],
		[
			-158,
			-26
		],
		[
			-16,
			-9
		],
		[
			-121,
			-4
		],
		[
			1,
			17
		],
		[
			22,
			27
		],
		[
			26,
			-4
		],
		[
			60,
			37
		],
		[
			-13,
			14
		],
		[
			14,
			40
		],
		[
			31,
			33
		],
		[
			52,
			14
		],
		[
			37,
			-3
		],
		[
			38,
			-11
		],
		[
			19,
			-13
		],
		[
			-4,
			-20
		],
		[
			-38,
			-6
		]
	],
	[
		[
			9641,
			732
		],
		[
			63,
			-13
		],
		[
			-27,
			-10
		],
		[
			-42,
			-2
		],
		[
			-19,
			12
		],
		[
			25,
			13
		]
	],
	[
		[
			839,
			754
		],
		[
			14,
			-14
		],
		[
			-32,
			3
		],
		[
			-11,
			7
		],
		[
			29,
			4
		]
	],
	[
		[
			938,
			754
		],
		[
			-21,
			-7
		],
		[
			-2,
			12
		],
		[
			23,
			-5
		]
	],
	[
		[
			951,
			834
		],
		[
			16,
			-10
		],
		[
			-24,
			3
		],
		[
			8,
			7
		]
	],
	[
		[
			9561,
			885
		],
		[
			-8,
			-14
		],
		[
			-7,
			9
		],
		[
			15,
			5
		]
	],
	[
		[
			1342,
			903
		],
		[
			19,
			-12
		],
		[
			-6,
			-6
		],
		[
			-27,
			12
		],
		[
			14,
			6
		]
	],
	[
		[
			1458,
			897
		],
		[
			-1,
			-13
		],
		[
			-17,
			20
		],
		[
			18,
			-7
		]
	],
	[
		[
			1760,
			918
		],
		[
			-17,
			-8
		],
		[
			-3,
			7
		],
		[
			26,
			11
		],
		[
			-6,
			-10
		]
	],
	[
		[
			1680,
			914
		],
		[
			-12,
			3
		],
		[
			10,
			17
		],
		[
			17,
			-2
		],
		[
			-1,
			-10
		],
		[
			-14,
			-8
		]
	],
	[
		[
			1635,
			935
		],
		[
			17,
			0
		],
		[
			7,
			-14
		],
		[
			-23,
			-10
		],
		[
			0,
			-10
		],
		[
			-32,
			-4
		],
		[
			-22,
			7
		],
		[
			3,
			11
		],
		[
			15,
			12
		],
		[
			-27,
			3
		],
		[
			7,
			10
		],
		[
			55,
			-5
		]
	],
	[
		[
			4425,
			917
		],
		[
			9,
			-22
		],
		[
			-14,
			0
		],
		[
			-4,
			16
		],
		[
			-29,
			3
		],
		[
			20,
			7
		],
		[
			12,
			19
		],
		[
			11,
			1
		],
		[
			-5,
			-24
		]
	],
	[
		[
			9717,
			944
		],
		[
			-11,
			3
		],
		[
			8,
			14
		],
		[
			3,
			-17
		]
	],
	[
		[
			1498,
			961
		],
		[
			13,
			-7
		],
		[
			9,
			-16
		],
		[
			-11,
			-7
		],
		[
			29,
			6
		],
		[
			17,
			-9
		],
		[
			7,
			-11
		],
		[
			-6,
			-12
		],
		[
			-22,
			3
		],
		[
			-48,
			22
		],
		[
			0,
			8
		],
		[
			-19,
			7
		],
		[
			-3,
			16
		],
		[
			34,
			0
		]
	],
	[
		[
			2955,
			972
		],
		[
			-2,
			-10
		],
		[
			-13,
			0
		],
		[
			15,
			10
		]
	],
	[
		[
			2514,
			979
		],
		[
			-20,
			-5
		],
		[
			-4,
			5
		],
		[
			22,
			8
		],
		[
			2,
			-8
		]
	],
	[
		[
			2918,
			987
		],
		[
			18,
			-3
		],
		[
			-8,
			-40
		],
		[
			-36,
			14
		],
		[
			-7,
			10
		],
		[
			11,
			7
		],
		[
			18,
			0
		],
		[
			-19,
			10
		],
		[
			23,
			2
		]
	],
	[
		[
			2474,
			988
		],
		[
			-3,
			-19
		],
		[
			-14,
			-1
		],
		[
			6,
			17
		],
		[
			-10,
			16
		],
		[
			23,
			1
		],
		[
			-2,
			-14
		]
	],
	[
		[
			2365,
			999
		],
		[
			-10,
			3
		],
		[
			18,
			7
		],
		[
			-8,
			-10
		]
	],
	[
		[
			2270,
			1031
		],
		[
			14,
			-3
		],
		[
			-2,
			14
		],
		[
			10,
			0
		],
		[
			2,
			-17
		],
		[
			10,
			19
		],
		[
			19,
			1
		],
		[
			5,
			-10
		],
		[
			-23,
			-11
		],
		[
			8,
			-3
		],
		[
			27,
			11
		],
		[
			-6,
			-10
		],
		[
			13,
			-10
		],
		[
			-15,
			-1
		],
		[
			1,
			-9
		],
		[
			-72,
			2
		],
		[
			2,
			5
		],
		[
			-24,
			-1
		],
		[
			6,
			7
		],
		[
			-29,
			6
		],
		[
			-58,
			7
		],
		[
			6,
			10
		],
		[
			57,
			7
		],
		[
			8,
			-11
		],
		[
			7,
			7
		],
		[
			23,
			-12
		],
		[
			-13,
			13
		],
		[
			17,
			9
		],
		[
			15,
			-6
		],
		[
			-8,
			-14
		]
	],
	[
		[
			4919,
			1112
		],
		[
			8,
			-10
		],
		[
			14,
			1
		],
		[
			-17,
			-19
		],
		[
			-8,
			18
		],
		[
			-16,
			10
		],
		[
			19,
			0
		]
	],
	[
		[
			2947,
			1119
		],
		[
			8,
			-13
		],
		[
			-22,
			-10
		],
		[
			-48,
			-11
		],
		[
			-9,
			4
		],
		[
			2,
			12
		],
		[
			33,
			5
		],
		[
			9,
			12
		],
		[
			8,
			-13
		],
		[
			3,
			14
		],
		[
			16,
			0
		]
	],
	[
		[
			3313,
			1111
		],
		[
			-7,
			10
		],
		[
			11,
			1
		],
		[
			-4,
			-11
		]
	],
	[
		[
			4835,
			1126
		],
		[
			-5,
			-10
		],
		[
			-10,
			9
		],
		[
			15,
			1
		]
	],
	[
		[
			5082,
			1116
		],
		[
			-11,
			6
		],
		[
			19,
			4
		],
		[
			-8,
			-10
		]
	],
	[
		[
			4913,
			1121
		],
		[
			-10,
			0
		],
		[
			6,
			12
		],
		[
			12,
			3
		],
		[
			2,
			-14
		],
		[
			-10,
			-1
		]
	],
	[
		[
			7004,
			1113
		],
		[
			-10,
			3
		],
		[
			-5,
			16
		],
		[
			16,
			-11
		],
		[
			-1,
			-8
		]
	],
	[
		[
			5124,
			1122
		],
		[
			-12,
			11
		],
		[
			12,
			5
		],
		[
			0,
			-16
		]
	],
	[
		[
			5745,
			1129
		],
		[
			-22,
			0
		],
		[
			-2,
			11
		],
		[
			19,
			6
		],
		[
			5,
			-17
		]
	],
	[
		[
			5040,
			1146
		],
		[
			-7,
			-18
		],
		[
			-5,
			21
		],
		[
			12,
			-3
		]
	],
	[
		[
			2924,
			1165
		],
		[
			8,
			-12
		],
		[
			-12,
			-13
		],
		[
			-23,
			5
		],
		[
			-1,
			13
		],
		[
			8,
			7
		],
		[
			20,
			0
		]
	],
	[
		[
			5449,
			1148
		],
		[
			-17,
			8
		],
		[
			11,
			12
		],
		[
			19,
			-1
		],
		[
			-11,
			-8
		],
		[
			-2,
			-11
		]
	],
	[
		[
			3001,
			1170
		],
		[
			-23,
			2
		],
		[
			-6,
			7
		],
		[
			17,
			4
		],
		[
			12,
			-13
		]
	],
	[
		[
			3283,
			1179
		],
		[
			-6,
			-12
		],
		[
			-16,
			30
		],
		[
			11,
			2
		],
		[
			11,
			-20
		]
	],
	[
		[
			3055,
			1197
		],
		[
			19,
			-24
		],
		[
			1,
			-17
		],
		[
			16,
			-26
		],
		[
			11,
			-25
		],
		[
			3,
			-60
		],
		[
			-6,
			-23
		],
		[
			-20,
			-7
		],
		[
			-2,
			-10
		],
		[
			-40,
			-7
		],
		[
			-49,
			0
		],
		[
			-21,
			13
		],
		[
			10,
			8
		],
		[
			16,
			-3
		],
		[
			45,
			-2
		],
		[
			14,
			8
		],
		[
			-7,
			6
		],
		[
			-28,
			-9
		],
		[
			-18,
			10
		],
		[
			35,
			8
		],
		[
			1,
			5
		],
		[
			-31,
			0
		],
		[
			-14,
			17
		],
		[
			-11,
			-17
		],
		[
			-31,
			2
		],
		[
			10,
			-8
		],
		[
			-14,
			-9
		],
		[
			-38,
			14
		],
		[
			-1,
			15
		],
		[
			15,
			8
		],
		[
			16,
			-8
		],
		[
			-4,
			12
		],
		[
			9,
			4
		],
		[
			16,
			-13
		],
		[
			-4,
			14
		],
		[
			29,
			-2
		],
		[
			9,
			7
		],
		[
			-23,
			7
		],
		[
			10,
			6
		],
		[
			30,
			-6
		],
		[
			19,
			11
		],
		[
			20,
			0
		],
		[
			13,
			-11
		],
		[
			-2,
			16
		],
		[
			-35,
			7
		],
		[
			5,
			17
		],
		[
			24,
			8
		],
		[
			15,
			-4
		],
		[
			-18,
			14
		],
		[
			-20,
			-4
		],
		[
			-27,
			14
		],
		[
			7,
			34
		],
		[
			-10,
			5
		],
		[
			0,
			20
		],
		[
			45,
			10
		],
		[
			9,
			-7
		],
		[
			2,
			-18
		]
	],
	[
		[
			7385,
			1327
		],
		[
			-15,
			4
		],
		[
			8,
			9
		],
		[
			7,
			-13
		]
	],
	[
		[
			3111,
			1321
		],
		[
			9,
			-5
		],
		[
			-16,
			-13
		],
		[
			-8,
			-22
		],
		[
			-11,
			0
		],
		[
			-7,
			9
		],
		[
			22,
			44
		],
		[
			15,
			12
		],
		[
			5,
			-5
		],
		[
			-10,
			-11
		],
		[
			1,
			-9
		]
	],
	[
		[
			7686,
			1378
		],
		[
			4,
			-8
		],
		[
			-14,
			-2
		],
		[
			10,
			10
		]
	],
	[
		[
			3174,
			1408
		],
		[
			-3,
			-16
		],
		[
			-10,
			-2
		],
		[
			6,
			17
		],
		[
			7,
			1
		]
	],
	[
		[
			7805,
			1401
		],
		[
			-19,
			0
		],
		[
			-1,
			7
		],
		[
			12,
			10
		],
		[
			15,
			-7
		],
		[
			-7,
			-10
		]
	],
	[
		[
			7870,
			1413
		],
		[
			-16,
			19
		],
		[
			9,
			-2
		],
		[
			7,
			-17
		]
	],
	[
		[
			3410,
			1465
		],
		[
			-6,
			6
		],
		[
			14,
			7
		],
		[
			-8,
			-13
		]
	],
	[
		[
			3242,
			1481
		],
		[
			-2,
			-9
		],
		[
			14,
			-8
		],
		[
			-14,
			-12
		],
		[
			-26,
			3
		],
		[
			20,
			26
		],
		[
			8,
			0
		]
	],
	[
		[
			3270,
			1492
		],
		[
			2,
			-17
		],
		[
			-12,
			-8
		],
		[
			10,
			25
		]
	],
	[
		[
			3394,
			1508
		],
		[
			-2,
			-9
		],
		[
			20,
			-7
		],
		[
			-8,
			-17
		],
		[
			-7,
			6
		],
		[
			-7,
			-7
		],
		[
			-14,
			20
		],
		[
			5,
			8
		],
		[
			13,
			6
		]
	],
	[
		[
			3446,
			1521
		],
		[
			-9,
			7
		],
		[
			15,
			-2
		],
		[
			-6,
			-5
		]
	],
	[
		[
			0,
			324
		],
		[
			46,
			3
		],
		[
			68,
			-14
		],
		[
			19,
			8
		],
		[
			194,
			-14
		],
		[
			21,
			-11
		],
		[
			128,
			-2
		],
		[
			122,
			-11
		],
		[
			81,
			-3
		],
		[
			-58,
			13
		],
		[
			54,
			1
		],
		[
			-124,
			12
		],
		[
			-104,
			7
		],
		[
			24,
			11
		],
		[
			-55,
			17
		],
		[
			37,
			2
		],
		[
			-52,
			17
		],
		[
			-71,
			-3
		],
		[
			-37,
			23
		],
		[
			-127,
			27
		],
		[
			73,
			-2
		],
		[
			18,
			-14
		],
		[
			73,
			-4
		],
		[
			20,
			4
		],
		[
			70,
			-3
		],
		[
			6,
			-14
		],
		[
			50,
			10
		],
		[
			19,
			-11
		],
		[
			127,
			8
		],
		[
			18,
			9
		],
		[
			-44,
			5
		],
		[
			81,
			5
		],
		[
			16,
			14
		],
		[
			70,
			14
		],
		[
			-10,
			10
		],
		[
			-54,
			26
		],
		[
			31,
			11
		],
		[
			-19,
			10
		],
		[
			-74,
			13
		],
		[
			17,
			11
		],
		[
			109,
			6
		],
		[
			135,
			7
		],
		[
			0,
			5
		],
		[
			-77,
			24
		],
		[
			-11,
			11
		],
		[
			13,
			10
		],
		[
			43,
			-4
		],
		[
			46,
			10
		],
		[
			-17,
			11
		],
		[
			-75,
			12
		],
		[
			-55,
			17
		],
		[
			-3,
			5
		],
		[
			-68,
			8
		],
		[
			-43,
			21
		],
		[
			14,
			11
		],
		[
			48,
			6
		],
		[
			-2,
			14
		],
		[
			-71,
			-7
		],
		[
			-47,
			23
		],
		[
			14,
			18
		],
		[
			-3,
			26
		],
		[
			9,
			1
		],
		[
			24,
			-17
		],
		[
			21,
			17
		],
		[
			21,
			-5
		],
		[
			18,
			4
		],
		[
			38,
			-10
		],
		[
			-9,
			-10
		],
		[
			36,
			-3
		],
		[
			2,
			10
		],
		[
			72,
			-30
		],
		[
			30,
			16
		],
		[
			30,
			6
		],
		[
			-36,
			7
		],
		[
			7,
			14
		],
		[
			32,
			-17
		],
		[
			21,
			7
		],
		[
			13,
			-13
		],
		[
			27,
			0
		],
		[
			-16,
			13
		],
		[
			21,
			1
		],
		[
			-31,
			15
		],
		[
			29,
			-5
		],
		[
			-22,
			20
		],
		[
			-27,
			16
		],
		[
			-38,
			-3
		],
		[
			-33,
			3
		],
		[
			2,
			9
		],
		[
			28,
			4
		],
		[
			9,
			7
		],
		[
			69,
			-21
		],
		[
			6,
			8
		],
		[
			-27,
			13
		],
		[
			9,
			11
		],
		[
			56,
			6
		],
		[
			1,
			10
		],
		[
			41,
			4
		],
		[
			2,
			6
		],
		[
			19,
			-3
		],
		[
			9,
			-14
		],
		[
			18,
			0
		],
		[
			-10,
			14
		],
		[
			29,
			6
		],
		[
			16,
			14
		],
		[
			61,
			4
		],
		[
			30,
			-4
		],
		[
			-16,
			9
		],
		[
			4,
			14
		],
		[
			30,
			0
		],
		[
			11,
			11
		],
		[
			22,
			-4
		],
		[
			18,
			-16
		],
		[
			30,
			9
		],
		[
			58,
			-4
		],
		[
			20,
			-5
		],
		[
			64,
			13
		],
		[
			93,
			0
		],
		[
			8,
			-7
		],
		[
			45,
			3
		],
		[
			41,
			0
		],
		[
			59,
			10
		],
		[
			-3,
			10
		],
		[
			24,
			6
		],
		[
			6,
			-12
		],
		[
			33,
			-3
		],
		[
			51,
			6
		],
		[
			-7,
			21
		],
		[
			11,
			10
		],
		[
			21,
			0
		],
		[
			-9,
			-7
		],
		[
			19,
			2
		],
		[
			-8,
			-12
		],
		[
			4,
			-14
		],
		[
			15,
			3
		],
		[
			-18,
			-16
		],
		[
			-6,
			-21
		],
		[
			9,
			6
		],
		[
			46,
			8
		],
		[
			15,
			0
		],
		[
			-10,
			11
		],
		[
			0,
			20
		],
		[
			15,
			6
		],
		[
			35,
			-17
		],
		[
			-5,
			-19
		],
		[
			-34,
			-18
		],
		[
			4,
			-7
		],
		[
			45,
			4
		],
		[
			84,
			-10
		],
		[
			53,
			13
		],
		[
			28,
			-3
		],
		[
			14,
			4
		],
		[
			49,
			-4
		],
		[
			-3,
			-8
		],
		[
			20,
			-8
		],
		[
			70,
			13
		],
		[
			-27,
			6
		],
		[
			2,
			10
		],
		[
			-34,
			3
		],
		[
			17,
			7
		],
		[
			3,
			14
		],
		[
			-46,
			3
		],
		[
			5,
			11
		],
		[
			-7,
			15
		],
		[
			-33,
			5
		],
		[
			-4,
			20
		],
		[
			42,
			-4
		],
		[
			3,
			-6
		],
		[
			47,
			2
		],
		[
			-5,
			21
		],
		[
			-41,
			3
		],
		[
			-46,
			0
		],
		[
			-11,
			7
		],
		[
			-4,
			20
		],
		[
			11,
			7
		],
		[
			26,
			-4
		],
		[
			-17,
			-12
		],
		[
			21,
			-4
		],
		[
			33,
			4
		],
		[
			84,
			-1
		],
		[
			9,
			-7
		],
		[
			44,
			-11
		],
		[
			17,
			7
		],
		[
			24,
			-7
		],
		[
			21,
			8
		],
		[
			46,
			0
		],
		[
			33,
			-7
		],
		[
			16,
			10
		],
		[
			25,
			1
		],
		[
			6,
			10
		],
		[
			-10,
			17
		],
		[
			33,
			-4
		],
		[
			1,
			-10
		],
		[
			-15,
			-14
		],
		[
			9,
			-9
		],
		[
			30,
			6
		],
		[
			8,
			-11
		],
		[
			38,
			11
		],
		[
			5,
			-13
		],
		[
			28,
			-10
		],
		[
			20,
			2
		],
		[
			43,
			-19
		],
		[
			29,
			9
		],
		[
			-2,
			28
		],
		[
			24,
			-11
		],
		[
			-8,
			25
		],
		[
			28,
			-2
		],
		[
			24,
			-17
		],
		[
			-2,
			-16
		],
		[
			55,
			8
		],
		[
			5,
			-7
		],
		[
			-15,
			-14
		],
		[
			48,
			6
		],
		[
			7,
			5
		],
		[
			34,
			-5
		],
		[
			26,
			15
		],
		[
			57,
			12
		],
		[
			21,
			-2
		],
		[
			42,
			10
		],
		[
			35,
			16
		],
		[
			22,
			43
		],
		[
			-1,
			7
		],
		[
			-20,
			21
		],
		[
			-4,
			13
		],
		[
			6,
			23
		],
		[
			-15,
			38
		],
		[
			-15,
			16
		],
		[
			4,
			21
		],
		[
			-13,
			16
		],
		[
			15,
			0
		],
		[
			-1,
			7
		],
		[
			25,
			-14
		],
		[
			5,
			14
		],
		[
			11,
			6
		],
		[
			0,
			11
		],
		[
			-18,
			7
		],
		[
			14,
			5
		],
		[
			-5,
			17
		],
		[
			6,
			14
		],
		[
			-9,
			16
		],
		[
			12,
			3
		],
		[
			6,
			21
		],
		[
			-10,
			5
		],
		[
			-19,
			-1
		],
		[
			15,
			30
		],
		[
			6,
			0
		],
		[
			-2,
			-17
		],
		[
			15,
			-6
		],
		[
			1,
			26
		],
		[
			-4,
			14
		],
		[
			8,
			4
		],
		[
			14,
			-7
		],
		[
			5,
			34
		],
		[
			14,
			-2
		],
		[
			-5,
			11
		],
		[
			19,
			-4
		],
		[
			3,
			23
		],
		[
			16,
			1
		],
		[
			-5,
			27
		],
		[
			11,
			6
		],
		[
			16,
			-7
		],
		[
			-4,
			11
		],
		[
			20,
			14
		],
		[
			11,
			-3
		],
		[
			9,
			12
		],
		[
			10,
			1
		],
		[
			-1,
			10
		],
		[
			14,
			4
		],
		[
			-1,
			13
		],
		[
			30,
			14
		],
		[
			13,
			-2
		],
		[
			3,
			10
		],
		[
			12,
			2
		],
		[
			1,
			8
		],
		[
			21,
			4
		],
		[
			7,
			8
		],
		[
			13,
			6
		],
		[
			11,
			-3
		],
		[
			7,
			-20
		],
		[
			-10,
			-3
		],
		[
			-2,
			12
		],
		[
			-15,
			-12
		],
		[
			-10,
			0
		],
		[
			-15,
			-17
		],
		[
			-9,
			-22
		],
		[
			-9,
			-6
		],
		[
			-7,
			7
		],
		[
			-6,
			-6
		],
		[
			-19,
			-5
		],
		[
			-17,
			-29
		],
		[
			-20,
			3
		],
		[
			6,
			-10
		],
		[
			-18,
			-10
		],
		[
			9,
			-14
		],
		[
			-14,
			-14
		],
		[
			13,
			-19
		],
		[
			16,
			3
		],
		[
			0,
			10
		],
		[
			21,
			-2
		],
		[
			-16,
			-14
		],
		[
			-16,
			0
		],
		[
			-2,
			-16
		],
		[
			-5,
			16
		],
		[
			-19,
			-3
		],
		[
			1,
			-28
		],
		[
			-16,
			27
		],
		[
			-15,
			3
		],
		[
			-10,
			-29
		],
		[
			11,
			-10
		],
		[
			-9,
			-4
		],
		[
			-14,
			11
		],
		[
			-12,
			-15
		],
		[
			6,
			-16
		],
		[
			-15,
			-6
		],
		[
			-8,
			5
		],
		[
			-3,
			-33
		],
		[
			10,
			-6
		],
		[
			-12,
			-11
		],
		[
			21,
			6
		],
		[
			6,
			-6
		],
		[
			-20,
			-7
		],
		[
			14,
			-6
		],
		[
			-10,
			-7
		],
		[
			36,
			-17
		],
		[
			-2,
			17
		],
		[
			23,
			7
		],
		[
			-14,
			-17
		],
		[
			15,
			-6
		],
		[
			-5,
			-8
		],
		[
			14,
			-25
		],
		[
			14,
			-7
		],
		[
			-2,
			-21
		],
		[
			15,
			-13
		],
		[
			-1,
			-11
		],
		[
			-10,
			4
		],
		[
			5,
			-18
		],
		[
			22,
			1
		],
		[
			-16,
			-24
		],
		[
			20,
			4
		],
		[
			9,
			-21
		],
		[
			-5,
			-12
		],
		[
			-12,
			-1
		],
		[
			-14,
			-13
		],
		[
			14,
			-1
		],
		[
			11,
			10
		],
		[
			9,
			-8
		],
		[
			-7,
			-12
		],
		[
			-38,
			-3
		],
		[
			36,
			-14
		],
		[
			13,
			10
		],
		[
			0,
			-26
		],
		[
			-19,
			-2
		],
		[
			6,
			-18
		],
		[
			17,
			8
		],
		[
			-7,
			-24
		],
		[
			25,
			4
		],
		[
			-11,
			-19
		],
		[
			-9,
			8
		],
		[
			-3,
			-13
		],
		[
			-15,
			12
		],
		[
			-21,
			5
		],
		[
			13,
			-17
		],
		[
			21,
			-10
		],
		[
			-7,
			-23
		],
		[
			-21,
			5
		],
		[
			21,
			-13
		],
		[
			-23,
			-13
		],
		[
			31,
			7
		],
		[
			-9,
			-17
		],
		[
			-36,
			6
		],
		[
			17,
			-17
		],
		[
			-10,
			-13
		],
		[
			-13,
			-3
		],
		[
			-2,
			17
		],
		[
			-17,
			2
		],
		[
			6,
			-15
		],
		[
			-14,
			3
		],
		[
			-10,
			-10
		],
		[
			18,
			2
		],
		[
			7,
			-9
		],
		[
			-35,
			-4
		],
		[
			-2,
			-7
		],
		[
			33,
			-3
		],
		[
			-85,
			-34
		],
		[
			-52,
			-9
		],
		[
			4,
			-3
		],
		[
			-60,
			-13
		],
		[
			4,
			-11
		],
		[
			-17,
			-7
		],
		[
			-31,
			-1
		],
		[
			-20,
			4
		],
		[
			-46,
			0
		],
		[
			-31,
			8
		],
		[
			-64,
			0
		],
		[
			34,
			-42
		],
		[
			23,
			-15
		],
		[
			10,
			6
		],
		[
			66,
			-8
		],
		[
			-25,
			-26
		],
		[
			-38,
			-9
		],
		[
			-61,
			13
		],
		[
			-95,
			13
		],
		[
			-30,
			-6
		],
		[
			118,
			-34
		],
		[
			-9,
			-17
		],
		[
			-71,
			-7
		],
		[
			-61,
			21
		],
		[
			-37,
			30
		],
		[
			12,
			-23
		],
		[
			-13,
			-4
		],
		[
			17,
			-20
		],
		[
			42,
			-17
		],
		[
			17,
			-23
		],
		[
			18,
			-7
		],
		[
			2,
			20
		],
		[
			108,
			-4
		],
		[
			17,
			-13
		],
		[
			-20,
			-24
		],
		[
			-22,
			-3
		],
		[
			-62,
			0
		],
		[
			55,
			-10
		],
		[
			39,
			6
		],
		[
			24,
			-26
		],
		[
			-8,
			-7
		],
		[
			24,
			-16
		],
		[
			19,
			7
		],
		[
			38,
			-10
		],
		[
			7,
			13
		],
		[
			39,
			9
		],
		[
			21,
			-6
		],
		[
			9,
			-14
		],
		[
			46,
			-9
		],
		[
			89,
			-24
		],
		[
			77,
			-3
		],
		[
			-92,
			-8
		],
		[
			62,
			-5
		],
		[
			-2,
			-4
		],
		[
			-62,
			-1
		],
		[
			-6,
			-25
		],
		[
			26,
			-5
		],
		[
			52,
			8
		],
		[
			75,
			3
		],
		[
			-64,
			-17
		],
		[
			33,
			-33
		],
		[
			-6,
			-17
		],
		[
			66,
			-4
		],
		[
			49,
			30
		],
		[
			72,
			31
		],
		[
			52,
			14
		],
		[
			16,
			-1
		],
		[
			53,
			11
		],
		[
			65,
			5
		],
		[
			59,
			-2
		],
		[
			6,
			-17
		],
		[
			-17,
			-11
		],
		[
			31,
			-7
		],
		[
			67,
			24
		],
		[
			-2,
			10
		],
		[
			36,
			18
		],
		[
			9,
			16
		],
		[
			79,
			27
		],
		[
			42,
			-13
		],
		[
			34,
			10
		],
		[
			18,
			17
		],
		[
			53,
			0
		],
		[
			40,
			12
		],
		[
			42,
			-3
		],
		[
			-21,
			10
		],
		[
			37,
			0
		],
		[
			5,
			7
		],
		[
			153,
			6
		],
		[
			48,
			10
		],
		[
			-61,
			7
		],
		[
			-165,
			11
		],
		[
			31,
			17
		],
		[
			-27,
			0
		],
		[
			9,
			15
		],
		[
			-73,
			-12
		],
		[
			-96,
			23
		],
		[
			-5,
			14
		],
		[
			12,
			23
		],
		[
			11,
			3
		],
		[
			8,
			18
		],
		[
			24,
			0
		],
		[
			-7,
			12
		],
		[
			28,
			18
		],
		[
			34,
			10
		],
		[
			17,
			0
		],
		[
			5,
			10
		],
		[
			28,
			7
		],
		[
			15,
			13
		],
		[
			36,
			16
		],
		[
			52,
			10
		],
		[
			29,
			14
		],
		[
			48,
			10
		],
		[
			53,
			7
		],
		[
			31,
			-4
		],
		[
			22,
			14
		],
		[
			17,
			-6
		],
		[
			43,
			6
		],
		[
			-18,
			11
		],
		[
			29,
			26
		],
		[
			-3,
			10
		],
		[
			14,
			17
		],
		[
			24,
			3
		],
		[
			23,
			-7
		],
		[
			39,
			33
		],
		[
			-10,
			4
		],
		[
			-27,
			-10
		],
		[
			-22,
			3
		],
		[
			17,
			4
		],
		[
			-20,
			7
		],
		[
			1,
			13
		],
		[
			28,
			23
		],
		[
			18,
			3
		],
		[
			12,
			-9
		],
		[
			16,
			11
		],
		[
			-15,
			16
		],
		[
			29,
			-7
		],
		[
			14,
			11
		],
		[
			42,
			13
		],
		[
			3,
			19
		],
		[
			10,
			20
		],
		[
			-18,
			0
		],
		[
			-18,
			7
		],
		[
			-1,
			18
		],
		[
			16,
			2
		],
		[
			1,
			-9
		],
		[
			21,
			-10
		],
		[
			7,
			17
		],
		[
			16,
			9
		],
		[
			-12,
			10
		],
		[
			13,
			4
		],
		[
			3,
			-10
		],
		[
			22,
			-7
		],
		[
			10,
			-28
		],
		[
			15,
			7
		],
		[
			15,
			-5
		],
		[
			-4,
			9
		],
		[
			6,
			23
		],
		[
			-11,
			13
		],
		[
			13,
			5
		],
		[
			25,
			-7
		],
		[
			16,
			14
		],
		[
			13,
			-8
		],
		[
			-20,
			-29
		],
		[
			71,
			-3
		],
		[
			7,
			-9
		],
		[
			4,
			12
		],
		[
			18,
			3
		],
		[
			5,
			-6
		],
		[
			28,
			-5
		],
		[
			7,
			11
		],
		[
			12,
			-7
		],
		[
			-4,
			-14
		],
		[
			12,
			-9
		],
		[
			21,
			25
		],
		[
			13,
			8
		],
		[
			41,
			14
		],
		[
			105,
			20
		],
		[
			19,
			0
		],
		[
			28,
			7
		],
		[
			-5,
			17
		],
		[
			12,
			2
		],
		[
			-1,
			-17
		],
		[
			11,
			-3
		],
		[
			25,
			9
		],
		[
			-8,
			8
		],
		[
			9,
			9
		],
		[
			22,
			-23
		],
		[
			31,
			-14
		],
		[
			21,
			-5
		],
		[
			14,
			25
		],
		[
			18,
			7
		],
		[
			-16,
			10
		],
		[
			16,
			1
		],
		[
			8,
			-13
		],
		[
			22,
			-4
		],
		[
			22,
			3
		],
		[
			27,
			-4
		],
		[
			3,
			9
		],
		[
			17,
			3
		],
		[
			-3,
			-18
		],
		[
			45,
			-4
		],
		[
			11,
			1
		],
		[
			-6,
			11
		],
		[
			17,
			9
		],
		[
			11,
			-10
		],
		[
			-10,
			-23
		],
		[
			10,
			-10
		],
		[
			23,
			-1
		],
		[
			26,
			4
		],
		[
			3,
			13
		],
		[
			16,
			24
		],
		[
			24,
			-18
		],
		[
			-21,
			-6
		],
		[
			14,
			-7
		],
		[
			26,
			-5
		],
		[
			13,
			26
		],
		[
			15,
			-4
		],
		[
			0,
			-15
		],
		[
			27,
			-15
		],
		[
			31,
			-3
		],
		[
			35,
			17
		],
		[
			23,
			3
		],
		[
			38,
			21
		],
		[
			40,
			5
		],
		[
			38,
			11
		],
		[
			7,
			7
		],
		[
			2,
			33
		],
		[
			-12,
			13
		],
		[
			-1,
			13
		],
		[
			20,
			12
		],
		[
			28,
			0
		],
		[
			4,
			-8
		],
		[
			-21,
			-13
		],
		[
			24,
			-1
		],
		[
			20,
			-13
		],
		[
			-2,
			-23
		],
		[
			45,
			4
		],
		[
			8,
			-15
		],
		[
			7,
			9
		],
		[
			26,
			-1
		],
		[
			-5,
			-7
		],
		[
			19,
			-19
		],
		[
			2,
			12
		],
		[
			13,
			7
		],
		[
			-1,
			10
		],
		[
			15,
			4
		],
		[
			-2,
			32
		],
		[
			4,
			14
		],
		[
			26,
			6
		],
		[
			21,
			15
		],
		[
			28,
			4
		],
		[
			8,
			17
		],
		[
			32,
			8
		],
		[
			24,
			0
		],
		[
			-6,
			5
		],
		[
			34,
			13
		],
		[
			14,
			-6
		],
		[
			-2,
			23
		],
		[
			18,
			5
		],
		[
			14,
			-8
		],
		[
			-13,
			-7
		],
		[
			10,
			-3
		],
		[
			6,
			-12
		],
		[
			9,
			8
		],
		[
			16,
			-6
		],
		[
			-5,
			-17
		],
		[
			13,
			20
		],
		[
			-3,
			14
		],
		[
			16,
			5
		],
		[
			2,
			11
		],
		[
			-19,
			-3
		],
		[
			-6,
			13
		],
		[
			27,
			6
		],
		[
			-2,
			-9
		],
		[
			15,
			2
		],
		[
			0,
			-13
		],
		[
			11,
			8
		],
		[
			11,
			-7
		],
		[
			10,
			7
		],
		[
			-14,
			3
		],
		[
			10,
			16
		],
		[
			-16,
			1
		],
		[
			-1,
			12
		],
		[
			9,
			14
		],
		[
			23,
			4
		],
		[
			11,
			12
		],
		[
			30,
			4
		],
		[
			25,
			7
		],
		[
			40,
			-6
		],
		[
			19,
			-10
		],
		[
			15,
			-20
		],
		[
			11,
			3
		],
		[
			13,
			-8
		],
		[
			1,
			-9
		],
		[
			-36,
			3
		],
		[
			15,
			-8
		],
		[
			-11,
			-23
		],
		[
			1,
			-12
		],
		[
			7,
			13
		],
		[
			33,
			10
		],
		[
			23,
			-11
		],
		[
			12,
			1
		],
		[
			5,
			-20
		],
		[
			12,
			-4
		],
		[
			4,
			11
		],
		[
			24,
			0
		],
		[
			18,
			-7
		],
		[
			45,
			-7
		],
		[
			24,
			9
		],
		[
			30,
			-9
		],
		[
			45,
			-7
		],
		[
			48,
			-4
		],
		[
			9,
			-3
		],
		[
			35,
			8
		],
		[
			-1,
			-15
		],
		[
			14,
			-30
		],
		[
			-13,
			-3
		],
		[
			-7,
			-17
		],
		[
			13,
			0
		],
		[
			-16,
			-9
		],
		[
			12,
			-8
		],
		[
			0,
			-9
		],
		[
			-27,
			-3
		],
		[
			17,
			-14
		],
		[
			-13,
			-6
		],
		[
			9,
			-5
		],
		[
			-17,
			-12
		],
		[
			-13,
			18
		],
		[
			-18,
			-29
		],
		[
			13,
			-14
		],
		[
			34,
			8
		],
		[
			1,
			-21
		],
		[
			-15,
			-30
		],
		[
			-17,
			-8
		],
		[
			-5,
			-19
		],
		[
			-10,
			-7
		],
		[
			-6,
			-33
		],
		[
			-12,
			-36
		],
		[
			-15,
			-8
		],
		[
			25,
			-10
		],
		[
			22,
			10
		],
		[
			-3,
			26
		],
		[
			14,
			11
		],
		[
			34,
			3
		],
		[
			8,
			20
		],
		[
			20,
			6
		],
		[
			-6,
			7
		],
		[
			17,
			12
		],
		[
			14,
			3
		],
		[
			-11,
			7
		],
		[
			16,
			40
		],
		[
			17,
			7
		],
		[
			14,
			12
		],
		[
			-6,
			15
		],
		[
			22,
			23
		],
		[
			15,
			5
		],
		[
			8,
			-12
		],
		[
			28,
			6
		],
		[
			5,
			-7
		],
		[
			13,
			8
		],
		[
			-3,
			16
		],
		[
			35,
			18
		],
		[
			22,
			5
		],
		[
			7,
			21
		],
		[
			16,
			4
		],
		[
			-7,
			13
		],
		[
			9,
			12
		],
		[
			19,
			10
		],
		[
			73,
			24
		],
		[
			30,
			4
		],
		[
			13,
			-3
		],
		[
			-6,
			13
		],
		[
			29,
			18
		],
		[
			36,
			-4
		],
		[
			9,
			7
		],
		[
			18,
			0
		],
		[
			34,
			17
		],
		[
			8,
			-5
		],
		[
			14,
			4
		],
		[
			23,
			-4
		],
		[
			23,
			1
		],
		[
			19,
			14
		],
		[
			25,
			5
		],
		[
			12,
			-6
		],
		[
			34,
			1
		],
		[
			4,
			-10
		],
		[
			31,
			17
		],
		[
			11,
			-4
		],
		[
			8,
			-10
		],
		[
			13,
			6
		],
		[
			16,
			0
		],
		[
			16,
			6
		],
		[
			13,
			-10
		],
		[
			14,
			13
		],
		[
			9,
			0
		],
		[
			8,
			-26
		],
		[
			8,
			11
		],
		[
			13,
			3
		],
		[
			9,
			9
		],
		[
			27,
			7
		],
		[
			14,
			17
		],
		[
			0,
			7
		],
		[
			27,
			0
		],
		[
			8,
			6
		],
		[
			27,
			-9
		],
		[
			24,
			-3
		],
		[
			65,
			-22
		],
		[
			29,
			-6
		],
		[
			-3,
			-17
		],
		[
			12,
			13
		],
		[
			16,
			-19
		],
		[
			18,
			0
		],
		[
			29,
			17
		],
		[
			7,
			0
		],
		[
			-5,
			20
		],
		[
			13,
			14
		],
		[
			62,
			17
		],
		[
			35,
			-27
		],
		[
			-3,
			-15
		],
		[
			21,
			2
		],
		[
			16,
			-8
		],
		[
			3,
			-10
		],
		[
			-17,
			-16
		],
		[
			-31,
			-8
		],
		[
			-11,
			-15
		],
		[
			25,
			3
		],
		[
			22,
			10
		],
		[
			32,
			6
		],
		[
			13,
			10
		],
		[
			-3,
			-10
		],
		[
			19,
			3
		],
		[
			5,
			-6
		],
		[
			32,
			-1
		],
		[
			41,
			14
		],
		[
			0,
			-3
		],
		[
			-45,
			-17
		],
		[
			5,
			-7
		],
		[
			73,
			19
		],
		[
			18,
			14
		],
		[
			58,
			14
		],
		[
			13,
			-9
		],
		[
			11,
			6
		],
		[
			8,
			14
		],
		[
			14,
			6
		],
		[
			12,
			-14
		],
		[
			14,
			6
		],
		[
			-8,
			-12
		],
		[
			3,
			-11
		],
		[
			11,
			0
		],
		[
			0,
			-16
		],
		[
			28,
			6
		],
		[
			11,
			-7
		],
		[
			10,
			7
		],
		[
			6,
			-10
		],
		[
			11,
			13
		],
		[
			2,
			21
		],
		[
			16,
			19
		],
		[
			18,
			8
		],
		[
			28,
			-7
		],
		[
			30,
			4
		],
		[
			8,
			6
		],
		[
			19,
			-2
		],
		[
			13,
			-11
		],
		[
			-5,
			-11
		],
		[
			19,
			10
		],
		[
			11,
			0
		],
		[
			9,
			12
		],
		[
			4,
			-14
		],
		[
			13,
			7
		],
		[
			8,
			-8
		],
		[
			30,
			1
		],
		[
			20,
			-11
		],
		[
			35,
			-3
		],
		[
			12,
			-6
		],
		[
			28,
			-3
		],
		[
			10,
			-5
		],
		[
			20,
			3
		],
		[
			14,
			-13
		],
		[
			27,
			10
		],
		[
			12,
			-6
		],
		[
			-4,
			-11
		],
		[
			21,
			8
		],
		[
			5,
			-6
		],
		[
			-22,
			-38
		],
		[
			0,
			-10
		],
		[
			11,
			0
		],
		[
			26,
			23
		],
		[
			9,
			-10
		],
		[
			14,
			7
		],
		[
			14,
			-31
		],
		[
			13,
			5
		],
		[
			-8,
			-14
		],
		[
			8,
			-7
		],
		[
			23,
			3
		],
		[
			4,
			-6
		],
		[
			39,
			4
		],
		[
			35,
			-1
		],
		[
			10,
			4
		],
		[
			-1,
			-21
		],
		[
			16,
			-13
		],
		[
			0,
			14
		],
		[
			24,
			0
		],
		[
			17,
			-11
		],
		[
			23,
			7
		],
		[
			-5,
			24
		],
		[
			5,
			3
		],
		[
			24,
			-14
		],
		[
			2,
			-10
		],
		[
			16,
			-13
		],
		[
			14,
			-3
		],
		[
			17,
			-14
		],
		[
			19,
			3
		],
		[
			6,
			-10
		],
		[
			6,
			8
		],
		[
			17,
			-1
		],
		[
			45,
			-17
		],
		[
			14,
			-20
		],
		[
			-16,
			0
		],
		[
			28,
			-13
		],
		[
			19,
			-34
		],
		[
			-3,
			-13
		],
		[
			18,
			0
		],
		[
			2,
			34
		],
		[
			16,
			3
		],
		[
			22,
			-23
		],
		[
			21,
			2
		],
		[
			-3,
			7
		],
		[
			38,
			-3
		],
		[
			13,
			-6
		],
		[
			12,
			5
		],
		[
			13,
			-6
		],
		[
			-9,
			-6
		],
		[
			27,
			2
		],
		[
			18,
			-20
		],
		[
			10,
			-3
		],
		[
			48,
			-30
		],
		[
			2,
			21
		],
		[
			19,
			-31
		],
		[
			-5,
			-6
		],
		[
			-13,
			7
		],
		[
			-13,
			-34
		],
		[
			12,
			6
		],
		[
			-5,
			-17
		],
		[
			-39,
			15
		],
		[
			-11,
			-1
		],
		[
			16,
			-13
		],
		[
			29,
			-8
		],
		[
			-8,
			-19
		],
		[
			-20,
			-10
		],
		[
			-14,
			16
		],
		[
			-2,
			-13
		],
		[
			-32,
			1
		],
		[
			-12,
			5
		],
		[
			1,
			-16
		],
		[
			9,
			6
		],
		[
			23,
			-6
		],
		[
			-20,
			-4
		],
		[
			-5,
			-9
		],
		[
			-34,
			0
		],
		[
			9,
			-14
		],
		[
			-26,
			-1
		],
		[
			1,
			15
		],
		[
			-11,
			9
		],
		[
			-4,
			-20
		],
		[
			17,
			-14
		],
		[
			-15,
			0
		],
		[
			13,
			-30
		],
		[
			-24,
			1
		],
		[
			-20,
			-6
		],
		[
			-3,
			16
		],
		[
			-30,
			-30
		],
		[
			9,
			-7
		],
		[
			-5,
			-13
		],
		[
			-22,
			2
		],
		[
			-34,
			-12
		],
		[
			45,
			-1
		],
		[
			-4,
			-7
		],
		[
			21,
			-16
		],
		[
			-2,
			-16
		],
		[
			-18,
			-5
		],
		[
			18,
			-3
		],
		[
			4,
			-13
		],
		[
			-13,
			-11
		],
		[
			14,
			-5
		],
		[
			-14,
			-17
		],
		[
			18,
			0
		],
		[
			20,
			-30
		],
		[
			-7,
			-11
		],
		[
			27,
			-7
		],
		[
			-11,
			-20
		],
		[
			14,
			-7
		],
		[
			20,
			8
		],
		[
			12,
			-14
		],
		[
			36,
			-4
		],
		[
			-15,
			-13
		],
		[
			-12,
			9
		],
		[
			-47,
			-2
		],
		[
			-37,
			-7
		],
		[
			-14,
			-13
		],
		[
			-34,
			22
		],
		[
			20,
			-29
		],
		[
			-38,
			2
		],
		[
			-9,
			-8
		],
		[
			9,
			-14
		],
		[
			-23,
			-14
		],
		[
			27,
			3
		],
		[
			-37,
			-16
		],
		[
			52,
			-4
		],
		[
			-72,
			-17
		],
		[
			-6,
			-13
		],
		[
			61,
			6
		],
		[
			7,
			-8
		],
		[
			-35,
			-4
		],
		[
			40,
			-4
		],
		[
			-17,
			-13
		],
		[
			9,
			-23
		],
		[
			-22,
			5
		],
		[
			25,
			-20
		],
		[
			40,
			-9
		],
		[
			38,
			-31
		],
		[
			-89,
			-12
		],
		[
			59,
			-2
		],
		[
			53,
			8
		],
		[
			73,
			-27
		],
		[
			12,
			-14
		],
		[
			24,
			3
		],
		[
			-3,
			-20
		],
		[
			86,
			-9
		],
		[
			66,
			-23
		],
		[
			124,
			-12
		],
		[
			-9955,
			-15
		]
	],
	[
		[
			3456,
			1546
		],
		[
			12,
			-3
		],
		[
			-1,
			-9
		],
		[
			-17,
			4
		],
		[
			-19,
			-9
		],
		[
			3,
			13
		],
		[
			22,
			4
		]
	],
	[
		[
			3431,
			1556
		],
		[
			12,
			-2
		],
		[
			-6,
			-9
		],
		[
			-6,
			11
		]
	],
	[
		[
			3331,
			1581
		],
		[
			7,
			-5
		],
		[
			-12,
			-7
		],
		[
			-4,
			7
		],
		[
			-20,
			-3
		],
		[
			-1,
			6
		],
		[
			30,
			2
		]
	],
	[
		[
			3392,
			1616
		],
		[
			7,
			-6
		],
		[
			-33,
			-7
		],
		[
			10,
			13
		],
		[
			16,
			0
		]
	],
	[
		[
			3470,
			1665
		],
		[
			-6,
			-10
		],
		[
			-5,
			8
		],
		[
			11,
			2
		]
	],
	[
		[
			6916,
			2373
		],
		[
			5,
			-3
		],
		[
			-5,
			-12
		],
		[
			16,
			-14
		],
		[
			19,
			13
		],
		[
			7,
			-1
		],
		[
			-1,
			-15
		],
		[
			-9,
			1
		],
		[
			-11,
			-5
		],
		[
			2,
			-7
		],
		[
			13,
			1
		],
		[
			-1,
			-9
		],
		[
			-22,
			3
		],
		[
			-7,
			8
		],
		[
			-5,
			-13
		],
		[
			-8,
			4
		],
		[
			5,
			20
		],
		[
			-5,
			14
		],
		[
			1,
			12
		],
		[
			6,
			3
		]
	],
	[
		[
			9093,
			2685
		],
		[
			-7,
			-6
		],
		[
			5,
			12
		],
		[
			2,
			-6
		]
	],
	[
		[
			9020,
			2837
		],
		[
			14,
			-3
		],
		[
			13,
			-8
		],
		[
			2,
			-6
		],
		[
			17,
			-8
		],
		[
			24,
			13
		],
		[
			5,
			-4
		],
		[
			5,
			11
		],
		[
			5,
			-4
		],
		[
			4,
			9
		],
		[
			10,
			-13
		],
		[
			-1,
			-28
		],
		[
			1,
			-39
		],
		[
			-7,
			1
		],
		[
			-1,
			-22
		],
		[
			-4,
			-21
		],
		[
			3,
			-1
		],
		[
			0,
			-21
		],
		[
			-10,
			9
		],
		[
			6,
			10
		],
		[
			-14,
			1
		],
		[
			-4,
			-23
		],
		[
			-2,
			6
		],
		[
			-8,
			-26
		],
		[
			-9,
			6
		],
		[
			-14,
			-1
		],
		[
			-3,
			20
		],
		[
			-2,
			-6
		],
		[
			-4,
			15
		],
		[
			-7,
			9
		],
		[
			-6,
			24
		],
		[
			0,
			13
		],
		[
			9,
			-9
		],
		[
			-13,
			31
		],
		[
			-11,
			37
		],
		[
			-2,
			13
		],
		[
			4,
			15
		]
	],
	[
		[
			9121,
			2859
		],
		[
			-9,
			-6
		],
		[
			0,
			6
		],
		[
			9,
			0
		]
	],
	[
		[
			9109,
			2896
		],
		[
			9,
			-16
		],
		[
			1,
			-14
		],
		[
			-5,
			-2
		],
		[
			-11,
			22
		],
		[
			6,
			10
		]
	],
	[
		[
			9001,
			2876
		],
		[
			-5,
			-4
		],
		[
			-1,
			25
		],
		[
			7,
			3
		],
		[
			-1,
			-24
		]
	],
	[
		[
			8822,
			3134
		],
		[
			-1,
			-10
		],
		[
			12,
			1
		],
		[
			0,
			-11
		],
		[
			-11,
			1
		],
		[
			-5,
			-10
		],
		[
			-20,
			1
		],
		[
			-4,
			17
		],
		[
			21,
			11
		],
		[
			8,
			0
		]
	],
	[
		[
			9263,
			3604
		],
		[
			-1,
			-18
		],
		[
			-2,
			14
		],
		[
			3,
			4
		]
	],
	[
		[
			9261,
			3608
		],
		[
			-2,
			17
		],
		[
			3,
			2
		],
		[
			-1,
			-19
		]
	],
	[
		[
			8136,
			3714
		],
		[
			7,
			-36
		],
		[
			-7,
			19
		],
		[
			0,
			17
		]
	],
	[
		[
			9257,
			3758
		],
		[
			2,
			-20
		],
		[
			-10,
			-37
		],
		[
			1,
			32
		],
		[
			5,
			7
		],
		[
			-2,
			14
		],
		[
			4,
			4
		]
	],
	[
		[
			9195,
			3832
		],
		[
			5,
			-3
		],
		[
			0,
			-17
		],
		[
			-7,
			17
		],
		[
			2,
			3
		]
	],
	[
		[
			9061,
			4133
		],
		[
			3,
			-7
		],
		[
			-3,
			-7
		],
		[
			-4,
			13
		],
		[
			4,
			1
		]
	],
	[
		[
			8880,
			4236
		],
		[
			-7,
			-7
		],
		[
			0,
			-6
		],
		[
			-8,
			0
		],
		[
			1,
			8
		],
		[
			10,
			8
		],
		[
			4,
			-3
		]
	],
	[
		[
			8805,
			4285
		],
		[
			2,
			-15
		],
		[
			-4,
			8
		],
		[
			2,
			7
		]
	],
	[
		[
			8797,
			4395
		],
		[
			0,
			-9
		],
		[
			6,
			2
		],
		[
			-5,
			-8
		],
		[
			-1,
			-14
		],
		[
			6,
			-6
		],
		[
			-8,
			0
		],
		[
			-6,
			5
		],
		[
			-1,
			14
		],
		[
			9,
			16
		]
	],
	[
		[
			8621,
			4522
		],
		[
			5,
			-21
		],
		[
			-7,
			4
		],
		[
			-8,
			-2
		],
		[
			5,
			9
		],
		[
			-2,
			9
		],
		[
			6,
			10
		],
		[
			1,
			-9
		]
	],
	[
		[
			8624,
			4533
		],
		[
			6,
			-6
		],
		[
			14,
			10
		],
		[
			6,
			-2
		],
		[
			1,
			-21
		],
		[
			-14,
			-18
		],
		[
			-13,
			16
		],
		[
			-3,
			29
		],
		[
			3,
			-8
		]
	],
	[
		[
			8682,
			4547
		],
		[
			1,
			-13
		],
		[
			-4,
			6
		],
		[
			3,
			7
		]
	],
	[
		[
			8959,
			4566
		],
		[
			-1,
			-8
		],
		[
			6,
			-7
		],
		[
			3,
			-19
		],
		[
			0,
			-30
		],
		[
			10,
			-9
		],
		[
			-4,
			-20
		],
		[
			6,
			-4
		],
		[
			4,
			-11
		],
		[
			-2,
			-17
		],
		[
			5,
			2
		],
		[
			-1,
			-13
		],
		[
			3,
			-19
		],
		[
			-2,
			-19
		],
		[
			5,
			-20
		],
		[
			3,
			-22
		],
		[
			5,
			-2
		],
		[
			15,
			18
		],
		[
			4,
			-22
		],
		[
			18,
			-23
		],
		[
			-3,
			-12
		],
		[
			2,
			-6
		],
		[
			2,
			-37
		],
		[
			3,
			-8
		],
		[
			-2,
			-16
		],
		[
			6,
			-22
		],
		[
			9,
			-9
		],
		[
			-1,
			-11
		],
		[
			5,
			-19
		],
		[
			1,
			-16
		],
		[
			-3,
			-34
		],
		[
			9,
			-15
		],
		[
			-2,
			-17
		],
		[
			5,
			-14
		],
		[
			13,
			-15
		],
		[
			4,
			7
		],
		[
			2,
			-12
		],
		[
			8,
			0
		],
		[
			4,
			-6
		],
		[
			1,
			-14
		],
		[
			19,
			-12
		],
		[
			1,
			-10
		],
		[
			7,
			5
		],
		[
			3,
			-13
		],
		[
			4,
			1
		],
		[
			1,
			-10
		],
		[
			-4,
			-1
		],
		[
			-1,
			-10
		],
		[
			15,
			-24
		],
		[
			-1,
			-8
		],
		[
			8,
			-30
		],
		[
			0,
			-14
		],
		[
			3,
			-20
		],
		[
			8,
			-7
		],
		[
			5,
			-13
		],
		[
			-3,
			22
		],
		[
			4,
			5
		],
		[
			3,
			-9
		],
		[
			10,
			-13
		],
		[
			2,
			13
		],
		[
			6,
			-21
		],
		[
			-2,
			-15
		],
		[
			3,
			-36
		],
		[
			4,
			0
		],
		[
			4,
			-13
		],
		[
			5,
			-4
		],
		[
			6,
			-13
		],
		[
			6,
			3
		],
		[
			4,
			-6
		],
		[
			6,
			-27
		],
		[
			8,
			-7
		],
		[
			4,
			-25
		],
		[
			10,
			-6
		],
		[
			0,
			-27
		],
		[
			6,
			-16
		],
		[
			-2,
			-19
		],
		[
			4,
			-40
		],
		[
			-4,
			-3
		],
		[
			10,
			-41
		],
		[
			1,
			-17
		],
		[
			3,
			-4
		],
		[
			1,
			-40
		],
		[
			-7,
			-21
		],
		[
			-2,
			-39
		],
		[
			-7,
			-32
		],
		[
			0,
			-30
		],
		[
			-3,
			-28
		],
		[
			-5,
			-21
		],
		[
			-6,
			-11
		],
		[
			0,
			-23
		],
		[
			-13,
			-15
		],
		[
			-11,
			-20
		],
		[
			-6,
			-26
		],
		[
			-5,
			-3
		],
		[
			0,
			-26
		],
		[
			-9,
			-18
		],
		[
			-3,
			-27
		],
		[
			-4,
			-14
		],
		[
			2,
			-9
		],
		[
			-8,
			-7
		],
		[
			-9,
			-34
		],
		[
			0,
			-24
		],
		[
			-7,
			-34
		],
		[
			4,
			-21
		],
		[
			-2,
			-14
		],
		[
			-13,
			-16
		],
		[
			-33,
			-2
		],
		[
			-16,
			-10
		],
		[
			-10,
			-13
		],
		[
			-13,
			-24
		],
		[
			-19,
			-4
		],
		[
			3,
			-12
		],
		[
			4,
			7
		],
		[
			-2,
			-20
		],
		[
			-6,
			16
		],
		[
			-8,
			-3
		],
		[
			-4,
			16
		],
		[
			-3,
			-3
		],
		[
			-8,
			9
		],
		[
			5,
			8
		],
		[
			-2,
			9
		],
		[
			-6,
			0
		],
		[
			-1,
			-10
		],
		[
			-8,
			-5
		],
		[
			-6,
			8
		],
		[
			8,
			1
		],
		[
			3,
			17
		],
		[
			-6,
			10
		],
		[
			-15,
			-14
		],
		[
			10,
			-2
		],
		[
			-2,
			-8
		],
		[
			-6,
			0
		],
		[
			-10,
			-11
		],
		[
			-14,
			-22
		],
		[
			-32,
			28
		],
		[
			-5,
			-2
		],
		[
			-8,
			7
		],
		[
			-9,
			-1
		],
		[
			1,
			-6
		],
		[
			-8,
			1
		],
		[
			-4,
			13
		],
		[
			-14,
			5
		],
		[
			-10,
			11
		],
		[
			-3,
			13
		],
		[
			-13,
			23
		],
		[
			-3,
			18
		],
		[
			5,
			6
		],
		[
			0,
			13
		],
		[
			-9,
			34
		],
		[
			-14,
			26
		],
		[
			6,
			2
		],
		[
			3,
			10
		],
		[
			-4,
			3
		],
		[
			-21,
			-20
		],
		[
			-8,
			0
		],
		[
			-1,
			7
		],
		[
			9,
			12
		],
		[
			3,
			33
		],
		[
			-8,
			16
		],
		[
			-3,
			16
		],
		[
			-7,
			-13
		],
		[
			-1,
			-20
		],
		[
			-5,
			-23
		],
		[
			-7,
			4
		],
		[
			-15,
			-11
		],
		[
			3,
			23
		],
		[
			11,
			-3
		],
		[
			3,
			21
		],
		[
			-1,
			25
		],
		[
			4,
			17
		],
		[
			9,
			19
		],
		[
			-3,
			19
		],
		[
			6,
			4
		],
		[
			-8,
			34
		],
		[
			0,
			-26
		],
		[
			-3,
			2
		],
		[
			-6,
			-11
		],
		[
			-5,
			-27
		],
		[
			-25,
			-26
		],
		[
			-8,
			-24
		],
		[
			-4,
			-3
		],
		[
			-4,
			-16
		],
		[
			6,
			2
		],
		[
			0,
			-12
		],
		[
			-5,
			7
		],
		[
			-6,
			-5
		],
		[
			-6,
			18
		],
		[
			-1,
			21
		],
		[
			-3,
			17
		],
		[
			-11,
			20
		],
		[
			-4,
			27
		],
		[
			-12,
			0
		],
		[
			-2,
			13
		],
		[
			-4,
			1
		],
		[
			7,
			15
		],
		[
			-5,
			12
		],
		[
			-8,
			-5
		],
		[
			3,
			9
		],
		[
			-8,
			16
		],
		[
			-14,
			-5
		],
		[
			-10,
			14
		],
		[
			-7,
			1
		],
		[
			-9,
			-6
		],
		[
			-12,
			18
		],
		[
			-18,
			14
		],
		[
			-9,
			-7
		],
		[
			-18,
			2
		],
		[
			-33,
			-7
		],
		[
			-27,
			-23
		],
		[
			-20,
			-11
		],
		[
			-17,
			-2
		],
		[
			-14,
			5
		],
		[
			-18,
			-19
		],
		[
			-15,
			-10
		],
		[
			-2,
			-6
		],
		[
			-17,
			-8
		],
		[
			-4,
			-5
		],
		[
			-5,
			-28
		],
		[
			-7,
			-16
		],
		[
			-6,
			-7
		],
		[
			-4,
			3
		],
		[
			-6,
			-7
		],
		[
			-3,
			9
		],
		[
			-19,
			-3
		],
		[
			-8,
			-6
		],
		[
			0,
			8
		],
		[
			-14,
			3
		],
		[
			-20,
			-2
		],
		[
			-13,
			-6
		],
		[
			-16,
			-1
		],
		[
			-9,
			-16
		],
		[
			-2,
			-12
		],
		[
			-16,
			1
		],
		[
			-3,
			-11
		],
		[
			-7,
			-4
		],
		[
			-2,
			-11
		],
		[
			-20,
			-8
		],
		[
			-2,
			-5
		],
		[
			-12,
			7
		],
		[
			-18,
			-1
		],
		[
			-15,
			14
		],
		[
			-10,
			19
		],
		[
			-10,
			9
		],
		[
			-4,
			-3
		],
		[
			-4,
			15
		],
		[
			0,
			32
		],
		[
			6,
			-7
		],
		[
			7,
			3
		],
		[
			6,
			18
		],
		[
			-1,
			36
		],
		[
			3,
			8
		],
		[
			0,
			43
		],
		[
			-18,
			66
		],
		[
			-4,
			34
		],
		[
			1,
			32
		],
		[
			-5,
			22
		],
		[
			-7,
			17
		],
		[
			0,
			16
		],
		[
			-11,
			24
		],
		[
			-2,
			38
		],
		[
			-5,
			16
		],
		[
			-11,
			32
		],
		[
			-7,
			13
		],
		[
			5,
			14
		],
		[
			6,
			-26
		],
		[
			7,
			6
		],
		[
			0,
			9
		],
		[
			-9,
			14
		],
		[
			-4,
			27
		],
		[
			2,
			4
		],
		[
			7,
			-20
		],
		[
			-1,
			-17
		],
		[
			5,
			14
		],
		[
			2,
			-22
		],
		[
			7,
			-2
		],
		[
			0,
			30
		],
		[
			-5,
			13
		],
		[
			-6,
			26
		],
		[
			-4,
			4
		],
		[
			-3,
			21
		],
		[
			-5,
			16
		],
		[
			1,
			26
		],
		[
			4,
			22
		],
		[
			5,
			6
		],
		[
			0,
			24
		],
		[
			2,
			10
		],
		[
			-5,
			22
		],
		[
			3,
			7
		],
		[
			7,
			33
		],
		[
			4,
			4
		],
		[
			-2,
			-20
		],
		[
			1,
			-21
		],
		[
			7,
			4
		],
		[
			8,
			34
		],
		[
			23,
			20
		],
		[
			13,
			26
		],
		[
			21,
			22
		],
		[
			5,
			-3
		],
		[
			8,
			6
		],
		[
			7,
			-7
		],
		[
			12,
			7
		],
		[
			8,
			14
		],
		[
			17,
			3
		],
		[
			10,
			20
		],
		[
			12,
			-6
		],
		[
			7,
			6
		],
		[
			12,
			3
		],
		[
			16,
			11
		],
		[
			11,
			13
		],
		[
			9,
			25
		],
		[
			3,
			19
		],
		[
			4,
			4
		],
		[
			16,
			39
		],
		[
			-4,
			1
		],
		[
			-2,
			36
		],
		[
			3,
			14
		],
		[
			8,
			17
		],
		[
			6,
			3
		],
		[
			0,
			10
		],
		[
			7,
			12
		],
		[
			-1,
			-15
		],
		[
			5,
			-3
		],
		[
			0,
			-14
		],
		[
			12,
			-37
		],
		[
			-1,
			10
		],
		[
			3,
			13
		],
		[
			-2,
			11
		],
		[
			7,
			-10
		],
		[
			-3,
			24
		],
		[
			-6,
			5
		],
		[
			6,
			13
		],
		[
			-5,
			8
		],
		[
			5,
			2
		],
		[
			7,
			-7
		],
		[
			-1,
			9
		],
		[
			7,
			-9
		],
		[
			16,
			-1
		],
		[
			-10,
			3
		],
		[
			-1,
			9
		],
		[
			6,
			4
		],
		[
			1,
			18
		],
		[
			-4,
			-11
		],
		[
			-3,
			18
		],
		[
			1,
			9
		],
		[
			6,
			1
		],
		[
			3,
			9
		],
		[
			5,
			0
		],
		[
			4,
			-9
		],
		[
			1,
			10
		],
		[
			-6,
			3
		],
		[
			4,
			17
		],
		[
			11,
			-10
		],
		[
			0,
			9
		],
		[
			-8,
			16
		],
		[
			10,
			14
		],
		[
			3,
			-4
		],
		[
			7,
			6
		],
		[
			1,
			-11
		],
		[
			3,
			5
		],
		[
			4,
			26
		],
		[
			-5,
			5
		],
		[
			4,
			7
		],
		[
			3,
			-19
		],
		[
			9,
			16
		],
		[
			1,
			-16
		],
		[
			4,
			14
		],
		[
			4,
			0
		],
		[
			-3,
			11
		],
		[
			6,
			4
		],
		[
			4,
			-14
		],
		[
			9,
			1
		],
		[
			11,
			-28
		],
		[
			10,
			-16
		],
		[
			-3,
			-17
		],
		[
			0,
			-13
		],
		[
			4,
			-1
		],
		[
			-1,
			11
		],
		[
			5,
			14
		],
		[
			4,
			3
		],
		[
			12,
			-5
		],
		[
			9,
			-11
		],
		[
			-1,
			11
		],
		[
			7,
			-5
		],
		[
			3,
			-14
		],
		[
			4,
			1
		],
		[
			-3,
			18
		],
		[
			5,
			-1
		],
		[
			-6,
			15
		],
		[
			-7,
			11
		],
		[
			4,
			20
		],
		[
			7,
			4
		],
		[
			1,
			18
		],
		[
			4,
			9
		],
		[
			11,
			12
		],
		[
			-5,
			9
		],
		[
			0,
			14
		],
		[
			6,
			2
		],
		[
			0,
			12
		],
		[
			6,
			6
		],
		[
			2,
			11
		],
		[
			7,
			-14
		],
		[
			0,
			17
		],
		[
			4,
			-2
		],
		[
			-1,
			12
		],
		[
			9,
			5
		],
		[
			3,
			-13
		],
		[
			13,
			4
		],
		[
			4,
			-5
		],
		[
			9,
			5
		],
		[
			7,
			9
		],
		[
			2,
			24
		],
		[
			-7,
			12
		],
		[
			-9,
			-5
		],
		[
			-5,
			12
		],
		[
			-5,
			0
		],
		[
			7,
			11
		],
		[
			10,
			-1
		],
		[
			9,
			-21
		],
		[
			6,
			10
		],
		[
			7,
			-21
		],
		[
			14,
			-7
		],
		[
			4,
			6
		],
		[
			4,
			-11
		],
		[
			3,
			4
		],
		[
			4,
			-12
		],
		[
			6,
			-1
		],
		[
			8,
			7
		],
		[
			11,
			-18
		],
		[
			13,
			11
		],
		[
			6,
			2
		],
		[
			-4,
			-8
		],
		[
			2,
			-6
		],
		[
			5,
			7
		],
		[
			5,
			-5
		],
		[
			-2,
			-11
		],
		[
			7,
			-1
		],
		[
			3,
			14
		],
		[
			-5,
			3
		],
		[
			10,
			9
		],
		[
			4,
			-17
		],
		[
			3,
			7
		],
		[
			4,
			-11
		],
		[
			-12,
			-28
		],
		[
			4,
			-6
		],
		[
			-9,
			-21
		],
		[
			0,
			9
		],
		[
			-5,
			-6
		],
		[
			0,
			8
		],
		[
			-7,
			-9
		],
		[
			0,
			-26
		],
		[
			4,
			3
		],
		[
			-4,
			-29
		],
		[
			-3,
			-3
		],
		[
			-7,
			-24
		],
		[
			-4,
			-4
		],
		[
			2,
			-13
		],
		[
			22,
			-27
		],
		[
			0,
			-8
		],
		[
			10,
			-11
		],
		[
			4,
			-9
		],
		[
			7,
			1
		],
		[
			10,
			-14
		],
		[
			10,
			-7
		],
		[
			9,
			-21
		],
		[
			7,
			-8
		],
		[
			20,
			-9
		],
		[
			4,
			-7
		],
		[
			1,
			-15
		],
		[
			22,
			-24
		],
		[
			14,
			4
		],
		[
			10,
			13
		],
		[
			3,
			24
		],
		[
			7,
			18
		],
		[
			3,
			26
		],
		[
			3,
			9
		],
		[
			-2,
			9
		],
		[
			3,
			25
		],
		[
			5,
			20
		],
		[
			-4,
			40
		],
		[
			3,
			16
		],
		[
			-4,
			13
		],
		[
			1,
			21
		],
		[
			5,
			21
		],
		[
			-2,
			18
		],
		[
			6,
			14
		],
		[
			-2,
			11
		],
		[
			-5,
			-4
		],
		[
			6,
			28
		],
		[
			6,
			1
		],
		[
			-2,
			8
		],
		[
			6,
			41
		],
		[
			0,
			14
		],
		[
			5,
			2
		],
		[
			6,
			11
		]
	],
	[
		[
			5470,
			7982
		],
		[
			-2,
			-9
		],
		[
			5,
			-23
		],
		[
			3,
			-3
		]
	],
	[
		[
			5476,
			7947
		],
		[
			-3,
			-17
		],
		[
			-12,
			3
		],
		[
			-6,
			-6
		],
		[
			7,
			-3
		],
		[
			-5,
			-12
		],
		[
			-1,
			-22
		],
		[
			-9,
			-9
		]
	],
	[
		[
			5447,
			7881
		],
		[
			-19,
			-12
		],
		[
			-16,
			-2
		],
		[
			-9,
			-14
		],
		[
			-23,
			9
		]
	],
	[
		[
			5380,
			7862
		],
		[
			-32,
			7
		],
		[
			-12,
			17
		],
		[
			2,
			7
		],
		[
			-12,
			-5
		],
		[
			-17,
			-1
		],
		[
			-4,
			-11
		],
		[
			-15,
			6
		]
	],
	[
		[
			5290,
			7882
		],
		[
			-2,
			7
		],
		[
			-6,
			-8
		],
		[
			-16,
			12
		]
	],
	[
		[
			5266,
			7893
		],
		[
			-2,
			12
		]
	],
	[
		[
			5264,
			7905
		],
		[
			1,
			14
		]
	],
	[
		[
			5265,
			7919
		],
		[
			4,
			2
		]
	],
	[
		[
			5269,
			7921
		],
		[
			7,
			0
		],
		[
			8,
			-16
		],
		[
			6,
			15
		],
		[
			12,
			-1
		],
		[
			2,
			-7
		],
		[
			9,
			1
		],
		[
			9,
			10
		],
		[
			32,
			4
		],
		[
			6,
			-11
		],
		[
			3,
			9
		],
		[
			-5,
			5
		],
		[
			1,
			13
		],
		[
			-6,
			9
		],
		[
			4,
			7
		],
		[
			12,
			5
		],
		[
			4,
			16
		],
		[
			7,
			-3
		],
		[
			3,
			13
		]
	],
	[
		[
			5383,
			7990
		],
		[
			7,
			-9
		],
		[
			18,
			0
		],
		[
			7,
			11
		],
		[
			0,
			12
		],
		[
			11,
			-1
		],
		[
			20,
			-13
		],
		[
			10,
			3
		],
		[
			13,
			-6
		],
		[
			1,
			-5
		]
	],
	[
		[
			6281,
			7420
		],
		[
			-19,
			8
		],
		[
			-9,
			14
		],
		[
			-9,
			24
		]
	],
	[
		[
			6244,
			7466
		],
		[
			-1,
			3
		]
	],
	[
		[
			6289,
			7594
		],
		[
			9,
			-6
		],
		[
			11,
			-12
		],
		[
			5,
			-17
		],
		[
			16,
			-3
		],
		[
			5,
			15
		],
		[
			9,
			6
		],
		[
			5,
			16
		]
	],
	[
		[
			6349,
			7593
		],
		[
			15,
			-31
		],
		[
			1,
			-11
		],
		[
			10,
			-28
		],
		[
			15,
			-3
		],
		[
			8,
			-10
		],
		[
			-11,
			-3
		],
		[
			-13,
			-11
		],
		[
			0,
			-11
		],
		[
			-6,
			-28
		],
		[
			4,
			-11
		],
		[
			-5,
			0
		],
		[
			-1,
			-17
		],
		[
			-7,
			10
		],
		[
			-2,
			-43
		]
	],
	[
		[
			6357,
			7396
		],
		[
			-7,
			-2
		],
		[
			-6,
			12
		],
		[
			-11,
			12
		],
		[
			1,
			8
		],
		[
			7,
			2
		],
		[
			-5,
			18
		],
		[
			6,
			7
		],
		[
			-10,
			16
		],
		[
			-4,
			-1
		],
		[
			-26,
			-29
		],
		[
			-11,
			-17
		]
	],
	[
		[
			6249,
			7560
		],
		[
			8,
			10
		],
		[
			13,
			-8
		],
		[
			8,
			-9
		],
		[
			6,
			1
		],
		[
			6,
			-8
		],
		[
			4,
			3
		],
		[
			1,
			15
		],
		[
			-10,
			9
		],
		[
			-3,
			13
		],
		[
			7,
			8
		]
	],
	[
		[
			5848,
			5045
		],
		[
			-4,
			-15
		],
		[
			2,
			-14
		],
		[
			9,
			-5
		],
		[
			0,
			-17
		],
		[
			-9,
			-13
		],
		[
			-9,
			-34
		],
		[
			-11,
			-21
		],
		[
			-3,
			1
		]
	],
	[
		[
			5823,
			4927
		],
		[
			-9,
			39
		],
		[
			1,
			21
		],
		[
			-4,
			4
		]
	],
	[
		[
			5811,
			4991
		],
		[
			0,
			18
		],
		[
			-4,
			5
		],
		[
			-2,
			12
		]
	],
	[
		[
			5805,
			5026
		],
		[
			4,
			7
		],
		[
			5,
			-4
		],
		[
			0,
			-9
		],
		[
			11,
			1
		],
		[
			5,
			7
		],
		[
			1,
			21
		],
		[
			6,
			-6
		],
		[
			7,
			7
		],
		[
			4,
			-5
		]
	],
	[
		[
			5166,
			8104
		],
		[
			10,
			-14
		],
		[
			1,
			-10
		],
		[
			-8,
			-11
		]
	],
	[
		[
			5169,
			8069
		],
		[
			-7,
			-3
		],
		[
			-4,
			-16
		],
		[
			2,
			-14
		]
	],
	[
		[
			5160,
			8036
		],
		[
			-9,
			-3
		],
		[
			-4,
			10
		],
		[
			-13,
			7
		],
		[
			-1,
			21
		],
		[
			-9,
			-13
		],
		[
			-10,
			3
		],
		[
			2,
			15
		],
		[
			-5,
			5
		],
		[
			-10,
			0
		],
		[
			0,
			6
		],
		[
			-11,
			5
		],
		[
			-4,
			15
		],
		[
			-7,
			-6
		],
		[
			-7,
			8
		],
		[
			-2,
			15
		]
	],
	[
		[
			5070,
			8124
		],
		[
			16,
			14
		],
		[
			7,
			3
		]
	],
	[
		[
			5093,
			8141
		],
		[
			0,
			-6
		],
		[
			16,
			-3
		],
		[
			8,
			9
		]
	],
	[
		[
			5117,
			8141
		],
		[
			1,
			0
		]
	],
	[
		[
			5118,
			8141
		],
		[
			3,
			3
		],
		[
			16,
			-1
		],
		[
			7,
			-8
		],
		[
			9,
			0
		],
		[
			9,
			-11
		],
		[
			-6,
			-13
		],
		[
			10,
			-7
		]
	],
	[
		[
			5099,
			5856
		],
		[
			-3,
			-17
		],
		[
			7,
			-16
		],
		[
			0,
			-19
		],
		[
			3,
			-5
		],
		[
			-1,
			-16
		],
		[
			-5,
			0
		],
		[
			1,
			-14
		],
		[
			-3,
			-18
		],
		[
			-6,
			-3
		],
		[
			0,
			-9
		],
		[
			-5,
			-12
		],
		[
			-2,
			-20
		],
		[
			-8,
			-4
		],
		[
			-2,
			-15
		],
		[
			0,
			-41
		],
		[
			-1,
			-12
		],
		[
			2,
			-25
		],
		[
			1,
			-42
		],
		[
			-2,
			-18
		]
	],
	[
		[
			5075,
			5550
		],
		[
			-31,
			-9
		]
	],
	[
		[
			5044,
			5541
		],
		[
			5,
			3
		],
		[
			-5,
			18
		],
		[
			1,
			24
		],
		[
			0,
			73
		],
		[
			-1,
			5
		],
		[
			0,
			43
		],
		[
			-6,
			13
		],
		[
			-1,
			37
		],
		[
			-16,
			23
		],
		[
			0,
			19
		],
		[
			4,
			17
		]
	],
	[
		[
			5025,
			5816
		],
		[
			5,
			3
		],
		[
			1,
			13
		],
		[
			4,
			-1
		],
		[
			3,
			11
		],
		[
			6,
			-3
		],
		[
			11,
			2
		],
		[
			8,
			13
		],
		[
			3,
			14
		]
	],
	[
		[
			5066,
			5868
		],
		[
			-1,
			19
		],
		[
			14,
			10
		],
		[
			10,
			-21
		],
		[
			2,
			-8
		],
		[
			6,
			-4
		],
		[
			2,
			-8
		]
	],
	[
		[
			5006,
			6041
		],
		[
			-2,
			-21
		],
		[
			6,
			-16
		],
		[
			-1,
			-9
		],
		[
			7,
			-24
		],
		[
			5,
			0
		],
		[
			7,
			-13
		],
		[
			7,
			-7
		],
		[
			-9,
			-1
		],
		[
			0,
			-15
		],
		[
			6,
			-6
		],
		[
			11,
			-19
		],
		[
			8,
			-1
		],
		[
			3,
			7
		],
		[
			5,
			-3
		],
		[
			3,
			-15
		],
		[
			-6,
			-4
		],
		[
			10,
			-26
		]
	],
	[
		[
			5025,
			5816
		],
		[
			-12,
			0
		],
		[
			-18,
			8
		]
	],
	[
		[
			4995,
			5824
		],
		[
			-8,
			-3
		],
		[
			-5,
			-10
		],
		[
			-2,
			5
		],
		[
			-59,
			0
		],
		[
			-3,
			-22
		],
		[
			3,
			-11
		],
		[
			2,
			-25
		],
		[
			0,
			-24
		],
		[
			2,
			-5
		]
	],
	[
		[
			4925,
			5729
		],
		[
			-4,
			-4
		],
		[
			-10,
			24
		],
		[
			-6,
			5
		],
		[
			-10,
			1
		],
		[
			-11,
			-7
		],
		[
			-4,
			-11
		],
		[
			-11,
			3
		],
		[
			-4,
			12
		],
		[
			-3,
			-1
		],
		[
			-4,
			24
		],
		[
			-9,
			1
		],
		[
			-3,
			7
		]
	],
	[
		[
			4846,
			5783
		],
		[
			3,
			24
		],
		[
			-2,
			14
		],
		[
			6,
			9
		],
		[
			1,
			19
		],
		[
			-4,
			14
		],
		[
			8,
			10
		],
		[
			9,
			1
		],
		[
			10,
			18
		],
		[
			-1,
			24
		],
		[
			6,
			0
		],
		[
			0,
			14
		],
		[
			-3,
			11
		],
		[
			10,
			13
		],
		[
			15,
			-13
		],
		[
			5,
			7
		],
		[
			0,
			25
		],
		[
			6,
			-5
		],
		[
			5,
			21
		],
		[
			11,
			16
		],
		[
			12,
			-6
		],
		[
			1,
			16
		],
		[
			8,
			3
		],
		[
			11,
			13
		],
		[
			8,
			5
		],
		[
			8,
			15
		],
		[
			8,
			-4
		],
		[
			8,
			2
		],
		[
			11,
			-8
		]
	],
	[
		[
			7529,
			6456
		],
		[
			0,
			16
		],
		[
			3,
			-11
		],
		[
			-3,
			-5
		]
	],
	[
		[
			7521,
			6458
		],
		[
			-5,
			-7
		],
		[
			2,
			29
		],
		[
			-4,
			4
		],
		[
			3,
			11
		],
		[
			6,
			-20
		],
		[
			-2,
			-17
		]
	],
	[
		[
			7571,
			6448
		],
		[
			0,
			-29
		],
		[
			2,
			-10
		],
		[
			-12,
			7
		],
		[
			1,
			-20
		]
	],
	[
		[
			7562,
			6396
		],
		[
			1,
			-15
		],
		[
			-7,
			20
		],
		[
			-1,
			27
		],
		[
			-3,
			9
		],
		[
			-2,
			29
		],
		[
			-11,
			31
		],
		[
			-5,
			-14
		],
		[
			-9,
			0
		],
		[
			-8,
			26
		],
		[
			1,
			14
		],
		[
			-4,
			6
		],
		[
			-9,
			4
		],
		[
			11,
			-11
		],
		[
			-4,
			-10
		],
		[
			2,
			-12
		],
		[
			-3,
			-8
		],
		[
			5,
			-13
		],
		[
			-2,
			-18
		],
		[
			-6,
			-9
		],
		[
			-1,
			-11
		],
		[
			-7,
			1
		],
		[
			1,
			7
		],
		[
			-5,
			6
		],
		[
			-2,
			-15
		],
		[
			-12,
			-7
		],
		[
			0,
			14
		],
		[
			-4,
			-18
		],
		[
			-4,
			10
		],
		[
			-1,
			18
		]
	],
	[
		[
			7473,
			6457
		],
		[
			-6,
			48
		],
		[
			2,
			14
		],
		[
			-7,
			2
		],
		[
			3,
			13
		],
		[
			-6,
			8
		],
		[
			0,
			11
		],
		[
			5,
			8
		],
		[
			0,
			22
		],
		[
			-7,
			0
		],
		[
			-11,
			12
		],
		[
			-2,
			7
		],
		[
			4,
			12
		],
		[
			5,
			1
		],
		[
			3,
			18
		],
		[
			13,
			-1
		],
		[
			-3,
			18
		],
		[
			-8,
			1
		],
		[
			-3,
			11
		],
		[
			-9,
			14
		],
		[
			2,
			12
		],
		[
			5,
			4
		],
		[
			4,
			14
		],
		[
			5,
			-9
		],
		[
			11,
			-3
		],
		[
			7,
			-14
		],
		[
			7,
			-2
		],
		[
			2,
			15
		],
		[
			6,
			-18
		],
		[
			-2,
			-4
		],
		[
			1,
			-32
		],
		[
			15,
			-8
		],
		[
			23,
			2
		],
		[
			7,
			-3
		],
		[
			18,
			3
		],
		[
			11,
			-14
		],
		[
			-6,
			-2
		],
		[
			-5,
			-31
		],
		[
			-5,
			-2
		],
		[
			0,
			-9
		],
		[
			-8,
			2
		],
		[
			0,
			-6
		],
		[
			-7,
			0
		],
		[
			-7,
			-21
		],
		[
			2,
			-14
		],
		[
			9,
			-30
		],
		[
			7,
			5
		],
		[
			0,
			15
		],
		[
			5,
			8
		],
		[
			-1,
			11
		],
		[
			5,
			4
		],
		[
			8,
			-22
		],
		[
			0,
			-25
		],
		[
			3,
			-12
		],
		[
			3,
			-42
		]
	],
	[
		[
			5793,
			7702
		],
		[
			0,
			-17
		],
		[
			-11,
			-3
		],
		[
			-6,
			-14
		],
		[
			-2,
			-26
		],
		[
			-4,
			1
		],
		[
			-8,
			-16
		],
		[
			5,
			1
		],
		[
			11,
			-28
		]
	],
	[
		[
			5778,
			7600
		],
		[
			-13,
			-4
		],
		[
			-6,
			9
		],
		[
			-21,
			-5
		],
		[
			-7,
			-15
		]
	],
	[
		[
			5731,
			7585
		],
		[
			-8,
			0
		],
		[
			2,
			-21
		],
		[
			-25,
			-7
		],
		[
			-9,
			10
		],
		[
			-8,
			1
		],
		[
			-2,
			6
		],
		[
			-14,
			0
		],
		[
			-8,
			-7
		],
		[
			-13,
			0
		],
		[
			-10,
			-4
		]
	],
	[
		[
			5636,
			7563
		],
		[
			3,
			22
		],
		[
			-5,
			18
		],
		[
			-9,
			5
		],
		[
			-5,
			11
		]
	],
	[
		[
			5620,
			7619
		],
		[
			5,
			6
		],
		[
			-3,
			23
		],
		[
			9,
			5
		],
		[
			7,
			17
		],
		[
			-13,
			15
		],
		[
			-4,
			15
		],
		[
			1,
			17
		],
		[
			8,
			13
		]
	],
	[
		[
			5630,
			7730
		],
		[
			9,
			-8
		],
		[
			-4,
			-15
		],
		[
			17,
			3
		],
		[
			18,
			-8
		],
		[
			10,
			3
		],
		[
			21,
			-5
		],
		[
			4,
			-4
		],
		[
			11,
			5
		],
		[
			9,
			16
		],
		[
			25,
			10
		],
		[
			10,
			-10
		],
		[
			15,
			-2
		],
		[
			8,
			-13
		],
		[
			10,
			0
		]
	],
	[
		[
			6402,
			6694
		],
		[
			3,
			0
		],
		[
			0,
			-24
		],
		[
			-4,
			8
		],
		[
			1,
			16
		]
	],
	[
		[
			2971,
			6401
		],
		[
			-3,
			-10
		],
		[
			-15,
			-3
		],
		[
			-1,
			6
		],
		[
			9,
			10
		],
		[
			4,
			-4
		],
		[
			6,
			12
		],
		[
			0,
			-11
		]
	],
	[
		[
			2969,
			6475
		],
		[
			8,
			-3
		],
		[
			-7,
			-3
		],
		[
			-1,
			6
		]
	],
	[
		[
			2948,
			6491
		],
		[
			0,
			-14
		],
		[
			-5,
			9
		],
		[
			5,
			5
		]
	],
	[
		[
			2889,
			6546
		],
		[
			9,
			-13
		],
		[
			-10,
			9
		],
		[
			1,
			4
		]
	],
	[
		[
			2908,
			6546
		],
		[
			6,
			-21
		],
		[
			0,
			-8
		],
		[
			7,
			-10
		],
		[
			0,
			-8
		],
		[
			-7,
			15
		],
		[
			-1,
			14
		],
		[
			-5,
			18
		]
	],
	[
		[
			2840,
			6572
		],
		[
			6,
			0
		],
		[
			0,
			-20
		],
		[
			-8,
			5
		],
		[
			-3,
			13
		],
		[
			5,
			2
		]
	],
	[
		[
			2908,
			6577
		],
		[
			-3,
			0
		],
		[
			-4,
			16
		],
		[
			7,
			-16
		]
	],
	[
		[
			2830,
			6632
		],
		[
			3,
			0
		],
		[
			8,
			-40
		],
		[
			-8,
			-11
		],
		[
			-10,
			14
		],
		[
			7,
			37
		]
	],
	[
		[
			2869,
			6655
		],
		[
			0,
			-4
		],
		[
			16,
			-20
		],
		[
			-1,
			-29
		],
		[
			-2,
			7
		],
		[
			3,
			17
		],
		[
			-6,
			14
		],
		[
			-11,
			8
		],
		[
			1,
			7
		]
	],
	[
		[
			2819,
			6722
		],
		[
			15,
			-4
		],
		[
			-21,
			-5
		],
		[
			6,
			9
		]
	],
	[
		[
			2839,
			6733
		],
		[
			5,
			0
		],
		[
			16,
			-25
		],
		[
			0,
			-11
		],
		[
			-4,
			-3
		],
		[
			0,
			-19
		],
		[
			-6,
			5
		],
		[
			4,
			8
		],
		[
			0,
			18
		],
		[
			-8,
			23
		],
		[
			-7,
			4
		]
	],
	[
		[
			5528,
			7765
		],
		[
			9,
			0
		],
		[
			-7,
			-29
		],
		[
			14,
			-17
		],
		[
			-10,
			-5
		],
		[
			7,
			-13
		],
		[
			-1,
			-8
		],
		[
			-7,
			-3
		]
	],
	[
		[
			5533,
			7690
		],
		[
			-8,
			-3
		],
		[
			0,
			-8
		],
		[
			-7,
			-6
		],
		[
			-1,
			-13
		],
		[
			-4,
			0
		],
		[
			-1,
			-26
		]
	],
	[
		[
			5512,
			7634
		],
		[
			-22,
			19
		]
	],
	[
		[
			5490,
			7653
		],
		[
			-2,
			3
		]
	],
	[
		[
			5488,
			7656
		],
		[
			0,
			8
		],
		[
			-35,
			57
		],
		[
			-8,
			32
		],
		[
			-7,
			3
		],
		[
			0,
			29
		],
		[
			6,
			2
		],
		[
			10,
			-12
		],
		[
			3,
			10
		],
		[
			9,
			-1
		],
		[
			4,
			7
		],
		[
			4,
			-7
		],
		[
			22,
			-6
		],
		[
			4,
			4
		],
		[
			19,
			-3
		],
		[
			2,
			-11
		],
		[
			7,
			-3
		]
	],
	[
		[
			5781,
			8416
		],
		[
			4,
			-6
		],
		[
			9,
			3
		],
		[
			3,
			-8
		],
		[
			9,
			4
		],
		[
			11,
			-6
		],
		[
			1,
			-13
		],
		[
			12,
			9
		],
		[
			16,
			-3
		],
		[
			11,
			-11
		],
		[
			-2,
			-19
		],
		[
			6,
			-15
		],
		[
			-7,
			-13
		],
		[
			11,
			-10
		],
		[
			-3,
			-7
		],
		[
			7,
			-14
		],
		[
			15,
			-15
		],
		[
			-3,
			-11
		],
		[
			10,
			1
		],
		[
			11,
			-9
		],
		[
			6,
			-11
		],
		[
			-15,
			-22
		],
		[
			-22,
			5
		],
		[
			-4,
			-9
		],
		[
			8,
			-10
		],
		[
			2,
			-30
		],
		[
			5,
			-13
		]
	],
	[
		[
			5882,
			8183
		],
		[
			-23,
			-2
		],
		[
			-12,
			-29
		],
		[
			3,
			-14
		],
		[
			-7,
			-1
		],
		[
			-6,
			11
		],
		[
			-15,
			-1
		],
		[
			-9,
			-6
		],
		[
			-5,
			14
		],
		[
			-13,
			-11
		],
		[
			-11,
			13
		],
		[
			-16,
			-10
		],
		[
			1,
			7
		],
		[
			-13,
			0
		],
		[
			-1,
			7
		],
		[
			-21,
			5
		],
		[
			-10,
			6
		],
		[
			-28,
			2
		],
		[
			-19,
			-4
		],
		[
			-11,
			-18
		],
		[
			-11,
			3
		],
		[
			0,
			-5
		]
	],
	[
		[
			5655,
			8150
		],
		[
			0,
			34
		],
		[
			-12,
			10
		],
		[
			6,
			13
		],
		[
			15,
			11
		],
		[
			0,
			18
		],
		[
			-7,
			25
		],
		[
			-5,
			28
		]
	],
	[
		[
			5652,
			8289
		],
		[
			20,
			1
		],
		[
			5,
			-4
		],
		[
			12,
			5
		],
		[
			-1,
			7
		],
		[
			19,
			11
		],
		[
			1,
			-8
		],
		[
			8,
			6
		],
		[
			-7,
			3
		],
		[
			9,
			37
		],
		[
			8,
			1
		],
		[
			3,
			10
		],
		[
			9,
			-1
		],
		[
			6,
			10
		],
		[
			-8,
			1
		],
		[
			2,
			20
		]
	],
	[
		[
			5738,
			8388
		],
		[
			11,
			10
		],
		[
			17,
			-2
		],
		[
			8,
			17
		],
		[
			7,
			3
		]
	],
	[
		[
			2547,
			6247
		],
		[
			-3,
			-6
		],
		[
			9,
			0
		],
		[
			-1,
			-18
		],
		[
			-5,
			-28
		],
		[
			4,
			-4
		],
		[
			-4,
			-10
		],
		[
			2,
			-16
		],
		[
			-2,
			-24
		],
		[
			-7,
			-21
		],
		[
			-5,
			-2
		],
		[
			-5,
			-20
		]
	],
	[
		[
			2530,
			6098
		],
		[
			-9,
			0
		],
		[
			2,
			51
		],
		[
			0,
			60
		]
	],
	[
		[
			2523,
			6209
		],
		[
			4,
			10
		],
		[
			4,
			-6
		],
		[
			9,
			26
		],
		[
			0,
			6
		],
		[
			7,
			2
		]
	],
	[
		[
			3084,
			4249
		],
		[
			-4,
			-1
		]
	],
	[
		[
			3080,
			4248
		],
		[
			4,
			1
		]
	],
	[
		[
			3384,
			4022
		],
		[
			-1,
			21
		],
		[
			-24,
			29
		],
		[
			-24,
			0
		],
		[
			-51,
			-22
		],
		[
			-4,
			-23
		],
		[
			-10,
			-28
		],
		[
			0,
			-29
		],
		[
			-8,
			-54
		],
		[
			-3,
			-14
		]
	],
	[
		[
			3133,
			3869
		],
		[
			-10,
			-5
		],
		[
			-9,
			4
		],
		[
			1,
			16
		],
		[
			-3,
			11
		],
		[
			0,
			16
		],
		[
			-4,
			7
		],
		[
			-3,
			23
		],
		[
			0,
			15
		],
		[
			-6,
			20
		],
		[
			-4,
			2
		],
		[
			2,
			18
		],
		[
			-6,
			6
		],
		[
			1,
			10
		],
		[
			-3,
			14
		],
		[
			6,
			2
		],
		[
			1,
			8
		],
		[
			-5,
			11
		],
		[
			7,
			16
		],
		[
			-13,
			23
		],
		[
			-3,
			34
		],
		[
			-3,
			18
		],
		[
			2,
			6
		],
		[
			-7,
			5
		],
		[
			0,
			8
		],
		[
			-5,
			18
		]
	],
	[
		[
			3069,
			4175
		],
		[
			-4,
			17
		],
		[
			7,
			8
		],
		[
			10,
			30
		]
	],
	[
		[
			3082,
			4230
		],
		[
			5,
			-3
		],
		[
			-1,
			11
		],
		[
			8,
			5
		],
		[
			0,
			6
		],
		[
			-7,
			0
		],
		[
			-1,
			9
		],
		[
			4,
			4
		],
		[
			-7,
			3
		],
		[
			0,
			7
		],
		[
			-10,
			17
		]
	],
	[
		[
			3073,
			4289
		],
		[
			6,
			16
		],
		[
			-7,
			15
		],
		[
			6,
			28
		],
		[
			5,
			6
		],
		[
			3,
			20
		],
		[
			-6,
			22
		],
		[
			4,
			8
		],
		[
			-1,
			36
		],
		[
			7,
			11
		],
		[
			2,
			12
		],
		[
			-16,
			55
		],
		[
			-9,
			34
		]
	],
	[
		[
			3067,
			4552
		],
		[
			23,
			-3
		],
		[
			-1,
			-8
		],
		[
			10,
			6
		],
		[
			9,
			20
		],
		[
			11,
			3
		],
		[
			11,
			19
		],
		[
			7,
			3
		],
		[
			11,
			20
		],
		[
			19,
			8
		],
		[
			7,
			1
		],
		[
			4,
			-5
		],
		[
			5,
			9
		],
		[
			3,
			-32
		],
		[
			-4,
			-13
		],
		[
			3,
			-21
		],
		[
			-2,
			-18
		],
		[
			2,
			-19
		],
		[
			3,
			-2
		],
		[
			1,
			-14
		],
		[
			4,
			-2
		],
		[
			1,
			-12
		],
		[
			5,
			-1
		],
		[
			4,
			-10
		],
		[
			6,
			-4
		],
		[
			1,
			-11
		],
		[
			13,
			-4
		],
		[
			4,
			4
		],
		[
			10,
			-7
		],
		[
			4,
			-8
		],
		[
			5,
			4
		],
		[
			9,
			-20
		],
		[
			4,
			1
		],
		[
			8,
			-10
		],
		[
			7,
			0
		],
		[
			0,
			-6
		],
		[
			8,
			-17
		],
		[
			22,
			4
		],
		[
			18,
			-27
		],
		[
			-2,
			-20
		],
		[
			5,
			-18
		],
		[
			1,
			-28
		],
		[
			-9,
			-1
		],
		[
			9,
			-20
		],
		[
			3,
			-47
		],
		[
			47,
			-4
		],
		[
			3,
			3
		],
		[
			0,
			-13
		],
		[
			-4,
			-8
		],
		[
			2,
			-34
		],
		[
			11,
			-15
		],
		[
			6,
			-1
		],
		[
			0,
			-8
		],
		[
			6,
			-27
		],
		[
			0,
			-10
		],
		[
			-6,
			-46
		],
		[
			-9,
			-38
		],
		[
			7,
			-13
		],
		[
			-8,
			-10
		]
	],
	[
		[
			3651,
			3581
		],
		[
			1,
			22
		],
		[
			3,
			0
		],
		[
			-4,
			-22
		]
	],
	[
		[
			3650,
			3661
		],
		[
			-4,
			8
		],
		[
			6,
			7
		],
		[
			-2,
			-15
		]
	],
	[
		[
			3919,
			4412
		],
		[
			0,
			-16
		],
		[
			-4,
			16
		],
		[
			4,
			0
		]
	],
	[
		[
			3660,
			5124
		],
		[
			-3,
			3
		],
		[
			4,
			9
		],
		[
			-1,
			-12
		]
	],
	[
		[
			3588,
			5149
		],
		[
			0,
			-7
		],
		[
			-8,
			-7
		],
		[
			1,
			9
		],
		[
			7,
			5
		]
	],
	[
		[
			3577,
			5151
		],
		[
			2,
			-5
		],
		[
			-4,
			-19
		],
		[
			-3,
			-11
		],
		[
			-15,
			-19
		],
		[
			0,
			13
		],
		[
			7,
			10
		],
		[
			0,
			14
		],
		[
			2,
			11
		],
		[
			8,
			8
		],
		[
			3,
			-2
		]
	],
	[
		[
			3573,
			5156
		],
		[
			5,
			19
		],
		[
			0,
			-10
		],
		[
			-5,
			-9
		]
	],
	[
		[
			3608,
			5175
		],
		[
			11,
			-6
		],
		[
			9,
			5
		],
		[
			27,
			-7
		],
		[
			-2,
			-14
		],
		[
			-1,
			-20
		],
		[
			-4,
			-14
		],
		[
			-5,
			-5
		],
		[
			0,
			-14
		],
		[
			-7,
			-5
		],
		[
			-3,
			7
		],
		[
			0,
			-11
		],
		[
			-9,
			1
		],
		[
			-6,
			-12
		],
		[
			-14,
			3
		],
		[
			-4,
			-6
		],
		[
			-5,
			2
		],
		[
			-7,
			28
		],
		[
			1,
			13
		],
		[
			6,
			-5
		],
		[
			1,
			8
		],
		[
			-7,
			-1
		],
		[
			0,
			23
		],
		[
			2,
			17
		],
		[
			4,
			10
		],
		[
			5,
			5
		],
		[
			8,
			-2
		]
	],
	[
		[
			3586,
			5165
		],
		[
			-4,
			4
		],
		[
			1,
			13
		],
		[
			7,
			3
		],
		[
			2,
			-9
		],
		[
			-6,
			-11
		]
	],
	[
		[
			3625,
			5187
		],
		[
			3,
			-5
		],
		[
			-2,
			-7
		],
		[
			-11,
			2
		],
		[
			10,
			10
		]
	],
	[
		[
			3599,
			5183
		],
		[
			-5,
			0
		],
		[
			-2,
			9
		],
		[
			6,
			-1
		],
		[
			1,
			-8
		]
	],
	[
		[
			3624,
			5200
		],
		[
			-6,
			-5
		],
		[
			-3,
			-12
		],
		[
			-14,
			0
		],
		[
			-1,
			12
		],
		[
			8,
			1
		],
		[
			15,
			9
		],
		[
			1,
			-5
		]
	],
	[
		[
			3600,
			5213
		],
		[
			1,
			-14
		],
		[
			-2,
			-7
		],
		[
			0,
			23
		],
		[
			1,
			-2
		]
	],
	[
		[
			3609,
			5216
		],
		[
			-6,
			-13
		],
		[
			1,
			14
		],
		[
			5,
			-1
		]
	],
	[
		[
			3608,
			5236
		],
		[
			0,
			-10
		],
		[
			-5,
			0
		],
		[
			5,
			10
		]
	],
	[
		[
			3600,
			5305
		],
		[
			1,
			-11
		],
		[
			-5,
			4
		],
		[
			4,
			7
		]
	],
	[
		[
			3431,
			5295
		],
		[
			13,
			-7
		],
		[
			2,
			14
		],
		[
			-6,
			10
		],
		[
			5,
			17
		],
		[
			6,
			-8
		],
		[
			11,
			2
		],
		[
			0,
			4
		],
		[
			10,
			2
		],
		[
			8,
			-5
		],
		[
			3,
			-7
		]
	],
	[
		[
			3483,
			5317
		],
		[
			3,
			-7
		],
		[
			8,
			-3
		],
		[
			7,
			3
		],
		[
			6,
			9
		],
		[
			5,
			-7
		],
		[
			6,
			5
		],
		[
			9,
			-9
		],
		[
			9,
			11
		],
		[
			8,
			31
		],
		[
			1,
			14
		],
		[
			4,
			7
		],
		[
			15,
			44
		]
	],
	[
		[
			3564,
			5415
		],
		[
			5,
			24
		],
		[
			8,
			-16
		],
		[
			1,
			-21
		],
		[
			3,
			4
		],
		[
			-1,
			-29
		],
		[
			3,
			-31
		],
		[
			7,
			-22
		],
		[
			1,
			-18
		],
		[
			6,
			-18
		],
		[
			13,
			-4
		],
		[
			4,
			-8
		],
		[
			0,
			-19
		],
		[
			-7,
			-4
		],
		[
			7,
			-3
		],
		[
			-11,
			-17
		],
		[
			-5,
			-12
		],
		[
			-4,
			-17
		],
		[
			-5,
			-11
		],
		[
			-5,
			-1
		],
		[
			-9,
			-17
		],
		[
			-4,
			-19
		],
		[
			-8,
			-19
		],
		[
			0,
			-14
		],
		[
			-7,
			-8
		],
		[
			-1,
			-13
		],
		[
			-6,
			4
		],
		[
			-14,
			-13
		],
		[
			13,
			2
		],
		[
			0,
			-10
		],
		[
			9,
			7
		],
		[
			7,
			10
		],
		[
			11,
			11
		],
		[
			13,
			17
		],
		[
			-5,
			-12
		],
		[
			5,
			-5
		],
		[
			0,
			-14
		],
		[
			4,
			-9
		],
		[
			0,
			-11
		],
		[
			7,
			-14
		],
		[
			4,
			9
		],
		[
			6,
			4
		],
		[
			5,
			-7
		],
		[
			12,
			10
		],
		[
			1,
			-7
		],
		[
			-5,
			-41
		],
		[
			2,
			-2
		],
		[
			8,
			40
		],
		[
			7,
			18
		],
		[
			2,
			-8
		],
		[
			8,
			21
		],
		[
			3,
			-12
		],
		[
			1,
			19
		],
		[
			4,
			-2
		],
		[
			4,
			16
		],
		[
			1,
			15
		],
		[
			5,
			0
		],
		[
			5,
			12
		],
		[
			2,
			-11
		],
		[
			4,
			10
		],
		[
			11,
			-7
		],
		[
			19,
			-9
		],
		[
			0,
			-10
		],
		[
			7,
			-6
		],
		[
			8,
			5
		],
		[
			1,
			-7
		],
		[
			10,
			-9
		],
		[
			1,
			-8
		],
		[
			6,
			9
		],
		[
			-2,
			-11
		],
		[
			1,
			-13
		],
		[
			3,
			11
		],
		[
			5,
			4
		],
		[
			10,
			-14
		],
		[
			-3,
			-5
		],
		[
			6,
			-1
		],
		[
			3,
			-8
		],
		[
			-5,
			-16
		],
		[
			5,
			5
		],
		[
			3,
			-14
		],
		[
			-4,
			0
		],
		[
			-5,
			-36
		],
		[
			2,
			-9
		],
		[
			6,
			14
		],
		[
			1,
			23
		],
		[
			8,
			8
		],
		[
			1,
			-9
		],
		[
			-7,
			-12
		],
		[
			7,
			-2
		],
		[
			2,
			14
		],
		[
			9,
			4
		],
		[
			6,
			-4
		],
		[
			-1,
			12
		],
		[
			4,
			0
		],
		[
			18,
			-13
		],
		[
			6,
			-11
		],
		[
			15,
			-5
		],
		[
			3,
			6
		],
		[
			5,
			-9
		],
		[
			29,
			4
		],
		[
			3,
			2
		],
		[
			14,
			-3
		],
		[
			25,
			-31
		],
		[
			3,
			-1
		],
		[
			8,
			-15
		],
		[
			5,
			-2
		],
		[
			11,
			-27
		],
		[
			14,
			-26
		],
		[
			9,
			-6
		],
		[
			4,
			-12
		],
		[
			6,
			-1
		],
		[
			6,
			-8
		],
		[
			16,
			-1
		],
		[
			5,
			3
		],
		[
			13,
			-6
		],
		[
			4,
			-13
		],
		[
			9,
			-57
		],
		[
			1,
			-24
		],
		[
			5,
			-21
		],
		[
			-1,
			-53
		],
		[
			-7,
			-40
		],
		[
			-7,
			-25
		],
		[
			-10,
			-27
		],
		[
			-3,
			5
		],
		[
			-2,
			-16
		],
		[
			-12,
			-24
		],
		[
			-3,
			-13
		],
		[
			-10,
			-10
		],
		[
			-5,
			-9
		],
		[
			-11,
			-37
		],
		[
			-15,
			-52
		],
		[
			-13,
			-34
		],
		[
			-5,
			0
		],
		[
			0,
			14
		],
		[
			-4,
			9
		],
		[
			-4,
			-16
		],
		[
			0,
			-17
		],
		[
			-4,
			-7
		],
		[
			0,
			-27
		],
		[
			-2,
			-5
		],
		[
			2,
			-28
		],
		[
			-3,
			-20
		],
		[
			2,
			-9
		],
		[
			0,
			-24
		],
		[
			2,
			-28
		],
		[
			2,
			-6
		],
		[
			-4,
			-25
		],
		[
			-6,
			-53
		],
		[
			1,
			-31
		],
		[
			-2,
			-9
		],
		[
			-7,
			-8
		],
		[
			-7,
			-30
		],
		[
			2,
			-51
		],
		[
			-3,
			-13
		],
		[
			-6,
			-6
		],
		[
			-9,
			-44
		],
		[
			-13,
			-31
		],
		[
			-8,
			-25
		],
		[
			4,
			-27
		],
		[
			-5,
			-10
		],
		[
			-12,
			-7
		],
		[
			-13,
			-20
		],
		[
			0,
			-21
		],
		[
			-17,
			1
		],
		[
			-11,
			-3
		],
		[
			0,
			18
		],
		[
			-7,
			-5
		],
		[
			2,
			-13
		],
		[
			-22,
			-7
		],
		[
			10,
			7
		],
		[
			-9,
			3
		],
		[
			-8,
			-7
		],
		[
			-2,
			7
		],
		[
			-9,
			-7
		],
		[
			1,
			-17
		],
		[
			-10,
			-3
		],
		[
			-2,
			-6
		],
		[
			-10,
			-7
		],
		[
			-1,
			-11
		],
		[
			-12,
			4
		],
		[
			-8,
			-7
		],
		[
			-1,
			-7
		],
		[
			-11,
			-6
		],
		[
			-11,
			-13
		],
		[
			-5,
			-12
		],
		[
			-10,
			-9
		],
		[
			-10,
			-15
		],
		[
			-1,
			-15
		],
		[
			-8,
			-7
		],
		[
			-6,
			4
		],
		[
			1,
			-17
		],
		[
			-4,
			-17
		],
		[
			-1,
			-19
		],
		[
			-5,
			-6
		],
		[
			4,
			-6
		],
		[
			-3,
			-16
		],
		[
			3,
			-6
		],
		[
			2,
			-32
		],
		[
			-2,
			-52
		],
		[
			-4,
			-17
		],
		[
			-17,
			-23
		],
		[
			-5,
			-12
		],
		[
			-14,
			-39
		],
		[
			-8,
			-37
		],
		[
			-10,
			-34
		],
		[
			-12,
			-25
		],
		[
			-22,
			-27
		],
		[
			-3,
			-9
		],
		[
			0,
			17
		],
		[
			5,
			-4
		],
		[
			11,
			20
		],
		[
			5,
			3
		],
		[
			4,
			11
		],
		[
			-1,
			12
		],
		[
			5,
			1
		],
		[
			0,
			10
		],
		[
			9,
			9
		],
		[
			-1,
			22
		],
		[
			4,
			-6
		],
		[
			1,
			12
		],
		[
			-12,
			-4
		],
		[
			-9,
			8
		],
		[
			3,
			-7
		],
		[
			-6,
			-21
		],
		[
			-1,
			-24
		],
		[
			-6,
			-10
		],
		[
			-9,
			-4
		],
		[
			-3,
			-21
		],
		[
			-4,
			-3
		],
		[
			-1,
			-14
		],
		[
			5,
			-10
		],
		[
			-5,
			-7
		],
		[
			-6,
			-30
		],
		[
			-7,
			-26
		],
		[
			-18,
			-28
		]
	],
	[
		[
			3517,
			3240
		],
		[
			-4,
			10
		]
	],
	[
		[
			3513,
			3250
		],
		[
			2,
			1
		],
		[
			1,
			23
		],
		[
			5,
			4
		],
		[
			2,
			13
		],
		[
			5,
			6
		],
		[
			5,
			-10
		],
		[
			6,
			18
		],
		[
			-4,
			16
		],
		[
			-12,
			-19
		]
	],
	[
		[
			3523,
			3302
		],
		[
			-11,
			11
		],
		[
			-5,
			23
		],
		[
			-15,
			14
		],
		[
			-9,
			21
		],
		[
			-8,
			3
		],
		[
			-4,
			8
		],
		[
			-7,
			3
		],
		[
			-2,
			10
		],
		[
			-8,
			11
		],
		[
			-6,
			-13
		],
		[
			-4,
			0
		],
		[
			0,
			16
		],
		[
			-23,
			40
		],
		[
			-7,
			0
		],
		[
			-2,
			-8
		],
		[
			-11,
			-2
		],
		[
			-2,
			6
		]
	],
	[
		[
			3483,
			3710
		],
		[
			0,
			8
		]
	],
	[
		[
			3483,
			3718
		],
		[
			5,
			3
		],
		[
			0,
			26
		],
		[
			4,
			16
		],
		[
			0,
			34
		]
	],
	[
		[
			3492,
			3797
		],
		[
			-9,
			15
		],
		[
			-10,
			-10
		],
		[
			-13,
			1
		],
		[
			-3,
			21
		],
		[
			1,
			11
		],
		[
			-4,
			23
		],
		[
			1,
			21
		],
		[
			-7,
			19
		],
		[
			-9,
			1
		],
		[
			-6,
			12
		],
		[
			-12,
			-10
		],
		[
			-31,
			8
		],
		[
			0,
			36
		],
		[
			3,
			16
		],
		[
			-9,
			61
		]
	],
	[
		[
			3067,
			4552
		],
		[
			-11,
			2
		],
		[
			-7,
			-8
		],
		[
			-12,
			3
		],
		[
			0,
			41
		],
		[
			1,
			29
		],
		[
			2,
			20
		],
		[
			-10,
			-14
		],
		[
			-2,
			-7
		],
		[
			-9,
			-11
		],
		[
			-25,
			0
		],
		[
			-3,
			27
		],
		[
			-14,
			7
		],
		[
			-11,
			0
		],
		[
			7,
			16
		],
		[
			0,
			8
		],
		[
			-6,
			17
		],
		[
			-4,
			2
		],
		[
			-1,
			11
		],
		[
			-5,
			6
		],
		[
			-2,
			15
		],
		[
			-5,
			9
		],
		[
			2,
			9
		],
		[
			-8,
			14
		],
		[
			1,
			11
		],
		[
			7,
			2
		],
		[
			-3,
			13
		],
		[
			2,
			13
		],
		[
			11,
			17
		],
		[
			5,
			3
		],
		[
			1,
			12
		],
		[
			-3,
			14
		],
		[
			8,
			24
		],
		[
			1,
			30
		],
		[
			14,
			14
		],
		[
			14,
			21
		],
		[
			17,
			5
		],
		[
			10,
			6
		],
		[
			5,
			11
		],
		[
			9,
			1
		],
		[
			3,
			-6
		],
		[
			10,
			-5
		],
		[
			0,
			5
		]
	],
	[
		[
			3056,
			4939
		],
		[
			6,
			58
		],
		[
			0,
			9
		],
		[
			5,
			46
		],
		[
			0,
			10
		],
		[
			5,
			54
		],
		[
			-4,
			13
		],
		[
			-2,
			24
		],
		[
			-13,
			21
		],
		[
			1,
			42
		],
		[
			12,
			4
		],
		[
			3,
			5
		],
		[
			10,
			-6
		],
		[
			-2,
			21
		],
		[
			-4,
			4
		],
		[
			-14,
			0
		],
		[
			0,
			37
		],
		[
			8,
			4
		],
		[
			5,
			-3
		],
		[
			34,
			0
		],
		[
			-1,
			16
		],
		[
			7,
			-15
		],
		[
			5,
			4
		],
		[
			9,
			19
		],
		[
			4,
			-5
		],
		[
			7,
			-29
		],
		[
			-1,
			-21
		],
		[
			6,
			2
		]
	],
	[
		[
			3142,
			5253
		],
		[
			11,
			-21
		],
		[
			10,
			-7
		],
		[
			10,
			14
		],
		[
			6,
			-1
		],
		[
			-1,
			-17
		],
		[
			11,
			17
		],
		[
			1,
			10
		],
		[
			11,
			6
		],
		[
			10,
			16
		],
		[
			0,
			-8
		],
		[
			9,
			16
		],
		[
			0,
			14
		],
		[
			19,
			16
		],
		[
			1,
			14
		],
		[
			-20,
			4
		],
		[
			2,
			15
		],
		[
			-6,
			20
		],
		[
			0,
			30
		],
		[
			-13,
			22
		],
		[
			-4,
			12
		],
		[
			2,
			5
		],
		[
			4,
			-10
		],
		[
			12,
			0
		],
		[
			4,
			-14
		],
		[
			10,
			4
		],
		[
			4,
			-5
		],
		[
			4,
			7
		],
		[
			4,
			-5
		],
		[
			7,
			-18
		],
		[
			7,
			5
		],
		[
			-1,
			20
		],
		[
			6,
			1
		],
		[
			4,
			9
		],
		[
			7,
			-6
		],
		[
			18,
			12
		],
		[
			0,
			6
		],
		[
			16,
			10
		],
		[
			10,
			22
		],
		[
			-2,
			13
		],
		[
			-3,
			1
		]
	],
	[
		[
			3312,
			5482
		],
		[
			11,
			0
		],
		[
			3,
			4
		],
		[
			8,
			-12
		],
		[
			-3,
			-33
		],
		[
			6,
			0
		],
		[
			5,
			-8
		],
		[
			-2,
			-8
		],
		[
			4,
			-14
		],
		[
			0,
			-10
		],
		[
			-7,
			-12
		],
		[
			1,
			-13
		],
		[
			-4,
			-17
		],
		[
			-1,
			-22
		],
		[
			2,
			-17
		],
		[
			5,
			-5
		],
		[
			0,
			-26
		],
		[
			6,
			-8
		],
		[
			8,
			-19
		],
		[
			8,
			-4
		],
		[
			4,
			-7
		],
		[
			8,
			5
		],
		[
			0,
			10
		],
		[
			5,
			9
		],
		[
			9,
			-5
		],
		[
			6,
			11
		],
		[
			7,
			0
		],
		[
			3,
			11
		],
		[
			9,
			7
		],
		[
			9,
			-8
		],
		[
			9,
			4
		]
	],
	[
		[
			3347,
			5935
		],
		[
			-4,
			3
		],
		[
			0,
			13
		],
		[
			6,
			-10
		],
		[
			-2,
			-6
		]
	],
	[
		[
			8198,
			5465
		],
		[
			5,
			-34
		],
		[
			-7,
			5
		],
		[
			-2,
			24
		]
	],
	[
		[
			8194,
			5460
		],
		[
			4,
			5
		]
	],
	[
		[
			8166,
			5448
		],
		[
			6,
			-1
		],
		[
			7,
			5
		],
		[
			7,
			12
		],
		[
			9,
			10
		],
		[
			-2,
			-10
		]
	],
	[
		[
			8193,
			5464
		],
		[
			-7,
			-9
		],
		[
			2,
			-17
		],
		[
			0,
			-14
		],
		[
			-7,
			-10
		],
		[
			-7,
			23
		],
		[
			-8,
			11
		]
	],
	[
		[
			7545,
			6781
		],
		[
			-2,
			-8
		],
		[
			5,
			-11
		],
		[
			6,
			3
		],
		[
			3,
			-10
		],
		[
			-3,
			-11
		],
		[
			3,
			-13
		],
		[
			-5,
			-4
		],
		[
			-33,
			-3
		],
		[
			-10,
			8
		],
		[
			-6,
			-9
		],
		[
			-11,
			-3
		],
		[
			-12,
			9
		],
		[
			-6,
			-2
		],
		[
			-7,
			7
		],
		[
			-3,
			12
		],
		[
			4,
			10
		]
	],
	[
		[
			7468,
			6756
		],
		[
			3,
			13
		],
		[
			13,
			29
		],
		[
			11,
			14
		],
		[
			12,
			3
		],
		[
			0,
			-5
		],
		[
			9,
			-1
		],
		[
			-4,
			-10
		],
		[
			18,
			-5
		],
		[
			5,
			6
		],
		[
			10,
			-8
		],
		[
			0,
			-11
		]
	],
	[
		[
			5701,
			4158
		],
		[
			-1,
			-8
		],
		[
			8,
			-27
		],
		[
			7,
			-13
		],
		[
			6,
			-21
		],
		[
			4,
			-29
		],
		[
			8,
			-13
		],
		[
			14,
			-17
		],
		[
			7,
			-3
		],
		[
			3,
			-9
		],
		[
			0,
			-15
		],
		[
			12,
			-1
		],
		[
			-1,
			-34
		],
		[
			6,
			-12
		],
		[
			3,
			-15
		],
		[
			18,
			-5
		],
		[
			12,
			-10
		],
		[
			1,
			-14
		],
		[
			7,
			-7
		]
	],
	[
		[
			5815,
			3905
		],
		[
			-9,
			-3
		],
		[
			-3,
			-13
		],
		[
			-8,
			-7
		],
		[
			-12,
			-4
		],
		[
			-12,
			-27
		],
		[
			-5,
			-6
		],
		[
			-2,
			-10
		],
		[
			-11,
			-7
		],
		[
			-4,
			-13
		],
		[
			-5,
			-31
		],
		[
			-8,
			-10
		],
		[
			-3,
			-10
		],
		[
			-15,
			-6
		],
		[
			0,
			-10
		],
		[
			-8,
			-41
		],
		[
			-5,
			-7
		],
		[
			-10,
			1
		],
		[
			-4,
			-5
		],
		[
			-17,
			5
		],
		[
			-10,
			6
		],
		[
			-13,
			20
		],
		[
			-7,
			1
		],
		[
			-7,
			-5
		],
		[
			-6,
			-23
		],
		[
			0,
			-14
		],
		[
			-6,
			-13
		],
		[
			-8,
			-7
		],
		[
			-6,
			-18
		],
		[
			-7,
			-2
		],
		[
			-2,
			-10
		],
		[
			-15,
			0
		],
		[
			-15,
			4
		],
		[
			0,
			21
		],
		[
			5,
			11
		],
		[
			0,
			19
		],
		[
			-4,
			13
		],
		[
			-1,
			14
		],
		[
			-10,
			29
		],
		[
			-8,
			10
		]
	],
	[
		[
			5554,
			3757
		],
		[
			0,
			159
		],
		[
			28,
			0
		],
		[
			0,
			212
		],
		[
			23,
			4
		],
		[
			21,
			9
		],
		[
			21,
			5
		],
		[
			9,
			-27
		],
		[
			15,
			26
		],
		[
			7,
			4
		],
		[
			4,
			-6
		],
		[
			7,
			13
		],
		[
			12,
			2
		]
	],
	[
		[
			5634,
			5812
		],
		[
			4,
			-14
		],
		[
			8,
			-14
		],
		[
			10,
			-31
		],
		[
			1,
			-16
		],
		[
			-1,
			-21
		],
		[
			-5,
			-6
		],
		[
			3,
			-9
		],
		[
			-2,
			-17
		],
		[
			19,
			-1
		]
	],
	[
		[
			5671,
			5683
		],
		[
			2,
			-7
		],
		[
			-4,
			-11
		],
		[
			3,
			-6
		],
		[
			16,
			-5
		],
		[
			8,
			-17
		],
		[
			5,
			-3
		],
		[
			1,
			-11
		],
		[
			-4,
			-4
		],
		[
			6,
			-14
		],
		[
			18,
			-19
		],
		[
			2,
			-10
		],
		[
			8,
			-10
		],
		[
			-2,
			-16
		],
		[
			8,
			-21
		],
		[
			6,
			-2
		],
		[
			13,
			-23
		],
		[
			-1,
			-15
		],
		[
			6,
			-14
		]
	],
	[
		[
			5762,
			5475
		],
		[
			-12,
			7
		],
		[
			-4,
			-8
		],
		[
			-10,
			-1
		],
		[
			-12,
			12
		],
		[
			-6,
			-3
		],
		[
			-11,
			9
		],
		[
			-4,
			-5
		],
		[
			0,
			-13
		],
		[
			-18,
			-7
		],
		[
			-5,
			11
		],
		[
			-6,
			-10
		],
		[
			-27,
			-19
		],
		[
			-12,
			12
		],
		[
			-9,
			-34
		],
		[
			-3,
			-5
		],
		[
			-23,
			9
		],
		[
			-2,
			-3
		],
		[
			-20,
			12
		],
		[
			-7,
			-2
		],
		[
			-6,
			20
		],
		[
			-13,
			14
		],
		[
			-3,
			7
		],
		[
			-10,
			1
		],
		[
			-17,
			-34
		],
		[
			-1,
			-7
		],
		[
			-6,
			-3
		],
		[
			2,
			-12
		],
		[
			-1,
			-27
		],
		[
			1,
			-13
		]
	],
	[
		[
			5517,
			5383
		],
		[
			-4,
			9
		],
		[
			-11,
			-4
		],
		[
			-16,
			7
		],
		[
			-8,
			-6
		],
		[
			-15,
			-2
		],
		[
			-4,
			-7
		],
		[
			-3,
			-27
		],
		[
			1,
			-7
		],
		[
			-8,
			-34
		]
	],
	[
		[
			5449,
			5312
		],
		[
			-2,
			8
		],
		[
			0,
			26
		],
		[
			-4,
			13
		],
		[
			-5,
			3
		],
		[
			-15,
			32
		],
		[
			-6,
			21
		],
		[
			4,
			1
		],
		[
			-3,
			14
		],
		[
			-10,
			19
		],
		[
			-1,
			31
		],
		[
			-4,
			6
		],
		[
			2,
			8
		],
		[
			1,
			27
		],
		[
			-7,
			10
		],
		[
			10,
			13
		],
		[
			5,
			24
		],
		[
			3,
			4
		],
		[
			6,
			30
		],
		[
			6,
			14
		]
	],
	[
		[
			5429,
			5616
		],
		[
			9,
			-4
		],
		[
			7,
			8
		],
		[
			10,
			5
		],
		[
			4,
			11
		],
		[
			2,
			-12
		],
		[
			5,
			-7
		],
		[
			23,
			26
		],
		[
			7,
			-2
		],
		[
			5,
			4
		],
		[
			15,
			1
		],
		[
			15,
			36
		],
		[
			-6,
			7
		],
		[
			0,
			8
		],
		[
			5,
			5
		],
		[
			17,
			0
		],
		[
			10,
			7
		],
		[
			9,
			-1
		],
		[
			4,
			12
		],
		[
			8,
			5
		],
		[
			5,
			19
		],
		[
			13,
			24
		],
		[
			5,
			4
		],
		[
			3,
			10
		],
		[
			-1,
			14
		],
		[
			8,
			5
		],
		[
			0,
			5
		],
		[
			14,
			9
		],
		[
			9,
			-3
		]
	],
	[
		[
			2957,
			7804
		],
		[
			-12,
			-5
		],
		[
			13,
			16
		],
		[
			-1,
			-11
		]
	],
	[
		[
			2699,
			7829
		],
		[
			2,
			-7
		],
		[
			13,
			9
		],
		[
			3,
			-9
		],
		[
			5,
			9
		],
		[
			9,
			-4
		],
		[
			2,
			-11
		],
		[
			-7,
			-12
		],
		[
			-23,
			15
		],
		[
			-15,
			6
		],
		[
			11,
			4
		]
	],
	[
		[
			2665,
			7849
		],
		[
			6,
			-2
		],
		[
			-2,
			-11
		],
		[
			-4,
			13
		]
	],
	[
		[
			3319,
			7889
		],
		[
			6,
			-10
		],
		[
			-2,
			-13
		],
		[
			-7,
			-22
		],
		[
			5,
			3
		],
		[
			-19,
			-34
		],
		[
			10,
			5
		],
		[
			9,
			11
		],
		[
			-10,
			0
		],
		[
			12,
			21
		],
		[
			4,
			-8
		],
		[
			11,
			0
		],
		[
			-7,
			-23
		],
		[
			-16,
			-12
		],
		[
			-6,
			3
		],
		[
			-13,
			-5
		],
		[
			-5,
			21
		],
		[
			1,
			13
		],
		[
			6,
			7
		],
		[
			10,
			30
		],
		[
			7,
			14
		],
		[
			4,
			-1
		]
	],
	[
		[
			3221,
			7879
		],
		[
			6,
			-21
		],
		[
			3,
			6
		],
		[
			12,
			-8
		],
		[
			33,
			3
		],
		[
			3,
			-3
		],
		[
			-17,
			-10
		],
		[
			4,
			-13
		],
		[
			-11,
			-3
		],
		[
			-2,
			12
		],
		[
			-19,
			2
		],
		[
			-4,
			11
		],
		[
			-11,
			0
		],
		[
			2,
			14
		],
		[
			-9,
			-1
		],
		[
			4,
			16
		],
		[
			7,
			9
		],
		[
			-1,
			-14
		]
	],
	[
		[
			3503,
			7956
		],
		[
			10,
			3
		],
		[
			-1,
			-7
		],
		[
			-9,
			4
		]
	],
	[
		[
			2562,
			7993
		],
		[
			-9,
			-6
		],
		[
			0,
			8
		],
		[
			9,
			-2
		]
	],
	[
		[
			2924,
			7774
		],
		[
			20,
			14
		],
		[
			8,
			11
		],
		[
			6,
			0
		],
		[
			2,
			17
		],
		[
			7,
			17
		],
		[
			14,
			11
		],
		[
			5,
			9
		],
		[
			17,
			17
		],
		[
			5,
			-2
		],
		[
			32,
			22
		],
		[
			14,
			22
		],
		[
			0,
			4
		],
		[
			14,
			20
		],
		[
			0,
			5
		],
		[
			16,
			23
		],
		[
			21,
			20
		],
		[
			44,
			28
		],
		[
			28,
			8
		],
		[
			18,
			-3
		],
		[
			10,
			-5
		],
		[
			11,
			-14
		],
		[
			1,
			-8
		],
		[
			-11,
			8
		],
		[
			11,
			-15
		],
		[
			-4,
			-13
		],
		[
			-11,
			-4
		],
		[
			-1,
			-6
		],
		[
			-18,
			-13
		],
		[
			-16,
			11
		],
		[
			-3,
			-5
		],
		[
			-11,
			0
		],
		[
			18,
			-11
		],
		[
			9,
			-15
		],
		[
			8,
			9
		],
		[
			12,
			0
		],
		[
			3,
			-6
		],
		[
			-7,
			-14
		],
		[
			-1,
			-10
		],
		[
			-11,
			-13
		],
		[
			16,
			0
		],
		[
			-3,
			-15
		],
		[
			11,
			-32
		],
		[
			20,
			-8
		],
		[
			-8,
			-6
		],
		[
			7,
			-7
		],
		[
			10,
			0
		],
		[
			4,
			-9
		],
		[
			5,
			5
		],
		[
			24,
			-6
		],
		[
			10,
			10
		],
		[
			5,
			-15
		],
		[
			7,
			3
		],
		[
			7,
			-12
		],
		[
			-7,
			-5
		],
		[
			14,
			-3
		],
		[
			-1,
			-4
		],
		[
			-18,
			-7
		],
		[
			0,
			-3
		],
		[
			-32,
			-21
		],
		[
			-9,
			4
		],
		[
			-4,
			-9
		],
		[
			-8,
			1
		],
		[
			1,
			-9
		],
		[
			-11,
			0
		],
		[
			1,
			10
		],
		[
			-9,
			-5
		],
		[
			-4,
			-8
		],
		[
			2,
			-10
		],
		[
			-6,
			-5
		],
		[
			-8,
			-19
		],
		[
			-9,
			-10
		],
		[
			-6,
			1
		],
		[
			-9,
			-11
		],
		[
			-5,
			14
		],
		[
			-9,
			5
		],
		[
			-1,
			14
		],
		[
			7,
			29
		],
		[
			21,
			24
		],
		[
			22,
			18
		],
		[
			1,
			-13
		],
		[
			7,
			8
		],
		[
			20,
			9
		],
		[
			-34,
			2
		],
		[
			-5,
			-6
		],
		[
			-4,
			6
		],
		[
			13,
			15
		],
		[
			-3,
			9
		],
		[
			-5,
			-12
		],
		[
			-16,
			-9
		],
		[
			-17,
			-16
		],
		[
			-4,
			4
		],
		[
			-10,
			-10
		],
		[
			-12,
			-1
		],
		[
			-8,
			6
		]
	],
	[
		[
			3134,
			7784
		],
		[
			-9,
			6
		],
		[
			1,
			19
		]
	],
	[
		[
			3126,
			7809
		],
		[
			-10,
			9
		]
	],
	[
		[
			3116,
			7818
		],
		[
			1,
			1
		],
		[
			-1,
			74
		],
		[
			-14,
			17
		],
		[
			-16,
			-11
		],
		[
			-9,
			17
		],
		[
			-19,
			-37
		],
		[
			-4,
			-23
		],
		[
			-7,
			-12
		],
		[
			1,
			-17
		],
		[
			-12,
			-20
		],
		[
			1,
			-11
		],
		[
			-18,
			-5
		],
		[
			-6,
			-16
		],
		[
			-89,
			-1
		]
	],
	[
		[
			1546,
			8044
		],
		[
			6,
			-11
		],
		[
			-14,
			13
		],
		[
			8,
			-2
		]
	],
	[
		[
			1479,
			8054
		],
		[
			4,
			-13
		],
		[
			-7,
			0
		],
		[
			-4,
			9
		],
		[
			7,
			4
		]
	],
	[
		[
			3218,
			8058
		],
		[
			33,
			-11
		],
		[
			15,
			-14
		],
		[
			11,
			-6
		],
		[
			10,
			-14
		],
		[
			-16,
			-6
		],
		[
			-24,
			11
		],
		[
			-14,
			9
		],
		[
			-2,
			9
		],
		[
			-22,
			16
		],
		[
			9,
			6
		]
	],
	[
		[
			1494,
			8104
		],
		[
			-11,
			-4
		],
		[
			6,
			9
		],
		[
			5,
			-5
		]
	],
	[
		[
			1448,
			8112
		],
		[
			20,
			-17
		],
		[
			22,
			-5
		],
		[
			26,
			-13
		],
		[
			5,
			-19
		],
		[
			9,
			-12
		],
		[
			4,
			-16
		],
		[
			22,
			-13
		],
		[
			10,
			-22
		],
		[
			8,
			-25
		],
		[
			-6,
			-6
		],
		[
			-11,
			3
		],
		[
			-22,
			14
		],
		[
			-14,
			12
		],
		[
			9,
			11
		],
		[
			-18,
			-4
		],
		[
			-9,
			9
		],
		[
			4,
			11
		],
		[
			-8,
			0
		],
		[
			-1,
			10
		],
		[
			-14,
			-3
		],
		[
			0,
			11
		],
		[
			7,
			3
		],
		[
			-8,
			5
		],
		[
			-1,
			10
		],
		[
			-15,
			-2
		],
		[
			-33,
			43
		],
		[
			-2,
			7
		],
		[
			16,
			8
		]
	],
	[
		[
			3447,
			8155
		],
		[
			6,
			-8
		],
		[
			7,
			7
		],
		[
			-5,
			-17
		],
		[
			-12,
			4
		],
		[
			2,
			-12
		],
		[
			7,
			-5
		],
		[
			-28,
			-60
		],
		[
			-3,
			-27
		],
		[
			6,
			13
		],
		[
			13,
			21
		],
		[
			12,
			-13
		],
		[
			7,
			0
		],
		[
			-17,
			-14
		],
		[
			11,
			-17
		],
		[
			15,
			9
		],
		[
			-2,
			-16
		],
		[
			12,
			1
		],
		[
			8,
			14
		],
		[
			9,
			-8
		],
		[
			5,
			3
		],
		[
			15,
			-10
		],
		[
			-4,
			-13
		],
		[
			-17,
			-15
		],
		[
			10,
			3
		],
		[
			-3,
			-15
		],
		[
			12,
			-7
		],
		[
			3,
			10
		],
		[
			4,
			-6
		],
		[
			7,
			9
		],
		[
			-5,
			-19
		],
		[
			-11,
			-9
		],
		[
			-7,
			0
		],
		[
			6,
			-14
		],
		[
			-6,
			-9
		],
		[
			8,
			-15
		],
		[
			2,
			13
		],
		[
			6,
			14
		],
		[
			12,
			6
		],
		[
			-9,
			-18
		],
		[
			-1,
			-22
		],
		[
			8,
			8
		],
		[
			3,
			14
		],
		[
			5,
			-19
		],
		[
			-5,
			-10
		],
		[
			-2,
			-19
		],
		[
			-5,
			-17
		],
		[
			-6,
			3
		],
		[
			-10,
			-3
		],
		[
			4,
			26
		],
		[
			-2,
			5
		],
		[
			-14,
			-23
		],
		[
			-4,
			1
		],
		[
			8,
			31
		],
		[
			1,
			14
		],
		[
			-5,
			15
		],
		[
			-18,
			-29
		],
		[
			-10,
			-9
		],
		[
			0,
			-8
		],
		[
			-8,
			-11
		],
		[
			-9,
			-1
		],
		[
			-9,
			5
		],
		[
			3,
			7
		],
		[
			11,
			3
		],
		[
			15,
			28
		],
		[
			-11,
			3
		],
		[
			-6,
			-12
		],
		[
			-10,
			12
		],
		[
			-28,
			-4
		],
		[
			-25,
			3
		],
		[
			-6,
			4
		],
		[
			-18,
			-6
		],
		[
			-15,
			-2
		],
		[
			-4,
			17
		],
		[
			27,
			37
		],
		[
			-9,
			3
		],
		[
			-14,
			-6
		],
		[
			8,
			9
		],
		[
			6,
			-3
		],
		[
			9,
			33
		],
		[
			10,
			-9
		],
		[
			-2,
			9
		],
		[
			8,
			4
		],
		[
			-11,
			4
		],
		[
			25,
			78
		],
		[
			8,
			11
		],
		[
			8,
			28
		],
		[
			24,
			18
		]
	],
	[
		[
			1448,
			8147
		],
		[
			-7,
			0
		],
		[
			2,
			14
		],
		[
			5,
			-14
		]
	],
	[
		[
			1445,
			8181
		],
		[
			-2,
			-17
		],
		[
			-4,
			14
		],
		[
			6,
			3
		]
	],
	[
		[
			2798,
			8181
		],
		[
			-3,
			-7
		],
		[
			-8,
			3
		],
		[
			11,
			4
		]
	],
	[
		[
			1462,
			8192
		],
		[
			-15,
			-17
		],
		[
			2,
			14
		],
		[
			17,
			12
		],
		[
			-4,
			-9
		]
	],
	[
		[
			1430,
			8212
		],
		[
			1,
			-9
		],
		[
			-8,
			2
		],
		[
			7,
			7
		]
	],
	[
		[
			2738,
			8248
		],
		[
			8,
			-1
		],
		[
			10,
			-15
		],
		[
			3,
			-12
		],
		[
			-10,
			1
		],
		[
			-29,
			15
		],
		[
			6,
			10
		],
		[
			12,
			2
		]
	],
	[
		[
			1339,
			8249
		],
		[
			4,
			-12
		],
		[
			-6,
			-9
		],
		[
			6,
			-21
		],
		[
			17,
			-18
		],
		[
			-5,
			-5
		],
		[
			-20,
			26
		],
		[
			-16,
			32
		],
		[
			20,
			7
		]
	],
	[
		[
			1427,
			8244
		],
		[
			3,
			-10
		],
		[
			-2,
			-21
		],
		[
			-14,
			7
		],
		[
			-3,
			12
		],
		[
			2,
			20
		],
		[
			14,
			-8
		]
	],
	[
		[
			1419,
			8255
		],
		[
			-7,
			1
		],
		[
			4,
			10
		],
		[
			3,
			-11
		]
	],
	[
		[
			1382,
			8268
		],
		[
			9,
			-8
		],
		[
			5,
			-15
		],
		[
			-7,
			0
		],
		[
			-15,
			26
		],
		[
			8,
			-3
		]
	],
	[
		[
			1386,
			8270
		],
		[
			-9,
			4
		],
		[
			2,
			6
		],
		[
			7,
			-10
		]
	],
	[
		[
			1395,
			8273
		],
		[
			11,
			-17
		],
		[
			-5,
			-9
		],
		[
			-21,
			36
		],
		[
			3,
			5
		],
		[
			12,
			-15
		]
	],
	[
		[
			1380,
			8293
		],
		[
			-2,
			-10
		],
		[
			-7,
			7
		],
		[
			9,
			3
		]
	],
	[
		[
			1305,
			8302
		],
		[
			20,
			-3
		],
		[
			5,
			-14
		],
		[
			-15,
			-10
		],
		[
			13,
			-2
		],
		[
			2,
			21
		],
		[
			12,
			6
		],
		[
			-8,
			-28
		],
		[
			0,
			-22
		],
		[
			-13,
			-7
		],
		[
			-9,
			10
		],
		[
			7,
			6
		],
		[
			-11,
			3
		],
		[
			-7,
			25
		],
		[
			4,
			15
		]
	],
	[
		[
			2815,
			8428
		],
		[
			-1,
			-10
		],
		[
			-7,
			-3
		],
		[
			4,
			17
		],
		[
			4,
			-4
		]
	],
	[
		[
			2787,
			8429
		],
		[
			-11,
			-11
		],
		[
			1,
			8
		],
		[
			10,
			3
		]
	],
	[
		[
			2801,
			8446
		],
		[
			-3,
			-6
		],
		[
			9,
			-8
		],
		[
			-12,
			-27
		],
		[
			-8,
			-3
		],
		[
			2,
			12
		],
		[
			-9,
			-16
		],
		[
			-3,
			4
		],
		[
			14,
			23
		],
		[
			3,
			-5
		],
		[
			3,
			26
		],
		[
			4,
			0
		]
	],
	[
		[
			3293,
			8462
		],
		[
			1,
			-19
		],
		[
			-7,
			7
		],
		[
			6,
			12
		]
	],
	[
		[
			3204,
			8666
		],
		[
			5,
			-10
		],
		[
			-11,
			7
		],
		[
			6,
			3
		]
	],
	[
		[
			3109,
			8672
		],
		[
			7,
			-7
		],
		[
			-4,
			-10
		],
		[
			-10,
			-6
		],
		[
			-3,
			7
		],
		[
			5,
			16
		],
		[
			5,
			0
		]
	],
	[
		[
			3200,
			8731
		],
		[
			-2,
			-16
		],
		[
			-16,
			19
		],
		[
			18,
			-3
		]
	],
	[
		[
			2793,
			8775
		],
		[
			5,
			-7
		],
		[
			-8,
			-30
		],
		[
			-8,
			-9
		],
		[
			-10,
			11
		],
		[
			-2,
			14
		],
		[
			12,
			23
		],
		[
			11,
			-2
		]
	],
	[
		[
			3203,
			8784
		],
		[
			8,
			0
		],
		[
			-6,
			-10
		],
		[
			-9,
			3
		],
		[
			7,
			7
		]
	],
	[
		[
			3033,
			8802
		],
		[
			15,
			-11
		],
		[
			0,
			-7
		],
		[
			-13,
			1
		],
		[
			-7,
			15
		],
		[
			5,
			2
		]
	],
	[
		[
			2719,
			8809
		],
		[
			7,
			-3
		],
		[
			-2,
			-12
		],
		[
			-27,
			-27
		],
		[
			-23,
			-5
		],
		[
			-6,
			18
		],
		[
			18,
			27
		],
		[
			8,
			-5
		],
		[
			9,
			6
		],
		[
			16,
			1
		]
	],
	[
		[
			2822,
			8839
		],
		[
			21,
			-4
		],
		[
			4,
			-9
		],
		[
			-13,
			-10
		],
		[
			-16,
			17
		],
		[
			4,
			6
		]
	],
	[
		[
			3216,
			8833
		],
		[
			-8,
			14
		],
		[
			5,
			2
		],
		[
			3,
			-16
		]
	],
	[
		[
			2857,
			8849
		],
		[
			12,
			-6
		],
		[
			0,
			-11
		],
		[
			-20,
			14
		],
		[
			8,
			3
		]
	],
	[
		[
			3204,
			8862
		],
		[
			4,
			-12
		],
		[
			-12,
			8
		],
		[
			8,
			4
		]
	],
	[
		[
			3186,
			8910
		],
		[
			2,
			-6
		],
		[
			-13,
			-6
		],
		[
			11,
			12
		]
	],
	[
		[
			2625,
			8972
		],
		[
			12,
			-9
		],
		[
			-7,
			-5
		],
		[
			11,
			-20
		],
		[
			9,
			16
		],
		[
			14,
			-17
		],
		[
			20,
			-4
		],
		[
			4,
			-10
		],
		[
			19,
			-12
		],
		[
			5,
			2
		],
		[
			16,
			-14
		],
		[
			5,
			-23
		],
		[
			19,
			-8
		],
		[
			-1,
			8
		],
		[
			22,
			-21
		],
		[
			-8,
			-2
		],
		[
			-19,
			-16
		],
		[
			-26,
			14
		],
		[
			-12,
			-1
		],
		[
			-1,
			17
		],
		[
			-15,
			-1
		],
		[
			2,
			13
		],
		[
			-19,
			-10
		],
		[
			2,
			-14
		],
		[
			-19,
			-8
		],
		[
			-9,
			-19
		],
		[
			-25,
			-10
		],
		[
			-5,
			33
		],
		[
			-27,
			-2
		],
		[
			-14,
			-5
		],
		[
			8,
			20
		],
		[
			20,
			13
		],
		[
			-6,
			24
		],
		[
			6,
			15
		],
		[
			0,
			28
		],
		[
			5,
			23
		],
		[
			13,
			12
		],
		[
			1,
			-7
		]
	],
	[
		[
			2638,
			8984
		],
		[
			9,
			-10
		],
		[
			0,
			-16
		],
		[
			-12,
			13
		],
		[
			3,
			13
		]
	],
	[
		[
			2657,
			8990
		],
		[
			18,
			-11
		],
		[
			-3,
			-6
		],
		[
			15,
			-10
		],
		[
			-15,
			2
		],
		[
			-15,
			25
		]
	],
	[
		[
			2936,
			9103
		],
		[
			24,
			-5
		],
		[
			1,
			-12
		],
		[
			-28,
			0
		],
		[
			-10,
			16
		],
		[
			13,
			1
		]
	],
	[
		[
			2601,
			9095
		],
		[
			-7,
			-12
		],
		[
			-8,
			5
		],
		[
			-3,
			16
		],
		[
			9,
			13
		],
		[
			7,
			-6
		],
		[
			2,
			-16
		]
	],
	[
		[
			2900,
			9117
		],
		[
			16,
			-9
		],
		[
			-4,
			-11
		],
		[
			3,
			-24
		],
		[
			-9,
			-11
		],
		[
			-14,
			-6
		],
		[
			-31,
			-1
		],
		[
			-7,
			12
		],
		[
			0,
			22
		],
		[
			15,
			25
		],
		[
			31,
			3
		]
	],
	[
		[
			2096,
			9122
		],
		[
			-15,
			8
		],
		[
			14,
			1
		],
		[
			1,
			-9
		]
	],
	[
		[
			2919,
			9131
		],
		[
			3,
			-14
		],
		[
			-16,
			10
		],
		[
			2,
			12
		],
		[
			11,
			-8
		]
	],
	[
		[
			2173,
			9144
		],
		[
			-3,
			-12
		],
		[
			-12,
			5
		],
		[
			15,
			7
		]
	],
	[
		[
			2218,
			9152
		],
		[
			-13,
			-10
		],
		[
			2,
			17
		],
		[
			11,
			-7
		]
	],
	[
		[
			2820,
			9179
		],
		[
			-10,
			-28
		],
		[
			-16,
			-3
		],
		[
			26,
			31
		]
	],
	[
		[
			2860,
			9180
		],
		[
			10,
			-6
		],
		[
			-13,
			-11
		],
		[
			-6,
			16
		],
		[
			9,
			1
		]
	],
	[
		[
			2315,
			9189
		],
		[
			14,
			0
		],
		[
			-4,
			-11
		],
		[
			-10,
			11
		]
	],
	[
		[
			2342,
			9191
		],
		[
			8,
			-12
		],
		[
			-14,
			-3
		],
		[
			6,
			15
		]
	],
	[
		[
			3114,
			9197
		],
		[
			-2,
			-10
		],
		[
			-10,
			3
		],
		[
			12,
			7
		]
	],
	[
		[
			2834,
			9196
		],
		[
			-16,
			-12
		],
		[
			-9,
			1
		],
		[
			20,
			15
		],
		[
			5,
			-4
		]
	],
	[
		[
			2787,
			9204
		],
		[
			9,
			-8
		],
		[
			-21,
			-3
		],
		[
			4,
			-8
		],
		[
			-24,
			10
		],
		[
			16,
			8
		],
		[
			16,
			1
		]
	],
	[
		[
			2294,
			9191
		],
		[
			5,
			5
		],
		[
			10,
			-12
		],
		[
			22,
			-14
		],
		[
			6,
			-20
		],
		[
			18,
			-3
		],
		[
			-17,
			-6
		],
		[
			-13,
			-15
		],
		[
			-33,
			4
		],
		[
			-9,
			7
		],
		[
			-25,
			7
		],
		[
			-3,
			8
		],
		[
			-11,
			-6
		],
		[
			-11,
			11
		],
		[
			33,
			17
		],
		[
			-4,
			16
		],
		[
			12,
			-9
		],
		[
			-6,
			16
		],
		[
			10,
			11
		],
		[
			18,
			-11
		],
		[
			-2,
			-6
		]
	],
	[
		[
			3004,
			9275
		],
		[
			14,
			-3
		],
		[
			-20,
			-12
		],
		[
			-5,
			8
		],
		[
			11,
			7
		]
	],
	[
		[
			2924,
			7774
		],
		[
			-11,
			-4
		],
		[
			-19,
			-25
		]
	],
	[
		[
			2894,
			7745
		],
		[
			-6,
			-7
		],
		[
			-19,
			-10
		],
		[
			-11,
			-18
		],
		[
			-17,
			9
		],
		[
			-5,
			-3
		],
		[
			-30,
			-8
		],
		[
			-17,
			-15
		],
		[
			-5,
			-17
		],
		[
			13,
			-6
		],
		[
			7,
			4
		]
	],
	[
		[
			2804,
			7674
		],
		[
			-1,
			-9
		]
	],
	[
		[
			2803,
			7665
		],
		[
			5,
			-11
		],
		[
			-36,
			-7
		],
		[
			-9,
			-13
		],
		[
			-11,
			6
		],
		[
			-12,
			-1
		],
		[
			-32,
			-36
		],
		[
			-12,
			-2
		],
		[
			-5,
			4
		],
		[
			0,
			12
		],
		[
			5,
			4
		],
		[
			13,
			-1
		],
		[
			1,
			10
		],
		[
			-6,
			4
		]
	],
	[
		[
			2704,
			7634
		],
		[
			5,
			9
		],
		[
			1,
			17
		]
	],
	[
		[
			2710,
			7660
		],
		[
			8,
			4
		],
		[
			12,
			20
		],
		[
			-1,
			38
		],
		[
			4,
			14
		],
		[
			9,
			16
		],
		[
			0,
			12
		],
		[
			-12,
			25
		],
		[
			11,
			0
		],
		[
			1,
			-14
		],
		[
			14,
			-17
		],
		[
			18,
			-14
		],
		[
			0,
			17
		],
		[
			4,
			6
		],
		[
			6,
			-5
		],
		[
			-9,
			17
		],
		[
			2,
			14
		],
		[
			-10,
			3
		],
		[
			-10,
			32
		],
		[
			-12,
			0
		],
		[
			-10,
			8
		],
		[
			-39,
			6
		],
		[
			-3,
			0
		],
		[
			-30,
			10
		]
	],
	[
		[
			2663,
			7852
		],
		[
			0,
			10
		],
		[
			-10,
			-4
		]
	],
	[
		[
			2653,
			7858
		],
		[
			-3,
			4
		],
		[
			4,
			24
		],
		[
			-8,
			1
		],
		[
			3,
			23
		],
		[
			-11,
			14
		],
		[
			5,
			20
		],
		[
			-25,
			0
		],
		[
			-8,
			9
		],
		[
			-12,
			39
		],
		[
			-22,
			-2
		],
		[
			-24,
			14
		],
		[
			-2,
			-22
		],
		[
			-7,
			-2
		],
		[
			3,
			15
		],
		[
			-6,
			-2
		],
		[
			-5,
			-26
		],
		[
			-5,
			-3
		],
		[
			3,
			16
		],
		[
			-10,
			-5
		],
		[
			-5,
			-22
		],
		[
			-7,
			-6
		]
	],
	[
		[
			2511,
			7947
		],
		[
			-9,
			-1
		],
		[
			-4,
			7
		],
		[
			-20,
			0
		],
		[
			-2,
			7
		],
		[
			-16,
			-11
		],
		[
			-8,
			4
		],
		[
			-10,
			14
		],
		[
			-8,
			-7
		],
		[
			-3,
			12
		],
		[
			-14,
			11
		],
		[
			-22,
			-6
		],
		[
			-3,
			7
		],
		[
			-17,
			3
		],
		[
			-6,
			5
		],
		[
			-4,
			31
		],
		[
			-9,
			3
		],
		[
			0,
			-22
		],
		[
			-79,
			0
		],
		[
			-80,
			0
		],
		[
			-55,
			0
		],
		[
			-79,
			0
		],
		[
			-79,
			0
		],
		[
			-49,
			0
		],
		[
			-49,
			0
		],
		[
			-80,
			0
		],
		[
			-61,
			0
		],
		[
			-74,
			0
		],
		[
			-81,
			0
		]
	],
	[
		[
			1590,
			8004
		],
		[
			-8,
			0
		]
	],
	[
		[
			1582,
			8004
		],
		[
			-1,
			0
		]
	],
	[
		[
			1581,
			8004
		],
		[
			-7,
			20
		],
		[
			2,
			14
		],
		[
			-8,
			-11
		],
		[
			-12,
			8
		],
		[
			-1,
			15
		],
		[
			-14,
			0
		],
		[
			-6,
			8
		],
		[
			3,
			18
		],
		[
			-3,
			5
		],
		[
			-9,
			0
		],
		[
			-20,
			12
		],
		[
			-13,
			-2
		],
		[
			6,
			17
		],
		[
			-14,
			1
		],
		[
			-10,
			6
		],
		[
			-4,
			-6
		],
		[
			-14,
			11
		],
		[
			-8,
			12
		],
		[
			9,
			23
		],
		[
			13,
			3
		],
		[
			-9,
			3
		],
		[
			-10,
			-15
		],
		[
			-4,
			12
		],
		[
			0,
			14
		],
		[
			19,
			25
		],
		[
			0,
			13
		],
		[
			-12,
			-16
		],
		[
			-7,
			-5
		],
		[
			-8,
			17
		],
		[
			-4,
			-12
		],
		[
			4,
			26
		],
		[
			-10,
			9
		],
		[
			-10,
			34
		],
		[
			10,
			-5
		],
		[
			-8,
			12
		],
		[
			5,
			21
		],
		[
			-17,
			-20
		],
		[
			-3,
			-14
		],
		[
			-21,
			32
		],
		[
			-4,
			26
		],
		[
			-6,
			-3
		],
		[
			1,
			17
		],
		[
			7,
			4
		],
		[
			10,
			33
		],
		[
			-5,
			0
		],
		[
			-4,
			28
		],
		[
			2,
			8
		]
	],
	[
		[
			1387,
			8402
		],
		[
			0,
			0
		]
	],
	[
		[
			1387,
			8402
		],
		[
			-1,
			12
		],
		[
			-9,
			1
		],
		[
			-9,
			13
		],
		[
			-10,
			3
		],
		[
			-14,
			11
		],
		[
			-7,
			0
		],
		[
			0,
			11
		],
		[
			-7,
			4
		],
		[
			2,
			10
		],
		[
			-29,
			56
		],
		[
			-20,
			40
		],
		[
			-12,
			8
		],
		[
			-4,
			12
		],
		[
			-21,
			22
		],
		[
			3,
			8
		],
		[
			-13,
			13
		],
		[
			-25,
			-11
		],
		[
			-2,
			-20
		],
		[
			-27,
			-20
		],
		[
			-5,
			17
		],
		[
			-43,
			50
		],
		[
			3,
			16
		],
		[
			-17,
			-1
		],
		[
			-9,
			-8
		],
		[
			-12,
			6
		],
		[
			-16,
			1
		],
		[
			0,
			538
		]
	],
	[
		[
			1083,
			9194
		],
		[
			29,
			-2
		],
		[
			23,
			-6
		],
		[
			15,
			-16
		],
		[
			50,
			-21
		],
		[
			26,
			2
		],
		[
			-3,
			18
		],
		[
			20,
			5
		],
		[
			-1,
			8
		],
		[
			29,
			8
		],
		[
			12,
			-5
		],
		[
			-9,
			-9
		],
		[
			24,
			4
		],
		[
			10,
			14
		],
		[
			16,
			0
		],
		[
			45,
			28
		],
		[
			22,
			-4
		],
		[
			5,
			11
		],
		[
			9,
			-11
		],
		[
			-45,
			-25
		],
		[
			-27,
			-6
		],
		[
			-3,
			-10
		],
		[
			-18,
			-6
		],
		[
			-4,
			-15
		],
		[
			-9,
			3
		],
		[
			-4,
			-11
		],
		[
			24,
			-3
		],
		[
			-11,
			15
		],
		[
			29,
			13
		],
		[
			15,
			12
		],
		[
			12,
			-9
		],
		[
			14,
			21
		],
		[
			35,
			9
		],
		[
			0,
			-10
		],
		[
			23,
			16
		],
		[
			-2,
			9
		],
		[
			22,
			7
		],
		[
			-13,
			3
		],
		[
			0,
			17
		],
		[
			23,
			-16
		],
		[
			14,
			-32
		],
		[
			15,
			-16
		],
		[
			20,
			-9
		],
		[
			9,
			4
		],
		[
			-8,
			12
		],
		[
			10,
			9
		],
		[
			8,
			18
		],
		[
			10,
			-1
		],
		[
			-2,
			-19
		],
		[
			12,
			0
		],
		[
			-13,
			-19
		],
		[
			24,
			-2
		],
		[
			14,
			8
		],
		[
			6,
			20
		],
		[
			36,
			-3
		],
		[
			23,
			-10
		],
		[
			23,
			-16
		],
		[
			31,
			-5
		],
		[
			23,
			-13
		],
		[
			57,
			-13
		],
		[
			-9,
			8
		],
		[
			11,
			4
		],
		[
			38,
			-17
		],
		[
			18,
			-18
		],
		[
			-3,
			-9
		],
		[
			-26,
			2
		],
		[
			-8,
			-18
		],
		[
			-9,
			-3
		],
		[
			47,
			-13
		],
		[
			40,
			-1
		],
		[
			3,
			4
		],
		[
			36,
			1
		],
		[
			22,
			14
		],
		[
			13,
			-16
		],
		[
			18,
			0
		],
		[
			7,
			-21
		],
		[
			6,
			15
		],
		[
			20,
			-23
		],
		[
			-7,
			-21
		],
		[
			25,
			-29
		],
		[
			-12,
			23
		],
		[
			1,
			18
		],
		[
			16,
			-14
		],
		[
			-4,
			15
		],
		[
			-9,
			8
		],
		[
			0,
			15
		],
		[
			-12,
			12
		],
		[
			7,
			19
		],
		[
			35,
			18
		],
		[
			21,
			5
		],
		[
			1,
			13
		],
		[
			-24,
			-7
		],
		[
			2,
			-8
		],
		[
			-22,
			-7
		],
		[
			-16,
			5
		],
		[
			7,
			-11
		],
		[
			-22,
			-3
		],
		[
			-2,
			12
		],
		[
			-10,
			-3
		],
		[
			14,
			20
		],
		[
			27,
			5
		],
		[
			31,
			14
		],
		[
			12,
			-3
		],
		[
			9,
			-11
		],
		[
			4,
			-20
		],
		[
			19,
			-6
		],
		[
			4,
			-12
		],
		[
			20,
			-1
		],
		[
			9,
			8
		],
		[
			5,
			-11
		],
		[
			27,
			-14
		],
		[
			21,
			-3
		],
		[
			23,
			10
		],
		[
			26,
			-1
		],
		[
			15,
			-7
		],
		[
			25,
			5
		],
		[
			22,
			-12
		],
		[
			12,
			11
		],
		[
			-16,
			12
		],
		[
			-10,
			-9
		],
		[
			-10,
			10
		],
		[
			3,
			9
		],
		[
			-11,
			11
		],
		[
			27,
			1
		],
		[
			-8,
			9
		],
		[
			21,
			-3
		],
		[
			5,
			-12
		],
		[
			18,
			3
		],
		[
			-11,
			-15
		],
		[
			26,
			12
		],
		[
			-16,
			-41
		],
		[
			11,
			-19
		],
		[
			10,
			8
		],
		[
			11,
			-20
		],
		[
			4,
			16
		],
		[
			-15,
			26
		],
		[
			7,
			19
		],
		[
			17,
			-3
		],
		[
			18,
			14
		],
		[
			18,
			33
		],
		[
			-10,
			8
		],
		[
			-5,
			-13
		],
		[
			-15,
			0
		],
		[
			11,
			34
		],
		[
			18,
			-2
		],
		[
			2,
			13
		],
		[
			-22,
			-5
		],
		[
			-9,
			14
		],
		[
			-7,
			-7
		],
		[
			-25,
			10
		],
		[
			-21,
			22
		],
		[
			1,
			14
		],
		[
			9,
			15
		],
		[
			-12,
			9
		],
		[
			5,
			30
		],
		[
			14,
			6
		],
		[
			8,
			-7
		],
		[
			5,
			12
		],
		[
			-13,
			4
		],
		[
			18,
			9
		],
		[
			2,
			13
		],
		[
			18,
			3
		],
		[
			4,
			-19
		],
		[
			7,
			7
		],
		[
			32,
			-24
		],
		[
			4,
			-30
		],
		[
			37,
			-41
		],
		[
			-25,
			2
		],
		[
			-4,
			-6
		],
		[
			18,
			-3
		],
		[
			-25,
			-18
		],
		[
			20,
			-9
		],
		[
			18,
			7
		],
		[
			10,
			-9
		],
		[
			19,
			-1
		],
		[
			-23,
			-12
		],
		[
			14,
			-11
		],
		[
			6,
			-20
		],
		[
			-2,
			-17
		],
		[
			9,
			-12
		],
		[
			11,
			12
		],
		[
			4,
			31
		],
		[
			11,
			15
		],
		[
			9,
			1
		],
		[
			28,
			-27
		],
		[
			5,
			-32
		],
		[
			-16,
			2
		],
		[
			1,
			-19
		],
		[
			8,
			-19
		],
		[
			17,
			-15
		],
		[
			-1,
			-14
		],
		[
			15,
			7
		],
		[
			-3,
			7
		],
		[
			14,
			-1
		],
		[
			1,
			20
		],
		[
			17,
			23
		],
		[
			7,
			37
		],
		[
			25,
			0
		],
		[
			-10,
			13
		],
		[
			11,
			7
		],
		[
			-20,
			11
		],
		[
			-2,
			10
		],
		[
			6,
			23
		],
		[
			7,
			-4
		],
		[
			20,
			5
		],
		[
			16,
			-9
		],
		[
			30,
			-1
		],
		[
			15,
			-23
		],
		[
			22,
			-5
		],
		[
			-6,
			-12
		],
		[
			-12,
			-5
		],
		[
			20,
			-5
		],
		[
			1,
			-10
		],
		[
			-20,
			-13
		],
		[
			-17,
			6
		],
		[
			-2,
			-7
		],
		[
			18,
			-11
		],
		[
			-5,
			-13
		],
		[
			26,
			-30
		],
		[
			-7,
			-27
		],
		[
			-13,
			-1
		],
		[
			-17,
			-24
		],
		[
			-12,
			-1
		],
		[
			-10,
			-11
		],
		[
			-25,
			21
		],
		[
			16,
			-30
		],
		[
			-4,
			-2
		],
		[
			-19,
			14
		],
		[
			4,
			-14
		],
		[
			-25,
			7
		],
		[
			-5,
			17
		],
		[
			-19,
			-5
		],
		[
			-18,
			2
		],
		[
			7,
			-12
		],
		[
			19,
			-9
		],
		[
			-16,
			-15
		],
		[
			-3,
			-13
		],
		[
			-23,
			-20
		],
		[
			-16,
			0
		],
		[
			-17,
			15
		],
		[
			-31,
			20
		],
		[
			-10,
			-3
		],
		[
			-30,
			2
		],
		[
			32,
			-7
		],
		[
			14,
			-11
		],
		[
			11,
			-16
		],
		[
			56,
			-5
		],
		[
			2,
			-11
		],
		[
			-16,
			-20
		],
		[
			-14,
			-27
		],
		[
			-18,
			-15
		],
		[
			-24,
			1
		],
		[
			-12,
			10
		],
		[
			4,
			-14
		],
		[
			-10,
			-17
		],
		[
			-21,
			-3
		],
		[
			-19,
			10
		],
		[
			-14,
			0
		],
		[
			-37,
			16
		],
		[
			-8,
			-2
		],
		[
			11,
			-10
		],
		[
			4,
			5
		],
		[
			31,
			-11
		],
		[
			-10,
			-11
		],
		[
			18,
			11
		],
		[
			6,
			-8
		],
		[
			25,
			-12
		],
		[
			2,
			-18
		],
		[
			-22,
			-16
		],
		[
			-19,
			5
		],
		[
			-10,
			-3
		],
		[
			15,
			-16
		],
		[
			-19,
			5
		],
		[
			-2,
			-20
		],
		[
			-8,
			-12
		],
		[
			-18,
			-12
		],
		[
			11,
			-4
		],
		[
			-17,
			-12
		],
		[
			-19,
			-60
		],
		[
			-8,
			-31
		],
		[
			3,
			-40
		],
		[
			-3,
			-17
		],
		[
			13,
			-17
		],
		[
			3,
			4
		],
		[
			29,
			-1
		],
		[
			2,
			-15
		],
		[
			10,
			-37
		],
		[
			9,
			-24
		],
		[
			-3,
			-25
		],
		[
			12,
			2
		],
		[
			30,
			12
		],
		[
			15,
			-3
		],
		[
			15,
			-12
		],
		[
			30,
			-8
		],
		[
			12,
			-15
		],
		[
			13,
			-10
		],
		[
			7,
			-15
		],
		[
			10,
			-12
		],
		[
			11,
			-1
		],
		[
			32,
			-17
		],
		[
			21,
			-20
		],
		[
			12,
			-3
		],
		[
			19,
			5
		],
		[
			15,
			-6
		],
		[
			12,
			1
		],
		[
			18,
			-9
		],
		[
			3,
			-14
		],
		[
			-6,
			-25
		],
		[
			0,
			-12
		],
		[
			8,
			-17
		],
		[
			-2,
			-23
		],
		[
			3,
			-13
		],
		[
			-5,
			-19
		],
		[
			20,
			-28
		],
		[
			6,
			-21
		],
		[
			10,
			-5
		],
		[
			15,
			-30
		],
		[
			1,
			-10
		],
		[
			19,
			-11
		],
		[
			1,
			16
		],
		[
			10,
			15
		],
		[
			11,
			-20
		],
		[
			6,
			11
		],
		[
			-9,
			15
		],
		[
			13,
			19
		],
		[
			2,
			22
		],
		[
			-6,
			4
		],
		[
			1,
			19
		],
		[
			-5,
			0
		],
		[
			-5,
			42
		],
		[
			-2,
			32
		],
		[
			-7,
			2
		],
		[
			-6,
			25
		],
		[
			-5,
			1
		],
		[
			39,
			22
		],
		[
			16,
			14
		],
		[
			19,
			23
		],
		[
			12,
			21
		],
		[
			4,
			16
		],
		[
			0,
			44
		],
		[
			-8,
			34
		],
		[
			-9,
			20
		],
		[
			-24,
			23
		],
		[
			-13,
			16
		],
		[
			-2,
			16
		],
		[
			22,
			21
		],
		[
			-1,
			20
		],
		[
			14,
			6
		],
		[
			-1,
			13
		],
		[
			-7,
			2
		],
		[
			-7,
			35
		],
		[
			6,
			6
		],
		[
			-16,
			2
		],
		[
			10,
			15
		],
		[
			2,
			20
		],
		[
			6,
			5
		],
		[
			-13,
			13
		],
		[
			-4,
			34
		],
		[
			18,
			16
		],
		[
			21,
			-4
		],
		[
			32,
			-14
		],
		[
			34,
			-1
		],
		[
			14,
			12
		],
		[
			18,
			-9
		],
		[
			17,
			-14
		],
		[
			-1,
			-8
		],
		[
			30,
			-19
		],
		[
			-9,
			-10
		],
		[
			14,
			-16
		],
		[
			23,
			-5
		],
		[
			11,
			2
		],
		[
			2,
			-11
		],
		[
			12,
			-1
		],
		[
			2,
			12
		],
		[
			5,
			-18
		],
		[
			-12,
			-15
		],
		[
			6,
			-26
		],
		[
			2,
			-26
		],
		[
			-6,
			-6
		],
		[
			3,
			-9
		],
		[
			11,
			-2
		],
		[
			-8,
			-8
		],
		[
			2,
			-18
		],
		[
			-19,
			-7
		],
		[
			10,
			-3
		],
		[
			15,
			12
		],
		[
			13,
			1
		],
		[
			11,
			-6
		],
		[
			5,
			-24
		],
		[
			7,
			10
		],
		[
			9,
			-20
		],
		[
			28,
			15
		],
		[
			6,
			21
		],
		[
			10,
			-9
		],
		[
			5,
			18
		],
		[
			7,
			3
		],
		[
			-2,
			12
		],
		[
			8,
			8
		],
		[
			-3,
			22
		],
		[
			8,
			2
		],
		[
			7,
			25
		],
		[
			14,
			2
		],
		[
			0,
			-12
		],
		[
			9,
			-6
		],
		[
			-1,
			-17
		],
		[
			6,
			0
		],
		[
			5,
			-15
		],
		[
			12,
			-13
		],
		[
			-11,
			-9
		],
		[
			13,
			3
		],
		[
			1,
			-13
		],
		[
			7,
			1
		],
		[
			4,
			-11
		],
		[
			-9,
			-11
		],
		[
			16,
			0
		],
		[
			-2,
			-19
		],
		[
			15,
			-12
		],
		[
			7,
			-20
		],
		[
			-14,
			-11
		],
		[
			10,
			2
		],
		[
			6,
			-6
		],
		[
			-6,
			-7
		],
		[
			18,
			-7
		],
		[
			-8,
			-18
		],
		[
			-7,
			0
		],
		[
			5,
			-13
		],
		[
			-9,
			-4
		],
		[
			11,
			-10
		],
		[
			-12,
			-2
		],
		[
			5,
			-5
		],
		[
			14,
			1
		],
		[
			-3,
			-13
		],
		[
			10,
			-2
		],
		[
			1,
			-7
		],
		[
			22,
			-5
		],
		[
			-4,
			-5
		],
		[
			3,
			-16
		],
		[
			-4,
			-16
		],
		[
			20,
			12
		],
		[
			-2,
			-10
		],
		[
			10,
			-5
		],
		[
			10,
			9
		],
		[
			6,
			-22
		],
		[
			30,
			-6
		],
		[
			14,
			-10
		],
		[
			-9,
			-11
		],
		[
			-15,
			-1
		],
		[
			-1,
			-6
		],
		[
			-33,
			-12
		],
		[
			21,
			5
		],
		[
			3,
			-3
		],
		[
			-30,
			-15
		],
		[
			-13,
			-3
		],
		[
			2,
			-15
		],
		[
			-11,
			-14
		],
		[
			38,
			24
		],
		[
			6,
			15
		],
		[
			19,
			9
		],
		[
			-5,
			7
		],
		[
			24,
			-1
		],
		[
			11,
			-22
		],
		[
			-12,
			-11
		],
		[
			6,
			-9
		],
		[
			9,
			15
		],
		[
			30,
			-19
		],
		[
			4,
			-15
		],
		[
			-6,
			-7
		],
		[
			5,
			-9
		],
		[
			-7,
			-12
		],
		[
			8,
			-9
		],
		[
			4,
			-17
		],
		[
			-8,
			-15
		],
		[
			-20,
			-17
		],
		[
			-10,
			-13
		],
		[
			-8,
			5
		],
		[
			-25,
			-14
		],
		[
			-8,
			3
		],
		[
			-7,
			-12
		],
		[
			-8,
			-5
		],
		[
			1,
			-12
		],
		[
			-13,
			-8
		],
		[
			0,
			-8
		],
		[
			-11,
			-6
		],
		[
			-3,
			-10
		],
		[
			-38,
			-3
		],
		[
			-10,
			-5
		],
		[
			-6,
			7
		],
		[
			-51,
			4
		],
		[
			-26,
			-2
		],
		[
			-37,
			0
		],
		[
			-5,
			-5
		],
		[
			-8,
			5
		],
		[
			-19,
			-25
		],
		[
			-3,
			-23
		],
		[
			-4,
			-6
		],
		[
			-19,
			-3
		],
		[
			-4,
			-11
		],
		[
			-24,
			-18
		],
		[
			-10,
			-28
		],
		[
			-7,
			-9
		],
		[
			-19,
			14
		],
		[
			-5,
			-2
		],
		[
			22,
			-14
		],
		[
			-5,
			-20
		],
		[
			-10,
			-17
		],
		[
			-6,
			-3
		],
		[
			-6,
			-17
		],
		[
			-17,
			-23
		],
		[
			-15,
			-1
		],
		[
			-21,
			-24
		],
		[
			-10,
			-4
		],
		[
			-7,
			-18
		],
		[
			-12,
			-11
		],
		[
			-7,
			-11
		],
		[
			-6,
			-2
		],
		[
			5,
			-8
		],
		[
			-15,
			-12
		],
		[
			-6,
			-8
		]
	],
	[
		[
			1827,
			9404
		],
		[
			6,
			-29
		],
		[
			-17,
			-11
		],
		[
			32,
			3
		],
		[
			-4,
			6
		],
		[
			17,
			15
		],
		[
			49,
			-17
		],
		[
			-3,
			-15
		],
		[
			17,
			6
		],
		[
			18,
			-8
		],
		[
			8,
			4
		],
		[
			-26,
			29
		],
		[
			23,
			-2
		],
		[
			24,
			-23
		],
		[
			11,
			-1
		],
		[
			-1,
			-11
		],
		[
			13,
			-38
		],
		[
			6,
			-4
		],
		[
			21,
			15
		],
		[
			-15,
			14
		],
		[
			-9,
			45
		],
		[
			0,
			25
		],
		[
			29,
			-10
		],
		[
			8,
			7
		],
		[
			26,
			-17
		],
		[
			18,
			-30
		],
		[
			4,
			-24
		],
		[
			19,
			-29
		],
		[
			-7,
			-28
		],
		[
			16,
			-17
		],
		[
			25,
			-16
		],
		[
			8,
			1
		],
		[
			35,
			-23
		],
		[
			16,
			4
		],
		[
			4,
			-24
		],
		[
			-13,
			-6
		],
		[
			-4,
			13
		],
		[
			-5,
			-14
		],
		[
			-19,
			11
		],
		[
			-14,
			-26
		],
		[
			22,
			5
		],
		[
			-2,
			-17
		],
		[
			9,
			-10
		],
		[
			-19,
			-8
		],
		[
			-24,
			-5
		],
		[
			-49,
			6
		],
		[
			4,
			12
		],
		[
			-40,
			5
		],
		[
			-4,
			18
		],
		[
			-10,
			-16
		],
		[
			-17,
			-13
		],
		[
			-28,
			-6
		],
		[
			-12,
			-9
		],
		[
			-56,
			-11
		],
		[
			-59,
			-3
		],
		[
			-16,
			19
		],
		[
			2,
			22
		],
		[
			-18,
			5
		],
		[
			-26,
			-3
		],
		[
			-22,
			4
		],
		[
			-18,
			9
		],
		[
			0,
			6
		],
		[
			-18,
			12
		],
		[
			-4,
			14
		],
		[
			39,
			12
		],
		[
			41,
			5
		],
		[
			53,
			-7
		],
		[
			9,
			7
		],
		[
			22,
			-3
		],
		[
			-18,
			14
		],
		[
			-19,
			2
		],
		[
			-18,
			8
		],
		[
			-58,
			-6
		],
		[
			-19,
			4
		],
		[
			-40,
			-1
		],
		[
			-19,
			23
		],
		[
			17,
			8
		],
		[
			41,
			11
		],
		[
			13,
			11
		],
		[
			-48,
			-10
		],
		[
			-21,
			6
		],
		[
			13,
			5
		],
		[
			-36,
			7
		],
		[
			0,
			11
		],
		[
			16,
			17
		],
		[
			13,
			3
		],
		[
			-13,
			15
		],
		[
			34,
			25
		],
		[
			50,
			16
		],
		[
			27,
			11
		],
		[
			10,
			-5
		]
	],
	[
		[
			2094,
			9405
		],
		[
			-16,
			-22
		],
		[
			-8,
			1
		],
		[
			-18,
			19
		],
		[
			-26,
			12
		],
		[
			13,
			13
		],
		[
			42,
			1
		],
		[
			16,
			-10
		],
		[
			-3,
			-14
		]
	],
	[
		[
			2768,
			9430
		],
		[
			25,
			-7
		],
		[
			37,
			2
		],
		[
			19,
			-6
		],
		[
			32,
			-26
		],
		[
			-1,
			-17
		],
		[
			-52,
			5
		],
		[
			-28,
			-9
		],
		[
			-22,
			6
		],
		[
			-4,
			22
		],
		[
			-21,
			5
		],
		[
			1,
			25
		],
		[
			14,
			0
		]
	],
	[
		[
			2595,
			9436
		],
		[
			41,
			-3
		],
		[
			4,
			-8
		],
		[
			-30,
			-21
		],
		[
			-18,
			-26
		],
		[
			10,
			-20
		],
		[
			-3,
			-28
		],
		[
			9,
			-14
		],
		[
			19,
			-16
		],
		[
			14,
			-5
		],
		[
			-16,
			-13
		],
		[
			-13,
			0
		],
		[
			-8,
			-10
		],
		[
			21,
			10
		],
		[
			18,
			-2
		],
		[
			8,
			17
		],
		[
			-4,
			14
		],
		[
			-16,
			-1
		],
		[
			-8,
			13
		],
		[
			2,
			21
		],
		[
			16,
			1
		],
		[
			-18,
			12
		],
		[
			-3,
			25
		],
		[
			14,
			2
		],
		[
			-6,
			11
		],
		[
			26,
			-5
		],
		[
			-19,
			15
		],
		[
			63,
			24
		],
		[
			37,
			-1
		],
		[
			11,
			-27
		],
		[
			14,
			-5
		],
		[
			0,
			-14
		],
		[
			10,
			-10
		],
		[
			-26,
			-24
		],
		[
			18,
			11
		],
		[
			-11,
			-18
		],
		[
			5,
			-13
		],
		[
			12,
			5
		],
		[
			16,
			25
		],
		[
			23,
			-13
		],
		[
			11,
			14
		],
		[
			26,
			14
		],
		[
			67,
			-15
		],
		[
			7,
			-14
		],
		[
			-14,
			-14
		],
		[
			33,
			4
		],
		[
			0,
			-15
		],
		[
			-32,
			-17
		],
		[
			31,
			12
		],
		[
			19,
			-1
		],
		[
			-10,
			-9
		],
		[
			-4,
			-17
		],
		[
			12,
			19
		],
		[
			3,
			-12
		],
		[
			15,
			-7
		],
		[
			13,
			23
		],
		[
			32,
			-12
		],
		[
			8,
			-11
		],
		[
			-10,
			-12
		],
		[
			-11,
			3
		],
		[
			-13,
			-14
		],
		[
			4,
			-6
		],
		[
			25,
			7
		],
		[
			4,
			9
		],
		[
			15,
			2
		],
		[
			3,
			-9
		],
		[
			-13,
			-17
		],
		[
			30,
			15
		],
		[
			-3,
			-16
		],
		[
			15,
			10
		],
		[
			31,
			-11
		],
		[
			-10,
			-16
		],
		[
			-31,
			-9
		],
		[
			32,
			3
		],
		[
			-1,
			-16
		],
		[
			12,
			9
		],
		[
			6,
			14
		],
		[
			24,
			-23
		],
		[
			2,
			-12
		],
		[
			-26,
			3
		],
		[
			-15,
			-11
		],
		[
			19,
			-8
		],
		[
			19,
			1
		],
		[
			16,
			-11
		],
		[
			-2,
			-8
		],
		[
			-26,
			2
		],
		[
			-15,
			8
		],
		[
			-22,
			3
		],
		[
			22,
			-8
		],
		[
			13,
			-10
		],
		[
			-8,
			-4
		],
		[
			5,
			-11
		],
		[
			-43,
			2
		],
		[
			33,
			-6
		],
		[
			-9,
			-8
		],
		[
			29,
			-2
		],
		[
			23,
			-6
		],
		[
			-10,
			-6
		],
		[
			8,
			-11
		],
		[
			37,
			-12
		],
		[
			12,
			7
		],
		[
			-2,
			-12
		],
		[
			18,
			-4
		],
		[
			13,
			-28
		],
		[
			-21,
			-10
		],
		[
			47,
			10
		],
		[
			-7,
			-18
		],
		[
			22,
			-5
		],
		[
			5,
			9
		],
		[
			18,
			-10
		],
		[
			10,
			-16
		],
		[
			-20,
			-10
		],
		[
			14,
			-3
		],
		[
			-30,
			-8
		],
		[
			14,
			-7
		],
		[
			-7,
			-17
		],
		[
			-15,
			-3
		],
		[
			7,
			-7
		],
		[
			-17,
			-1
		],
		[
			-7,
			16
		],
		[
			3,
			-21
		],
		[
			-9,
			-4
		],
		[
			9,
			-9
		],
		[
			-5,
			-24
		],
		[
			-17,
			9
		],
		[
			-9,
			14
		],
		[
			-1,
			-9
		],
		[
			-18,
			16
		],
		[
			-1,
			14
		],
		[
			-9,
			5
		],
		[
			19,
			17
		],
		[
			-31,
			-5
		],
		[
			-2,
			9
		],
		[
			-22,
			20
		],
		[
			2,
			8
		],
		[
			-13,
			-6
		],
		[
			-6,
			-11
		],
		[
			-16,
			12
		],
		[
			7,
			-15
		],
		[
			16,
			-12
		],
		[
			-1,
			-7
		],
		[
			-20,
			-1
		],
		[
			-9,
			18
		],
		[
			-2,
			-18
		],
		[
			12,
			-16
		],
		[
			14,
			3
		],
		[
			-2,
			-10
		],
		[
			10,
			-2
		],
		[
			10,
			-39
		],
		[
			1,
			14
		],
		[
			31,
			-16
		],
		[
			-3,
			-16
		],
		[
			17,
			0
		],
		[
			-10,
			-10
		],
		[
			11,
			-14
		],
		[
			11,
			-5
		],
		[
			-9,
			-11
		],
		[
			12,
			-6
		],
		[
			0,
			-25
		],
		[
			-7,
			5
		],
		[
			-4,
			18
		],
		[
			-2,
			-14
		],
		[
			10,
			-29
		],
		[
			-17,
			5
		],
		[
			8,
			-19
		],
		[
			-7,
			-5
		],
		[
			-1,
			13
		],
		[
			-12,
			11
		],
		[
			-12,
			-3
		],
		[
			-13,
			13
		],
		[
			-5,
			-5
		],
		[
			-20,
			21
		],
		[
			-6,
			12
		],
		[
			-1,
			-16
		],
		[
			-27,
			24
		],
		[
			-8,
			-3
		],
		[
			23,
			-33
		],
		[
			17,
			-6
		],
		[
			17,
			-21
		],
		[
			5,
			0
		],
		[
			16,
			-26
		],
		[
			7,
			-2
		],
		[
			-9,
			-20
		],
		[
			-30,
			16
		],
		[
			-35,
			7
		],
		[
			-12,
			7
		],
		[
			-25,
			24
		],
		[
			-9,
			-2
		],
		[
			-38,
			22
		],
		[
			-5,
			14
		],
		[
			15,
			10
		],
		[
			-16,
			12
		],
		[
			-2,
			-7
		],
		[
			-15,
			9
		],
		[
			-13,
			14
		],
		[
			-15,
			33
		],
		[
			-20,
			-9
		],
		[
			4,
			15
		],
		[
			-14,
			-6
		],
		[
			-5,
			-14
		],
		[
			-30,
			14
		],
		[
			-5,
			-12
		],
		[
			-24,
			-12
		],
		[
			-14,
			2
		],
		[
			-18,
			11
		],
		[
			-4,
			27
		],
		[
			5,
			9
		],
		[
			18,
			8
		],
		[
			-3,
			15
		],
		[
			21,
			-2
		],
		[
			25,
			-11
		],
		[
			9,
			-9
		],
		[
			-6,
			-7
		],
		[
			10,
			-12
		],
		[
			-2,
			16
		],
		[
			-16,
			17
		],
		[
			23,
			-3
		],
		[
			1,
			7
		],
		[
			15,
			-3
		],
		[
			11,
			12
		],
		[
			19,
			-5
		],
		[
			-7,
			19
		],
		[
			-8,
			4
		],
		[
			-13,
			18
		],
		[
			41,
			32
		],
		[
			5,
			19
		],
		[
			15,
			6
		],
		[
			-4,
			22
		],
		[
			-12,
			18
		],
		[
			-4,
			23
		],
		[
			-23,
			5
		],
		[
			3,
			18
		],
		[
			-19,
			-6
		],
		[
			-13,
			16
		],
		[
			2,
			15
		],
		[
			-9,
			-11
		],
		[
			-10,
			2
		],
		[
			-32,
			-14
		],
		[
			0,
			20
		],
		[
			28,
			3
		],
		[
			1,
			9
		],
		[
			-30,
			19
		],
		[
			-15,
			5
		],
		[
			10,
			9
		],
		[
			-23,
			0
		],
		[
			0,
			21
		],
		[
			-20,
			2
		],
		[
			-10,
			12
		],
		[
			-21,
			2
		],
		[
			21,
			-15
		],
		[
			3,
			-13
		],
		[
			-29,
			-7
		],
		[
			-6,
			8
		],
		[
			-39,
			3
		],
		[
			15,
			-14
		],
		[
			-9,
			-2
		],
		[
			-14,
			13
		],
		[
			-15,
			-11
		],
		[
			-25,
			12
		],
		[
			-15,
			-3
		],
		[
			-31,
			3
		],
		[
			-5,
			4
		],
		[
			-39,
			2
		],
		[
			-21,
			21
		],
		[
			1,
			-11
		],
		[
			-47,
			11
		],
		[
			-21,
			25
		],
		[
			9,
			7
		],
		[
			22,
			-4
		],
		[
			27,
			0
		],
		[
			-15,
			18
		],
		[
			-6,
			-3
		],
		[
			-47,
			6
		],
		[
			-5,
			7
		],
		[
			5,
			17
		],
		[
			-9,
			11
		],
		[
			5,
			24
		],
		[
			25,
			52
		],
		[
			36,
			27
		],
		[
			33,
			8
		]
	],
	[
		[
			2227,
			9438
		],
		[
			17,
			-9
		],
		[
			57,
			6
		],
		[
			4,
			-12
		],
		[
			-12,
			-6
		],
		[
			8,
			-7
		],
		[
			-19,
			-7
		],
		[
			-19,
			-16
		],
		[
			35,
			-3
		],
		[
			9,
			-16
		],
		[
			12,
			3
		],
		[
			5,
			-18
		],
		[
			-9,
			-6
		],
		[
			3,
			-27
		],
		[
			-25,
			-13
		],
		[
			-26,
			2
		],
		[
			9,
			-8
		],
		[
			-13,
			-13
		],
		[
			-19,
			3
		],
		[
			-13,
			25
		],
		[
			-27,
			24
		],
		[
			-21,
			3
		],
		[
			-34,
			24
		],
		[
			-4,
			9
		],
		[
			14,
			16
		],
		[
			11,
			-4
		],
		[
			16,
			-18
		],
		[
			24,
			2
		],
		[
			10,
			8
		],
		[
			-4,
			14
		],
		[
			-11,
			1
		],
		[
			-28,
			20
		],
		[
			11,
			7
		],
		[
			16,
			-9
		],
		[
			3,
			8
		],
		[
			-13,
			12
		],
		[
			33,
			5
		]
	],
	[
		[
			2287,
			9448
		],
		[
			-13,
			-11
		],
		[
			-23,
			-4
		],
		[
			-12,
			7
		],
		[
			34,
			10
		],
		[
			14,
			-2
		]
	],
	[
		[
			2423,
			9449
		],
		[
			18,
			-8
		],
		[
			8,
			5
		],
		[
			45,
			-7
		],
		[
			-28,
			-33
		],
		[
			-12,
			-21
		],
		[
			-14,
			-14
		],
		[
			-33,
			4
		],
		[
			-13,
			-4
		],
		[
			10,
			-16
		],
		[
			-18,
			-22
		],
		[
			-29,
			-6
		],
		[
			-2,
			33
		],
		[
			-11,
			9
		],
		[
			-2,
			60
		],
		[
			11,
			2
		],
		[
			1,
			14
		],
		[
			44,
			9
		],
		[
			25,
			-5
		]
	],
	[
		[
			1623,
			9476
		],
		[
			28,
			-12
		],
		[
			41,
			-10
		],
		[
			46,
			4
		],
		[
			58,
			-41
		],
		[
			-3,
			-6
		],
		[
			-28,
			-9
		],
		[
			-76,
			-37
		],
		[
			-3,
			-15
		],
		[
			-14,
			-8
		],
		[
			-13,
			1
		],
		[
			-3,
			-32
		],
		[
			-7,
			-11
		],
		[
			-22,
			-7
		],
		[
			-9,
			5
		],
		[
			-11,
			-12
		],
		[
			-27,
			-10
		],
		[
			-26,
			36
		],
		[
			-34,
			14
		],
		[
			-14,
			0
		],
		[
			0,
			10
		],
		[
			14,
			22
		],
		[
			9,
			4
		],
		[
			-4,
			18
		],
		[
			17,
			2
		],
		[
			-12,
			9
		],
		[
			14,
			21
		],
		[
			16,
			15
		],
		[
			-10,
			9
		],
		[
			-14,
			28
		],
		[
			87,
			12
		]
	],
	[
		[
			2118,
			9518
		],
		[
			-3,
			-12
		],
		[
			-30,
			4
		],
		[
			15,
			17
		],
		[
			18,
			-9
		]
	],
	[
		[
			2378,
			9537
		],
		[
			25,
			-20
		],
		[
			2,
			-24
		],
		[
			-5,
			-11
		],
		[
			-41,
			1
		],
		[
			-43,
			18
		],
		[
			23,
			30
		],
		[
			25,
			8
		],
		[
			14,
			-2
		]
	],
	[
		[
			2325,
			9539
		],
		[
			-16,
			-17
		],
		[
			-5,
			9
		],
		[
			21,
			8
		]
	],
	[
		[
			2164,
			9558
		],
		[
			-14,
			-12
		],
		[
			-20,
			-1
		],
		[
			7,
			9
		],
		[
			27,
			4
		]
	],
	[
		[
			2380,
			9546
		],
		[
			-17,
			10
		],
		[
			11,
			3
		],
		[
			6,
			-13
		]
	],
	[
		[
			2157,
			9563
		],
		[
			-38,
			-10
		],
		[
			11,
			8
		],
		[
			27,
			2
		]
	],
	[
		[
			1732,
			9567
		],
		[
			5,
			-3
		],
		[
			-22,
			-28
		],
		[
			-10,
			-5
		],
		[
			-22,
			5
		],
		[
			20,
			18
		],
		[
			29,
			13
		]
	],
	[
		[
			2805,
			9567
		],
		[
			0,
			-15
		],
		[
			-16,
			-3
		],
		[
			16,
			18
		]
	],
	[
		[
			2149,
			9575
		],
		[
			-6,
			-11
		],
		[
			-43,
			0
		],
		[
			2,
			8
		],
		[
			47,
			3
		]
	],
	[
		[
			2113,
			9595
		],
		[
			25,
			-12
		],
		[
			-38,
			-5
		],
		[
			-7,
			16
		],
		[
			20,
			1
		]
	],
	[
		[
			2266,
			9598
		],
		[
			21,
			-11
		],
		[
			7,
			-58
		],
		[
			-18,
			1
		],
		[
			14,
			-20
		],
		[
			-11,
			-7
		],
		[
			-47,
			-3
		],
		[
			-20,
			3
		],
		[
			-11,
			19
		],
		[
			33,
			20
		],
		[
			-52,
			-5
		],
		[
			-33,
			-7
		],
		[
			2,
			14
		],
		[
			20,
			10
		],
		[
			-6,
			28
		],
		[
			18,
			3
		],
		[
			35,
			-31
		],
		[
			7,
			21
		],
		[
			-30,
			12
		],
		[
			15,
			9
		],
		[
			23,
			0
		],
		[
			13,
			-10
		],
		[
			20,
			12
		]
	],
	[
		[
			2213,
			9601
		],
		[
			-38,
			-8
		],
		[
			20,
			9
		],
		[
			18,
			-1
		]
	],
	[
		[
			2508,
			9589
		],
		[
			-10,
			-2
		],
		[
			-15,
			15
		],
		[
			17,
			6
		],
		[
			8,
			-19
		]
	],
	[
		[
			1981,
			9607
		],
		[
			-3,
			-11
		],
		[
			20,
			-20
		],
		[
			-11,
			-11
		],
		[
			22,
			-7
		],
		[
			-10,
			-10
		],
		[
			27,
			5
		],
		[
			12,
			10
		],
		[
			31,
			-10
		],
		[
			1,
			-18
		],
		[
			-15,
			-30
		],
		[
			-28,
			-8
		],
		[
			-21,
			7
		],
		[
			-19,
			-7
		],
		[
			-5,
			8
		],
		[
			-25,
			-11
		],
		[
			-22,
			-4
		],
		[
			-24,
			-12
		],
		[
			-34,
			-10
		],
		[
			-29,
			0
		],
		[
			-27,
			17
		],
		[
			52,
			17
		],
		[
			27,
			0
		],
		[
			19,
			13
		],
		[
			-36,
			-6
		],
		[
			-3,
			5
		],
		[
			-44,
			-9
		],
		[
			-5,
			24
		],
		[
			-10,
			-23
		],
		[
			-35,
			-6
		],
		[
			-55,
			16
		],
		[
			12,
			13
		],
		[
			30,
			0
		],
		[
			31,
			14
		],
		[
			-30,
			-8
		],
		[
			-32,
			0
		],
		[
			10,
			12
		],
		[
			57,
			5
		],
		[
			-39,
			0
		],
		[
			-12,
			12
		],
		[
			23,
			10
		],
		[
			10,
			12
		],
		[
			36,
			1
		],
		[
			7,
			-17
		],
		[
			28,
			5
		],
		[
			33,
			-21
		],
		[
			14,
			-22
		],
		[
			62,
			-1
		],
		[
			6,
			7
		],
		[
			-32,
			17
		],
		[
			18,
			11
		],
		[
			-30,
			11
		],
		[
			18,
			11
		],
		[
			15,
			19
		],
		[
			15,
			0
		]
	],
	[
		[
			1840,
			9610
		],
		[
			3,
			-10
		],
		[
			-34,
			3
		],
		[
			31,
			7
		]
	],
	[
		[
			2354,
			9618
		],
		[
			44,
			-6
		],
		[
			16,
			-16
		],
		[
			46,
			3
		],
		[
			26,
			-13
		],
		[
			-26,
			0
		],
		[
			59,
			-9
		],
		[
			-2,
			-7
		],
		[
			-52,
			-1
		],
		[
			30,
			-6
		],
		[
			28,
			-18
		],
		[
			2,
			-16
		],
		[
			14,
			11
		],
		[
			11,
			-8
		],
		[
			26,
			6
		],
		[
			13,
			-9
		],
		[
			59,
			10
		],
		[
			21,
			10
		],
		[
			23,
			-5
		],
		[
			16,
			6
		],
		[
			39,
			-3
		],
		[
			40,
			-18
		],
		[
			6,
			-11
		],
		[
			-25,
			-15
		],
		[
			16,
			1
		],
		[
			10,
			-9
		],
		[
			-23,
			-7
		],
		[
			-1,
			-11
		],
		[
			-29,
			0
		],
		[
			-12,
			-6
		],
		[
			-33,
			5
		],
		[
			-7,
			16
		],
		[
			-11,
			-16
		],
		[
			-84,
			-5
		],
		[
			-53,
			2
		],
		[
			2,
			20
		],
		[
			-21,
			-15
		],
		[
			-21,
			-3
		],
		[
			-30,
			10
		],
		[
			-10,
			-4
		],
		[
			-19,
			9
		],
		[
			1,
			10
		],
		[
			-13,
			14
		],
		[
			11,
			38
		],
		[
			-14,
			8
		],
		[
			-14,
			21
		],
		[
			-17,
			-6
		],
		[
			-37,
			-3
		],
		[
			6,
			7
		],
		[
			-27,
			3
		],
		[
			-11,
			14
		],
		[
			-18,
			4
		],
		[
			15,
			6
		],
		[
			-15,
			7
		],
		[
			13,
			6
		],
		[
			32,
			-1
		]
	],
	[
		[
			1774,
			9644
		],
		[
			20,
			-9
		],
		[
			-25,
			-7
		],
		[
			-2,
			-15
		],
		[
			13,
			-14
		],
		[
			-30,
			-8
		],
		[
			-9,
			-17
		],
		[
			-20,
			9
		],
		[
			5,
			24
		],
		[
			-19,
			-6
		],
		[
			-1,
			-22
		],
		[
			-34,
			-26
		],
		[
			-19,
			-3
		],
		[
			-7,
			19
		],
		[
			-15,
			-12
		],
		[
			-46,
			8
		],
		[
			9,
			15
		],
		[
			31,
			5
		],
		[
			9,
			14
		],
		[
			22,
			7
		],
		[
			15,
			17
		],
		[
			27,
			15
		],
		[
			26,
			1
		],
		[
			18,
			-6
		],
		[
			32,
			11
		]
	],
	[
		[
			2491,
			9653
		],
		[
			17,
			-10
		],
		[
			-11,
			-14
		],
		[
			-30,
			11
		],
		[
			0,
			13
		],
		[
			24,
			0
		]
	],
	[
		[
			2083,
			9641
		],
		[
			18,
			-11
		],
		[
			-11,
			-7
		],
		[
			-23,
			12
		],
		[
			-14,
			25
		],
		[
			13,
			0
		],
		[
			17,
			-19
		]
	],
	[
		[
			2350,
			9662
		],
		[
			51,
			0
		],
		[
			13,
			-7
		],
		[
			-11,
			-10
		],
		[
			-70,
			0
		],
		[
			-6,
			13
		],
		[
			23,
			4
		]
	],
	[
		[
			2196,
			9660
		],
		[
			-42,
			-1
		],
		[
			0,
			9
		],
		[
			21,
			1
		],
		[
			21,
			-9
		]
	],
	[
		[
			1824,
			9675
		],
		[
			20,
			-11
		],
		[
			-15,
			-6
		],
		[
			-27,
			14
		],
		[
			22,
			3
		]
	],
	[
		[
			1955,
			9679
		],
		[
			-35,
			-12
		],
		[
			21,
			-5
		],
		[
			-3,
			-16
		],
		[
			-52,
			-10
		],
		[
			-31,
			11
		],
		[
			3,
			23
		],
		[
			51,
			10
		],
		[
			46,
			-1
		]
	],
	[
		[
			1933,
			9718
		],
		[
			31,
			-15
		],
		[
			-4,
			-11
		],
		[
			-50,
			5
		],
		[
			-52,
			-7
		],
		[
			-5,
			8
		],
		[
			40,
			8
		],
		[
			40,
			12
		]
	],
	[
		[
			2308,
			9715
		],
		[
			18,
			-10
		],
		[
			40,
			-9
		],
		[
			-15,
			-7
		],
		[
			9,
			-16
		],
		[
			-51,
			-11
		],
		[
			-22,
			18
		],
		[
			22,
			2
		],
		[
			-33,
			10
		],
		[
			-10,
			12
		],
		[
			7,
			18
		],
		[
			35,
			-7
		]
	],
	[
		[
			2120,
			9752
		],
		[
			22,
			-6
		],
		[
			10,
			-21
		],
		[
			25,
			12
		],
		[
			58,
			-29
		],
		[
			-8,
			-16
		],
		[
			22,
			-13
		],
		[
			0,
			-11
		],
		[
			-25,
			-6
		],
		[
			-19,
			5
		],
		[
			-12,
			19
		],
		[
			-45,
			10
		],
		[
			-50,
			-6
		],
		[
			-10,
			18
		],
		[
			38,
			-3
		],
		[
			1,
			15
		],
		[
			-18,
			11
		],
		[
			-27,
			-9
		],
		[
			10,
			11
		],
		[
			-26,
			2
		],
		[
			4,
			16
		],
		[
			50,
			1
		]
	],
	[
		[
			2237,
			9796
		],
		[
			21,
			-8
		],
		[
			-5,
			-17
		],
		[
			-36,
			22
		],
		[
			20,
			3
		]
	],
	[
		[
			2423,
			9866
		],
		[
			56,
			-44
		],
		[
			40,
			-1
		],
		[
			1,
			-15
		],
		[
			22,
			9
		],
		[
			22,
			-2
		],
		[
			19,
			-26
		],
		[
			-9,
			-26
		],
		[
			20,
			9
		],
		[
			23,
			-2
		],
		[
			24,
			-19
		],
		[
			-46,
			-14
		],
		[
			-69,
			-50
		],
		[
			-26,
			25
		],
		[
			15,
			-26
		],
		[
			-24,
			10
		],
		[
			0,
			-11
		],
		[
			-49,
			4
		],
		[
			-22,
			17
		],
		[
			34,
			3
		],
		[
			-45,
			2
		],
		[
			-28,
			21
		],
		[
			25,
			12
		],
		[
			79,
			3
		],
		[
			-58,
			1
		],
		[
			0,
			12
		],
		[
			-36,
			-11
		],
		[
			-3,
			7
		],
		[
			-33,
			-6
		],
		[
			-14,
			15
		],
		[
			27,
			4
		],
		[
			-31,
			3
		],
		[
			-21,
			14
		],
		[
			-4,
			14
		],
		[
			53,
			-6
		],
		[
			21,
			9
		],
		[
			-36,
			-4
		],
		[
			-32,
			9
		],
		[
			14,
			17
		],
		[
			41,
			2
		],
		[
			7,
			8
		],
		[
			-33,
			3
		],
		[
			17,
			15
		],
		[
			39,
			0
		],
		[
			7,
			9
		],
		[
			-28,
			8
		],
		[
			41,
			-2
		]
	],
	[
		[
			3064,
			9969
		],
		[
			92,
			-13
		],
		[
			-63,
			-13
		],
		[
			33,
			0
		],
		[
			64,
			14
		],
		[
			63,
			-22
		],
		[
			36,
			-2
		],
		[
			8,
			-17
		],
		[
			-85,
			-27
		],
		[
			-75,
			-6
		],
		[
			11,
			-7
		],
		[
			-78,
			-18
		],
		[
			137,
			21
		],
		[
			-4,
			-9
		],
		[
			-119,
			-45
		],
		[
			-9,
			-11
		],
		[
			-28,
			-4
		],
		[
			-23,
			-32
		],
		[
			-31,
			-8
		],
		[
			-32,
			7
		],
		[
			7,
			-13
		],
		[
			-52,
			-10
		],
		[
			-85,
			-2
		],
		[
			20,
			-4
		],
		[
			80,
			-3
		],
		[
			-1,
			-11
		],
		[
			-35,
			3
		],
		[
			-9,
			7
		],
		[
			-57,
			-2
		],
		[
			56,
			-5
		],
		[
			-45,
			-3
		],
		[
			55,
			-3
		],
		[
			-14,
			-6
		],
		[
			38,
			-1
		],
		[
			8,
			-15
		],
		[
			-22,
			-5
		],
		[
			-30,
			2
		],
		[
			38,
			-10
		],
		[
			-14,
			-14
		],
		[
			-35,
			-13
		],
		[
			-43,
			0
		],
		[
			19,
			-17
		],
		[
			-14,
			-13
		],
		[
			-47,
			-6
		],
		[
			-38,
			9
		],
		[
			-17,
			14
		],
		[
			5,
			-14
		],
		[
			18,
			-8
		],
		[
			57,
			-7
		],
		[
			-10,
			-14
		],
		[
			19,
			-6
		],
		[
			18,
			11
		],
		[
			7,
			-22
		],
		[
			-21,
			-10
		],
		[
			-5,
			7
		],
		[
			-22,
			-15
		],
		[
			-42,
			-11
		],
		[
			8,
			17
		],
		[
			-36,
			5
		],
		[
			-6,
			-7
		],
		[
			-40,
			2
		],
		[
			-13,
			10
		],
		[
			-6,
			-17
		],
		[
			-23,
			-1
		],
		[
			-61,
			10
		],
		[
			-4,
			-7
		],
		[
			-37,
			4
		],
		[
			-15,
			10
		],
		[
			-1,
			17
		],
		[
			33,
			15
		],
		[
			23,
			-1
		],
		[
			15,
			8
		],
		[
			-21,
			5
		],
		[
			-15,
			25
		],
		[
			29,
			7
		],
		[
			27,
			-6
		],
		[
			22,
			-23
		],
		[
			54,
			-3
		],
		[
			27,
			35
		],
		[
			-39,
			-27
		],
		[
			-38,
			10
		],
		[
			15,
			39
		],
		[
			-21,
			-13
		],
		[
			-21,
			5
		],
		[
			-35,
			-4
		],
		[
			1,
			19
		],
		[
			24,
			20
		],
		[
			44,
			7
		],
		[
			35,
			-5
		],
		[
			56,
			1
		],
		[
			-53,
			4
		],
		[
			-30,
			6
		],
		[
			11,
			9
		],
		[
			-23,
			27
		],
		[
			-37,
			6
		],
		[
			0,
			32
		],
		[
			75,
			-4
		],
		[
			67,
			-35
		],
		[
			-7,
			16
		],
		[
			-44,
			23
		],
		[
			80,
			9
		],
		[
			54,
			8
		],
		[
			-44,
			0
		],
		[
			94,
			17
		],
		[
			-62,
			-3
		],
		[
			-2,
			9
		],
		[
			57,
			26
		],
		[
			-37,
			-9
		],
		[
			-40,
			-28
		],
		[
			-44,
			-11
		],
		[
			-53,
			-5
		],
		[
			27,
			11
		],
		[
			-48,
			2
		],
		[
			1,
			-13
		],
		[
			-55,
			-1
		],
		[
			-26,
			5
		],
		[
			26,
			19
		],
		[
			85,
			11
		],
		[
			-93,
			-8
		],
		[
			-33,
			-21
		],
		[
			-58,
			14
		],
		[
			99,
			12
		],
		[
			30,
			12
		],
		[
			-43,
			-8
		],
		[
			-98,
			-8
		],
		[
			-15,
			8
		],
		[
			12,
			11
		],
		[
			45,
			14
		],
		[
			-57,
			-12
		],
		[
			12,
			13
		],
		[
			-22,
			4
		],
		[
			-21,
			-8
		],
		[
			-14,
			7
		],
		[
			27,
			11
		],
		[
			83,
			15
		],
		[
			87,
			-6
		],
		[
			-56,
			12
		],
		[
			43,
			5
		],
		[
			-12,
			10
		],
		[
			30,
			1
		],
		[
			59,
			-23
		],
		[
			-11,
			12
		],
		[
			82,
			-19
		],
		[
			-75,
			24
		],
		[
			18,
			17
		],
		[
			41,
			-8
		],
		[
			-28,
			15
		],
		[
			47,
			-2
		],
		[
			16,
			12
		],
		[
			41,
			-3
		],
		[
			44,
			-11
		],
		[
			-31,
			15
		],
		[
			35,
			4
		],
		[
			54,
			-3
		],
		[
			10,
			-8
		],
		[
			24,
			12
		],
		[
			91,
			2
		]
	],
	[
		[
			5255,
			7927
		],
		[
			0,
			0
		]
	],
	[
		[
			5255,
			7927
		],
		[
			0,
			0
		]
	],
	[
		[
			5255,
			7927
		],
		[
			10,
			-8
		]
	],
	[
		[
			5264,
			7905
		],
		[
			2,
			-12
		]
	],
	[
		[
			5290,
			7882
		],
		[
			-2,
			-13
		],
		[
			-10,
			-7
		],
		[
			4,
			-15
		],
		[
			-6,
			6
		],
		[
			-12,
			-4
		],
		[
			-2,
			10
		],
		[
			-5,
			0
		],
		[
			-1,
			-14
		],
		[
			-5,
			-6
		],
		[
			-1,
			-18
		],
		[
			-7,
			10
		],
		[
			2,
			5
		],
		[
			-11,
			9
		],
		[
			0,
			13
		],
		[
			-10,
			-11
		],
		[
			1,
			-8
		],
		[
			-9,
			-12
		],
		[
			-8,
			4
		],
		[
			-13,
			-4
		]
	],
	[
		[
			5195,
			7827
		],
		[
			-7,
			15
		],
		[
			0,
			14
		]
	],
	[
		[
			5188,
			7856
		],
		[
			-5,
			6
		],
		[
			-8,
			-4
		],
		[
			-3,
			-9
		]
	],
	[
		[
			5172,
			7849
		],
		[
			-4,
			7
		],
		[
			2,
			10
		],
		[
			8,
			9
		],
		[
			0,
			11
		],
		[
			7,
			4
		],
		[
			12,
			28
		],
		[
			8,
			-5
		],
		[
			5,
			10
		]
	],
	[
		[
			5210,
			7923
		],
		[
			14,
			-1
		],
		[
			9,
			5
		],
		[
			4,
			9
		],
		[
			9,
			-9
		],
		[
			9,
			0
		]
	],
	[
		[
			3101,
			2016
		],
		[
			-9,
			-10
		],
		[
			13,
			-7
		],
		[
			6,
			-18
		],
		[
			-2,
			-7
		],
		[
			-8,
			14
		],
		[
			-15,
			-2
		],
		[
			2,
			19
		],
		[
			-18,
			-5
		],
		[
			-1,
			-4
		],
		[
			-14,
			10
		],
		[
			3,
			5
		],
		[
			39,
			9
		],
		[
			4,
			-4
		]
	],
	[
		[
			3116,
			2021
		],
		[
			14,
			-1
		],
		[
			7,
			-9
		],
		[
			-5,
			-12
		],
		[
			-7,
			7
		],
		[
			-9,
			-6
		],
		[
			-8,
			1
		],
		[
			-2,
			15
		],
		[
			10,
			5
		]
	],
	[
		[
			3041,
			2018
		],
		[
			7,
			-9
		],
		[
			-19,
			2
		],
		[
			-1,
			8
		],
		[
			13,
			-1
		]
	],
	[
		[
			3069,
			2021
		],
		[
			8,
			-5
		],
		[
			-19,
			-3
		],
		[
			-1,
			8
		],
		[
			12,
			0
		]
	],
	[
		[
			3013,
			2074
		],
		[
			7,
			-1
		],
		[
			8,
			-15
		],
		[
			-5,
			-7
		],
		[
			-8,
			10
		],
		[
			-4,
			-3
		],
		[
			-2,
			16
		],
		[
			4,
			0
		]
	],
	[
		[
			3003,
			2080
		],
		[
			6,
			-2
		],
		[
			-5,
			-24
		],
		[
			-11,
			16
		],
		[
			0,
			7
		],
		[
			10,
			3
		]
	],
	[
		[
			3044,
			2081
		],
		[
			2,
			-8
		],
		[
			-9,
			4
		],
		[
			3,
			-17
		],
		[
			-9,
			10
		],
		[
			-1,
			10
		],
		[
			8,
			1
		],
		[
			-2,
			10
		],
		[
			6,
			7
		],
		[
			2,
			-17
		]
	],
	[
		[
			2972,
			2103
		],
		[
			2,
			3
		],
		[
			22,
			-21
		],
		[
			-6,
			-2
		],
		[
			-14,
			-18
		],
		[
			4,
			15
		],
		[
			-9,
			1
		],
		[
			-7,
			-7
		],
		[
			1,
			12
		],
		[
			-8,
			1
		],
		[
			3,
			17
		],
		[
			12,
			-1
		]
	],
	[
		[
			2925,
			2147
		],
		[
			15,
			-16
		],
		[
			8,
			0
		],
		[
			21,
			-22
		],
		[
			-10,
			3
		],
		[
			-11,
			14
		],
		[
			-13,
			-1
		],
		[
			-10,
			22
		]
	],
	[
		[
			3093,
			2028
		],
		[
			0,
			-1
		]
	],
	[
		[
			3093,
			2021
		],
		[
			-12,
			-3
		],
		[
			-17,
			9
		],
		[
			-13,
			-4
		],
		[
			-23,
			10
		],
		[
			-10,
			10
		],
		[
			-17,
			-8
		],
		[
			-1,
			12
		],
		[
			8,
			-7
		],
		[
			10,
			12
		],
		[
			7,
			-9
		],
		[
			6,
			12
		],
		[
			-2,
			12
		],
		[
			20,
			-15
		],
		[
			7,
			5
		],
		[
			13,
			-4
		],
		[
			10,
			-11
		],
		[
			3,
			8
		],
		[
			-28,
			18
		],
		[
			-4,
			19
		],
		[
			24,
			15
		],
		[
			-1,
			8
		],
		[
			-25,
			-6
		],
		[
			-6,
			8
		],
		[
			1,
			17
		],
		[
			9,
			1
		],
		[
			0,
			8
		],
		[
			12,
			7
		],
		[
			2,
			13
		],
		[
			6,
			4
		],
		[
			5,
			-11
		],
		[
			16,
			0
		]
	],
	[
		[
			2952,
			2165
		],
		[
			-2,
			-17
		],
		[
			-9,
			0
		],
		[
			-2,
			7
		],
		[
			13,
			10
		]
	],
	[
		[
			2921,
			2176
		],
		[
			8,
			-2
		],
		[
			-6,
			-7
		],
		[
			-2,
			9
		]
	],
	[
		[
			2938,
			2182
		],
		[
			8,
			-11
		],
		[
			-5,
			-6
		],
		[
			-3,
			17
		]
	],
	[
		[
			2920,
			2209
		],
		[
			3,
			-4
		],
		[
			-3,
			-19
		],
		[
			-5,
			7
		],
		[
			5,
			16
		]
	],
	[
		[
			2943,
			2211
		],
		[
			3,
			-10
		],
		[
			-9,
			5
		],
		[
			6,
			5
		]
	],
	[
		[
			2925,
			2234
		],
		[
			1,
			-8
		],
		[
			-9,
			1
		],
		[
			8,
			7
		]
	],
	[
		[
			2931,
			2257
		],
		[
			2,
			-13
		],
		[
			-14,
			-1
		],
		[
			-1,
			9
		],
		[
			9,
			-2
		],
		[
			4,
			7
		]
	],
	[
		[
			2924,
			2263
		],
		[
			1,
			-11
		],
		[
			-8,
			7
		],
		[
			7,
			4
		]
	],
	[
		[
			2906,
			2275
		],
		[
			8,
			0
		],
		[
			-10,
			-15
		],
		[
			2,
			15
		]
	],
	[
		[
			2931,
			2276
		],
		[
			3,
			1
		],
		[
			5,
			-22
		],
		[
			-5,
			0
		],
		[
			-6,
			13
		],
		[
			3,
			8
		]
	],
	[
		[
			2908,
			2302
		],
		[
			14,
			-5
		],
		[
			0,
			-6
		],
		[
			-18,
			-9
		],
		[
			1,
			12
		],
		[
			7,
			-5
		],
		[
			-4,
			13
		]
	],
	[
		[
			2903,
			2329
		],
		[
			8,
			-14
		],
		[
			-12,
			3
		],
		[
			4,
			11
		]
	],
	[
		[
			2914,
			2359
		],
		[
			5,
			-2
		],
		[
			0,
			-12
		],
		[
			-9,
			10
		],
		[
			4,
			4
		]
	],
	[
		[
			2906,
			2359
		],
		[
			2,
			-6
		],
		[
			-9,
			-5
		],
		[
			7,
			11
		]
	],
	[
		[
			2925,
			2377
		],
		[
			5,
			0
		],
		[
			2,
			-27
		],
		[
			-3,
			-27
		],
		[
			3,
			-13
		],
		[
			-9,
			-10
		],
		[
			-4,
			6
		],
		[
			1,
			25
		],
		[
			-4,
			-21
		],
		[
			-7,
			11
		],
		[
			-2,
			25
		],
		[
			13,
			-3
		],
		[
			2,
			12
		],
		[
			-7,
			18
		],
		[
			10,
			4
		]
	],
	[
		[
			2906,
			2392
		],
		[
			1,
			-9
		],
		[
			-7,
			-5
		],
		[
			-2,
			13
		],
		[
			8,
			1
		]
	],
	[
		[
			2924,
			2406
		],
		[
			4,
			-8
		],
		[
			2,
			-18
		],
		[
			-14,
			4
		],
		[
			-1,
			6
		],
		[
			9,
			16
		]
	],
	[
		[
			2913,
			2413
		],
		[
			9,
			-4
		],
		[
			-1,
			-11
		],
		[
			-7,
			-2
		],
		[
			-5,
			19
		],
		[
			4,
			-2
		]
	],
	[
		[
			2907,
			2415
		],
		[
			7,
			-32
		],
		[
			-6,
			0
		],
		[
			0,
			16
		],
		[
			-5,
			-5
		],
		[
			-3,
			20
		],
		[
			7,
			1
		]
	],
	[
		[
			2921,
			2430
		],
		[
			3,
			-17
		],
		[
			-11,
			6
		],
		[
			-1,
			6
		],
		[
			9,
			5
		]
	],
	[
		[
			2945,
			2427
		],
		[
			4,
			-6
		],
		[
			-19,
			2
		],
		[
			7,
			7
		],
		[
			8,
			-3
		]
	],
	[
		[
			2914,
			2436
		],
		[
			-3,
			-8
		],
		[
			-5,
			6
		],
		[
			8,
			2
		]
	],
	[
		[
			2924,
			2545
		],
		[
			-1,
			-11
		],
		[
			-10,
			7
		],
		[
			11,
			4
		]
	],
	[
		[
			2936,
			2556
		],
		[
			-5,
			-9
		],
		[
			0,
			15
		],
		[
			5,
			-6
		]
	],
	[
		[
			2955,
			2556
		],
		[
			-6,
			-2
		],
		[
			3,
			11
		],
		[
			3,
			-9
		]
	],
	[
		[
			2948,
			2591
		],
		[
			3,
			-16
		],
		[
			-7,
			2
		],
		[
			-6,
			12
		],
		[
			10,
			2
		]
	],
	[
		[
			2946,
			2594
		],
		[
			-9,
			-4
		],
		[
			3,
			9
		],
		[
			6,
			-5
		]
	],
	[
		[
			2946,
			2613
		],
		[
			2,
			-4
		],
		[
			-11,
			-6
		],
		[
			-4,
			10
		],
		[
			13,
			0
		]
	],
	[
		[
			2974,
			2623
		],
		[
			6,
			-4
		],
		[
			-12,
			-23
		],
		[
			-4,
			-1
		],
		[
			-5,
			16
		],
		[
			7,
			2
		],
		[
			-1,
			11
		],
		[
			9,
			-1
		]
	],
	[
		[
			2948,
			2662
		],
		[
			3,
			-7
		],
		[
			-11,
			0
		],
		[
			8,
			7
		]
	],
	[
		[
			2945,
			2775
		],
		[
			11,
			1
		],
		[
			5,
			-30
		],
		[
			-8,
			-2
		],
		[
			-4,
			-15
		],
		[
			9,
			-10
		],
		[
			-6,
			-5
		],
		[
			6,
			-13
		],
		[
			-7,
			-2
		],
		[
			2,
			-14
		],
		[
			-17,
			3
		],
		[
			-3,
			4
		],
		[
			7,
			21
		],
		[
			-1,
			36
		],
		[
			4,
			8
		],
		[
			2,
			18
		]
	],
	[
		[
			3098,
			2168
		],
		[
			-21,
			9
		],
		[
			-7,
			-4
		],
		[
			-3,
			-12
		],
		[
			-8,
			-1
		],
		[
			-27,
			-20
		],
		[
			-3,
			-19
		],
		[
			-1,
			-36
		],
		[
			-7,
			-5
		],
		[
			-24,
			11
		],
		[
			-10,
			15
		],
		[
			5,
			11
		],
		[
			15,
			1
		],
		[
			10,
			5
		],
		[
			6,
			18
		],
		[
			-5,
			1
		],
		[
			-22,
			-19
		],
		[
			-5,
			6
		],
		[
			-7,
			-20
		],
		[
			1,
			-10
		],
		[
			-20,
			22
		],
		[
			9,
			0
		],
		[
			-1,
			20
		],
		[
			14,
			1
		],
		[
			13,
			9
		],
		[
			14,
			0
		],
		[
			-2,
			5
		],
		[
			-21,
			3
		],
		[
			-19,
			-19
		],
		[
			1,
			-11
		],
		[
			-6,
			-4
		],
		[
			-8,
			6
		],
		[
			6,
			5
		],
		[
			-9,
			6
		],
		[
			9,
			1
		],
		[
			2,
			11
		],
		[
			-11,
			-5
		],
		[
			0,
			29
		],
		[
			6,
			-2
		],
		[
			15,
			16
		],
		[
			9,
			-1
		],
		[
			0,
			13
		],
		[
			-7,
			-6
		],
		[
			-15,
			13
		],
		[
			10,
			-15
		],
		[
			-6,
			-4
		],
		[
			-4,
			-13
		],
		[
			-8,
			7
		],
		[
			0,
			17
		],
		[
			-9,
			7
		],
		[
			-1,
			13
		],
		[
			6,
			2
		],
		[
			1,
			13
		],
		[
			-6,
			-6
		],
		[
			-7,
			4
		],
		[
			-1,
			17
		],
		[
			11,
			-2
		],
		[
			-1,
			9
		],
		[
			-6,
			-4
		],
		[
			-5,
			21
		],
		[
			-13,
			14
		],
		[
			9,
			8
		],
		[
			1,
			26
		],
		[
			3,
			6
		],
		[
			-5,
			9
		],
		[
			0,
			44
		],
		[
			10,
			11
		],
		[
			-11,
			13
		],
		[
			-3,
			13
		],
		[
			21,
			-4
		],
		[
			6,
			-13
		],
		[
			5,
			5
		],
		[
			-10,
			27
		],
		[
			-1,
			-6
		],
		[
			-21,
			1
		],
		[
			-2,
			12
		],
		[
			9,
			-2
		],
		[
			-7,
			11
		],
		[
			6,
			12
		],
		[
			5,
			0
		],
		[
			6,
			11
		],
		[
			-6,
			2
		],
		[
			-3,
			12
		],
		[
			-11,
			0
		],
		[
			-1,
			-5
		],
		[
			-11,
			14
		],
		[
			4,
			11
		],
		[
			-13,
			-16
		],
		[
			2,
			-11
		],
		[
			-6,
			-3
		],
		[
			-4,
			19
		],
		[
			13,
			13
		],
		[
			3,
			10
		],
		[
			12,
			11
		],
		[
			0,
			11
		],
		[
			14,
			3
		],
		[
			6,
			-14
		],
		[
			-1,
			-8
		],
		[
			7,
			-4
		],
		[
			-7,
			-18
		],
		[
			4,
			-3
		],
		[
			5,
			16
		],
		[
			4,
			49
		],
		[
			8,
			10
		],
		[
			-3,
			20
		],
		[
			4,
			-1
		],
		[
			14,
			13
		],
		[
			1,
			15
		],
		[
			-14,
			13
		],
		[
			4,
			39
		],
		[
			-1,
			17
		],
		[
			9,
			12
		],
		[
			-3,
			14
		],
		[
			0,
			18
		],
		[
			5,
			2
		],
		[
			-3,
			15
		],
		[
			5,
			3
		],
		[
			4,
			-15
		],
		[
			0,
			27
		],
		[
			-8,
			-3
		],
		[
			-4,
			6
		],
		[
			8,
			12
		],
		[
			-10,
			13
		],
		[
			-3,
			-13
		],
		[
			-12,
			-6
		],
		[
			-7,
			4
		],
		[
			2,
			7
		],
		[
			-5,
			11
		],
		[
			-2,
			27
		],
		[
			5,
			20
		],
		[
			1,
			37
		],
		[
			9,
			7
		],
		[
			4,
			19
		],
		[
			1,
			19
		],
		[
			-9,
			38
		],
		[
			2,
			30
		],
		[
			-6,
			26
		],
		[
			1,
			22
		],
		[
			9,
			-3
		],
		[
			5,
			16
		],
		[
			0,
			18
		],
		[
			4,
			-4
		],
		[
			5,
			42
		],
		[
			6,
			9
		],
		[
			-1,
			15
		],
		[
			6,
			18
		],
		[
			5,
			6
		],
		[
			1,
			15
		],
		[
			4,
			12
		],
		[
			1,
			31
		],
		[
			6,
			21
		],
		[
			4,
			4
		],
		[
			1,
			12
		],
		[
			-4,
			23
		],
		[
			6,
			5
		],
		[
			4,
			37
		],
		[
			-4,
			9
		],
		[
			1,
			25
		],
		[
			-5,
			52
		],
		[
			0,
			24
		],
		[
			2,
			12
		],
		[
			7,
			5
		],
		[
			2,
			44
		],
		[
			-5,
			10
		],
		[
			-1,
			19
		],
		[
			6,
			11
		],
		[
			4,
			20
		],
		[
			0,
			18
		],
		[
			3,
			22
		],
		[
			4,
			2
		],
		[
			-1,
			30
		],
		[
			4,
			5
		],
		[
			2,
			15
		],
		[
			2,
			41
		],
		[
			-2,
			11
		],
		[
			2,
			19
		],
		[
			6,
			8
		],
		[
			-1,
			24
		],
		[
			-2,
			5
		],
		[
			1,
			62
		],
		[
			3,
			17
		],
		[
			-6,
			0
		],
		[
			1,
			25
		],
		[
			6,
			1
		],
		[
			4,
			33
		],
		[
			0,
			23
		],
		[
			2,
			25
		],
		[
			2,
			3
		],
		[
			0,
			24
		],
		[
			-3,
			10
		],
		[
			0,
			37
		],
		[
			2,
			6
		],
		[
			-1,
			31
		],
		[
			-5,
			51
		],
		[
			0,
			21
		],
		[
			-2,
			8
		]
	],
	[
		[
			3044,
			4127
		],
		[
			12,
			4
		],
		[
			4,
			9
		],
		[
			0,
			26
		],
		[
			9,
			9
		]
	],
	[
		[
			8073,
			6343
		],
		[
			8,
			-9
		],
		[
			1,
			-20
		],
		[
			-9,
			-13
		],
		[
			-7,
			-43
		],
		[
			-4,
			0
		],
		[
			-5,
			-15
		],
		[
			-9,
			-1
		],
		[
			-2,
			-11
		],
		[
			-14,
			6
		],
		[
			-14,
			12
		],
		[
			-1,
			42
		],
		[
			10,
			19
		],
		[
			8,
			9
		],
		[
			-1,
			10
		],
		[
			7,
			-3
		],
		[
			5,
			9
		],
		[
			8,
			-6
		],
		[
			10,
			10
		],
		[
			8,
			-9
		],
		[
			1,
			13
		]
	],
	[
		[
			8066,
			6398
		],
		[
			4,
			-5
		],
		[
			-8,
			-2
		],
		[
			4,
			7
		]
	],
	[
		[
			8393,
			6916
		],
		[
			2,
			-7
		],
		[
			-8,
			4
		],
		[
			6,
			3
		]
	],
	[
		[
			8386,
			6994
		],
		[
			-10,
			4
		],
		[
			-11,
			15
		],
		[
			6,
			2
		],
		[
			9,
			-11
		],
		[
			8,
			-5
		],
		[
			-2,
			-5
		]
	],
	[
		[
			8689,
			7778
		],
		[
			-2,
			10
		],
		[
			-10,
			6
		],
		[
			-11,
			-7
		]
	],
	[
		[
			8666,
			7787
		],
		[
			-4,
			7
		],
		[
			-12,
			-22
		],
		[
			-11,
			-4
		],
		[
			0,
			-9
		],
		[
			6,
			-40
		],
		[
			-2,
			-28
		],
		[
			3,
			-6
		],
		[
			-5,
			-31
		],
		[
			-19,
			-10
		],
		[
			3,
			-13
		]
	],
	[
		[
			8625,
			7631
		],
		[
			-8,
			13
		],
		[
			0,
			9
		],
		[
			-9,
			7
		],
		[
			-4,
			-13
		],
		[
			-1,
			-19
		],
		[
			-14,
			-5
		],
		[
			-1,
			-10
		],
		[
			-7,
			-10
		],
		[
			-26,
			-3
		],
		[
			8,
			-20
		],
		[
			-3,
			-13
		],
		[
			-30,
			7
		],
		[
			-2,
			12
		],
		[
			-9,
			1
		],
		[
			-12,
			-34
		],
		[
			-9,
			-16
		],
		[
			-6,
			0
		],
		[
			-8,
			-10
		],
		[
			-16,
			-14
		],
		[
			-14,
			-21
		]
	],
	[
		[
			8454,
			7492
		],
		[
			-5,
			-13
		],
		[
			-6,
			-5
		],
		[
			-9,
			3
		],
		[
			-11,
			-3
		],
		[
			-28,
			-28
		],
		[
			-3,
			-9
		],
		[
			-8,
			-11
		],
		[
			-3,
			5
		],
		[
			-7,
			-13
		],
		[
			-10,
			-4
		],
		[
			0,
			12
		],
		[
			15,
			8
		],
		[
			-10,
			29
		],
		[
			6,
			0
		],
		[
			-2,
			11
		],
		[
			12,
			12
		],
		[
			11,
			27
		],
		[
			-3,
			13
		],
		[
			-22,
			14
		],
		[
			-12,
			-7
		],
		[
			0,
			-7
		],
		[
			-10,
			-13
		],
		[
			-4,
			-16
		],
		[
			-14,
			-7
		],
		[
			-17,
			-19
		],
		[
			-1,
			-19
		],
		[
			-10,
			-15
		],
		[
			-10,
			0
		],
		[
			-7,
			-8
		],
		[
			-11,
			11
		],
		[
			-6,
			-6
		],
		[
			-5,
			-28
		],
		[
			5,
			-14
		],
		[
			10,
			-13
		],
		[
			14,
			-4
		],
		[
			7,
			5
		],
		[
			12,
			-25
		],
		[
			-7,
			-1
		],
		[
			-2,
			-21
		],
		[
			10,
			-12
		],
		[
			13,
			1
		],
		[
			2,
			11
		],
		[
			10,
			10
		],
		[
			3,
			9
		],
		[
			12,
			10
		],
		[
			11,
			-8
		],
		[
			0,
			-6
		],
		[
			9,
			-7
		],
		[
			34,
			-4
		],
		[
			-7,
			-15
		],
		[
			3,
			-13
		],
		[
			-9,
			-5
		],
		[
			-5,
			9
		],
		[
			-28,
			-23
		],
		[
			-6,
			3
		],
		[
			4,
			-11
		],
		[
			-7,
			-1
		],
		[
			0,
			-17
		],
		[
			-11,
			-5
		],
		[
			2,
			8
		],
		[
			-8,
			2
		],
		[
			2,
			-13
		],
		[
			-7,
			-22
		],
		[
			-8,
			-4
		],
		[
			-7,
			-26
		],
		[
			-5,
			-3
		],
		[
			1,
			-16
		],
		[
			12,
			-14
		],
		[
			17,
			-12
		],
		[
			6,
			-38
		],
		[
			11,
			-36
		],
		[
			-1,
			-21
		],
		[
			15,
			-16
		],
		[
			0,
			-13
		],
		[
			11,
			-10
		],
		[
			4,
			-16
		],
		[
			-8,
			1
		],
		[
			-9,
			9
		],
		[
			-10,
			-3
		],
		[
			-4,
			11
		],
		[
			-11,
			2
		],
		[
			-5,
			-7
		],
		[
			-7,
			4
		],
		[
			-3,
			16
		],
		[
			-6,
			2
		],
		[
			3,
			-11
		],
		[
			11,
			-13
		],
		[
			16,
			4
		],
		[
			2,
			-9
		],
		[
			7,
			-5
		],
		[
			8,
			-15
		],
		[
			9,
			-9
		],
		[
			6,
			-12
		],
		[
			2,
			-13
		],
		[
			-9,
			-2
		],
		[
			-12,
			-10
		],
		[
			-8,
			-11
		],
		[
			-5,
			-15
		],
		[
			6,
			-2
		],
		[
			6,
			9
		],
		[
			6,
			-1
		],
		[
			8,
			-19
		],
		[
			13,
			-6
		],
		[
			-13,
			-19
		],
		[
			7,
			5
		],
		[
			0,
			-22
		],
		[
			-4,
			-6
		],
		[
			-5,
			3
		],
		[
			1,
			-27
		],
		[
			-5,
			-3
		],
		[
			5,
			-23
		],
		[
			-5,
			2
		],
		[
			-4,
			-10
		],
		[
			-3,
			12
		],
		[
			-9,
			-28
		],
		[
			-8,
			-17
		],
		[
			-3,
			-23
		],
		[
			-6,
			-4
		],
		[
			-1,
			-11
		],
		[
			-9,
			-7
		],
		[
			-1,
			-8
		],
		[
			-5,
			9
		],
		[
			-4,
			-6
		],
		[
			5,
			-6
		],
		[
			2,
			-11
		],
		[
			-5,
			4
		],
		[
			2,
			-10
		],
		[
			-5,
			-15
		],
		[
			5,
			-3
		],
		[
			-3,
			-18
		],
		[
			-4,
			0
		],
		[
			6,
			-17
		],
		[
			-11,
			10
		],
		[
			-4,
			-8
		],
		[
			5,
			-14
		],
		[
			-9,
			1
		],
		[
			-3,
			-9
		],
		[
			3,
			-10
		],
		[
			-10,
			0
		],
		[
			4,
			-9
		],
		[
			-3,
			-8
		],
		[
			-6,
			3
		],
		[
			-5,
			-5
		],
		[
			-2,
			8
		],
		[
			-5,
			-13
		],
		[
			3,
			-11
		],
		[
			-5,
			-4
		],
		[
			-1,
			-10
		],
		[
			-6,
			-1
		],
		[
			-7,
			-13
		],
		[
			-4,
			1
		],
		[
			-5,
			-14
		],
		[
			-6,
			5
		],
		[
			0,
			-9
		],
		[
			-10,
			-21
		],
		[
			-1,
			-10
		],
		[
			-6,
			1
		],
		[
			-13,
			-12
		],
		[
			-7,
			6
		],
		[
			0,
			-11
		],
		[
			-14,
			8
		],
		[
			-5,
			-13
		],
		[
			-6,
			11
		],
		[
			-5,
			-7
		],
		[
			4,
			-8
		],
		[
			-4,
			-3
		],
		[
			-2,
			9
		],
		[
			-5,
			-3
		]
	],
	[
		[
			8172,
			6482
		],
		[
			-4,
			-2
		]
	],
	[
		[
			8168,
			6480
		],
		[
			-7,
			-3
		],
		[
			-2,
			17
		],
		[
			-3,
			-1
		],
		[
			-2,
			15
		],
		[
			-6,
			-8
		],
		[
			6,
			-17
		],
		[
			0,
			-15
		],
		[
			-2,
			-9
		],
		[
			-10,
			20
		],
		[
			7,
			-19
		],
		[
			-10,
			-14
		],
		[
			-5,
			1
		],
		[
			-13,
			-12
		],
		[
			-10,
			3
		],
		[
			-11,
			-15
		],
		[
			-25,
			-8
		],
		[
			-3,
			-10
		],
		[
			-6,
			-1
		],
		[
			-7,
			-13
		],
		[
			5,
			-7
		],
		[
			-1,
			-13
		],
		[
			7,
			-9
		],
		[
			-4,
			-10
		],
		[
			-13,
			-2
		],
		[
			-1,
			10
		],
		[
			-7,
			25
		],
		[
			3,
			28
		],
		[
			5,
			0
		],
		[
			0,
			8
		],
		[
			-8,
			1
		],
		[
			-2,
			14
		],
		[
			-1,
			-16
		],
		[
			-12,
			1
		],
		[
			0,
			6
		],
		[
			-9,
			2
		],
		[
			-9,
			13
		],
		[
			2,
			-16
		],
		[
			-6,
			7
		],
		[
			0,
			-8
		],
		[
			-9,
			-5
		]
	],
	[
		[
			7999,
			6420
		],
		[
			-7,
			10
		],
		[
			-9,
			-4
		],
		[
			-12,
			14
		],
		[
			1,
			6
		],
		[
			-10,
			2
		],
		[
			0,
			14
		],
		[
			-4,
			7
		],
		[
			0,
			14
		],
		[
			5,
			0
		],
		[
			0,
			16
		],
		[
			-14,
			0
		],
		[
			-18,
			12
		],
		[
			-7,
			14
		],
		[
			-14,
			-13
		],
		[
			1,
			-9
		],
		[
			-14,
			-14
		],
		[
			-3,
			8
		],
		[
			-6,
			-8
		],
		[
			0,
			-9
		],
		[
			-11,
			16
		],
		[
			-4,
			-12
		],
		[
			-5,
			11
		],
		[
			-7,
			-21
		],
		[
			-5,
			10
		],
		[
			-13,
			9
		],
		[
			-4,
			-20
		],
		[
			-3,
			0
		]
	],
	[
		[
			7836,
			6473
		],
		[
			-13,
			3
		],
		[
			-4,
			-12
		],
		[
			1,
			-10
		],
		[
			5,
			-15
		],
		[
			0,
			-39
		],
		[
			-5,
			6
		],
		[
			-9,
			-2
		],
		[
			-2,
			20
		]
	],
	[
		[
			7809,
			6424
		],
		[
			-2,
			12
		],
		[
			-7,
			-6
		],
		[
			-3,
			-8
		],
		[
			-8,
			-4
		],
		[
			-2,
			5
		],
		[
			-5,
			-6
		],
		[
			-2,
			13
		],
		[
			-4,
			3
		],
		[
			-1,
			19
		],
		[
			-14,
			5
		],
		[
			-6,
			-1
		],
		[
			0,
			16
		],
		[
			4,
			5
		],
		[
			-1,
			14
		],
		[
			6,
			11
		],
		[
			-5,
			13
		],
		[
			-8,
			-2
		],
		[
			-7,
			5
		],
		[
			2,
			6
		],
		[
			-6,
			40
		],
		[
			6,
			9
		],
		[
			-9,
			-3
		],
		[
			-13,
			1
		],
		[
			-14,
			-14
		],
		[
			-2,
			5
		],
		[
			5,
			10
		],
		[
			-1,
			18
		],
		[
			-4,
			0
		],
		[
			0,
			17
		],
		[
			7,
			8
		],
		[
			-2,
			12
		],
		[
			4,
			11
		],
		[
			2,
			-3
		],
		[
			6,
			10
		],
		[
			0,
			13
		],
		[
			6,
			-3
		],
		[
			3,
			13
		],
		[
			7,
			6
		],
		[
			-4,
			6
		],
		[
			5,
			33
		],
		[
			0,
			29
		],
		[
			-2,
			31
		],
		[
			-7,
			4
		],
		[
			-1,
			-9
		],
		[
			-7,
			20
		],
		[
			0,
			16
		],
		[
			-8,
			13
		],
		[
			-9,
			9
		],
		[
			-5,
			-18
		]
	],
	[
		[
			7703,
			6808
		],
		[
			-7,
			9
		],
		[
			-4,
			-3
		],
		[
			-7,
			15
		],
		[
			-7,
			1
		],
		[
			5,
			6
		],
		[
			-4,
			17
		],
		[
			-9,
			21
		],
		[
			-12,
			-9
		],
		[
			-6,
			0
		],
		[
			-6,
			-9
		],
		[
			-9,
			4
		],
		[
			-9,
			11
		],
		[
			-8,
			-6
		],
		[
			-3,
			-16
		],
		[
			-9,
			-6
		],
		[
			-6,
			-8
		],
		[
			-7,
			-1
		],
		[
			-9,
			-16
		],
		[
			-12,
			-14
		],
		[
			0,
			-11
		],
		[
			-9,
			-9
		],
		[
			-12,
			-5
		],
		[
			-8,
			2
		]
	],
	[
		[
			7468,
			6756
		],
		[
			-4,
			12
		],
		[
			3,
			18
		],
		[
			-1,
			10
		],
		[
			-6,
			5
		],
		[
			-13,
			-14
		]
	],
	[
		[
			7447,
			6787
		],
		[
			-8,
			2
		],
		[
			-4,
			-5
		],
		[
			-15,
			1
		],
		[
			-3,
			7
		],
		[
			-14,
			9
		],
		[
			-4,
			-11
		],
		[
			-9,
			10
		],
		[
			-3,
			-11
		],
		[
			-2,
			13
		],
		[
			-6,
			7
		],
		[
			-16,
			3
		],
		[
			2,
			17
		],
		[
			-4,
			3
		],
		[
			-7,
			-6
		],
		[
			-9,
			11
		],
		[
			-7,
			12
		],
		[
			-2,
			16
		],
		[
			-5,
			5
		],
		[
			-13,
			-7
		],
		[
			-9,
			26
		],
		[
			-9,
			2
		],
		[
			-9,
			15
		],
		[
			-10,
			8
		],
		[
			-1,
			15
		],
		[
			-14,
			5
		],
		[
			-11,
			-23
		],
		[
			-7,
			11
		]
	],
	[
		[
			7248,
			6922
		],
		[
			-11,
			15
		],
		[
			-10,
			6
		],
		[
			1,
			9
		],
		[
			-14,
			15
		],
		[
			-4,
			-3
		],
		[
			-9,
			13
		],
		[
			-5,
			16
		],
		[
			-9,
			-8
		],
		[
			-2,
			12
		],
		[
			4,
			5
		],
		[
			-4,
			7
		],
		[
			2,
			15
		],
		[
			-9,
			14
		],
		[
			-2,
			20
		],
		[
			9,
			4
		],
		[
			6,
			-16
		],
		[
			10,
			8
		],
		[
			7,
			13
		],
		[
			-5,
			14
		],
		[
			0,
			12
		],
		[
			-7,
			3
		],
		[
			-8,
			16
		],
		[
			-3,
			33
		],
		[
			8,
			8
		],
		[
			0,
			7
		],
		[
			-10,
			12
		],
		[
			-9,
			5
		],
		[
			-8,
			41
		],
		[
			1,
			9
		],
		[
			-7,
			0
		]
	],
	[
		[
			7160,
			7227
		],
		[
			-18,
			1
		],
		[
			-11,
			8
		]
	],
	[
		[
			7131,
			7236
		],
		[
			-5,
			6
		],
		[
			0,
			8
		],
		[
			-13,
			-4
		],
		[
			-4,
			10
		],
		[
			1,
			27
		],
		[
			-7,
			15
		],
		[
			-9,
			1
		],
		[
			0,
			7
		],
		[
			-8,
			7
		],
		[
			-7,
			-2
		],
		[
			-9,
			4
		]
	],
	[
		[
			7080,
			7327
		],
		[
			7,
			10
		],
		[
			-8,
			13
		],
		[
			3,
			7
		],
		[
			-5,
			17
		],
		[
			-1,
			26
		],
		[
			-12,
			9
		],
		[
			-6,
			0
		],
		[
			-2,
			-9
		],
		[
			-6,
			3
		],
		[
			-4,
			16
		],
		[
			4,
			9
		],
		[
			-6,
			12
		],
		[
			1,
			14
		]
	],
	[
		[
			7045,
			7454
		],
		[
			8,
			8
		],
		[
			-3,
			9
		],
		[
			4,
			18
		],
		[
			11,
			3
		],
		[
			10,
			14
		],
		[
			3,
			10
		],
		[
			11,
			-4
		],
		[
			8,
			11
		],
		[
			4,
			-20
		],
		[
			18,
			4
		],
		[
			9,
			13
		],
		[
			0,
			10
		],
		[
			5,
			15
		],
		[
			18,
			-2
		],
		[
			11,
			5
		],
		[
			5,
			-2
		],
		[
			8,
			19
		],
		[
			26,
			23
		],
		[
			27,
			15
		],
		[
			-1,
			8
		]
	],
	[
		[
			7227,
			7611
		],
		[
			1,
			3
		],
		[
			-3,
			23
		],
		[
			3,
			11
		],
		[
			9,
			6
		],
		[
			-7,
			5
		],
		[
			13,
			6
		],
		[
			-4,
			13
		],
		[
			2,
			7
		],
		[
			-11,
			37
		],
		[
			0,
			32
		],
		[
			5,
			5
		],
		[
			-18,
			8
		],
		[
			7,
			9
		],
		[
			21,
			5
		],
		[
			23,
			13
		],
		[
			3,
			-9
		],
		[
			13,
			3
		],
		[
			7,
			-7
		],
		[
			4,
			17
		],
		[
			-11,
			7
		],
		[
			7,
			21
		],
		[
			9,
			47
		],
		[
			5,
			14
		],
		[
			0,
			14
		],
		[
			24,
			-13
		],
		[
			21,
			1
		],
		[
			4,
			-10
		],
		[
			13,
			13
		],
		[
			7,
			0
		],
		[
			5,
			9
		],
		[
			-4,
			41
		],
		[
			4,
			25
		],
		[
			25,
			10
		],
		[
			4,
			10
		],
		[
			0,
			17
		],
		[
			4,
			6
		],
		[
			12,
			-1
		]
	],
	[
		[
			7424,
			8009
		],
		[
			15,
			5
		]
	],
	[
		[
			7439,
			8014
		],
		[
			-4,
			-17
		],
		[
			9,
			-8
		],
		[
			-2,
			-9
		],
		[
			16,
			-10
		],
		[
			2,
			-12
		],
		[
			14,
			-12
		],
		[
			11,
			1
		],
		[
			7,
			-11
		],
		[
			9,
			3
		],
		[
			11,
			-21
		],
		[
			0,
			-11
		],
		[
			15,
			-34
		],
		[
			1,
			-11
		],
		[
			-5,
			-14
		],
		[
			3,
			-17
		],
		[
			-7,
			-13
		],
		[
			-2,
			-16
		],
		[
			6,
			-17
		],
		[
			6,
			2
		],
		[
			16,
			-9
		],
		[
			23,
			-4
		],
		[
			11,
			2
		],
		[
			23,
			-8
		],
		[
			6,
			-13
		],
		[
			7,
			0
		],
		[
			14,
			-19
		],
		[
			9,
			-5
		],
		[
			11,
			2
		],
		[
			-2,
			-16
		],
		[
			6,
			-3
		],
		[
			9,
			-41
		],
		[
			12,
			-19
		],
		[
			2,
			-11
		],
		[
			23,
			4
		],
		[
			63,
			-13
		],
		[
			14,
			6
		],
		[
			49,
			-12
		],
		[
			7,
			-15
		],
		[
			29,
			-11
		],
		[
			18,
			-15
		],
		[
			23,
			7
		],
		[
			0,
			-12
		],
		[
			13,
			-5
		],
		[
			6,
			10
		],
		[
			44,
			30
		],
		[
			36,
			10
		],
		[
			20,
			-3
		],
		[
			20,
			4
		],
		[
			25,
			19
		],
		[
			15,
			29
		],
		[
			18,
			12
		],
		[
			10,
			13
		],
		[
			-9,
			18
		],
		[
			-7,
			23
		],
		[
			11,
			33
		],
		[
			5,
			4
		],
		[
			13,
			-1
		],
		[
			5,
			-10
		],
		[
			14,
			-6
		],
		[
			13,
			-3
		],
		[
			16,
			16
		],
		[
			14,
			24
		],
		[
			6,
			-3
		],
		[
			23,
			5
		],
		[
			15,
			18
		],
		[
			-1,
			7
		],
		[
			11,
			24
		],
		[
			6,
			3
		],
		[
			15,
			-1
		],
		[
			1,
			13
		],
		[
			9,
			-4
		],
		[
			16,
			12
		],
		[
			12,
			-3
		],
		[
			3,
			5
		],
		[
			14,
			-8
		],
		[
			11,
			-1
		],
		[
			5,
			6
		],
		[
			-4,
			23
		],
		[
			-18,
			25
		],
		[
			0,
			6
		],
		[
			-10,
			7
		],
		[
			-6,
			11
		],
		[
			-10,
			5
		],
		[
			-12,
			-3
		]
	],
	[
		[
			8270,
			7946
		],
		[
			-7,
			-13
		]
	],
	[
		[
			8263,
			7933
		],
		[
			-5,
			-6
		],
		[
			-13,
			13
		],
		[
			-17,
			-1
		],
		[
			-11,
			-9
		],
		[
			-7,
			10
		],
		[
			-2,
			13
		],
		[
			8,
			8
		],
		[
			-1,
			12
		],
		[
			25,
			79
		]
	],
	[
		[
			8240,
			8052
		],
		[
			16,
			-12
		],
		[
			14,
			-6
		],
		[
			12,
			9
		],
		[
			13,
			17
		],
		[
			12,
			1
		],
		[
			7,
			6
		],
		[
			1,
			14
		],
		[
			-4,
			6
		],
		[
			8,
			27
		],
		[
			7,
			10
		],
		[
			1,
			11
		],
		[
			8,
			23
		],
		[
			16,
			14
		],
		[
			3,
			17
		],
		[
			-4,
			7
		],
		[
			3,
			13
		],
		[
			-8,
			5
		],
		[
			-12,
			-1
		],
		[
			22,
			37
		],
		[
			12,
			1
		],
		[
			26,
			11
		],
		[
			19,
			0
		],
		[
			11,
			6
		],
		[
			28,
			-11
		],
		[
			4,
			-9
		],
		[
			20,
			-1
		],
		[
			17,
			-13
		],
		[
			23,
			-49
		],
		[
			-3,
			-10
		],
		[
			6,
			-23
		],
		[
			6,
			-9
		],
		[
			1,
			-20
		],
		[
			10,
			-19
		],
		[
			1,
			-23
		],
		[
			7,
			-6
		],
		[
			-2,
			-23
		],
		[
			5,
			-9
		],
		[
			11,
			-7
		],
		[
			20,
			2
		],
		[
			7,
			-14
		],
		[
			13,
			-3
		],
		[
			9,
			-7
		],
		[
			11,
			-17
		],
		[
			12,
			0
		],
		[
			-4,
			-13
		],
		[
			6,
			-8
		],
		[
			2,
			-13
		],
		[
			-4,
			-13
		],
		[
			7,
			-20
		],
		[
			15,
			2
		],
		[
			13,
			-5
		],
		[
			17,
			3
		],
		[
			3,
			9
		],
		[
			12,
			14
		],
		[
			12,
			-1
		],
		[
			6,
			9
		],
		[
			18,
			8
		],
		[
			9,
			-7
		],
		[
			-4,
			-13
		],
		[
			6,
			-17
		],
		[
			-8,
			-19
		],
		[
			-9,
			-6
		],
		[
			-4,
			-38
		],
		[
			-5,
			-13
		],
		[
			2,
			-9
		],
		[
			-11,
			-22
		],
		[
			-1,
			-15
		],
		[
			-8,
			-8
		],
		[
			-2,
			-21
		],
		[
			-8,
			-3
		]
	],
	[
		[
			4913,
			5477
		],
		[
			0,
			-1
		]
	],
	[
		[
			4913,
			5476
		],
		[
			0,
			1
		]
	],
	[
		[
			4925,
			5729
		],
		[
			-2,
			-26
		],
		[
			3,
			-1
		],
		[
			4,
			-47
		],
		[
			-8,
			-15
		],
		[
			-6,
			-39
		],
		[
			-7,
			-28
		],
		[
			2,
			-31
		],
		[
			2,
			-4
		],
		[
			4,
			-31
		],
		[
			5,
			-1
		],
		[
			2,
			-13
		],
		[
			-3,
			-14
		]
	],
	[
		[
			4921,
			5479
		],
		[
			-10,
			3
		],
		[
			-3,
			-4
		],
		[
			-15,
			4
		],
		[
			-5,
			4
		],
		[
			-18,
			3
		],
		[
			-3,
			-9
		],
		[
			16,
			7
		],
		[
			6,
			-3
		],
		[
			-22,
			-5
		],
		[
			-22,
			-3
		],
		[
			-38,
			-25
		],
		[
			-5,
			-8
		],
		[
			-12,
			-10
		]
	],
	[
		[
			4790,
			5433
		],
		[
			-1,
			2
		],
		[
			0,
			41
		],
		[
			5,
			10
		],
		[
			-1,
			33
		],
		[
			-10,
			7
		],
		[
			-1,
			13
		],
		[
			-6,
			7
		],
		[
			-10,
			3
		],
		[
			-6,
			8
		],
		[
			8,
			15
		],
		[
			1,
			23
		],
		[
			-5,
			23
		]
	],
	[
		[
			4764,
			5618
		],
		[
			7,
			-1
		],
		[
			3,
			10
		],
		[
			3,
			27
		],
		[
			-7,
			4
		],
		[
			2,
			14
		],
		[
			7,
			0
		],
		[
			5,
			-7
		],
		[
			2,
			15
		],
		[
			-8,
			9
		],
		[
			1,
			12
		],
		[
			5,
			5
		],
		[
			-5,
			6
		],
		[
			2,
			13
		],
		[
			-5,
			-2
		],
		[
			-3,
			7
		],
		[
			1,
			32
		],
		[
			4,
			6
		]
	],
	[
		[
			4778,
			5768
		],
		[
			4,
			2
		],
		[
			5,
			14
		],
		[
			5,
			1
		],
		[
			3,
			-12
		],
		[
			9,
			-6
		],
		[
			2,
			12
		],
		[
			7,
			-1
		],
		[
			1,
			18
		],
		[
			8,
			-5
		],
		[
			-1,
			8
		],
		[
			5,
			2
		],
		[
			2,
			-15
		],
		[
			-2,
			-13
		],
		[
			6,
			-3
		],
		[
			3,
			9
		],
		[
			11,
			4
		]
	],
	[
		[
			5402,
			5930
		],
		[
			2,
			-13
		],
		[
			7,
			-8
		],
		[
			3,
			-17
		],
		[
			-1,
			-10
		],
		[
			5,
			-3
		],
		[
			2,
			-34
		],
		[
			-2,
			-3
		],
		[
			-1,
			-26
		],
		[
			3,
			-28
		],
		[
			9,
			-22
		],
		[
			6,
			-8
		],
		[
			-7,
			-3
		],
		[
			-9,
			3
		],
		[
			-10,
			-4
		],
		[
			-15,
			3
		],
		[
			-7,
			-19
		],
		[
			11,
			-27
		],
		[
			17,
			-29
		],
		[
			3,
			-1
		],
		[
			8,
			-30
		],
		[
			2,
			-17
		],
		[
			4,
			-2
		],
		[
			-3,
			-16
		]
	],
	[
		[
			5449,
			5312
		],
		[
			-3,
			-5
		],
		[
			2,
			-25
		],
		[
			-18,
			15
		],
		[
			-7,
			3
		],
		[
			-10,
			-2
		],
		[
			-8,
			12
		],
		[
			-9,
			-3
		],
		[
			-27,
			0
		]
	],
	[
		[
			5369,
			5307
		],
		[
			-6,
			5
		],
		[
			-48,
			3
		],
		[
			-1,
			-7
		]
	],
	[
		[
			5314,
			5308
		],
		[
			-38,
			0
		],
		[
			-4,
			10
		]
	],
	[
		[
			5272,
			5318
		],
		[
			0,
			12
		],
		[
			4,
			27
		],
		[
			-1,
			12
		],
		[
			-8,
			18
		],
		[
			-2,
			13
		],
		[
			6,
			11
		],
		[
			-2,
			8
		],
		[
			-10,
			-11
		],
		[
			-10,
			10
		],
		[
			-2,
			29
		],
		[
			-11,
			-4
		],
		[
			2,
			17
		]
	],
	[
		[
			5238,
			5460
		],
		[
			6,
			19
		],
		[
			1,
			41
		],
		[
			4,
			2
		],
		[
			10,
			24
		],
		[
			10,
			13
		],
		[
			2,
			14
		],
		[
			10,
			13
		],
		[
			3,
			-8
		],
		[
			7,
			1
		],
		[
			1,
			9
		],
		[
			8,
			-5
		],
		[
			7,
			-14
		],
		[
			1,
			-16
		],
		[
			7,
			1
		],
		[
			6,
			15
		],
		[
			-1,
			8
		],
		[
			10,
			15
		],
		[
			-2,
			17
		],
		[
			5,
			9
		],
		[
			0,
			9
		],
		[
			5,
			14
		],
		[
			1,
			25
		],
		[
			16,
			23
		],
		[
			2,
			34
		],
		[
			9,
			9
		],
		[
			2,
			17
		],
		[
			-1,
			14
		],
		[
			6,
			5
		],
		[
			3,
			30
		],
		[
			12,
			34
		],
		[
			6,
			-1
		],
		[
			11,
			14
		],
		[
			1,
			37
		],
		[
			-3,
			10
		],
		[
			-10,
			4
		],
		[
			-3,
			40
		]
	],
	[
		[
			5390,
			5936
		],
		[
			7,
			0
		]
	],
	[
		[
			5397,
			5936
		],
		[
			-1,
			-11
		],
		[
			6,
			5
		]
	],
	[
		[
			5398,
			5936
		],
		[
			1,
			0
		]
	],
	[
		[
			5399,
			5936
		],
		[
			-1,
			0
		]
	],
	[
		[
			5944,
			7202
		],
		[
			0,
			0
		]
	],
	[
		[
			5944,
			7202
		],
		[
			-3,
			0
		]
	],
	[
		[
			5941,
			7202
		],
		[
			0,
			0
		]
	],
	[
		[
			5941,
			7202
		],
		[
			3,
			0
		]
	],
	[
		[
			5905,
			7208
		],
		[
			0,
			1
		]
	],
	[
		[
			5905,
			7209
		],
		[
			1,
			0
		]
	],
	[
		[
			5906,
			7209
		],
		[
			1,
			0
		]
	],
	[
		[
			5907,
			7209
		],
		[
			-2,
			-1
		]
	],
	[
		[
			5935,
			7200
		],
		[
			1,
			-2
		]
	],
	[
		[
			5936,
			7198
		],
		[
			-7,
			-1
		],
		[
			-1,
			11
		],
		[
			-17,
			-6
		],
		[
			-3,
			7
		]
	],
	[
		[
			5908,
			7209
		],
		[
			0,
			0
		]
	],
	[
		[
			5908,
			7209
		],
		[
			3,
			-5
		],
		[
			17,
			6
		],
		[
			1,
			-10
		],
		[
			6,
			0
		]
	],
	[
		[
			5807,
			5072
		],
		[
			0,
			-19
		],
		[
			-2,
			6
		],
		[
			2,
			13
		]
	],
	[
		[
			5762,
			5475
		],
		[
			2,
			-10
		],
		[
			7,
			-8
		],
		[
			0,
			-10
		],
		[
			16,
			-18
		],
		[
			12,
			12
		],
		[
			6,
			1
		],
		[
			5,
			-9
		],
		[
			7,
			12
		],
		[
			0,
			6
		],
		[
			10,
			-5
		],
		[
			0,
			-12
		],
		[
			4,
			-3
		],
		[
			7,
			-21
		],
		[
			10,
			-6
		],
		[
			0,
			-14
		],
		[
			6,
			4
		],
		[
			2,
			-10
		]
	],
	[
		[
			5856,
			5384
		],
		[
			2,
			-7
		],
		[
			-5,
			-19
		],
		[
			3,
			-15
		],
		[
			-4,
			-19
		],
		[
			8,
			-3
		],
		[
			8,
			-13
		]
	],
	[
		[
			5868,
			5308
		],
		[
			-10,
			-15
		],
		[
			-12,
			-24
		],
		[
			0,
			-15
		]
	],
	[
		[
			5846,
			5254
		],
		[
			-7,
			-6
		],
		[
			-2,
			-13
		],
		[
			-6,
			-5
		],
		[
			0,
			-21
		],
		[
			-3,
			-7
		],
		[
			-4,
			-25
		]
	],
	[
		[
			5824,
			5177
		],
		[
			-7,
			-9
		],
		[
			-3,
			-12
		],
		[
			1,
			-13
		],
		[
			8,
			12
		]
	],
	[
		[
			5823,
			5155
		],
		[
			-1,
			-6
		],
		[
			-1,
			-46
		]
	],
	[
		[
			5821,
			5103
		],
		[
			-7,
			-8
		],
		[
			-3,
			-9
		]
	],
	[
		[
			5811,
			5086
		],
		[
			-3,
			1
		],
		[
			-7,
			-28
		],
		[
			3,
			-9
		],
		[
			-3,
			-10
		]
	],
	[
		[
			5801,
			5040
		],
		[
			4,
			-14
		]
	],
	[
		[
			5811,
			4991
		],
		[
			-2,
			-3
		],
		[
			-1,
			-49
		],
		[
			4,
			11
		],
		[
			-1,
			-27
		],
		[
			-3,
			-5
		],
		[
			0,
			-30
		],
		[
			7,
			-28
		],
		[
			-1,
			-13
		],
		[
			-4,
			-5
		],
		[
			10,
			-49
		],
		[
			6,
			-14
		],
		[
			6,
			-6
		],
		[
			6,
			-13
		],
		[
			2,
			-29
		],
		[
			7,
			-10
		],
		[
			2,
			-12
		]
	],
	[
		[
			5849,
			4709
		],
		[
			-28,
			-8
		],
		[
			-19,
			-7
		]
	],
	[
		[
			5802,
			4694
		],
		[
			-16,
			-35
		],
		[
			0,
			-23
		],
		[
			4,
			-2
		],
		[
			2,
			9
		]
	],
	[
		[
			5792,
			4643
		],
		[
			4,
			-21
		],
		[
			-1,
			-21
		],
		[
			1,
			-34
		],
		[
			-5,
			-16
		],
		[
			0,
			-10
		],
		[
			-4,
			-17
		],
		[
			4,
			-25
		],
		[
			9,
			-11
		],
		[
			6,
			-17
		],
		[
			14,
			-4
		],
		[
			-2,
			11
		],
		[
			9,
			5
		],
		[
			0,
			-75
		],
		[
			-5,
			1
		],
		[
			-1,
			12
		],
		[
			-10,
			-10
		],
		[
			-7,
			1
		],
		[
			-2,
			14
		],
		[
			-6,
			17
		],
		[
			-4,
			-2
		],
		[
			-1,
			13
		],
		[
			-5,
			13
		],
		[
			-16,
			7
		],
		[
			-6,
			6
		],
		[
			-3,
			16
		],
		[
			-5,
			7
		],
		[
			-1,
			12
		],
		[
			-5,
			0
		],
		[
			-1,
			-16
		],
		[
			-7,
			-8
		],
		[
			-10,
			6
		],
		[
			-11,
			0
		],
		[
			-4,
			7
		],
		[
			-14,
			8
		],
		[
			0,
			26
		],
		[
			-17,
			-7
		],
		[
			-8,
			-8
		],
		[
			-4,
			5
		],
		[
			3,
			14
		],
		[
			-8,
			6
		],
		[
			-4,
			9
		]
	],
	[
		[
			5366,
			4846
		],
		[
			-9,
			2
		],
		[
			-4,
			-10
		],
		[
			-7,
			-3
		],
		[
			-7,
			16
		]
	],
	[
		[
			5363,
			4916
		],
		[
			8,
			-9
		],
		[
			0,
			-6
		],
		[
			8,
			11
		],
		[
			1,
			14
		],
		[
			7,
			-2
		],
		[
			12,
			12
		],
		[
			2,
			-8
		],
		[
			-3,
			-7
		],
		[
			1,
			-20
		],
		[
			9,
			0
		],
		[
			4,
			6
		],
		[
			10,
			27
		],
		[
			8,
			8
		],
		[
			1,
			8
		],
		[
			9,
			4
		],
		[
			10,
			35
		],
		[
			-1,
			29
		],
		[
			1,
			13
		],
		[
			-1,
			26
		],
		[
			12,
			25
		],
		[
			0,
			7
		],
		[
			11,
			30
		],
		[
			8,
			5
		],
		[
			12,
			27
		],
		[
			0,
			21
		],
		[
			3,
			25
		],
		[
			3,
			7
		],
		[
			-2,
			14
		],
		[
			1,
			28
		],
		[
			5,
			27
		],
		[
			-1,
			34
		],
		[
			16,
			57
		],
		[
			0,
			19
		]
	],
	[
		[
			5333,
			4894
		],
		[
			-5,
			13
		],
		[
			0,
			10
		],
		[
			-15,
			33
		],
		[
			-5,
			6
		]
	],
	[
		[
			5308,
			4956
		],
		[
			2,
			12
		],
		[
			8,
			13
		],
		[
			5,
			-10
		],
		[
			5,
			-2
		],
		[
			4,
			22
		],
		[
			-8,
			9
		],
		[
			3,
			10
		],
		[
			-7,
			12
		],
		[
			2,
			7
		],
		[
			-1,
			20
		],
		[
			4,
			-5
		],
		[
			6,
			5
		],
		[
			4,
			-5
		],
		[
			11,
			5
		],
		[
			-1,
			24
		],
		[
			5,
			5
		],
		[
			5,
			-5
		],
		[
			5,
			-26
		],
		[
			11,
			-4
		],
		[
			9,
			13
		],
		[
			1,
			6
		],
		[
			9,
			-22
		],
		[
			5,
			9
		],
		[
			0,
			20
		],
		[
			5,
			5
		],
		[
			1,
			41
		],
		[
			-2,
			10
		],
		[
			3,
			23
		],
		[
			-9,
			9
		],
		[
			-3,
			11
		],
		[
			-5,
			0
		],
		[
			0,
			27
		],
		[
			5,
			19
		],
		[
			5,
			0
		],
		[
			6,
			16
		],
		[
			-5,
			18
		],
		[
			0,
			11
		],
		[
			-14,
			6
		],
		[
			-7,
			-9
		],
		[
			-7,
			-3
		],
		[
			-4,
			22
		],
		[
			2,
			23
		],
		[
			3,
			9
		]
	],
	[
		[
			3018,
			5865
		],
		[
			-19,
			-13
		],
		[
			-7,
			-27
		],
		[
			-6,
			-1
		],
		[
			-7,
			-26
		],
		[
			-5,
			-13
		],
		[
			-2,
			-37
		],
		[
			-11,
			-37
		],
		[
			11,
			7
		],
		[
			1,
			-11
		],
		[
			4,
			2
		],
		[
			4,
			-28
		],
		[
			8,
			-16
		],
		[
			1,
			-19
		],
		[
			-4,
			-7
		],
		[
			1,
			-28
		],
		[
			7,
			-3
		],
		[
			3,
			-18
		],
		[
			7,
			-5
		],
		[
			5,
			4
		],
		[
			18,
			-4
		],
		[
			9,
			7
		],
		[
			10,
			-10
		],
		[
			7,
			-1
		],
		[
			18,
			-46
		],
		[
			5,
			-2
		],
		[
			7,
			8
		],
		[
			11,
			-5
		],
		[
			29,
			8
		],
		[
			4,
			-18
		],
		[
			-6,
			-10
		],
		[
			0,
			-17
		],
		[
			-5,
			-6
		],
		[
			0,
			-66
		],
		[
			5,
			-28
		],
		[
			4,
			-2
		],
		[
			5,
			-17
		],
		[
			-15,
			-35
		],
		[
			7,
			-6
		],
		[
			11,
			-18
		],
		[
			0,
			-12
		],
		[
			4,
			-17
		],
		[
			5,
			-39
		]
	],
	[
		[
			3056,
			4939
		],
		[
			-8,
			22
		],
		[
			-6,
			-2
		],
		[
			-7,
			6
		],
		[
			18,
			59
		],
		[
			0,
			7
		],
		[
			-26,
			25
		],
		[
			-10,
			-10
		],
		[
			-2,
			7
		],
		[
			-8,
			7
		],
		[
			-6,
			-11
		],
		[
			-10,
			-7
		],
		[
			-8,
			6
		],
		[
			-9,
			-5
		],
		[
			-7,
			8
		],
		[
			2,
			12
		],
		[
			-2,
			17
		],
		[
			-10,
			6
		],
		[
			1,
			12
		],
		[
			-4,
			13
		],
		[
			-7,
			3
		],
		[
			-5,
			10
		],
		[
			-5,
			2
		],
		[
			-4,
			26
		],
		[
			-6,
			11
		],
		[
			-5,
			2
		],
		[
			-8,
			14
		],
		[
			-5,
			-2
		]
	],
	[
		[
			2909,
			5177
		],
		[
			-11,
			11
		],
		[
			-3,
			-1
		],
		[
			-7,
			15
		],
		[
			-8,
			7
		],
		[
			-3,
			-12
		],
		[
			-9,
			-1
		],
		[
			-19,
			10
		],
		[
			-1,
			14
		],
		[
			-7,
			11
		],
		[
			-11,
			5
		],
		[
			-13,
			16
		],
		[
			-7,
			13
		]
	],
	[
		[
			2810,
			5265
		],
		[
			-5,
			10
		],
		[
			5,
			13
		],
		[
			7,
			-2
		],
		[
			-3,
			14
		],
		[
			0,
			13
		],
		[
			7,
			19
		],
		[
			10,
			-5
		],
		[
			0,
			9
		],
		[
			9,
			-4
		],
		[
			1,
			22
		],
		[
			12,
			29
		],
		[
			0,
			6
		],
		[
			7,
			20
		],
		[
			-6,
			-5
		],
		[
			-4,
			5
		],
		[
			-1,
			15
		],
		[
			3,
			16
		],
		[
			-2,
			57
		],
		[
			-5,
			2
		],
		[
			9,
			12
		],
		[
			0,
			7
		],
		[
			-7,
			20
		],
		[
			3,
			5
		],
		[
			1,
			19
		],
		[
			-5,
			6
		],
		[
			-3,
			17
		],
		[
			-7,
			14
		]
	],
	[
		[
			2836,
			5599
		],
		[
			2,
			14
		],
		[
			13,
			12
		],
		[
			1,
			13
		],
		[
			4,
			2
		],
		[
			-6,
			28
		],
		[
			-3,
			3
		],
		[
			3,
			11
		]
	],
	[
		[
			2850,
			5682
		],
		[
			12,
			-31
		],
		[
			1,
			-12
		],
		[
			5,
			0
		],
		[
			-1,
			29
		],
		[
			-4,
			10
		],
		[
			7,
			5
		],
		[
			10,
			15
		],
		[
			6,
			23
		],
		[
			12,
			4
		],
		[
			2,
			15
		],
		[
			-3,
			1
		],
		[
			3,
			13
		],
		[
			-1,
			20
		],
		[
			3,
			2
		],
		[
			0,
			16
		],
		[
			8,
			14
		],
		[
			11,
			14
		],
		[
			9,
			-5
		],
		[
			-3,
			-8
		],
		[
			7,
			-4
		],
		[
			4,
			18
		],
		[
			1,
			14
		],
		[
			10,
			-3
		],
		[
			15,
			1
		],
		[
			6,
			12
		],
		[
			10,
			13
		],
		[
			13,
			10
		],
		[
			3,
			11
		],
		[
			-1,
			9
		],
		[
			6,
			1
		],
		[
			12,
			10
		],
		[
			8,
			-6
		],
		[
			3,
			-18
		],
		[
			-6,
			-10
		]
	],
	[
		[
			6235,
			4487
		],
		[
			1,
			-17
		],
		[
			-4,
			8
		],
		[
			3,
			9
		]
	],
	[
		[
			6207,
			4496
		],
		[
			-7,
			9
		],
		[
			1,
			21
		],
		[
			4,
			1
		],
		[
			-1,
			-12
		],
		[
			3,
			-19
		]
	],
	[
		[
			4324,
			6037
		],
		[
			-5,
			9
		],
		[
			5,
			2
		],
		[
			0,
			-11
		]
	],
	[
		[
			4340,
			6065
		],
		[
			8,
			-16
		],
		[
			-5,
			-7
		],
		[
			-4,
			7
		],
		[
			1,
			16
		]
	],
	[
		[
			4365,
			6116
		],
		[
			5,
			-8
		],
		[
			-8,
			-3
		],
		[
			3,
			11
		]
	],
	[
		[
			4303,
			6173
		],
		[
			3,
			-6
		],
		[
			-7,
			-10
		],
		[
			-3,
			11
		],
		[
			7,
			5
		]
	],
	[
		[
			2676,
			5812
		],
		[
			7,
			-32
		],
		[
			16,
			-36
		],
		[
			7,
			-10
		]
	],
	[
		[
			2706,
			5734
		],
		[
			-3,
			-5
		],
		[
			-5,
			7
		],
		[
			-2,
			-8
		],
		[
			0,
			-23
		],
		[
			6,
			-10
		],
		[
			-5,
			-4
		],
		[
			2,
			-19
		],
		[
			-6,
			-11
		],
		[
			4,
			-16
		]
	],
	[
		[
			2697,
			5645
		],
		[
			-2,
			11
		],
		[
			-5,
			9
		],
		[
			0,
			15
		],
		[
			-9,
			5
		],
		[
			5,
			-10
		],
		[
			0,
			-10
		],
		[
			-12,
			12
		],
		[
			3,
			27
		],
		[
			-8,
			14
		],
		[
			-10,
			11
		],
		[
			-11,
			8
		],
		[
			1,
			10
		],
		[
			-12,
			21
		],
		[
			-4,
			-7
		],
		[
			9,
			-12
		],
		[
			-6,
			-16
		],
		[
			-6,
			15
		],
		[
			-10,
			5
		],
		[
			-5,
			19
		],
		[
			1,
			16
		],
		[
			3,
			2
		],
		[
			1,
			15
		],
		[
			-8,
			5
		],
		[
			7,
			2
		],
		[
			0,
			9
		]
	],
	[
		[
			2619,
			5821
		],
		[
			2,
			7
		],
		[
			21,
			-15
		],
		[
			5,
			7
		],
		[
			13,
			-10
		],
		[
			0,
			-5
		],
		[
			8,
			-5
		],
		[
			8,
			5
		],
		[
			0,
			7
		]
	],
	[
		[
			2698,
			6446
		],
		[
			5,
			-3
		],
		[
			4,
			-17
		],
		[
			-10,
			-9
		],
		[
			-8,
			8
		],
		[
			7,
			1
		],
		[
			-4,
			15
		],
		[
			6,
			5
		]
	],
	[
		[
			2836,
			6454
		],
		[
			6,
			-1
		],
		[
			-1,
			-7
		],
		[
			-5,
			8
		]
	],
	[
		[
			2823,
			6481
		],
		[
			-2,
			-7
		],
		[
			-7,
			5
		],
		[
			9,
			2
		]
	],
	[
		[
			2914,
			6329
		],
		[
			-1,
			4
		]
	],
	[
		[
			2913,
			6333
		],
		[
			-1,
			0
		]
	],
	[
		[
			2912,
			6333
		],
		[
			-2,
			-4
		]
	],
	[
		[
			2910,
			6329
		],
		[
			-10,
			-1
		],
		[
			-15,
			6
		],
		[
			-21,
			-3
		],
		[
			-2,
			-3
		],
		[
			-21,
			-3
		],
		[
			6,
			17
		],
		[
			9,
			10
		],
		[
			3,
			9
		],
		[
			-8,
			15
		],
		[
			-19,
			-1
		],
		[
			-13,
			20
		],
		[
			-1,
			18
		],
		[
			-6,
			16
		],
		[
			-14,
			-5
		],
		[
			-10,
			8
		],
		[
			-8,
			0
		],
		[
			-10,
			11
		],
		[
			-5,
			10
		],
		[
			-13,
			-1
		],
		[
			-13,
			8
		],
		[
			-13,
			4
		],
		[
			-7,
			11
		],
		[
			12,
			1
		],
		[
			1,
			7
		],
		[
			-7,
			6
		],
		[
			-25,
			1
		],
		[
			-10,
			-21
		],
		[
			-7,
			-9
		],
		[
			-15,
			0
		],
		[
			-2,
			-15
		],
		[
			-3,
			2
		],
		[
			-11,
			-11
		],
		[
			1,
			10
		],
		[
			-11,
			-3
		],
		[
			10,
			9
		],
		[
			5,
			0
		],
		[
			-2,
			15
		],
		[
			3,
			11
		],
		[
			12,
			15
		],
		[
			14,
			8
		],
		[
			3,
			6
		],
		[
			19,
			3
		],
		[
			9,
			8
		],
		[
			27,
			-2
		],
		[
			3,
			-6
		],
		[
			15,
			2
		],
		[
			6,
			-8
		],
		[
			10,
			1
		],
		[
			11,
			-12
		],
		[
			9,
			-20
		],
		[
			15,
			-1
		],
		[
			13,
			-13
		],
		[
			5,
			-1
		],
		[
			7,
			-16
		],
		[
			12,
			-5
		],
		[
			-3,
			9
		],
		[
			12,
			-16
		],
		[
			5,
			-11
		],
		[
			23,
			-17
		],
		[
			0,
			-5
		],
		[
			12,
			2
		],
		[
			3,
			-6
		],
		[
			-5,
			-10
		],
		[
			2,
			-9
		],
		[
			20,
			1
		],
		[
			7,
			-5
		],
		[
			9,
			-19
		],
		[
			5,
			2
		],
		[
			2,
			-9
		],
		[
			-3,
			-6
		],
		[
			-13,
			0
		],
		[
			-10,
			-9
		]
	],
	[
		[
			3089,
			5876
		],
		[
			-11,
			16
		],
		[
			3,
			2
		],
		[
			8,
			-18
		]
	],
	[
		[
			5905,
			7209
		],
		[
			1,
			0
		]
	],
	[
		[
			5941,
			7202
		],
		[
			-6,
			-2
		]
	],
	[
		[
			5908,
			7209
		],
		[
			6,
			1
		],
		[
			0,
			11
		],
		[
			14,
			-4
		],
		[
			17,
			8
		],
		[
			15,
			13
		],
		[
			0,
			-3
		],
		[
			-19,
			-22
		],
		[
			3,
			-11
		]
	],
	[
		[
			5938,
			7197
		],
		[
			0,
			0
		]
	],
	[
		[
			5938,
			7197
		],
		[
			0,
			0
		]
	],
	[
		[
			5937,
			7198
		],
		[
			0,
			0
		]
	],
	[
		[
			5944,
			7202
		],
		[
			-3,
			-6
		]
	],
	[
		[
			5941,
			7196
		],
		[
			0,
			6
		]
	],
	[
		[
			5936,
			7198
		],
		[
			0,
			-1
		]
	],
	[
		[
			5936,
			7197
		],
		[
			-3,
			-9
		],
		[
			-16,
			-11
		]
	],
	[
		[
			5917,
			7177
		],
		[
			-8,
			1
		]
	],
	[
		[
			5909,
			7178
		],
		[
			-7,
			3
		],
		[
			-5,
			11
		],
		[
			1,
			9
		],
		[
			7,
			7
		]
	],
	[
		[
			5907,
			7209
		],
		[
			1,
			0
		]
	],
	[
		[
			5411,
			8112
		],
		[
			4,
			8
		],
		[
			9,
			-9
		],
		[
			14,
			-7
		],
		[
			6,
			-6
		],
		[
			12,
			-3
		],
		[
			-7,
			-8
		],
		[
			13,
			-20
		],
		[
			10,
			7
		],
		[
			-4,
			12
		],
		[
			9,
			-2
		],
		[
			19,
			-24
		],
		[
			4,
			4
		],
		[
			7,
			-7
		],
		[
			8,
			0
		],
		[
			8,
			-23
		]
	],
	[
		[
			5523,
			8034
		],
		[
			-8,
			-1
		],
		[
			-12,
			-15
		],
		[
			-1,
			-11
		],
		[
			-15,
			-14
		],
		[
			-9,
			4
		],
		[
			-8,
			-15
		]
	],
	[
		[
			5383,
			7990
		],
		[
			-10,
			11
		],
		[
			-13,
			20
		],
		[
			-10,
			9
		],
		[
			-7,
			17
		],
		[
			3,
			13
		],
		[
			-5,
			11
		],
		[
			6,
			13
		],
		[
			26,
			11
		],
		[
			3,
			8
		],
		[
			9,
			1
		],
		[
			13,
			9
		],
		[
			-2,
			8
		],
		[
			15,
			-9
		]
	],
	[
		[
			5255,
			7927
		],
		[
			0,
			0
		]
	],
	[
		[
			5394,
			8289
		],
		[
			0,
			-4
		]
	],
	[
		[
			5394,
			8285
		],
		[
			0,
			4
		]
	],
	[
		[
			5371,
			8330
		],
		[
			6,
			-3
		],
		[
			4,
			-14
		],
		[
			-11,
			-5
		],
		[
			-6,
			4
		],
		[
			1,
			12
		],
		[
			6,
			6
		]
	],
	[
		[
			5262,
			8339
		],
		[
			4,
			3
		],
		[
			12,
			-11
		],
		[
			5,
			-15
		],
		[
			13,
			-5
		],
		[
			11,
			2
		],
		[
			1,
			-9
		],
		[
			-10,
			-8
		],
		[
			12,
			-2
		],
		[
			8,
			-7
		],
		[
			5,
			14
		],
		[
			11,
			2
		],
		[
			14,
			11
		],
		[
			13,
			4
		],
		[
			3,
			-10
		],
		[
			10,
			-8
		],
		[
			6,
			2
		],
		[
			3,
			-17
		],
		[
			13,
			-10
		]
	],
	[
		[
			5396,
			8275
		],
		[
			3,
			-23
		],
		[
			-5,
			-27
		],
		[
			12,
			-14
		],
		[
			-3,
			-9
		],
		[
			7,
			-21
		],
		[
			-4,
			-20
		],
		[
			2,
			-11
		],
		[
			7,
			-4
		],
		[
			2,
			-14
		],
		[
			-6,
			-20
		]
	],
	[
		[
			5269,
			7921
		],
		[
			-15,
			12
		],
		[
			1,
			-6
		]
	],
	[
		[
			5210,
			7923
		],
		[
			-2,
			4
		],
		[
			8,
			55
		],
		[
			9,
			11
		],
		[
			2,
			10
		],
		[
			-16,
			4
		],
		[
			-4,
			7
		],
		[
			-18,
			-1
		],
		[
			-13,
			17
		]
	],
	[
		[
			5176,
			8030
		],
		[
			4,
			20
		],
		[
			-6,
			3
		],
		[
			-5,
			16
		]
	],
	[
		[
			5166,
			8104
		],
		[
			-3,
			14
		],
		[
			9,
			22
		],
		[
			0,
			9
		],
		[
			-8,
			12
		],
		[
			5,
			10
		],
		[
			8,
			-4
		],
		[
			10,
			5
		],
		[
			8,
			28
		],
		[
			-10,
			5
		],
		[
			2,
			9
		],
		[
			8,
			1
		],
		[
			4,
			18
		],
		[
			0,
			16
		]
	],
	[
		[
			5199,
			8249
		],
		[
			-3,
			19
		],
		[
			6,
			6
		],
		[
			21,
			2
		],
		[
			6,
			-18
		],
		[
			0,
			12
		],
		[
			8,
			-4
		],
		[
			2,
			20
		],
		[
			9,
			1
		],
		[
			-8,
			29
		],
		[
			10,
			6
		],
		[
			-9,
			13
		],
		[
			-1,
			9
		]
	],
	[
		[
			5240,
			8344
		],
		[
			22,
			-5
		]
	],
	[
		[
			6201,
			5844
		],
		[
			-9,
			-28
		]
	],
	[
		[
			6192,
			5816
		],
		[
			-6,
			4
		],
		[
			-22,
			-7
		],
		[
			-4,
			8
		]
	],
	[
		[
			6160,
			5821
		],
		[
			0,
			12
		]
	],
	[
		[
			6160,
			5833
		],
		[
			0,
			24
		],
		[
			10,
			22
		],
		[
			7,
			22
		]
	],
	[
		[
			6177,
			5901
		],
		[
			8,
			-6
		],
		[
			3,
			9
		],
		[
			9,
			11
		]
	],
	[
		[
			6197,
			5915
		],
		[
			6,
			-14
		],
		[
			2,
			-25
		],
		[
			-10,
			-14
		],
		[
			-7,
			-3
		],
		[
			-3,
			-11
		],
		[
			13,
			3
		],
		[
			3,
			-7
		]
	],
	[
		[
			3294,
			6081
		],
		[
			4,
			-5
		],
		[
			0,
			-15
		],
		[
			-3,
			-3
		],
		[
			-3,
			16
		],
		[
			2,
			7
		]
	],
	[
		[
			5312,
			8347
		],
		[
			17,
			-10
		],
		[
			-1,
			-7
		],
		[
			-10,
			-1
		],
		[
			-8,
			6
		],
		[
			2,
			12
		]
	],
	[
		[
			5348,
			8350
		],
		[
			-12,
			-5
		],
		[
			4,
			7
		],
		[
			8,
			-2
		]
	],
	[
		[
			5272,
			8355
		],
		[
			7,
			-12
		],
		[
			-8,
			2
		],
		[
			1,
			10
		]
	],
	[
		[
			5413,
			8363
		],
		[
			6,
			-13
		],
		[
			-9,
			3
		],
		[
			3,
			10
		]
	],
	[
		[
			5287,
			8385
		],
		[
			7,
			0
		],
		[
			6,
			-15
		],
		[
			-2,
			-16
		],
		[
			-19,
			1
		],
		[
			-11,
			24
		],
		[
			19,
			6
		]
	],
	[
		[
			5342,
			8415
		],
		[
			7,
			-3
		],
		[
			0,
			-22
		],
		[
			-11,
			-12
		],
		[
			8,
			-11
		],
		[
			-13,
			-8
		],
		[
			5,
			-3
		],
		[
			-8,
			-10
		],
		[
			8,
			-5
		],
		[
			-9,
			-11
		],
		[
			-4,
			32
		],
		[
			-13,
			0
		],
		[
			-2,
			28
		],
		[
			13,
			12
		],
		[
			5,
			-13
		],
		[
			14,
			26
		]
	],
	[
		[
			5247,
			8463
		],
		[
			-2,
			-13
		],
		[
			-9,
			0
		],
		[
			11,
			13
		]
	],
	[
		[
			5240,
			8344
		],
		[
			-2,
			32
		],
		[
			-14,
			7
		],
		[
			3,
			14
		],
		[
			6,
			5
		],
		[
			-4,
			11
		],
		[
			-4,
			-6
		],
		[
			0,
			34
		],
		[
			16,
			1
		],
		[
			7,
			12
		],
		[
			9,
			-10
		],
		[
			-3,
			15
		],
		[
			18,
			12
		],
		[
			-32,
			-9
		],
		[
			-5,
			-13
		],
		[
			-7,
			3
		],
		[
			11,
			20
		],
		[
			17,
			1
		],
		[
			9,
			6
		],
		[
			10,
			19
		],
		[
			20,
			10
		],
		[
			-6,
			-10
		],
		[
			3,
			-20
		],
		[
			-7,
			-15
		],
		[
			2,
			-23
		],
		[
			12,
			-1
		],
		[
			5,
			-6
		],
		[
			-6,
			-16
		],
		[
			-11,
			2
		],
		[
			-4,
			-20
		],
		[
			-20,
			-21
		],
		[
			6,
			-16
		],
		[
			-7,
			-5
		],
		[
			8,
			-8
		],
		[
			-8,
			-10
		]
	],
	[
		[
			3006,
			6222
		],
		[
			2,
			16
		],
		[
			-6,
			10
		]
	],
	[
		[
			3002,
			6248
		],
		[
			0,
			0
		]
	],
	[
		[
			3002,
			6248
		],
		[
			-1,
			2
		]
	],
	[
		[
			3001,
			6250
		],
		[
			-1,
			4
		]
	],
	[
		[
			3000,
			6254
		],
		[
			8,
			11
		],
		[
			-2,
			9
		],
		[
			4,
			12
		],
		[
			-4,
			32
		]
	],
	[
		[
			3006,
			6318
		],
		[
			3,
			11
		],
		[
			14,
			-4
		],
		[
			4,
			6
		],
		[
			11,
			-10
		],
		[
			5,
			1
		],
		[
			4,
			-8
		],
		[
			11,
			0
		],
		[
			4,
			-20
		],
		[
			6,
			2
		],
		[
			11,
			-3
		],
		[
			-2,
			-5
		],
		[
			-11,
			2
		],
		[
			0,
			-8
		],
		[
			24,
			-7
		],
		[
			12,
			-20
		],
		[
			-9,
			-23
		],
		[
			-8,
			11
		],
		[
			-17,
			0
		],
		[
			-9,
			4
		],
		[
			-8,
			-14
		],
		[
			-9,
			-2
		],
		[
			-3,
			12
		],
		[
			-9,
			-8
		],
		[
			-5,
			2
		],
		[
			1,
			-9
		],
		[
			-10,
			-31
		],
		[
			-6,
			8
		],
		[
			-4,
			17
		]
	],
	[
		[
			5238,
			7310
		],
		[
			2,
			-6
		],
		[
			-7,
			-4
		],
		[
			1,
			-6
		],
		[
			-8,
			-8
		],
		[
			6,
			-5
		],
		[
			-4,
			-35
		],
		[
			3,
			-10
		],
		[
			-1,
			-19
		],
		[
			4,
			-5
		],
		[
			-4,
			-8
		],
		[
			-3,
			-30
		],
		[
			-11,
			-11
		],
		[
			-1,
			-9
		],
		[
			-7,
			-8
		],
		[
			-1,
			-14
		],
		[
			7,
			-25
		],
		[
			0,
			-11
		],
		[
			10,
			-7
		],
		[
			6,
			-15
		],
		[
			2,
			-20
		],
		[
			19,
			-24
		],
		[
			7,
			-62
		],
		[
			6,
			-44
		]
	],
	[
		[
			5264,
			6924
		],
		[
			-7,
			-7
		],
		[
			11,
			-29
		],
		[
			5,
			-37
		],
		[
			-2,
			-44
		],
		[
			4,
			-19
		],
		[
			-5,
			-34
		],
		[
			2,
			-21
		],
		[
			3,
			-4
		],
		[
			-2,
			-20
		],
		[
			-10,
			-9
		],
		[
			-3,
			-10
		],
		[
			18,
			-52
		],
		[
			0,
			-25
		],
		[
			5,
			-5
		],
		[
			1,
			-10
		],
		[
			6,
			-6
		],
		[
			7,
			5
		],
		[
			21,
			-13
		],
		[
			3,
			-4
		],
		[
			11,
			-43
		]
	],
	[
		[
			5332,
			6537
		],
		[
			-28,
			-35
		],
		[
			-99,
			-122
		],
		[
			-24,
			-40
		],
		[
			-17,
			-32
		],
		[
			-8,
			-8
		],
		[
			-39,
			-15
		]
	],
	[
		[
			5117,
			6285
		],
		[
			-26,
			-9
		],
		[
			-5,
			7
		],
		[
			4,
			15
		],
		[
			-2,
			11
		],
		[
			1,
			14
		],
		[
			-8,
			8
		],
		[
			-12,
			4
		],
		[
			-9,
			16
		],
		[
			-2,
			-4
		],
		[
			-9,
			5
		],
		[
			-4,
			14
		],
		[
			-14,
			12
		],
		[
			1,
			19
		],
		[
			-14,
			18
		],
		[
			-28,
			40
		],
		[
			-8,
			9
		],
		[
			-36,
			49
		],
		[
			-21,
			30
		],
		[
			-8,
			9
		],
		[
			-51,
			70
		]
	],
	[
		[
			4866,
			6622
		],
		[
			-64,
			78
		],
		[
			-16,
			21
		],
		[
			-28,
			33
		]
	],
	[
		[
			4758,
			6754
		],
		[
			0,
			22
		]
	],
	[
		[
			4758,
			6776
		],
		[
			0,
			59
		],
		[
			12,
			18
		],
		[
			18,
			22
		],
		[
			7,
			0
		],
		[
			8,
			8
		],
		[
			10,
			0
		],
		[
			27,
			5
		],
		[
			6,
			-5
		],
		[
			7,
			21
		],
		[
			11,
			17
		],
		[
			11,
			11
		],
		[
			6,
			11
		],
		[
			17,
			8
		],
		[
			3,
			14
		],
		[
			-8,
			21
		],
		[
			4,
			4
		],
		[
			1,
			15
		],
		[
			23,
			9
		],
		[
			-3,
			14
		],
		[
			12,
			5
		],
		[
			35,
			-3
		],
		[
			0,
			17
		],
		[
			6,
			7
		],
		[
			-11,
			14
		],
		[
			-4,
			11
		],
		[
			2,
			8
		],
		[
			-5,
			10
		],
		[
			2,
			18
		],
		[
			-4,
			8
		],
		[
			2,
			24
		],
		[
			-4,
			15
		],
		[
			3,
			6
		],
		[
			-4,
			7
		],
		[
			2,
			9
		],
		[
			-12,
			19
		]
	],
	[
		[
			4938,
			7203
		],
		[
			8,
			0
		],
		[
			18,
			16
		],
		[
			2,
			12
		],
		[
			11,
			12
		],
		[
			8,
			0
		],
		[
			1,
			7
		],
		[
			6,
			-5
		],
		[
			8,
			2
		],
		[
			5,
			15
		],
		[
			24,
			22
		],
		[
			25,
			4
		],
		[
			10,
			4
		],
		[
			8,
			-2
		],
		[
			11,
			13
		],
		[
			3,
			-4
		],
		[
			12,
			2
		],
		[
			9,
			8
		],
		[
			21,
			-1
		],
		[
			13,
			-7
		],
		[
			8,
			-8
		],
		[
			10,
			11
		],
		[
			14,
			5
		],
		[
			6,
			10
		],
		[
			12,
			-12
		],
		[
			8,
			2
		],
		[
			0,
			9
		],
		[
			9,
			-1
		],
		[
			7,
			-10
		],
		[
			13,
			4
		],
		[
			10,
			-1
		]
	],
	[
		[
			2774,
			5010
		],
		[
			-4,
			-1
		],
		[
			0,
			11
		],
		[
			5,
			9
		],
		[
			5,
			-3
		],
		[
			-6,
			-16
		]
	],
	[
		[
			2519,
			5143
		],
		[
			-4,
			-14
		],
		[
			-5,
			0
		],
		[
			9,
			14
		]
	],
	[
		[
			2493,
			5154
		],
		[
			0,
			-14
		],
		[
			-8,
			2
		],
		[
			1,
			11
		],
		[
			7,
			1
		]
	],
	[
		[
			2459,
			5168
		],
		[
			2,
			-12
		],
		[
			-7,
			2
		],
		[
			-1,
			8
		],
		[
			6,
			2
		]
	],
	[
		[
			2478,
			5174
		],
		[
			6,
			-6
		],
		[
			-5,
			-6
		],
		[
			-4,
			5
		],
		[
			3,
			7
		]
	],
	[
		[
			2463,
			5192
		],
		[
			4,
			-22
		],
		[
			6,
			-11
		],
		[
			-1,
			-9
		],
		[
			6,
			-10
		],
		[
			-4,
			-13
		],
		[
			-13,
			-3
		],
		[
			-3,
			10
		],
		[
			12,
			14
		],
		[
			-9,
			21
		],
		[
			-3,
			18
		],
		[
			5,
			5
		]
	],
	[
		[
			2909,
			5177
		],
		[
			-10,
			0
		],
		[
			6,
			-20
		],
		[
			4,
			-4
		],
		[
			-1,
			-13
		],
		[
			2,
			-13
		],
		[
			-5,
			0
		],
		[
			-4,
			-27
		],
		[
			-15,
			-40
		],
		[
			-16,
			-25
		],
		[
			-33,
			-24
		],
		[
			-9,
			-21
		],
		[
			1,
			-7
		],
		[
			-6,
			5
		],
		[
			-1,
			-22
		],
		[
			-8,
			-31
		],
		[
			-1,
			-17
		],
		[
			-4,
			-3
		],
		[
			-1,
			-12
		],
		[
			-4,
			-7
		],
		[
			-8,
			2
		],
		[
			-5,
			16
		],
		[
			0,
			9
		],
		[
			-8,
			2
		],
		[
			-9,
			11
		],
		[
			-8,
			-11
		],
		[
			-2,
			5
		],
		[
			4,
			10
		],
		[
			-5,
			9
		],
		[
			10,
			10
		],
		[
			-2,
			22
		],
		[
			-3,
			6
		]
	],
	[
		[
			2768,
			4987
		],
		[
			11,
			12
		],
		[
			6,
			40
		],
		[
			-3,
			5
		],
		[
			-4,
			-11
		],
		[
			-1,
			15
		],
		[
			-7,
			-22
		],
		[
			-11,
			18
		],
		[
			-7,
			5
		],
		[
			5,
			13
		],
		[
			-1,
			22
		],
		[
			-2,
			5
		],
		[
			2,
			15
		],
		[
			-4,
			19
		],
		[
			10,
			7
		],
		[
			3,
			21
		],
		[
			-1,
			11
		],
		[
			12,
			24
		],
		[
			1,
			31
		],
		[
			-2,
			13
		],
		[
			12,
			11
		],
		[
			19,
			9
		],
		[
			4,
			15
		]
	],
	[
		[
			5949,
			6986
		],
		[
			2,
			-6
		]
	],
	[
		[
			5951,
			6980
		],
		[
			17,
			-99
		]
	],
	[
		[
			5968,
			6881
		],
		[
			-4,
			-12
		],
		[
			-3,
			-33
		],
		[
			-5,
			-16
		],
		[
			0,
			-26
		],
		[
			-5,
			-14
		],
		[
			-13,
			15
		],
		[
			-6,
			17
		],
		[
			-10,
			16
		],
		[
			-1,
			26
		],
		[
			-8,
			12
		],
		[
			-5,
			14
		],
		[
			-2,
			23
		],
		[
			-4,
			-1
		],
		[
			-4,
			-16
		],
		[
			6,
			-10
		],
		[
			3,
			-16
		],
		[
			0,
			-14
		],
		[
			4,
			-6
		],
		[
			14,
			-42
		],
		[
			5,
			-5
		],
		[
			5,
			-36
		],
		[
			4,
			-4
		],
		[
			5,
			-25
		],
		[
			0,
			-11
		],
		[
			11,
			-43
		],
		[
			15,
			-51
		],
		[
			8,
			-35
		],
		[
			15,
			-29
		],
		[
			-8,
			3
		],
		[
			2,
			-41
		],
		[
			3,
			-16
		],
		[
			6,
			-13
		],
		[
			10,
			-6
		],
		[
			2,
			-8
		],
		[
			16,
			-29
		]
	],
	[
		[
			6024,
			6449
		],
		[
			-78,
			0
		],
		[
			-73,
			0
		],
		[
			0,
			14
		],
		[
			-6,
			-14
		],
		[
			-57,
			0
		],
		[
			-71,
			0
		],
		[
			-46,
			0
		]
	],
	[
		[
			5693,
			6449
		],
		[
			0,
			421
		],
		[
			-3,
			10
		],
		[
			-1,
			24
		],
		[
			-4,
			13
		],
		[
			6,
			20
		],
		[
			3,
			17
		],
		[
			-4,
			22
		],
		[
			0,
			14
		],
		[
			8,
			16
		]
	],
	[
		[
			5698,
			7006
		],
		[
			1,
			-7
		],
		[
			7,
			-2
		],
		[
			12,
			7
		],
		[
			14,
			-6
		],
		[
			27,
			-8
		],
		[
			1,
			-7
		],
		[
			8,
			-5
		],
		[
			5,
			4
		],
		[
			4,
			-9
		],
		[
			21,
			-6
		],
		[
			8,
			-9
		],
		[
			13,
			7
		],
		[
			16,
			22
		],
		[
			4,
			-4
		],
		[
			4,
			14
		],
		[
			3,
			-3
		],
		[
			11,
			6
		],
		[
			-9,
			-10
		],
		[
			9,
			2
		],
		[
			7,
			11
		],
		[
			13,
			-9
		],
		[
			8,
			5
		],
		[
			-3,
			-15
		],
		[
			7,
			-4
		],
		[
			1,
			-7
		],
		[
			6,
			2
		],
		[
			0,
			9
		],
		[
			6,
			-10
		],
		[
			7,
			-4
		],
		[
			31,
			7
		],
		[
			9,
			9
		]
	],
	[
		[
			6111,
			6097
		],
		[
			3,
			-11
		],
		[
			8,
			-6
		],
		[
			-12,
			2
		],
		[
			-2,
			8
		],
		[
			3,
			7
		]
	],
	[
		[
			6177,
			5901
		],
		[
			-6,
			15
		],
		[
			-8,
			12
		],
		[
			-5,
			18
		],
		[
			-14,
			19
		],
		[
			-7,
			23
		],
		[
			-5,
			10
		],
		[
			-10,
			7
		],
		[
			-5,
			9
		],
		[
			-9,
			-1
		],
		[
			-10,
			9
		],
		[
			-10,
			-6
		],
		[
			-5,
			10
		],
		[
			-3,
			-8
		],
		[
			-13,
			-5
		],
		[
			-6,
			16
		],
		[
			-3,
			-1
		],
		[
			-6,
			12
		],
		[
			-9,
			-45
		],
		[
			-6,
			19
		],
		[
			-5,
			1
		],
		[
			-2,
			-8
		],
		[
			-10,
			1
		],
		[
			-6,
			-4
		]
	],
	[
		[
			6014,
			6004
		],
		[
			-3,
			51
		],
		[
			6,
			17
		],
		[
			1,
			18
		],
		[
			3,
			5
		],
		[
			5,
			24
		],
		[
			-2,
			23
		],
		[
			3,
			6
		],
		[
			-1,
			17
		],
		[
			12,
			-2
		],
		[
			3,
			17
		],
		[
			21,
			13
		],
		[
			5,
			18
		],
		[
			5,
			9
		]
	],
	[
		[
			6072,
			6220
		],
		[
			9,
			-35
		],
		[
			0,
			-9
		],
		[
			6,
			-31
		],
		[
			1,
			-24
		],
		[
			3,
			-23
		],
		[
			4,
			-4
		],
		[
			0,
			-17
		],
		[
			5,
			-2
		],
		[
			2,
			-22
		],
		[
			4,
			-1
		],
		[
			-2,
			18
		],
		[
			3,
			4
		],
		[
			6,
			-7
		],
		[
			0,
			-17
		],
		[
			6,
			-8
		],
		[
			3,
			5
		],
		[
			6,
			-3
		],
		[
			3,
			-12
		],
		[
			12,
			-6
		],
		[
			12,
			-31
		],
		[
			2,
			-9
		],
		[
			9,
			-6
		],
		[
			3,
			-12
		],
		[
			3,
			1
		],
		[
			4,
			-13
		],
		[
			1,
			-13
		],
		[
			4,
			2
		],
		[
			6,
			-13
		],
		[
			0,
			-8
		],
		[
			10,
			-9
		]
	],
	[
		[
			5941,
			7196
		],
		[
			-3,
			1
		]
	],
	[
		[
			5938,
			7197
		],
		[
			-2,
			0
		]
	],
	[
		[
			4503,
			6784
		],
		[
			-3,
			-9
		],
		[
			-5,
			3
		],
		[
			8,
			6
		]
	],
	[
		[
			4571,
			6803
		],
		[
			1,
			-17
		],
		[
			-5,
			-6
		],
		[
			-6,
			6
		],
		[
			2,
			19
		],
		[
			8,
			-2
		]
	],
	[
		[
			4552,
			6828
		],
		[
			-7,
			-11
		],
		[
			-2,
			-14
		],
		[
			-7,
			-8
		],
		[
			-6,
			21
		],
		[
			12,
			4
		],
		[
			4,
			8
		],
		[
			6,
			0
		]
	],
	[
		[
			4604,
			6803
		],
		[
			7,
			35
		],
		[
			5,
			-4
		],
		[
			-4,
			-26
		],
		[
			-8,
			-5
		]
	],
	[
		[
			4503,
			6844
		],
		[
			4,
			-7
		],
		[
			-3,
			-16
		],
		[
			-4,
			14
		],
		[
			3,
			9
		]
	],
	[
		[
			4626,
			6861
		],
		[
			0,
			-6
		],
		[
			-9,
			-10
		],
		[
			-1,
			11
		],
		[
			10,
			5
		]
	],
	[
		[
			4919,
			7214
		],
		[
			-1,
			3
		]
	],
	[
		[
			4918,
			7217
		],
		[
			1,
			-3
		]
	],
	[
		[
			4851,
			7247
		],
		[
			-1,
			5
		]
	],
	[
		[
			4850,
			7252
		],
		[
			1,
			-5
		]
	],
	[
		[
			5043,
			7435
		],
		[
			2,
			-6
		],
		[
			-6,
			-9
		],
		[
			-6,
			2
		],
		[
			10,
			13
		]
	],
	[
		[
			5088,
			7483
		],
		[
			0,
			-11
		],
		[
			8,
			0
		],
		[
			-7,
			-23
		],
		[
			-4,
			-6
		],
		[
			-8,
			7
		],
		[
			-3,
			10
		],
		[
			-9,
			0
		],
		[
			9,
			14
		],
		[
			14,
			9
		]
	],
	[
		[
			5114,
			7490
		],
		[
			6,
			-11
		],
		[
			-3,
			-3
		],
		[
			-12,
			12
		],
		[
			9,
			2
		]
	],
	[
		[
			5055,
			7627
		],
		[
			0,
			0
		]
	],
	[
		[
			4950,
			7681
		],
		[
			11,
			-8
		],
		[
			1,
			-9
		],
		[
			16,
			-8
		],
		[
			6,
			-11
		],
		[
			6,
			3
		],
		[
			8,
			-7
		],
		[
			20,
			0
		],
		[
			0,
			9
		],
		[
			18,
			-7
		],
		[
			3,
			-7
		]
	],
	[
		[
			5047,
			7630
		],
		[
			8,
			-9
		],
		[
			8,
			4
		],
		[
			6,
			-5
		],
		[
			12,
			8
		],
		[
			7,
			-3
		]
	],
	[
		[
			5088,
			7625
		],
		[
			4,
			-5
		],
		[
			-6,
			-6
		],
		[
			3,
			-18
		],
		[
			-4,
			-6
		],
		[
			-23,
			-20
		],
		[
			-3,
			-10
		],
		[
			-17,
			-6
		],
		[
			-15,
			-8
		],
		[
			-8,
			-13
		],
		[
			5,
			-6
		],
		[
			-8,
			-7
		],
		[
			-7,
			-18
		],
		[
			-8,
			-14
		],
		[
			-11,
			-32
		],
		[
			3,
			-21
		],
		[
			6,
			-15
		],
		[
			7,
			-7
		],
		[
			-21,
			-22
		],
		[
			-9,
			-36
		],
		[
			4,
			-6
		],
		[
			-19,
			-4
		],
		[
			-12,
			-20
		],
		[
			-2,
			-15
		],
		[
			-7,
			-12
		],
		[
			-5,
			6
		],
		[
			-7,
			-1
		],
		[
			-3,
			-8
		],
		[
			-6,
			4
		],
		[
			-42,
			-1
		],
		[
			-7,
			-13
		],
		[
			-15,
			-5
		],
		[
			-4,
			-16
		]
	],
	[
		[
			4851,
			7264
		],
		[
			0,
			0
		]
	],
	[
		[
			4851,
			7264
		],
		[
			-6,
			-7
		],
		[
			-14,
			11
		],
		[
			-9,
			24
		],
		[
			-2,
			18
		],
		[
			-12,
			13
		],
		[
			-14,
			2
		]
	],
	[
		[
			4794,
			7325
		],
		[
			-3,
			18
		],
		[
			7,
			27
		],
		[
			6,
			2
		],
		[
			3,
			10
		],
		[
			-5,
			0
		],
		[
			-6,
			14
		],
		[
			1,
			17
		],
		[
			6,
			6
		],
		[
			3,
			12
		],
		[
			-5,
			3
		],
		[
			-5,
			22
		],
		[
			-6,
			12
		],
		[
			14,
			0
		],
		[
			4,
			14
		],
		[
			-4,
			17
		],
		[
			7,
			8
		],
		[
			-1,
			30
		],
		[
			-3,
			6
		],
		[
			8,
			16
		],
		[
			6,
			4
		],
		[
			6,
			14
		],
		[
			-10,
			6
		],
		[
			0,
			16
		],
		[
			-16,
			2
		],
		[
			-2,
			-7
		],
		[
			-11,
			-3
		],
		[
			-3,
			3
		],
		[
			-13,
			-3
		],
		[
			3,
			13
		],
		[
			-4,
			6
		],
		[
			-15,
			-10
		]
	],
	[
		[
			4756,
			7600
		],
		[
			-4,
			7
		],
		[
			8,
			12
		],
		[
			-7,
			6
		],
		[
			1,
			13
		],
		[
			-6,
			-4
		],
		[
			1,
			10
		],
		[
			-7,
			18
		],
		[
			12,
			17
		],
		[
			5,
			-3
		],
		[
			11,
			5
		],
		[
			-2,
			4
		],
		[
			13,
			17
		],
		[
			6,
			2
		],
		[
			13,
			-13
		],
		[
			36,
			2
		],
		[
			14,
			-2
		],
		[
			17,
			-9
		],
		[
			16,
			0
		],
		[
			17,
			6
		],
		[
			3,
			-6
		],
		[
			11,
			-2
		],
		[
			10,
			4
		],
		[
			16,
			-8
		],
		[
			10,
			5
		]
	],
	[
		[
			5628,
			8557
		],
		[
			8,
			2
		],
		[
			12,
			-10
		],
		[
			-17,
			-13
		],
		[
			-15,
			-4
		],
		[
			-10,
			7
		],
		[
			0,
			13
		],
		[
			22,
			5
		]
	],
	[
		[
			5631,
			8581
		],
		[
			8,
			-10
		],
		[
			-15,
			-8
		],
		[
			-3,
			11
		],
		[
			-9,
			4
		],
		[
			19,
			3
		]
	],
	[
		[
			5778,
			8608
		],
		[
			4,
			-7
		]
	],
	[
		[
			5782,
			8601
		],
		[
			-5,
			-1
		]
	],
	[
		[
			5777,
			8600
		],
		[
			3,
			-1
		]
	],
	[
		[
			5780,
			8599
		],
		[
			-7,
			-9
		]
	],
	[
		[
			5773,
			8590
		],
		[
			-4,
			-10
		]
	],
	[
		[
			5769,
			8580
		],
		[
			-12,
			1
		],
		[
			-9,
			-8
		],
		[
			13,
			-28
		],
		[
			6,
			-22
		]
	],
	[
		[
			5767,
			8523
		],
		[
			5,
			-8
		],
		[
			-7,
			-3
		],
		[
			-6,
			-16
		]
	],
	[
		[
			5759,
			8496
		],
		[
			-14,
			5
		],
		[
			-8,
			-6
		],
		[
			-15,
			19
		],
		[
			-26,
			13
		],
		[
			-21,
			-12
		]
	],
	[
		[
			5675,
			8515
		],
		[
			7,
			26
		],
		[
			-10,
			-3
		],
		[
			-13,
			5
		],
		[
			-6,
			13
		],
		[
			-3,
			20
		],
		[
			6,
			3
		],
		[
			-5,
			14
		],
		[
			18,
			5
		],
		[
			6,
			10
		],
		[
			30,
			1
		],
		[
			8,
			10
		],
		[
			35,
			-13
		],
		[
			27,
			-2
		],
		[
			3,
			4
		]
	],
	[
		[
			6160,
			5833
		],
		[
			0,
			-12
		]
	],
	[
		[
			6192,
			5816
		],
		[
			-8,
			-22
		],
		[
			5,
			-23
		],
		[
			5,
			-13
		],
		[
			6,
			-8
		],
		[
			1,
			-13
		],
		[
			4,
			-12
		],
		[
			5,
			-4
		],
		[
			12,
			-21
		],
		[
			51,
			-34
		],
		[
			31,
			-23
		],
		[
			28,
			0
		]
	],
	[
		[
			6332,
			5643
		],
		[
			-21,
			-43
		],
		[
			-31,
			-61
		],
		[
			-14,
			-31
		],
		[
			-14,
			-34
		],
		[
			-5,
			-9
		],
		[
			-27,
			3
		],
		[
			-20,
			-14
		],
		[
			-8,
			-12
		],
		[
			-1,
			-8
		],
		[
			-9,
			-7
		],
		[
			-12,
			-2
		],
		[
			-7,
			-13
		]
	],
	[
		[
			6163,
			5412
		],
		[
			-19,
			-3
		],
		[
			-3,
			2
		],
		[
			-9,
			19
		],
		[
			-26,
			-24
		],
		[
			-8,
			-27
		],
		[
			-25,
			12
		],
		[
			-15,
			0
		],
		[
			-7,
			11
		],
		[
			-28,
			36
		],
		[
			-23,
			1
		],
		[
			-3,
			10
		]
	],
	[
		[
			5997,
			5449
		],
		[
			-4,
			8
		],
		[
			0,
			27
		],
		[
			-2,
			9
		],
		[
			-11,
			-2
		],
		[
			-1,
			9
		],
		[
			-5,
			7
		],
		[
			-3,
			12
		],
		[
			0,
			13
		],
		[
			-4,
			11
		],
		[
			-3,
			24
		],
		[
			-6,
			5
		],
		[
			0,
			8
		],
		[
			-6,
			4
		],
		[
			-7,
			24
		],
		[
			-9,
			16
		],
		[
			-19,
			8
		],
		[
			-1,
			9
		],
		[
			5,
			9
		],
		[
			0,
			17
		],
		[
			12,
			3
		],
		[
			2,
			-5
		],
		[
			7,
			3
		],
		[
			5,
			9
		],
		[
			-1,
			50
		]
	],
	[
		[
			5946,
			5727
		],
		[
			4,
			33
		],
		[
			3,
			9
		],
		[
			-1,
			22
		],
		[
			7,
			18
		],
		[
			6,
			-7
		],
		[
			5,
			5
		],
		[
			0,
			25
		],
		[
			4,
			16
		],
		[
			-1,
			14
		],
		[
			6,
			8
		],
		[
			2,
			12
		],
		[
			11,
			31
		],
		[
			11,
			1
		],
		[
			0,
			19
		],
		[
			3,
			19
		],
		[
			6,
			24
		],
		[
			2,
			28
		]
	],
	[
		[
			5634,
			8649
		],
		[
			-3,
			-11
		],
		[
			-9,
			9
		],
		[
			12,
			2
		]
	],
	[
		[
			5804,
			9158
		],
		[
			-14,
			-7
		],
		[
			8,
			-9
		],
		[
			-8,
			-12
		],
		[
			7,
			-21
		],
		[
			18,
			-7
		],
		[
			18,
			-21
		],
		[
			-2,
			-10
		],
		[
			-23,
			-30
		],
		[
			-1,
			-9
		],
		[
			13,
			-20
		],
		[
			11,
			-25
		],
		[
			5,
			-23
		],
		[
			-10,
			-1
		],
		[
			2,
			-32
		],
		[
			-7,
			-6
		],
		[
			6,
			-11
		],
		[
			9,
			-1
		],
		[
			-2,
			-23
		],
		[
			14,
			-8
		],
		[
			1,
			-11
		],
		[
			-17,
			-18
		],
		[
			14,
			-16
		],
		[
			21,
			-15
		],
		[
			9,
			-17
		],
		[
			-9,
			-24
		],
		[
			-25,
			-28
		],
		[
			-15,
			-23
		],
		[
			-18,
			-22
		],
		[
			-10,
			-7
		],
		[
			-27,
			-31
		]
	],
	[
		[
			5772,
			8670
		],
		[
			-31,
			-8
		],
		[
			-19,
			-2
		],
		[
			-8,
			-8
		],
		[
			-15,
			0
		],
		[
			-6,
			-6
		],
		[
			-38,
			-11
		],
		[
			-10,
			-6
		],
		[
			-10,
			17
		],
		[
			3,
			10
		],
		[
			-12,
			-6
		],
		[
			2,
			10
		],
		[
			-10,
			0
		],
		[
			-12,
			14
		],
		[
			-5,
			-7
		],
		[
			-8,
			8
		],
		[
			-2,
			23
		],
		[
			5,
			3
		],
		[
			3,
			23
		],
		[
			-5,
			25
		],
		[
			-5,
			3
		],
		[
			3,
			22
		],
		[
			-6,
			2
		],
		[
			3,
			27
		],
		[
			13,
			9
		],
		[
			-5,
			12
		],
		[
			11,
			-3
		],
		[
			13,
			8
		],
		[
			-5,
			9
		],
		[
			17,
			9
		],
		[
			3,
			10
		],
		[
			13,
			6
		],
		[
			10,
			18
		],
		[
			17,
			18
		],
		[
			5,
			16
		],
		[
			25,
			8
		],
		[
			-4,
			14
		],
		[
			2,
			17
		],
		[
			-33,
			19
		]
	],
	[
		[
			5671,
			8973
		],
		[
			-15,
			37
		],
		[
			10,
			20
		],
		[
			-12,
			20
		],
		[
			5,
			16
		],
		[
			-7,
			26
		],
		[
			5,
			3
		],
		[
			-23,
			26
		],
		[
			-21,
			5
		],
		[
			-41,
			32
		]
	],
	[
		[
			5572,
			9158
		],
		[
			12,
			1
		],
		[
			7,
			14
		],
		[
			10,
			-2
		],
		[
			21,
			-31
		],
		[
			22,
			-6
		],
		[
			20,
			12
		],
		[
			27,
			-15
		],
		[
			7,
			13
		],
		[
			18,
			12
		],
		[
			-1,
			17
		],
		[
			6,
			22
		],
		[
			15,
			15
		],
		[
			16,
			-2
		],
		[
			22,
			10
		],
		[
			17,
			-16
		],
		[
			18,
			-7
		],
		[
			6,
			-12
		],
		[
			-14,
			-14
		],
		[
			3,
			-11
		]
	],
	[
		[
			9954,
			4093
		],
		[
			-5,
			-13
		],
		[
			-7,
			0
		],
		[
			12,
			13
		]
	],
	[
		[
			9951,
			4184
		],
		[
			0,
			-5
		],
		[
			9,
			-12
		],
		[
			2,
			-26
		],
		[
			-10,
			-2
		],
		[
			-3,
			-6
		],
		[
			-10,
			-2
		],
		[
			-15,
			11
		],
		[
			-1,
			12
		],
		[
			5,
			7
		],
		[
			-2,
			6
		],
		[
			7,
			12
		],
		[
			18,
			5
		]
	],
	[
		[
			0,
			4252
		],
		[
			9987,
			-23
		],
		[
			-2,
			-11
		],
		[
			4,
			2
		],
		[
			7,
			14
		],
		[
			0,
			-17
		],
		[
			-16,
			-2
		],
		[
			-1,
			7
		],
		[
			-11,
			-10
		],
		[
			-4,
			-9
		],
		[
			-7,
			15
		],
		[
			12,
			16
		],
		[
			13,
			4
		],
		[
			2,
			8
		],
		[
			-9984,
			6
		]
	],
	[
		[
			3351,
			2225
		],
		[
			4,
			-3
		],
		[
			-17,
			-28
		],
		[
			-11,
			-4
		],
		[
			-4,
			-11
		],
		[
			-8,
			-4
		],
		[
			-11,
			12
		],
		[
			16,
			3
		],
		[
			-4,
			17
		],
		[
			12,
			1
		],
		[
			-13,
			15
		],
		[
			11,
			-5
		],
		[
			9,
			6
		],
		[
			15,
			-3
		],
		[
			1,
			4
		]
	],
	[
		[
			3368,
			2227
		],
		[
			7,
			2
		],
		[
			4,
			-8
		],
		[
			12,
			3
		],
		[
			4,
			-18
		],
		[
			-17,
			-11
		],
		[
			-16,
			0
		],
		[
			8,
			-4
		],
		[
			-12,
			-6
		],
		[
			1,
			-10
		],
		[
			-11,
			5
		],
		[
			3,
			-11
		],
		[
			-9,
			12
		],
		[
			6,
			17
		],
		[
			13,
			11
		],
		[
			-3,
			14
		],
		[
			10,
			4
		]
	],
	[
		[
			6541,
			3981
		],
		[
			5,
			-2
		],
		[
			5,
			-13
		],
		[
			-1,
			-13
		],
		[
			-7,
			-1
		],
		[
			-6,
			6
		],
		[
			-4,
			14
		],
		[
			8,
			9
		]
	],
	[
		[
			6252,
			4454
		],
		[
			4,
			-5
		],
		[
			-1,
			-13
		],
		[
			-3,
			-1
		],
		[
			0,
			19
		]
	],
	[
		[
			3483,
			5317
		],
		[
			7,
			10
		],
		[
			4,
			16
		],
		[
			2,
			29
		],
		[
			4,
			19
		],
		[
			-10,
			24
		],
		[
			-3,
			26
		],
		[
			-1,
			25
		],
		[
			4,
			16
		],
		[
			5,
			9
		]
	],
	[
		[
			3495,
			5491
		],
		[
			3,
			5
		],
		[
			3,
			18
		],
		[
			12,
			-10
		],
		[
			11,
			-4
		],
		[
			6,
			-6
		],
		[
			10,
			-19
		],
		[
			22,
			-31
		],
		[
			3,
			-18
		],
		[
			-1,
			-11
		]
	],
	[
		[
			3306,
			6034
		],
		[
			4,
			-11
		],
		[
			-1,
			-7
		],
		[
			-9,
			13
		],
		[
			1,
			11
		],
		[
			5,
			-6
		]
	],
	[
		[
			3288,
			6120
		],
		[
			2,
			-14
		],
		[
			-4,
			-5
		],
		[
			-3,
			22
		],
		[
			5,
			-3
		]
	],
	[
		[
			3295,
			6124
		],
		[
			5,
			-5
		],
		[
			-9,
			-3
		],
		[
			1,
			18
		],
		[
			3,
			-10
		]
	],
	[
		[
			5262,
			7641
		],
		[
			2,
			-7
		],
		[
			1,
			-27
		],
		[
			-4,
			-7
		],
		[
			-2,
			-24
		],
		[
			-7,
			-9
		],
		[
			-8,
			9
		],
		[
			3,
			8
		],
		[
			-7,
			3
		],
		[
			2,
			19
		],
		[
			-5,
			15
		],
		[
			3,
			10
		],
		[
			13,
			13
		],
		[
			6,
			-1
		],
		[
			3,
			16
		],
		[
			0,
			-18
		]
	],
	[
		[
			5160,
			8036
		],
		[
			5,
			-6
		],
		[
			11,
			0
		]
	],
	[
		[
			5172,
			7849
		],
		[
			16,
			7
		]
	],
	[
		[
			5195,
			7827
		],
		[
			-7,
			-5
		],
		[
			5,
			-18
		],
		[
			5,
			-6
		],
		[
			-2,
			-11
		],
		[
			-13,
			-6
		],
		[
			3,
			-11
		],
		[
			8,
			-5
		],
		[
			1,
			-9
		],
		[
			-6,
			-11
		],
		[
			4,
			-14
		],
		[
			10,
			-7
		],
		[
			9,
			3
		],
		[
			-4,
			-22
		]
	],
	[
		[
			5208,
			7705
		],
		[
			-2,
			-3
		]
	],
	[
		[
			5206,
			7702
		],
		[
			-2,
			-1
		]
	],
	[
		[
			5204,
			7701
		],
		[
			-11,
			-10
		],
		[
			-9,
			-23
		],
		[
			-14,
			-6
		],
		[
			-22,
			9
		],
		[
			0,
			7
		],
		[
			-15,
			1
		],
		[
			-7,
			6
		],
		[
			-11,
			0
		],
		[
			-5,
			6
		],
		[
			-13,
			-17
		],
		[
			-10,
			-6
		],
		[
			-3,
			-9
		],
		[
			0,
			-26
		],
		[
			4,
			-8
		]
	],
	[
		[
			4950,
			7681
		],
		[
			9,
			13
		],
		[
			6,
			48
		],
		[
			-1,
			11
		],
		[
			4,
			49
		],
		[
			11,
			-11
		],
		[
			0,
			8
		],
		[
			-14,
			16
		],
		[
			3,
			6
		],
		[
			1,
			26
		],
		[
			-20,
			14
		],
		[
			-9,
			18
		],
		[
			4,
			14
		],
		[
			-5,
			12
		],
		[
			-8,
			1
		],
		[
			-3,
			15
		],
		[
			-6,
			-3
		],
		[
			-11,
			11
		],
		[
			-18,
			6
		],
		[
			-4,
			6
		],
		[
			-11,
			-5
		],
		[
			0,
			7
		],
		[
			-9,
			7
		],
		[
			12,
			5
		],
		[
			-14,
			12
		],
		[
			1,
			13
		],
		[
			10,
			6
		],
		[
			22,
			0
		],
		[
			2,
			9
		],
		[
			12,
			2
		],
		[
			10,
			-20
		],
		[
			12,
			9
		],
		[
			16,
			-4
		],
		[
			4,
			8
		],
		[
			-1,
			28
		],
		[
			-6,
			8
		],
		[
			0,
			18
		],
		[
			16,
			0
		],
		[
			-1,
			-11
		],
		[
			5,
			-6
		],
		[
			30,
			-4
		],
		[
			8,
			7
		],
		[
			-5,
			3
		],
		[
			2,
			11
		],
		[
			10,
			9
		],
		[
			18,
			7
		],
		[
			11,
			15
		],
		[
			0,
			37
		],
		[
			10,
			8
		],
		[
			17,
			4
		]
	],
	[
		[
			4800,
			8771
		],
		[
			13,
			-21
		],
		[
			-14,
			13
		],
		[
			1,
			8
		]
	],
	[
		[
			4808,
			8772
		],
		[
			9,
			-11
		],
		[
			-11,
			3
		],
		[
			2,
			8
		]
	],
	[
		[
			9394,
			5584
		],
		[
			3,
			-9
		],
		[
			-4,
			-1
		],
		[
			1,
			10
		]
	],
	[
		[
			5308,
			4956
		],
		[
			-3,
			13
		],
		[
			-10,
			15
		],
		[
			0,
			9
		],
		[
			-17,
			28
		],
		[
			-8,
			19
		],
		[
			7,
			-8
		],
		[
			5,
			3
		],
		[
			-8,
			8
		],
		[
			-7,
			1
		],
		[
			-2,
			13
		],
		[
			-9,
			21
		],
		[
			1,
			10
		],
		[
			8,
			2
		],
		[
			-2,
			7
		],
		[
			-4,
			-5
		],
		[
			-9,
			16
		],
		[
			-1,
			11
		],
		[
			-6,
			18
		],
		[
			5,
			6
		],
		[
			2,
			-7
		],
		[
			2,
			12
		],
		[
			6,
			13
		],
		[
			1,
			14
		],
		[
			-1,
			27
		],
		[
			2,
			-7
		],
		[
			11,
			-2
		],
		[
			-8,
			7
		],
		[
			-5,
			19
		],
		[
			9,
			-6
		],
		[
			-2,
			24
		],
		[
			3,
			7
		],
		[
			4,
			-4
		]
	],
	[
		[
			5272,
			5240
		],
		[
			6,
			1
		],
		[
			36,
			-1
		],
		[
			0,
			68
		]
	],
	[
		[
			4964,
			8107
		],
		[
			6,
			-6
		],
		[
			-7,
			-6
		],
		[
			-6,
			6
		],
		[
			7,
			6
		]
	],
	[
		[
			4883,
			8252
		],
		[
			-4,
			-10
		],
		[
			-6,
			16
		],
		[
			10,
			-6
		]
	],
	[
		[
			4825,
			8298
		],
		[
			-11,
			-2
		],
		[
			-8,
			20
		],
		[
			-10,
			-17
		],
		[
			-14,
			5
		],
		[
			-9,
			13
		],
		[
			11,
			10
		],
		[
			-5,
			6
		],
		[
			11,
			2
		],
		[
			8,
			19
		]
	],
	[
		[
			4798,
			8354
		],
		[
			20,
			10
		],
		[
			13,
			-2
		],
		[
			0,
			-8
		],
		[
			18,
			-35
		],
		[
			-7,
			-6
		],
		[
			-11,
			-19
		],
		[
			-6,
			4
		]
	],
	[
		[
			4857,
			8375
		],
		[
			-7,
			14
		],
		[
			7,
			-1
		],
		[
			0,
			-13
		]
	],
	[
		[
			4830,
			8398
		],
		[
			2,
			-9
		],
		[
			-7,
			-6
		],
		[
			-6,
			6
		],
		[
			1,
			10
		],
		[
			10,
			-1
		]
	],
	[
		[
			4839,
			8409
		],
		[
			-5,
			-13
		],
		[
			-4,
			6
		],
		[
			9,
			7
		]
	],
	[
		[
			4832,
			8443
		],
		[
			11,
			-10
		],
		[
			-2,
			-5
		],
		[
			-18,
			-4
		],
		[
			7,
			10
		],
		[
			-7,
			5
		],
		[
			9,
			4
		]
	],
	[
		[
			4795,
			8489
		],
		[
			3,
			-18
		],
		[
			-4,
			1
		],
		[
			1,
			17
		]
	],
	[
		[
			4800,
			8503
		],
		[
			1,
			-8
		],
		[
			-10,
			7
		],
		[
			9,
			1
		]
	],
	[
		[
			4824,
			8506
		],
		[
			5,
			-20
		],
		[
			14,
			-6
		],
		[
			-9,
			-6
		],
		[
			-10,
			1
		],
		[
			-13,
			15
		],
		[
			11,
			5
		],
		[
			2,
			11
		]
	],
	[
		[
			4827,
			8543
		],
		[
			-5,
			-20
		],
		[
			-16,
			-15
		],
		[
			3,
			11
		],
		[
			-7,
			3
		],
		[
			2,
			15
		],
		[
			23,
			15
		],
		[
			0,
			-9
		]
	],
	[
		[
			4907,
			8560
		],
		[
			9,
			0
		],
		[
			-6,
			-20
		],
		[
			-22,
			-20
		],
		[
			6,
			-7
		],
		[
			-8,
			-14
		],
		[
			22,
			8
		],
		[
			20,
			-3
		],
		[
			16,
			2
		],
		[
			7,
			-13
		],
		[
			-6,
			-9
		],
		[
			-6,
			-24
		],
		[
			-9,
			-18
		],
		[
			-10,
			-8
		],
		[
			8,
			-10
		],
		[
			-21,
			-15
		],
		[
			9,
			-4
		],
		[
			11,
			6
		],
		[
			13,
			-8
		],
		[
			14,
			-19
		],
		[
			4,
			-29
		],
		[
			8,
			-27
		],
		[
			19,
			-9
		],
		[
			4,
			-13
		],
		[
			8,
			-7
		],
		[
			-4,
			-5
		],
		[
			11,
			-24
		],
		[
			-7,
			1
		],
		[
			12,
			-23
		],
		[
			-7,
			-19
		],
		[
			8,
			-7
		],
		[
			5,
			11
		],
		[
			20,
			-2
		],
		[
			11,
			-10
		],
		[
			3,
			-16
		],
		[
			-5,
			-24
		],
		[
			-4,
			0
		],
		[
			-14,
			-26
		],
		[
			-11,
			-12
		],
		[
			12,
			-3
		],
		[
			13,
			1
		],
		[
			-3,
			-14
		],
		[
			-11,
			-13
		],
		[
			-5,
			1
		],
		[
			-14,
			-11
		],
		[
			-12,
			6
		],
		[
			-18,
			-6
		],
		[
			-3,
			7
		],
		[
			-18,
			-7
		],
		[
			-14,
			-1
		],
		[
			2,
			-8
		],
		[
			-27,
			9
		],
		[
			-13,
			-6
		],
		[
			-2,
			-17
		],
		[
			-8,
			-7
		],
		[
			-11,
			10
		],
		[
			-16,
			-3
		],
		[
			-12,
			-21
		],
		[
			-8,
			10
		],
		[
			19,
			25
		],
		[
			7,
			14
		],
		[
			1,
			12
		],
		[
			6,
			-1
		],
		[
			2,
			11
		],
		[
			12,
			3
		],
		[
			11,
			-4
		],
		[
			11,
			2
		],
		[
			8,
			20
		],
		[
			-23,
			-9
		],
		[
			-8,
			12
		],
		[
			-13,
			-3
		],
		[
			0,
			6
		],
		[
			-10,
			3
		],
		[
			-8,
			-7
		],
		[
			-10,
			18
		],
		[
			13,
			6
		],
		[
			20,
			18
		],
		[
			2,
			9
		],
		[
			-2,
			24
		],
		[
			-17,
			-4
		],
		[
			11,
			12
		],
		[
			5,
			11
		],
		[
			27,
			10
		],
		[
			8,
			19
		],
		[
			-4,
			11
		],
		[
			5,
			2
		],
		[
			-1,
			14
		],
		[
			-9,
			-6
		],
		[
			-11,
			23
		],
		[
			9,
			26
		],
		[
			-19,
			-10
		],
		[
			-11,
			5
		],
		[
			1,
			-10
		],
		[
			-13,
			10
		],
		[
			-5,
			-5
		],
		[
			-1,
			21
		],
		[
			11,
			19
		],
		[
			-15,
			29
		],
		[
			-8,
			-15
		],
		[
			-4,
			-23
		],
		[
			-5,
			-1
		],
		[
			3,
			22
		],
		[
			-1,
			18
		],
		[
			5,
			24
		],
		[
			8,
			18
		],
		[
			-12,
			-13
		],
		[
			-5,
			11
		],
		[
			0,
			17
		],
		[
			5,
			10
		],
		[
			-6,
			19
		],
		[
			7,
			25
		],
		[
			12,
			0
		],
		[
			-5,
			20
		],
		[
			11,
			21
		],
		[
			20,
			-6
		],
		[
			26,
			7
		]
	],
	[
		[
			4912,
			8589
		],
		[
			-2,
			-13
		],
		[
			-4,
			10
		],
		[
			6,
			3
		]
	],
	[
		[
			4964,
			8673
		],
		[
			4,
			-27
		],
		[
			-15,
			5
		],
		[
			9,
			7
		],
		[
			2,
			15
		]
	],
	[
		[
			6206,
			7550
		],
		[
			-23,
			27
		],
		[
			-5,
			-9
		],
		[
			-8,
			5
		],
		[
			-9,
			-5
		],
		[
			-8,
			5
		]
	],
	[
		[
			6153,
			7573
		],
		[
			7,
			17
		],
		[
			-8,
			51
		],
		[
			-10,
			6
		],
		[
			-3,
			11
		],
		[
			-21,
			13
		],
		[
			-8,
			10
		]
	],
	[
		[
			6110,
			7681
		],
		[
			2,
			9
		],
		[
			16,
			0
		],
		[
			27,
			-19
		],
		[
			21,
			2
		],
		[
			7,
			-6
		],
		[
			6,
			1
		],
		[
			10,
			-14
		],
		[
			17,
			-9
		],
		[
			-2,
			-8
		],
		[
			6,
			-4
		],
		[
			16,
			12
		],
		[
			7,
			-8
		],
		[
			4,
			8
		],
		[
			11,
			-14
		],
		[
			11,
			0
		],
		[
			-2,
			-18
		],
		[
			8,
			-10
		],
		[
			14,
			-9
		]
	],
	[
		[
			4995,
			5824
		],
		[
			5,
			-3
		],
		[
			-3,
			-26
		],
		[
			10,
			-13
		],
		[
			3,
			-27
		],
		[
			-4,
			-30
		],
		[
			8,
			0
		],
		[
			-2,
			-24
		],
		[
			2,
			-8
		],
		[
			-4,
			-8
		],
		[
			9,
			-19
		],
		[
			-3,
			-11
		],
		[
			0,
			-28
		],
		[
			-3,
			-15
		],
		[
			4,
			-3
		],
		[
			-1,
			-23
		],
		[
			-3,
			-2
		],
		[
			6,
			-28
		],
		[
			8,
			-9
		],
		[
			5,
			-13
		]
	],
	[
		[
			5032,
			5534
		],
		[
			-7,
			-19
		],
		[
			-15,
			1
		],
		[
			-21,
			-17
		],
		[
			-12,
			-16
		],
		[
			-6,
			0
		],
		[
			-6,
			-7
		],
		[
			-11,
			-5
		],
		[
			-10,
			-15
		],
		[
			-7,
			8
		],
		[
			-24,
			12
		]
	],
	[
		[
			4913,
			5477
		],
		[
			8,
			2
		]
	],
	[
		[
			4851,
			7264
		],
		[
			0,
			0
		]
	],
	[
		[
			4683,
			5897
		],
		[
			-3,
			-14
		],
		[
			6,
			-9
		],
		[
			6,
			11
		],
		[
			4,
			0
		],
		[
			8,
			-17
		],
		[
			4,
			13
		],
		[
			5,
			5
		],
		[
			16,
			-11
		],
		[
			2,
			7
		],
		[
			14,
			19
		],
		[
			5,
			-5
		],
		[
			2,
			-20
		],
		[
			3,
			-1
		],
		[
			-1,
			-21
		],
		[
			13,
			-17
		],
		[
			-9,
			-23
		],
		[
			5,
			5
		],
		[
			6,
			-3
		],
		[
			0,
			-28
		],
		[
			9,
			-12
		],
		[
			0,
			-8
		]
	],
	[
		[
			4764,
			5618
		],
		[
			-6,
			8
		],
		[
			-1,
			-12
		],
		[
			-11,
			-17
		],
		[
			-5,
			13
		],
		[
			-4,
			0
		],
		[
			3,
			19
		],
		[
			-5,
			25
		],
		[
			0,
			11
		],
		[
			-8,
			10
		],
		[
			-7,
			-7
		],
		[
			-6,
			3
		]
	],
	[
		[
			4714,
			5671
		],
		[
			-3,
			1
		],
		[
			-5,
			-11
		],
		[
			-3,
			4
		],
		[
			5,
			15
		],
		[
			-3,
			10
		],
		[
			0,
			15
		],
		[
			-4,
			1
		],
		[
			2,
			13
		],
		[
			-15,
			39
		],
		[
			-19,
			0
		],
		[
			-17,
			-7
		],
		[
			-5,
			-26
		],
		[
			-12,
			-21
		],
		[
			-5,
			-1
		]
	],
	[
		[
			4630,
			5703
		],
		[
			4,
			8
		],
		[
			-12,
			23
		],
		[
			0,
			12
		],
		[
			-4,
			-2
		],
		[
			-6,
			13
		],
		[
			-20,
			29
		],
		[
			4,
			20
		],
		[
			-5,
			-10
		],
		[
			-3,
			21
		],
		[
			-4,
			-14
		],
		[
			-2,
			11
		]
	],
	[
		[
			4582,
			5814
		],
		[
			8,
			30
		],
		[
			12,
			8
		],
		[
			16,
			4
		],
		[
			0,
			19
		],
		[
			-6,
			11
		],
		[
			7,
			3
		],
		[
			-1,
			24
		]
	],
	[
		[
			4618,
			5913
		],
		[
			19,
			-3
		],
		[
			-1,
			-8
		],
		[
			17,
			-6
		],
		[
			3,
			-5
		],
		[
			7,
			6
		],
		[
			20,
			0
		]
	],
	[
		[
			4534,
			5935
		],
		[
			-2,
			17
		],
		[
			4,
			7
		],
		[
			8,
			-14
		],
		[
			5,
			5
		],
		[
			-8,
			2
		],
		[
			-1,
			13
		]
	],
	[
		[
			4540,
			5965
		],
		[
			29,
			0
		],
		[
			4,
			12
		],
		[
			7,
			2
		],
		[
			8,
			-5
		],
		[
			2,
			-7
		],
		[
			6,
			1
		],
		[
			4,
			-10
		],
		[
			12,
			7
		],
		[
			3,
			-14
		],
		[
			-15,
			-6
		],
		[
			-5,
			7
		],
		[
			-11,
			6
		],
		[
			-6,
			7
		],
		[
			-1,
			-9
		],
		[
			-5,
			-4
		],
		[
			-12,
			-1
		],
		[
			0,
			-11
		],
		[
			-24,
			1
		],
		[
			-2,
			-6
		]
	],
	[
		[
			4553,
			5826
		],
		[
			1,
			-7
		],
		[
			-6,
			3
		],
		[
			5,
			4
		]
	],
	[
		[
			4582,
			5814
		],
		[
			-1,
			9
		],
		[
			-5,
			-7
		],
		[
			-7,
			20
		],
		[
			5,
			15
		],
		[
			8,
			-2
		],
		[
			-9,
			7
		],
		[
			-2,
			-8
		],
		[
			-3,
			8
		],
		[
			2,
			11
		],
		[
			8,
			-1
		],
		[
			-5,
			6
		],
		[
			-6,
			-7
		],
		[
			-11,
			-6
		],
		[
			3,
			14
		],
		[
			-7,
			-6
		],
		[
			-6,
			6
		],
		[
			1,
			13
		],
		[
			-5,
			-2
		],
		[
			-7,
			9
		]
	],
	[
		[
			4535,
			5893
		],
		[
			14,
			7
		],
		[
			15,
			-1
		],
		[
			13,
			14
		],
		[
			41,
			0
		]
	],
	[
		[
			5272,
			5240
		],
		[
			-3,
			6
		],
		[
			-10,
			3
		],
		[
			3,
			15
		],
		[
			10,
			28
		],
		[
			0,
			26
		]
	],
	[
		[
			5243,
			5399
		],
		[
			5,
			-8
		],
		[
			-8,
			-24
		],
		[
			-6,
			4
		],
		[
			0,
			10
		],
		[
			4,
			1
		],
		[
			1,
			11
		],
		[
			4,
			6
		]
	],
	[
		[
			5663,
			7229
		],
		[
			13,
			-11
		],
		[
			9,
			5
		],
		[
			22,
			-8
		],
		[
			8,
			3
		],
		[
			-1,
			-12
		],
		[
			9,
			6
		],
		[
			7,
			-7
		],
		[
			-2,
			-5
		],
		[
			-25,
			-2
		],
		[
			-16,
			-4
		],
		[
			0,
			9
		],
		[
			-10,
			6
		],
		[
			-24,
			5
		],
		[
			1,
			17
		],
		[
			4,
			5
		],
		[
			5,
			-7
		]
	],
	[
		[
			5756,
			7245
		],
		[
			-1,
			-17
		],
		[
			-3,
			-5
		],
		[
			4,
			22
		]
	],
	[
		[
			5640,
			7268
		],
		[
			-4,
			-2
		],
		[
			0,
			12
		],
		[
			4,
			-10
		]
	],
	[
		[
			5784,
			7281
		],
		[
			-5,
			-19
		],
		[
			-8,
			-12
		],
		[
			-2,
			13
		],
		[
			5,
			13
		],
		[
			10,
			5
		]
	],
	[
		[
			5710,
			7319
		],
		[
			-4,
			-10
		],
		[
			-2,
			10
		],
		[
			6,
			0
		]
	],
	[
		[
			5731,
			7350
		],
		[
			-10,
			-7
		],
		[
			2,
			7
		],
		[
			8,
			0
		]
	],
	[
		[
			5748,
			7357
		],
		[
			-5,
			-6
		],
		[
			-5,
			6
		],
		[
			10,
			0
		]
	],
	[
		[
			5576,
			7363
		],
		[
			5,
			-7
		],
		[
			-4,
			-5
		],
		[
			-5,
			10
		],
		[
			4,
			2
		]
	],
	[
		[
			5690,
			7366
		],
		[
			3,
			-13
		],
		[
			-8,
			16
		],
		[
			5,
			-3
		]
	],
	[
		[
			5571,
			7398
		],
		[
			6,
			-23
		],
		[
			-8,
			2
		],
		[
			-3,
			14
		],
		[
			5,
			7
		]
	],
	[
		[
			5723,
			7405
		],
		[
			3,
			-16
		],
		[
			-4,
			-9
		],
		[
			-5,
			25
		],
		[
			6,
			0
		]
	],
	[
		[
			5651,
			7423
		],
		[
			11,
			-14
		],
		[
			8,
			0
		],
		[
			5,
			-29
		],
		[
			7,
			0
		],
		[
			0,
			-10
		],
		[
			-7,
			1
		],
		[
			-8,
			23
		],
		[
			-11,
			0
		],
		[
			-1,
			9
		],
		[
			-12,
			17
		],
		[
			-9,
			-1
		],
		[
			13,
			12
		],
		[
			4,
			-8
		]
	],
	[
		[
			5733,
			7446
		],
		[
			6,
			-17
		],
		[
			-13,
			0
		],
		[
			4,
			10
		],
		[
			-10,
			-4
		],
		[
			-2,
			8
		],
		[
			13,
			8
		],
		[
			2,
			-5
		]
	],
	[
		[
			5553,
			7474
		],
		[
			-2,
			-18
		],
		[
			-5,
			18
		],
		[
			7,
			0
		]
	],
	[
		[
			5706,
			7488
		],
		[
			-2,
			-14
		],
		[
			-9,
			3
		],
		[
			0,
			9
		],
		[
			11,
			2
		]
	],
	[
		[
			5688,
			7522
		],
		[
			-8,
			1
		],
		[
			4,
			10
		],
		[
			4,
			-11
		]
	],
	[
		[
			5586,
			7536
		],
		[
			18,
			3
		],
		[
			4,
			11
		],
		[
			23,
			3
		],
		[
			5,
			10
		]
	],
	[
		[
			5731,
			7585
		],
		[
			7,
			-8
		],
		[
			1,
			-14
		],
		[
			-8,
			-6
		],
		[
			0,
			-15
		],
		[
			-8,
			-13
		]
	],
	[
		[
			5723,
			7529
		],
		[
			-3,
			5
		],
		[
			-11,
			2
		],
		[
			-11,
			8
		],
		[
			-12,
			-10
		],
		[
			-8,
			6
		],
		[
			-9,
			-12
		],
		[
			-11,
			1
		],
		[
			4,
			-19
		],
		[
			-4,
			-10
		],
		[
			8,
			-6
		],
		[
			-1,
			-11
		],
		[
			-9,
			17
		],
		[
			-8,
			0
		],
		[
			0,
			-6
		],
		[
			10,
			-14
		],
		[
			-9,
			6
		],
		[
			-2,
			14
		],
		[
			-12,
			9
		],
		[
			0,
			14
		],
		[
			-6,
			-6
		],
		[
			-3,
			-28
		],
		[
			8,
			-15
		],
		[
			2,
			-11
		],
		[
			5,
			-6
		],
		[
			7,
			-17
		],
		[
			-11,
			9
		],
		[
			-4,
			-7
		],
		[
			6,
			-16
		],
		[
			-9,
			-6
		],
		[
			17,
			-11
		],
		[
			0,
			-9
		],
		[
			8,
			-2
		],
		[
			13,
			-15
		],
		[
			-2,
			-5
		],
		[
			2,
			-25
		],
		[
			-3,
			-1
		],
		[
			-12,
			22
		],
		[
			-15,
			-11
		],
		[
			5,
			-3
		],
		[
			0,
			-11
		],
		[
			10,
			-10
		],
		[
			-11,
			-8
		],
		[
			-11,
			16
		],
		[
			0,
			-8
		],
		[
			7,
			-21
		],
		[
			3,
			-20
		],
		[
			0,
			-17
		],
		[
			-11,
			22
		],
		[
			-5,
			-6
		],
		[
			-4,
			-14
		],
		[
			0,
			13
		],
		[
			-6,
			19
		],
		[
			-6,
			-1
		],
		[
			0,
			-14
		],
		[
			-7,
			3
		],
		[
			-3,
			13
		],
		[
			3,
			14
		],
		[
			-3,
			15
		],
		[
			-13,
			17
		],
		[
			7,
			16
		],
		[
			7,
			2
		],
		[
			6,
			9
		],
		[
			19,
			-10
		],
		[
			10,
			-12
		],
		[
			9,
			10
		],
		[
			-5,
			6
		],
		[
			-17,
			14
		],
		[
			-1,
			-6
		],
		[
			-12,
			4
		],
		[
			-12,
			-7
		],
		[
			-4,
			8
		],
		[
			-8,
			-4
		],
		[
			-5,
			24
		],
		[
			-4,
			-1
		],
		[
			-1,
			16
		],
		[
			-13,
			20
		],
		[
			-2,
			14
		],
		[
			-5,
			4
		]
	],
	[
		[
			5583,
			7526
		],
		[
			0,
			0
		]
	],
	[
		[
			5582,
			7531
		],
		[
			4,
			5
		]
	],
	[
		[
			3288,
			5876
		],
		[
			-5,
			-2
		],
		[
			5,
			13
		],
		[
			0,
			-11
		]
	],
	[
		[
			3786,
			8632
		],
		[
			-12,
			-4
		],
		[
			4,
			9
		],
		[
			8,
			-5
		]
	],
	[
		[
			3787,
			8645
		],
		[
			3,
			-11
		],
		[
			-11,
			4
		],
		[
			-4,
			10
		],
		[
			12,
			-3
		]
	],
	[
		[
			3846,
			8835
		],
		[
			12,
			-11
		],
		[
			-9,
			0
		],
		[
			-12,
			15
		],
		[
			9,
			-4
		]
	],
	[
		[
			3579,
			8886
		],
		[
			3,
			14
		],
		[
			6,
			-4
		],
		[
			-9,
			-10
		]
	],
	[
		[
			3876,
			8910
		],
		[
			-1,
			-14
		],
		[
			-10,
			26
		],
		[
			11,
			-12
		]
	],
	[
		[
			3961,
			8973
		],
		[
			2,
			-9
		],
		[
			-18,
			-2
		],
		[
			0,
			10
		],
		[
			16,
			1
		]
	],
	[
		[
			3583,
			9209
		],
		[
			9,
			-5
		],
		[
			-9,
			-16
		],
		[
			-11,
			9
		],
		[
			11,
			12
		]
	],
	[
		[
			3535,
			9210
		],
		[
			20,
			-7
		],
		[
			5,
			-10
		],
		[
			-9,
			-9
		],
		[
			-40,
			-14
		],
		[
			-19,
			9
		],
		[
			8,
			9
		],
		[
			-21,
			2
		],
		[
			3,
			11
		],
		[
			-6,
			23
		],
		[
			14,
			9
		],
		[
			30,
			-7
		],
		[
			15,
			-16
		]
	],
	[
		[
			4292,
			9258
		],
		[
			5,
			-6
		],
		[
			-22,
			-8
		],
		[
			-56,
			-5
		],
		[
			5,
			12
		],
		[
			24,
			14
		],
		[
			11,
			0
		],
		[
			27,
			11
		],
		[
			6,
			-18
		]
	],
	[
		[
			3513,
			9274
		],
		[
			-13,
			6
		],
		[
			9,
			10
		],
		[
			4,
			-16
		]
	],
	[
		[
			3537,
			9281
		],
		[
			-14,
			10
		],
		[
			21,
			1
		],
		[
			-7,
			-11
		]
	],
	[
		[
			3472,
			9375
		],
		[
			-13,
			-11
		],
		[
			-4,
			9
		],
		[
			17,
			2
		]
	],
	[
		[
			4335,
			9380
		],
		[
			22,
			-3
		],
		[
			33,
			-25
		],
		[
			-20,
			4
		],
		[
			17,
			-11
		],
		[
			-5,
			-9
		],
		[
			-50,
			20
		],
		[
			-10,
			8
		],
		[
			0,
			15
		],
		[
			13,
			1
		]
	],
	[
		[
			4354,
			9391
		],
		[
			36,
			-8
		],
		[
			-3,
			-13
		],
		[
			-17,
			-1
		],
		[
			-14,
			11
		],
		[
			-38,
			1
		],
		[
			0,
			5
		],
		[
			36,
			5
		]
	],
	[
		[
			4333,
			9407
		],
		[
			21,
			-8
		],
		[
			-47,
			6
		],
		[
			55,
			-12
		],
		[
			-48,
			-4
		],
		[
			-29,
			9
		],
		[
			13,
			12
		],
		[
			35,
			-3
		]
	],
	[
		[
			4418,
			9469
		],
		[
			11,
			-1
		],
		[
			11,
			-14
		],
		[
			-32,
			-5
		],
		[
			-18,
			7
		],
		[
			3,
			8
		],
		[
			25,
			5
		]
	],
	[
		[
			4439,
			9496
		],
		[
			13,
			-2
		],
		[
			-12,
			-10
		],
		[
			-14,
			7
		],
		[
			13,
			5
		]
	],
	[
		[
			4505,
			9520
		],
		[
			-7,
			-8
		],
		[
			21,
			-2
		],
		[
			-15,
			-6
		],
		[
			-30,
			-2
		],
		[
			2,
			17
		],
		[
			29,
			1
		]
	],
	[
		[
			4481,
			9596
		],
		[
			3,
			-41
		],
		[
			-16,
			34
		],
		[
			13,
			7
		]
	],
	[
		[
			2994,
			9643
		],
		[
			23,
			-5
		],
		[
			-21,
			-3
		],
		[
			-2,
			8
		]
	],
	[
		[
			4445,
			9674
		],
		[
			18,
			-11
		],
		[
			-32,
			9
		],
		[
			14,
			2
		]
	],
	[
		[
			4519,
			9788
		],
		[
			-33,
			-16
		],
		[
			-26,
			9
		],
		[
			49,
			14
		],
		[
			10,
			-7
		]
	],
	[
		[
			3575,
			9904
		],
		[
			-53,
			7
		],
		[
			4,
			13
		],
		[
			49,
			-20
		]
	],
	[
		[
			3722,
			9942
		],
		[
			44,
			-15
		],
		[
			-28,
			-11
		],
		[
			-44,
			11
		],
		[
			-20,
			15
		],
		[
			48,
			0
		]
	],
	[
		[
			3880,
			9983
		],
		[
			38,
			-14
		],
		[
			-47,
			9
		],
		[
			9,
			5
		]
	],
	[
		[
			4105,
			9998
		],
		[
			43,
			-1
		],
		[
			139,
			-17
		],
		[
			-12,
			-6
		],
		[
			-116,
			-3
		],
		[
			-142,
			-14
		],
		[
			100,
			5
		],
		[
			47,
			8
		],
		[
			96,
			-4
		],
		[
			39,
			6
		],
		[
			2,
			-18
		],
		[
			34,
			4
		],
		[
			72,
			-17
		],
		[
			-31,
			-17
		],
		[
			-54,
			-4
		],
		[
			-152,
			-7
		],
		[
			-81,
			-17
		],
		[
			1,
			-9
		],
		[
			30,
			8
		],
		[
			107,
			13
		],
		[
			89,
			-4
		],
		[
			-3,
			-12
		],
		[
			-44,
			-9
		],
		[
			-2,
			-11
		],
		[
			85,
			20
		],
		[
			2,
			14
		],
		[
			51,
			4
		],
		[
			11,
			-19
		],
		[
			-7,
			-14
		],
		[
			-56,
			-36
		],
		[
			-16,
			-18
		],
		[
			53,
			26
		],
		[
			58,
			30
		],
		[
			75,
			-8
		],
		[
			37,
			24
		],
		[
			53,
			-1
		],
		[
			57,
			-12
		],
		[
			13,
			-8
		],
		[
			-64,
			-27
		],
		[
			-24,
			0
		],
		[
			7,
			-12
		],
		[
			-31,
			-8
		],
		[
			-46,
			1
		],
		[
			36,
			-15
		],
		[
			-18,
			-11
		],
		[
			-40,
			-3
		],
		[
			-44,
			6
		],
		[
			-25,
			-22
		],
		[
			11,
			-12
		],
		[
			20,
			3
		],
		[
			-9,
			-21
		],
		[
			17,
			-12
		],
		[
			-27,
			-8
		],
		[
			0,
			-11
		],
		[
			-28,
			-2
		],
		[
			-11,
			-42
		],
		[
			-18,
			-22
		],
		[
			18,
			0
		],
		[
			10,
			17
		],
		[
			51,
			-16
		],
		[
			-6,
			-10
		],
		[
			-19,
			10
		],
		[
			-22,
			-2
		],
		[
			38,
			-26
		],
		[
			10,
			6
		],
		[
			21,
			-5
		],
		[
			2,
			-18
		],
		[
			-10,
			-12
		],
		[
			-35,
			13
		],
		[
			-27,
			-3
		],
		[
			-24,
			-13
		],
		[
			-13,
			12
		],
		[
			-14,
			-8
		],
		[
			10,
			-12
		],
		[
			18,
			1
		],
		[
			0,
			-16
		],
		[
			19,
			4
		],
		[
			30,
			-4
		],
		[
			6,
			-11
		],
		[
			-15,
			-4
		],
		[
			21,
			-14
		],
		[
			3,
			-29
		],
		[
			-17,
			-4
		],
		[
			-4,
			9
		],
		[
			-16,
			-2
		],
		[
			-26,
			17
		],
		[
			8,
			-12
		],
		[
			24,
			-14
		],
		[
			-8,
			-27
		],
		[
			30,
			-5
		],
		[
			7,
			6
		],
		[
			13,
			-11
		],
		[
			-18,
			-15
		],
		[
			-16,
			2
		],
		[
			-7,
			11
		],
		[
			-36,
			-2
		],
		[
			-11,
			-18
		],
		[
			9,
			-27
		],
		[
			-2,
			21
		],
		[
			9,
			3
		],
		[
			36,
			-10
		],
		[
			-7,
			-26
		],
		[
			-28,
			3
		],
		[
			-18,
			-14
		],
		[
			-36,
			11
		],
		[
			-14,
			9
		],
		[
			-1,
			13
		],
		[
			-10,
			-16
		],
		[
			-25,
			-4
		],
		[
			-17,
			-16
		],
		[
			24,
			-7
		],
		[
			-16,
			-14
		],
		[
			22,
			-6
		],
		[
			6,
			-12
		],
		[
			-19,
			-7
		],
		[
			21,
			1
		],
		[
			23,
			-15
		],
		[
			33,
			-16
		],
		[
			-17,
			-14
		],
		[
			20,
			9
		],
		[
			14,
			-3
		],
		[
			-17,
			-11
		],
		[
			2,
			-17
		],
		[
			9,
			14
		],
		[
			10,
			-1
		],
		[
			0,
			-35
		],
		[
			8,
			-18
		],
		[
			-13,
			-10
		],
		[
			-11,
			3
		],
		[
			-7,
			22
		],
		[
			-2,
			-22
		],
		[
			-19,
			0
		],
		[
			-16,
			10
		],
		[
			-9,
			27
		],
		[
			-24,
			13
		],
		[
			-15,
			14
		],
		[
			-20,
			5
		],
		[
			-16,
			-3
		],
		[
			-26,
			23
		],
		[
			-16,
			-2
		],
		[
			31,
			-13
		],
		[
			-8,
			-6
		],
		[
			26,
			-8
		],
		[
			25,
			1
		],
		[
			11,
			-12
		],
		[
			-16,
			-13
		],
		[
			-24,
			-7
		],
		[
			-44,
			2
		],
		[
			14,
			-7
		],
		[
			-11,
			-17
		],
		[
			2,
			-11
		],
		[
			40,
			7
		],
		[
			13,
			-6
		],
		[
			-17,
			-3
		],
		[
			-27,
			-14
		],
		[
			-16,
			-3
		],
		[
			34,
			-3
		],
		[
			11,
			16
		],
		[
			15,
			-4
		],
		[
			29,
			13
		],
		[
			23,
			-11
		],
		[
			25,
			-7
		],
		[
			33,
			0
		],
		[
			0,
			-8
		],
		[
			-14,
			0
		],
		[
			-4,
			-12
		],
		[
			-19,
			-2
		],
		[
			1,
			-10
		],
		[
			-13,
			-8
		],
		[
			-17,
			-1
		],
		[
			2,
			-9
		],
		[
			-26,
			-21
		],
		[
			-31,
			-10
		],
		[
			-13,
			-9
		],
		[
			-23,
			1
		],
		[
			1,
			-6
		],
		[
			-24,
			-7
		],
		[
			-9,
			4
		],
		[
			-5,
			-11
		],
		[
			-18,
			10
		],
		[
			-1,
			-16
		],
		[
			-30,
			-3
		],
		[
			-30,
			17
		],
		[
			6,
			-17
		],
		[
			-4,
			-12
		],
		[
			-11,
			1
		],
		[
			-16,
			-12
		],
		[
			-12,
			-33
		],
		[
			-13,
			-5
		],
		[
			-1,
			-15
		],
		[
			-27,
			-26
		],
		[
			-15,
			-2
		],
		[
			-14,
			-18
		],
		[
			-13,
			3
		],
		[
			-20,
			-12
		],
		[
			-17,
			14
		],
		[
			15,
			16
		],
		[
			-12,
			0
		],
		[
			-7,
			-21
		],
		[
			-14,
			-1
		],
		[
			8,
			-16
		],
		[
			-17,
			1
		],
		[
			-7,
			-6
		],
		[
			-8,
			9
		],
		[
			-14,
			-12
		],
		[
			2,
			-15
		],
		[
			-14,
			-14
		],
		[
			-10,
			8
		],
		[
			-13,
			-3
		],
		[
			1,
			-12
		],
		[
			14,
			-11
		],
		[
			-1,
			-13
		],
		[
			-13,
			-9
		],
		[
			-12,
			1
		],
		[
			3,
			-8
		],
		[
			18,
			-1
		],
		[
			7,
			-27
		],
		[
			-13,
			0
		],
		[
			6,
			-7
		],
		[
			-18,
			-12
		],
		[
			-13,
			6
		],
		[
			12,
			-15
		],
		[
			-4,
			-15
		],
		[
			-21,
			-8
		],
		[
			-6,
			-11
		],
		[
			9,
			-15
		],
		[
			-21,
			9
		],
		[
			12,
			-11
		],
		[
			9,
			-1
		],
		[
			-8,
			-21
		],
		[
			11,
			5
		],
		[
			-6,
			-22
		],
		[
			-8,
			-6
		],
		[
			7,
			-7
		],
		[
			-17,
			-13
		],
		[
			9,
			-6
		],
		[
			-3,
			-17
		],
		[
			-20,
			3
		],
		[
			20,
			-7
		],
		[
			-12,
			-15
		],
		[
			-11,
			5
		],
		[
			14,
			-18
		],
		[
			0,
			-9
		],
		[
			-29,
			6
		],
		[
			-13,
			-12
		],
		[
			-12,
			10
		],
		[
			3,
			19
		],
		[
			-9,
			0
		],
		[
			6,
			10
		],
		[
			-15,
			-11
		],
		[
			-11,
			20
		],
		[
			6,
			8
		],
		[
			-3,
			10
		],
		[
			-10,
			-9
		],
		[
			-22,
			-8
		],
		[
			3,
			7
		],
		[
			-19,
			-8
		],
		[
			-17,
			0
		],
		[
			14,
			12
		],
		[
			-20,
			6
		],
		[
			-4,
			9
		],
		[
			7,
			5
		],
		[
			-20,
			5
		],
		[
			-1,
			9
		],
		[
			-10,
			13
		],
		[
			8,
			10
		],
		[
			-10,
			16
		],
		[
			-15,
			2
		],
		[
			-8,
			9
		],
		[
			5,
			28
		],
		[
			-12,
			7
		],
		[
			15,
			8
		],
		[
			-28,
			-3
		],
		[
			-2,
			19
		],
		[
			-11,
			10
		],
		[
			3,
			23
		],
		[
			-6,
			8
		],
		[
			14,
			-1
		],
		[
			13,
			13
		],
		[
			6,
			16
		],
		[
			9,
			-13
		],
		[
			-4,
			16
		],
		[
			-11,
			4
		],
		[
			-15,
			-12
		],
		[
			2,
			10
		],
		[
			-19,
			-33
		],
		[
			-9,
			0
		],
		[
			1,
			29
		],
		[
			22,
			16
		],
		[
			-10,
			2
		],
		[
			-8,
			-13
		],
		[
			-23,
			50
		],
		[
			-12,
			0
		],
		[
			-4,
			23
		],
		[
			19,
			15
		],
		[
			18,
			9
		],
		[
			21,
			21
		],
		[
			-21,
			-13
		],
		[
			-3,
			-7
		],
		[
			-33,
			-23
		],
		[
			-9,
			1
		],
		[
			1,
			22
		],
		[
			11,
			11
		],
		[
			16,
			-1
		],
		[
			5,
			10
		],
		[
			-34,
			3
		],
		[
			-6,
			14
		],
		[
			49,
			13
		],
		[
			17,
			-3
		],
		[
			12,
			6
		],
		[
			-28,
			-2
		],
		[
			-28,
			-7
		],
		[
			-21,
			-2
		],
		[
			2,
			10
		],
		[
			25,
			18
		],
		[
			15,
			2
		],
		[
			12,
			-7
		],
		[
			24,
			4
		],
		[
			-49,
			5
		],
		[
			-24,
			-17
		],
		[
			0,
			18
		],
		[
			22,
			10
		],
		[
			-5,
			12
		],
		[
			15,
			-1
		],
		[
			16,
			-8
		],
		[
			21,
			2
		],
		[
			-6,
			8
		],
		[
			7,
			12
		],
		[
			-13,
			0
		],
		[
			9,
			-8
		],
		[
			-31,
			-6
		],
		[
			-3,
			7
		],
		[
			-15,
			-1
		],
		[
			13,
			14
		],
		[
			18,
			4
		],
		[
			23,
			-2
		],
		[
			-5,
			11
		],
		[
			7,
			22
		],
		[
			16,
			-8
		],
		[
			0,
			19
		],
		[
			-17,
			-7
		],
		[
			10,
			18
		],
		[
			-2,
			11
		],
		[
			15,
			4
		],
		[
			-8,
			11
		],
		[
			-24,
			0
		],
		[
			-25,
			5
		],
		[
			-25,
			17
		],
		[
			-22,
			4
		],
		[
			-15,
			18
		],
		[
			11,
			6
		],
		[
			48,
			-8
		],
		[
			25,
			-15
		],
		[
			24,
			-6
		],
		[
			5,
			11
		],
		[
			-14,
			-6
		],
		[
			1,
			16
		],
		[
			-24,
			21
		],
		[
			17,
			-6
		],
		[
			-5,
			9
		],
		[
			-22,
			-1
		],
		[
			16,
			9
		],
		[
			-4,
			6
		],
		[
			-19,
			-12
		],
		[
			5,
			13
		],
		[
			24,
			4
		],
		[
			-8,
			4
		],
		[
			-21,
			-8
		],
		[
			-7,
			9
		],
		[
			25,
			4
		],
		[
			-41,
			6
		],
		[
			-4,
			7
		],
		[
			-14,
			-11
		],
		[
			0,
			-11
		],
		[
			-14,
			-5
		],
		[
			-24,
			1
		],
		[
			-17,
			17
		],
		[
			17,
			13
		],
		[
			-8,
			8
		],
		[
			19,
			13
		],
		[
			-21,
			11
		],
		[
			17,
			5
		],
		[
			10,
			12
		],
		[
			-3,
			15
		],
		[
			-18,
			4
		],
		[
			4,
			18
		],
		[
			-30,
			38
		],
		[
			7,
			13
		],
		[
			-16,
			5
		],
		[
			7,
			11
		],
		[
			-21,
			13
		],
		[
			4,
			8
		],
		[
			-31,
			10
		],
		[
			-14,
			17
		],
		[
			13,
			3
		],
		[
			-7,
			17
		],
		[
			-16,
			-2
		],
		[
			-4,
			10
		],
		[
			-26,
			9
		],
		[
			-17,
			-2
		],
		[
			-4,
			9
		],
		[
			-42,
			5
		],
		[
			-31,
			8
		],
		[
			-6,
			-11
		],
		[
			-27,
			5
		],
		[
			1,
			-9
		],
		[
			-35,
			-1
		],
		[
			7,
			10
		],
		[
			-15,
			1
		],
		[
			-6,
			-12
		],
		[
			-18,
			11
		],
		[
			-7,
			-6
		],
		[
			23,
			-12
		],
		[
			-58,
			9
		],
		[
			-30,
			15
		],
		[
			36,
			17
		],
		[
			-57,
			7
		],
		[
			-26,
			11
		],
		[
			12,
			12
		],
		[
			50,
			5
		],
		[
			21,
			6
		],
		[
			50,
			-3
		],
		[
			14,
			9
		],
		[
			-19,
			13
		],
		[
			-24,
			-11
		],
		[
			-45,
			-4
		],
		[
			-29,
			6
		],
		[
			21,
			8
		],
		[
			-33,
			-1
		],
		[
			13,
			9
		],
		[
			-30,
			-4
		],
		[
			-44,
			23
		],
		[
			8,
			21
		],
		[
			91,
			16
		],
		[
			8,
			10
		],
		[
			43,
			9
		],
		[
			42,
			-2
		],
		[
			31,
			23
		],
		[
			-5,
			30
		],
		[
			-56,
			2
		],
		[
			-12,
			15
		],
		[
			39,
			20
		],
		[
			28,
			7
		],
		[
			8,
			12
		],
		[
			46,
			13
		],
		[
			44,
			-9
		],
		[
			16,
			6
		],
		[
			6,
			19
		],
		[
			-19,
			15
		],
		[
			104,
			24
		],
		[
			90,
			11
		],
		[
			24,
			-14
		],
		[
			-6,
			-33
		],
		[
			24,
			17
		],
		[
			-1,
			11
		],
		[
			85,
			-18
		],
		[
			-31,
			13
		],
		[
			44,
			0
		],
		[
			-31,
			12
		],
		[
			-15,
			20
		],
		[
			65,
			-8
		],
		[
			77,
			-19
		],
		[
			22,
			-14
		],
		[
			25,
			1
		],
		[
			-8,
			28
		],
		[
			38,
			-1
		],
		[
			-68,
			26
		],
		[
			132,
			2
		],
		[
			-157,
			7
		],
		[
			28,
			14
		],
		[
			74,
			4
		],
		[
			6,
			5
		],
		[
			54,
			-17
		],
		[
			95,
			1
		],
		[
			-42,
			3
		],
		[
			53,
			5
		],
		[
			-49,
			3
		],
		[
			0,
			13
		],
		[
			180,
			11
		]
	],
	[
		[
			2530,
			6098
		],
		[
			8,
			-8
		],
		[
			4,
			5
		],
		[
			7,
			-7
		]
	],
	[
		[
			2549,
			6088
		],
		[
			-17,
			-28
		],
		[
			-9,
			-9
		],
		[
			-2,
			-15
		],
		[
			2,
			-14
		],
		[
			-6,
			-9
		]
	],
	[
		[
			2517,
			6013
		],
		[
			-6,
			-1
		],
		[
			2,
			-10
		],
		[
			-5,
			-3
		],
		[
			-10,
			-17
		],
		[
			-1,
			-9
		]
	],
	[
		[
			2497,
			5973
		],
		[
			-15,
			12
		],
		[
			-19,
			1
		],
		[
			-9,
			9
		],
		[
			-17,
			25
		]
	],
	[
		[
			2437,
			6020
		],
		[
			3,
			7
		],
		[
			-1,
			33
		],
		[
			1,
			10
		],
		[
			11,
			38
		],
		[
			36,
			0
		],
		[
			2,
			20
		],
		[
			-7,
			4
		],
		[
			-4,
			17
		],
		[
			-8,
			7
		],
		[
			-1,
			7
		],
		[
			-9,
			13
		],
		[
			12,
			0
		],
		[
			1,
			33
		],
		[
			50,
			0
		]
	],
	[
		[
			9022,
			5957
		],
		[
			-2,
			-11
		],
		[
			-3,
			10
		],
		[
			5,
			12
		],
		[
			4,
			-3
		],
		[
			-4,
			-8
		]
	],
	[
		[
			3409,
			5499
		],
		[
			-2,
			-9
		],
		[
			4,
			-10
		],
		[
			-2,
			-8
		],
		[
			-13,
			-2
		],
		[
			-5,
			-8
		],
		[
			2,
			-9
		],
		[
			-6,
			-39
		],
		[
			4,
			-7
		],
		[
			2,
			-13
		],
		[
			5,
			-8
		],
		[
			0,
			-8
		],
		[
			10,
			0
		],
		[
			2,
			-28
		],
		[
			6,
			-15
		],
		[
			0,
			-8
		],
		[
			9,
			-27
		],
		[
			6,
			-5
		]
	],
	[
		[
			3312,
			5482
		],
		[
			-18,
			43
		],
		[
			8,
			14
		],
		[
			-2,
			28
		],
		[
			9,
			7
		],
		[
			5,
			-2
		],
		[
			11,
			21
		],
		[
			-7,
			0
		],
		[
			-5,
			21
		],
		[
			5,
			19
		],
		[
			5,
			3
		],
		[
			15,
			22
		],
		[
			-6,
			18
		]
	],
	[
		[
			3332,
			5676
		],
		[
			4,
			-9
		],
		[
			7,
			-3
		],
		[
			15,
			-20
		],
		[
			17,
			-36
		],
		[
			1,
			-15
		],
		[
			-4,
			-18
		],
		[
			1,
			-10
		],
		[
			3,
			13
		],
		[
			4,
			2
		],
		[
			10,
			-8
		],
		[
			9,
			-18
		],
		[
			2,
			-9
		],
		[
			6,
			-1
		],
		[
			5,
			-11
		],
		[
			0,
			-27
		],
		[
			-3,
			-7
		]
	],
	[
		[
			8172,
			6482
		],
		[
			5,
			-7
		],
		[
			-5,
			-9
		],
		[
			-9,
			5
		],
		[
			5,
			9
		]
	],
	[
		[
			7037,
			2130
		],
		[
			10,
			-6
		],
		[
			-7,
			-4
		],
		[
			-3,
			10
		]
	],
	[
		[
			2691,
			6046
		],
		[
			-12,
			-1
		],
		[
			-4,
			-8
		],
		[
			-12,
			-4
		],
		[
			-8,
			-7
		],
		[
			-8,
			2
		],
		[
			-3,
			9
		],
		[
			-6,
			-6
		],
		[
			-4,
			-11
		],
		[
			0,
			-12
		],
		[
			-5,
			-3
		],
		[
			-5,
			-13
		],
		[
			-6,
			-5
		],
		[
			0,
			-7
		],
		[
			-8,
			9
		],
		[
			-8,
			-14
		],
		[
			-13,
			-2
		],
		[
			2,
			-26
		],
		[
			-6,
			-2
		],
		[
			0,
			-10
		],
		[
			-11,
			-5
		]
	],
	[
		[
			2574,
			5930
		],
		[
			-4,
			22
		],
		[
			-10,
			3
		]
	],
	[
		[
			2560,
			5955
		],
		[
			3,
			17
		],
		[
			-2,
			12
		],
		[
			-6,
			-1
		],
		[
			-3,
			6
		],
		[
			-10,
			-8
		],
		[
			0,
			7
		],
		[
			-7,
			3
		],
		[
			-8,
			17
		],
		[
			-10,
			5
		]
	],
	[
		[
			2549,
			6088
		],
		[
			8,
			9
		],
		[
			7,
			2
		],
		[
			7,
			-7
		],
		[
			2,
			4
		],
		[
			12,
			-6
		],
		[
			4,
			3
		],
		[
			12,
			-1
		],
		[
			13,
			11
		],
		[
			15,
			-6
		],
		[
			11,
			6
		],
		[
			18,
			-9
		],
		[
			13,
			-22
		],
		[
			-8,
			6
		],
		[
			10,
			-19
		],
		[
			8,
			0
		],
		[
			-7,
			9
		],
		[
			9,
			-6
		],
		[
			4,
			-13
		],
		[
			4,
			-3
		]
	],
	[
		[
			5512,
			7634
		],
		[
			1,
			-9
		]
	],
	[
		[
			5513,
			7625
		],
		[
			-8,
			12
		],
		[
			-27,
			21
		],
		[
			12,
			-5
		]
	],
	[
		[
			5466,
			7679
		],
		[
			-8,
			-5
		],
		[
			-2,
			8
		],
		[
			10,
			-3
		]
	],
	[
		[
			5412,
			7751
		],
		[
			11,
			-14
		],
		[
			-10,
			8
		],
		[
			-1,
			6
		]
	],
	[
		[
			5401,
			7772
		],
		[
			0,
			-20
		],
		[
			-5,
			27
		],
		[
			5,
			-7
		]
	],
	[
		[
			5404,
			7789
		],
		[
			3,
			-10
		],
		[
			-5,
			-3
		],
		[
			2,
			13
		]
	],
	[
		[
			5458,
			7861
		],
		[
			5,
			-3
		],
		[
			18,
			-29
		],
		[
			6,
			0
		],
		[
			9,
			-10
		],
		[
			17,
			0
		],
		[
			11,
			9
		]
	],
	[
		[
			5524,
			7828
		],
		[
			3,
			-33
		],
		[
			12,
			-10
		],
		[
			-10,
			-3
		],
		[
			-1,
			-17
		]
	],
	[
		[
			5488,
			7656
		],
		[
			-12,
			12
		],
		[
			-6,
			13
		],
		[
			-14,
			10
		],
		[
			-11,
			-4
		],
		[
			-2,
			10
		],
		[
			-14,
			14
		],
		[
			-9,
			17
		],
		[
			8,
			5
		],
		[
			-15,
			23
		],
		[
			-1,
			23
		],
		[
			-9,
			12
		],
		[
			-7,
			2
		],
		[
			-3,
			-20
		],
		[
			-8,
			-11
		],
		[
			-8,
			20
		],
		[
			0,
			20
		]
	],
	[
		[
			5377,
			7802
		],
		[
			9,
			-3
		],
		[
			13,
			3
		],
		[
			6,
			6
		],
		[
			20,
			-9
		],
		[
			-2,
			17
		],
		[
			12,
			6
		],
		[
			-2,
			20
		],
		[
			9,
			5
		],
		[
			8,
			12
		],
		[
			8,
			2
		]
	],
	[
		[
			3002,
			6248
		],
		[
			-1,
			2
		]
	],
	[
		[
			2977,
			6260
		],
		[
			-12,
			8
		],
		[
			1,
			7
		],
		[
			11,
			-10
		],
		[
			0,
			-5
		]
	],
	[
		[
			3000,
			6254
		],
		[
			2,
			-6
		]
	],
	[
		[
			3006,
			6222
		],
		[
			-8,
			11
		],
		[
			-24,
			-5
		],
		[
			-11,
			6
		],
		[
			-8,
			0
		],
		[
			-6,
			-5
		],
		[
			1,
			-8
		],
		[
			-12,
			16
		],
		[
			-7,
			4
		],
		[
			2,
			15
		],
		[
			6,
			2
		],
		[
			16,
			-10
		],
		[
			24,
			-4
		],
		[
			4,
			8
		],
		[
			7,
			-2
		],
		[
			0,
			7
		],
		[
			-13,
			23
		],
		[
			1,
			19
		],
		[
			3,
			2
		],
		[
			-9,
			11
		],
		[
			-11,
			1
		],
		[
			-2,
			6
		],
		[
			8,
			10
		],
		[
			11,
			2
		],
		[
			13,
			-11
		],
		[
			15,
			-2
		]
	],
	[
		[
			5614,
			7970
		],
		[
			21,
			-26
		]
	],
	[
		[
			5635,
			7944
		],
		[
			-8,
			-11
		],
		[
			-4,
			2
		],
		[
			-13,
			-17
		],
		[
			-4,
			-19
		],
		[
			-5,
			-6
		],
		[
			-4,
			-21
		],
		[
			-6,
			-5
		],
		[
			-1,
			-12
		],
		[
			-6,
			-10
		],
		[
			-7,
			2
		],
		[
			-5,
			-8
		],
		[
			-10,
			-1
		]
	],
	[
		[
			5562,
			7838
		],
		[
			-16,
			4
		],
		[
			-11,
			-11
		],
		[
			-11,
			-3
		]
	],
	[
		[
			5458,
			7861
		],
		[
			-7,
			21
		],
		[
			-4,
			-1
		]
	],
	[
		[
			5476,
			7947
		],
		[
			6,
			-1
		],
		[
			10,
			-13
		],
		[
			15,
			0
		],
		[
			14,
			3
		],
		[
			-1,
			10
		],
		[
			7,
			4
		],
		[
			14,
			3
		],
		[
			4,
			7
		],
		[
			8,
			-7
		],
		[
			12,
			11
		],
		[
			3,
			13
		],
		[
			9,
			3
		],
		[
			9,
			-5
		],
		[
			11,
			3
		],
		[
			5,
			-11
		],
		[
			12,
			3
		]
	],
	[
		[
			8426,
			4574
		],
		[
			2,
			-3
		],
		[
			-6,
			-11
		],
		[
			-11,
			-6
		],
		[
			0,
			8
		],
		[
			6,
			3
		],
		[
			10,
			17
		],
		[
			-1,
			-8
		]
	],
	[
		[
			8386,
			4582
		],
		[
			-1,
			-10
		],
		[
			-6,
			2
		],
		[
			7,
			8
		]
	],
	[
		[
			8333,
			4644
		],
		[
			9,
			-18
		],
		[
			4,
			2
		],
		[
			10,
			-24
		],
		[
			-10,
			-15
		],
		[
			-9,
			5
		],
		[
			-5,
			14
		],
		[
			-10,
			12
		],
		[
			-15,
			3
		],
		[
			-4,
			11
		],
		[
			10,
			10
		],
		[
			20,
			0
		]
	],
	[
		[
			8473,
			4637
		],
		[
			-2,
			-11
		],
		[
			-16,
			-29
		],
		[
			-8,
			0
		],
		[
			-2,
			-6
		],
		[
			-12,
			-5
		],
		[
			-3,
			9
		],
		[
			7,
			6
		],
		[
			-5,
			10
		],
		[
			2,
			16
		],
		[
			10,
			18
		]
	],
	[
		[
			8444,
			4645
		],
		[
			2,
			-5
		],
		[
			7,
			4
		],
		[
			3,
			10
		]
	],
	[
		[
			8456,
			4654
		],
		[
			13,
			13
		]
	],
	[
		[
			8469,
			4667
		],
		[
			7,
			-5
		],
		[
			0,
			-8
		],
		[
			-6,
			-2
		],
		[
			3,
			-15
		]
	],
	[
		[
			8318,
			4695
		],
		[
			-3,
			-16
		],
		[
			1,
			18
		],
		[
			2,
			-2
		]
	],
	[
		[
			8424,
			4708
		],
		[
			1,
			-8
		],
		[
			-8,
			-2
		],
		[
			4,
			11
		],
		[
			3,
			-1
		]
	],
	[
		[
			8242,
			4700
		],
		[
			-7,
			-24
		],
		[
			3,
			-4
		],
		[
			-11,
			-3
		],
		[
			-10,
			6
		],
		[
			6,
			6
		],
		[
			-1,
			15
		],
		[
			7,
			13
		],
		[
			8,
			-1
		],
		[
			5,
			-8
		]
	],
	[
		[
			8442,
			4708
		],
		[
			-5,
			-4
		],
		[
			-10,
			-16
		],
		[
			-5,
			4
		],
		[
			7,
			9
		],
		[
			-2,
			6
		],
		[
			12,
			4
		],
		[
			3,
			-3
		]
	],
	[
		[
			8450,
			4700
		],
		[
			-5,
			-10
		],
		[
			-4,
			6
		],
		[
			11,
			16
		],
		[
			-2,
			-12
		]
	],
	[
		[
			8858,
			4702
		],
		[
			-10,
			-1
		],
		[
			7,
			12
		],
		[
			3,
			-11
		]
	],
	[
		[
			8265,
			4700
		],
		[
			-2,
			12
		],
		[
			5,
			2
		],
		[
			-3,
			-14
		]
	],
	[
		[
			8459,
			4715
		],
		[
			2,
			-3
		],
		[
			13,
			1
		],
		[
			1,
			-11
		],
		[
			-22,
			-6
		],
		[
			3,
			18
		],
		[
			3,
			1
		]
	],
	[
		[
			8550,
			4716
		],
		[
			8,
			-3
		],
		[
			-2,
			-6
		],
		[
			-6,
			9
		]
	],
	[
		[
			8276,
			4716
		],
		[
			4,
			0
		],
		[
			5,
			-15
		],
		[
			6,
			7
		],
		[
			6,
			-6
		],
		[
			8,
			2
		],
		[
			1,
			-19
		],
		[
			-18,
			-12
		],
		[
			0,
			10
		],
		[
			-7,
			-11
		],
		[
			-12,
			-2
		],
		[
			-9,
			-9
		],
		[
			-7,
			-2
		],
		[
			-11,
			5
		],
		[
			2,
			11
		],
		[
			-1,
			13
		],
		[
			12,
			14
		],
		[
			6,
			-8
		],
		[
			4,
			5
		],
		[
			6,
			-18
		],
		[
			14,
			4
		],
		[
			-6,
			11
		],
		[
			-4,
			1
		],
		[
			-6,
			16
		],
		[
			7,
			3
		]
	],
	[
		[
			8415,
			4713
		],
		[
			2,
			-8
		],
		[
			-7,
			-8
		],
		[
			2,
			-8
		],
		[
			-13,
			-10
		],
		[
			-8,
			1
		],
		[
			-9,
			-9
		],
		[
			-11,
			5
		],
		[
			-1,
			-7
		],
		[
			-12,
			0
		],
		[
			-2,
			6
		],
		[
			-7,
			2
		],
		[
			-9,
			-3
		],
		[
			-13,
			4
		],
		[
			0,
			11
		],
		[
			13,
			18
		],
		[
			19,
			-4
		],
		[
			15,
			-16
		],
		[
			15,
			11
		],
		[
			6,
			-12
		],
		[
			6,
			1
		],
		[
			0,
			7
		],
		[
			12,
			12
		],
		[
			-4,
			4
		],
		[
			3,
			8
		],
		[
			3,
			-5
		]
	],
	[
		[
			8208,
			4712
		],
		[
			5,
			-15
		],
		[
			-14,
			-15
		],
		[
			-7,
			13
		],
		[
			-11,
			8
		],
		[
			-3,
			14
		],
		[
			12,
			-6
		],
		[
			8,
			8
		],
		[
			10,
			-7
		]
	],
	[
		[
			8604,
			4733
		],
		[
			0,
			-14
		],
		[
			-5,
			14
		],
		[
			5,
			0
		]
	],
	[
		[
			8519,
			4741
		],
		[
			-6,
			-15
		],
		[
			-15,
			2
		],
		[
			-5,
			-7
		],
		[
			5,
			21
		],
		[
			11,
			-2
		],
		[
			8,
			7
		],
		[
			2,
			-6
		]
	],
	[
		[
			8857,
			4720
		],
		[
			-12,
			-20
		],
		[
			-23,
			0
		],
		[
			5,
			24
		],
		[
			6,
			21
		],
		[
			6,
			8
		],
		[
			11,
			6
		],
		[
			5,
			-1
		],
		[
			7,
			-11
		],
		[
			-5,
			-27
		]
	],
	[
		[
			8656,
			4770
		],
		[
			0,
			-26
		],
		[
			-8,
			-16
		],
		[
			-7,
			-6
		],
		[
			3,
			28
		],
		[
			10,
			23
		],
		[
			2,
			-3
		]
	],
	[
		[
			8664,
			4774
		],
		[
			1,
			-9
		],
		[
			-7,
			7
		],
		[
			6,
			2
		]
	],
	[
		[
			8166,
			4787
		],
		[
			3,
			-6
		],
		[
			-12,
			-8
		],
		[
			-3,
			-6
		],
		[
			-12,
			-1
		],
		[
			-12,
			5
		],
		[
			4,
			15
		],
		[
			32,
			1
		]
	],
	[
		[
			8204,
			4789
		],
		[
			6,
			-5
		],
		[
			-10,
			-1
		],
		[
			4,
			6
		]
	],
	[
		[
			8738,
			4813
		],
		[
			-1,
			-5
		],
		[
			-6,
			7
		],
		[
			3,
			6
		],
		[
			4,
			-8
		]
	],
	[
		[
			8733,
			4812
		],
		[
			3,
			-8
		],
		[
			-6,
			-16
		],
		[
			-7,
			2
		],
		[
			2,
			30
		],
		[
			-1,
			7
		],
		[
			9,
			-15
		]
	],
	[
		[
			7948,
			4837
		],
		[
			3,
			4
		],
		[
			13,
			-9
		],
		[
			8,
			1
		],
		[
			0,
			9
		],
		[
			9,
			-3
		],
		[
			2,
			-10
		],
		[
			7,
			-5
		],
		[
			6,
			2
		],
		[
			5,
			-8
		],
		[
			8,
			5
		],
		[
			5,
			-14
		],
		[
			2,
			-16
		],
		[
			11,
			-1
		],
		[
			10,
			-5
		],
		[
			4,
			4
		],
		[
			11,
			-7
		],
		[
			7,
			4
		],
		[
			5,
			-7
		],
		[
			7,
			8
		],
		[
			2,
			19
		],
		[
			4,
			5
		],
		[
			7,
			-1
		],
		[
			3,
			-15
		],
		[
			12,
			3
		],
		[
			12,
			-14
		],
		[
			16,
			1
		],
		[
			0,
			-13
		],
		[
			6,
			-8
		],
		[
			-2,
			-17
		],
		[
			16,
			-15
		],
		[
			12,
			4
		],
		[
			7,
			6
		],
		[
			13,
			-11
		],
		[
			-3,
			-41
		],
		[
			7,
			-10
		],
		[
			-18,
			4
		],
		[
			-20,
			20
		],
		[
			-6,
			-1
		],
		[
			-10,
			-8
		],
		[
			-9,
			6
		],
		[
			-16,
			4
		],
		[
			-2,
			-6
		],
		[
			-9,
			6
		],
		[
			-11,
			0
		],
		[
			-13,
			8
		],
		[
			-14,
			14
		],
		[
			-18,
			10
		],
		[
			-23,
			1
		],
		[
			-2,
			-7
		],
		[
			-18,
			4
		],
		[
			-11,
			14
		],
		[
			-25,
			5
		],
		[
			-4,
			10
		],
		[
			4,
			15
		],
		[
			-7,
			-1
		],
		[
			-7,
			10
		],
		[
			-20,
			-2
		],
		[
			3,
			10
		],
		[
			2,
			-8
		],
		[
			4,
			17
		],
		[
			5,
			1
		],
		[
			1,
			18
		],
		[
			5,
			17
		],
		[
			4,
			-6
		]
	],
	[
		[
			8346,
			4810
		],
		[
			-1,
			39
		],
		[
			3,
			-8
		],
		[
			-2,
			-31
		]
	],
	[
		[
			8685,
			4859
		],
		[
			3,
			-16
		],
		[
			-4,
			0
		],
		[
			1,
			16
		]
	],
	[
		[
			8737,
			4870
		],
		[
			5,
			-12
		],
		[
			1,
			-27
		],
		[
			-5,
			-14
		],
		[
			-8,
			8
		],
		[
			-1,
			9
		],
		[
			2,
			19
		],
		[
			6,
			17
		]
	],
	[
		[
			7843,
			4868
		],
		[
			-9,
			8
		],
		[
			9,
			-3
		],
		[
			0,
			-5
		]
	],
	[
		[
			8386,
			4889
		],
		[
			2,
			1
		],
		[
			2,
			-20
		],
		[
			-3,
			-2
		],
		[
			-4,
			10
		],
		[
			3,
			11
		]
	],
	[
		[
			8410,
			4898
		],
		[
			-4,
			-6
		],
		[
			0,
			-18
		],
		[
			-10,
			-1
		],
		[
			3,
			23
		],
		[
			-2,
			8
		],
		[
			11,
			13
		],
		[
			2,
			-19
		]
	],
	[
		[
			8422,
			4913
		],
		[
			0,
			-9
		],
		[
			-5,
			6
		],
		[
			-2,
			-24
		],
		[
			7,
			-6
		],
		[
			-2,
			-7
		],
		[
			-8,
			-5
		],
		[
			0,
			-10
		],
		[
			-6,
			-1
		],
		[
			-2,
			9
		],
		[
			5,
			17
		],
		[
			3,
			22
		],
		[
			0,
			15
		],
		[
			4,
			10
		],
		[
			6,
			-17
		]
	],
	[
		[
			8418,
			4952
		],
		[
			5,
			-5
		],
		[
			-3,
			-8
		],
		[
			-5,
			6
		],
		[
			3,
			7
		]
	],
	[
		[
			8564,
			4977
		],
		[
			-2,
			-8
		],
		[
			-9,
			-3
		],
		[
			3,
			10
		],
		[
			8,
			1
		]
	],
	[
		[
			8225,
			4951
		],
		[
			-3,
			23
		],
		[
			3,
			18
		],
		[
			4,
			5
		],
		[
			1,
			-36
		],
		[
			-5,
			-10
		]
	],
	[
		[
			8523,
			5004
		],
		[
			7,
			-6
		],
		[
			-2,
			-7
		],
		[
			6,
			-2
		],
		[
			0,
			-14
		],
		[
			-15,
			-15
		],
		[
			-15,
			15
		],
		[
			-5,
			14
		],
		[
			1,
			12
		],
		[
			11,
			5
		],
		[
			12,
			-2
		]
	],
	[
		[
			8598,
			5023
		],
		[
			14,
			-13
		],
		[
			8,
			1
		],
		[
			7,
			-8
		],
		[
			1,
			-15
		],
		[
			7,
			-11
		],
		[
			-1,
			-17
		],
		[
			-24,
			23
		],
		[
			-3,
			8
		],
		[
			-9,
			2
		],
		[
			-2,
			-10
		],
		[
			-15,
			7
		],
		[
			-2,
			8
		],
		[
			-6,
			-10
		],
		[
			-7,
			-2
		],
		[
			-6,
			20
		],
		[
			-4,
			-17
		],
		[
			-6,
			11
		],
		[
			8,
			6
		],
		[
			1,
			12
		],
		[
			21,
			0
		],
		[
			5,
			-5
		],
		[
			13,
			10
		]
	],
	[
		[
			7789,
			5006
		],
		[
			0,
			-13
		],
		[
			-7,
			21
		],
		[
			0,
			8
		],
		[
			6,
			-7
		],
		[
			1,
			-9
		]
	],
	[
		[
			7994,
			5036
		],
		[
			13,
			-12
		],
		[
			-2,
			-21
		],
		[
			-6,
			-7
		],
		[
			-3,
			11
		],
		[
			-8,
			-10
		],
		[
			0,
			26
		],
		[
			2,
			12
		],
		[
			4,
			1
		]
	],
	[
		[
			7782,
			5024
		],
		[
			-5,
			-4
		],
		[
			0,
			20
		],
		[
			5,
			-16
		]
	],
	[
		[
			7769,
			5060
		],
		[
			4,
			-12
		],
		[
			-4,
			1
		],
		[
			-5,
			11
		],
		[
			5,
			0
		]
	],
	[
		[
			8501,
			5041
		],
		[
			-3,
			3
		],
		[
			-3,
			21
		],
		[
			4,
			3
		],
		[
			2,
			-27
		]
	],
	[
		[
			8483,
			5079
		],
		[
			15,
			1
		],
		[
			11,
			-2
		],
		[
			-2,
			-3
		],
		[
			-24,
			-4
		],
		[
			0,
			8
		]
	],
	[
		[
			8620,
			5085
		],
		[
			2,
			-15
		],
		[
			-6,
			-6
		],
		[
			-14,
			10
		],
		[
			10,
			9
		],
		[
			8,
			2
		]
	],
	[
		[
			8458,
			5089
		],
		[
			22,
			-6
		],
		[
			0,
			-9
		],
		[
			-8,
			-3
		],
		[
			-7,
			2
		],
		[
			-10,
			-6
		],
		[
			-1,
			20
		],
		[
			4,
			2
		]
	],
	[
		[
			8762,
			5091
		],
		[
			20,
			-3
		],
		[
			6,
			-5
		],
		[
			14,
			-4
		],
		[
			-11,
			-5
		],
		[
			-15,
			5
		],
		[
			-14,
			12
		]
	],
	[
		[
			7940,
			5097
		],
		[
			5,
			-5
		],
		[
			4,
			-17
		],
		[
			0,
			-18
		],
		[
			4,
			-16
		],
		[
			14,
			-6
		],
		[
			-5,
			-8
		],
		[
			-2,
			-12
		],
		[
			4,
			-10
		],
		[
			-22,
			15
		],
		[
			0,
			21
		],
		[
			-3,
			4
		],
		[
			-1,
			14
		],
		[
			-18,
			4
		],
		[
			0,
			8
		],
		[
			7,
			9
		],
		[
			-3,
			5
		],
		[
			9,
			9
		],
		[
			2,
			-13
		],
		[
			3,
			1
		],
		[
			-2,
			12
		],
		[
			4,
			3
		]
	],
	[
		[
			8550,
			5100
		],
		[
			9,
			-9
		],
		[
			-6,
			-5
		],
		[
			-11,
			-3
		],
		[
			-5,
			6
		],
		[
			1,
			9
		],
		[
			6,
			8
		],
		[
			6,
			-6
		]
	],
	[
		[
			8421,
			5116
		],
		[
			1,
			-14
		],
		[
			3,
			9
		],
		[
			6,
			-1
		],
		[
			0,
			-10
		],
		[
			-4,
			-5
		],
		[
			-3,
			6
		],
		[
			-1,
			-12
		],
		[
			-3,
			18
		],
		[
			-6,
			-15
		],
		[
			-4,
			10
		],
		[
			3,
			13
		],
		[
			8,
			1
		]
	],
	[
		[
			8044,
			5127
		],
		[
			4,
			-10
		],
		[
			-9,
			-8
		],
		[
			0,
			18
		],
		[
			5,
			0
		]
	],
	[
		[
			7746,
			5129
		],
		[
			7,
			-31
		],
		[
			4,
			-7
		],
		[
			-2,
			-11
		],
		[
			-9,
			6
		],
		[
			-9,
			29
		],
		[
			3,
			13
		],
		[
			6,
			1
		]
	],
	[
		[
			8636,
			5129
		],
		[
			4,
			-8
		],
		[
			-2,
			-16
		],
		[
			-7,
			6
		],
		[
			-3,
			15
		],
		[
			8,
			3
		]
	],
	[
		[
			8634,
			5139
		],
		[
			-7,
			-9
		],
		[
			-4,
			6
		],
		[
			11,
			3
		]
	],
	[
		[
			8761,
			5145
		],
		[
			12,
			-2
		],
		[
			9,
			-20
		],
		[
			6,
			-4
		],
		[
			-7,
			-7
		],
		[
			-7,
			2
		],
		[
			-4,
			22
		],
		[
			-3,
			-4
		],
		[
			-6,
			13
		]
	],
	[
		[
			8536,
			5138
		],
		[
			-5,
			0
		],
		[
			3,
			9
		],
		[
			2,
			-9
		]
	],
	[
		[
			8915,
			5033
		],
		[
			0,
			-218
		],
		[
			-3,
			-12
		],
		[
			3,
			-17
		],
		[
			0,
			-128
		]
	],
	[
		[
			8915,
			4658
		],
		[
			-10,
			18
		],
		[
			-4,
			12
		],
		[
			-15,
			28
		],
		[
			-17,
			-5
		],
		[
			-3,
			6
		],
		[
			-7,
			-8
		],
		[
			-1,
			19
		],
		[
			5,
			19
		],
		[
			-4,
			4
		],
		[
			-7,
			18
		],
		[
			13,
			-3
		],
		[
			-12,
			8
		],
		[
			-4,
			13
		],
		[
			10,
			2
		],
		[
			-8,
			7
		],
		[
			1,
			5
		],
		[
			-7,
			13
		],
		[
			-3,
			32
		],
		[
			-8,
			7
		],
		[
			0,
			12
		],
		[
			-4,
			8
		],
		[
			-15,
			20
		],
		[
			-21,
			12
		],
		[
			-18,
			18
		],
		[
			-14,
			4
		],
		[
			-7,
			-1
		],
		[
			-16,
			20
		],
		[
			1,
			11
		],
		[
			-4,
			-6
		],
		[
			-5,
			9
		],
		[
			-1,
			-9
		],
		[
			-5,
			7
		],
		[
			1,
			8
		],
		[
			-6,
			-4
		],
		[
			-4,
			14
		],
		[
			-3,
			-5
		],
		[
			0,
			28
		],
		[
			6,
			6
		],
		[
			-1,
			9
		],
		[
			-6,
			-11
		],
		[
			0,
			-14
		],
		[
			-7,
			-21
		],
		[
			1,
			-8
		],
		[
			-5,
			-11
		],
		[
			-7,
			-3
		],
		[
			-6,
			11
		],
		[
			-2,
			14
		],
		[
			6,
			8
		],
		[
			-9,
			15
		],
		[
			-3,
			12
		],
		[
			-6,
			8
		],
		[
			-6,
			-2
		],
		[
			-2,
			12
		],
		[
			5,
			5
		],
		[
			10,
			-2
		],
		[
			4,
			-6
		],
		[
			9,
			18
		],
		[
			7,
			5
		],
		[
			7,
			-10
		],
		[
			8,
			7
		],
		[
			4,
			12
		],
		[
			-1,
			9
		],
		[
			-7,
			-8
		],
		[
			-11,
			2
		],
		[
			-16,
			-6
		],
		[
			-4,
			7
		],
		[
			-6,
			-5
		],
		[
			-8,
			11
		],
		[
			-4,
			22
		],
		[
			-5,
			11
		],
		[
			-9,
			2
		],
		[
			-5,
			-3
		],
		[
			-7,
			4
		],
		[
			3,
			13
		],
		[
			5,
			6
		],
		[
			0,
			18
		],
		[
			7,
			5
		],
		[
			8,
			0
		],
		[
			10,
			17
		],
		[
			8,
			5
		],
		[
			8,
			-1
		],
		[
			12,
			-10
		],
		[
			6,
			-11
		],
		[
			17,
			0
		],
		[
			5,
			-8
		],
		[
			-4,
			-5
		],
		[
			7,
			-22
		],
		[
			-1,
			-12
		],
		[
			-4,
			-7
		],
		[
			2,
			-39
		],
		[
			5,
			-10
		],
		[
			3,
			-17
		],
		[
			1,
			17
		],
		[
			5,
			-3
		],
		[
			1,
			-23
		],
		[
			5,
			-17
		],
		[
			6,
			-6
		],
		[
			11,
			0
		],
		[
			2,
			7
		],
		[
			10,
			16
		],
		[
			1,
			11
		],
		[
			9,
			14
		],
		[
			3,
			18
		],
		[
			9,
			-2
		],
		[
			14,
			10
		],
		[
			-3,
			16
		],
		[
			19,
			18
		],
		[
			4,
			0
		],
		[
			11,
			-13
		],
		[
			9,
			-4
		],
		[
			5,
			-10
		],
		[
			7,
			-3
		],
		[
			20,
			-21
		],
		[
			10,
			3
		],
		[
			16,
			-10
		],
		[
			-2,
			-6
		],
		[
			8,
			0
		]
	],
	[
		[
			7903,
			5160
		],
		[
			0,
			-12
		],
		[
			-8,
			7
		],
		[
			6,
			9
		],
		[
			2,
			-4
		]
	],
	[
		[
			8544,
			5159
		],
		[
			1,
			-17
		],
		[
			6,
			0
		],
		[
			-1,
			-9
		],
		[
			-5,
			6
		],
		[
			-5,
			-3
		],
		[
			0,
			10
		],
		[
			-5,
			11
		],
		[
			6,
			9
		],
		[
			3,
			-7
		]
	],
	[
		[
			8533,
			5168
		],
		[
			1,
			-14
		],
		[
			-4,
			-1
		],
		[
			0,
			14
		],
		[
			3,
			1
		]
	],
	[
		[
			7735,
			5153
		],
		[
			-4,
			0
		],
		[
			3,
			16
		],
		[
			1,
			-16
		]
	],
	[
		[
			7881,
			5163
		],
		[
			-8,
			-1
		],
		[
			3,
			8
		],
		[
			5,
			-7
		]
	],
	[
		[
			8633,
			5183
		],
		[
			14,
			-10
		],
		[
			-2,
			-13
		],
		[
			-6,
			2
		],
		[
			-11,
			13
		],
		[
			8,
			-16
		],
		[
			-6,
			-1
		],
		[
			-1,
			8
		],
		[
			-9,
			2
		],
		[
			-2,
			9
		],
		[
			15,
			6
		]
	],
	[
		[
			7737,
			5167
		],
		[
			-5,
			8
		],
		[
			0,
			8
		],
		[
			5,
			-16
		]
	],
	[
		[
			7904,
			5183
		],
		[
			11,
			-16
		],
		[
			-7,
			4
		],
		[
			-8,
			-1
		],
		[
			4,
			13
		]
	],
	[
		[
			7850,
			5240
		],
		[
			4,
			0
		],
		[
			7,
			-11
		],
		[
			-14,
			-1
		],
		[
			-1,
			20
		],
		[
			4,
			-8
		]
	],
	[
		[
			7861,
			5243
		],
		[
			2,
			-12
		],
		[
			-8,
			11
		],
		[
			-5,
			-1
		],
		[
			5,
			9
		],
		[
			6,
			-7
		]
	],
	[
		[
			7892,
			5248
		],
		[
			-1,
			-8
		],
		[
			-5,
			3
		],
		[
			6,
			5
		]
	],
	[
		[
			7904,
			5252
		],
		[
			2,
			-10
		],
		[
			-2,
			-11
		],
		[
			-3,
			13
		],
		[
			-6,
			-3
		],
		[
			2,
			9
		],
		[
			7,
			2
		]
	],
	[
		[
			7845,
			5238
		],
		[
			-6,
			7
		],
		[
			-1,
			17
		],
		[
			3,
			2
		],
		[
			5,
			-9
		],
		[
			-1,
			-17
		]
	],
	[
		[
			7704,
			5270
		],
		[
			3,
			-2
		],
		[
			6,
			-18
		],
		[
			6,
			-7
		],
		[
			-2,
			-28
		],
		[
			-4,
			1
		],
		[
			-3,
			14
		],
		[
			-5,
			7
		],
		[
			-8,
			26
		],
		[
			7,
			7
		]
	],
	[
		[
			7839,
			5273
		],
		[
			7,
			-4
		],
		[
			0,
			-13
		],
		[
			-10,
			11
		],
		[
			-2,
			10
		],
		[
			5,
			-4
		]
	],
	[
		[
			8473,
			5279
		],
		[
			5,
			-11
		],
		[
			-3,
			-3
		],
		[
			-6,
			-26
		],
		[
			-5,
			-5
		],
		[
			-7,
			-25
		],
		[
			-24,
			-11
		],
		[
			-11,
			3
		],
		[
			-4,
			10
		],
		[
			-24,
			0
		],
		[
			-12,
			-4
		],
		[
			-6,
			6
		],
		[
			-13,
			-7
		],
		[
			-11,
			7
		],
		[
			-10,
			-4
		],
		[
			-7,
			-19
		],
		[
			-3,
			-19
		],
		[
			3,
			-26
		],
		[
			4,
			-13
		],
		[
			5,
			-1
		],
		[
			5,
			-12
		],
		[
			2,
			-17
		],
		[
			13,
			1
		],
		[
			2,
			12
		],
		[
			8,
			18
		],
		[
			5,
			-3
		],
		[
			13,
			0
		],
		[
			1,
			9
		],
		[
			15,
			-2
		],
		[
			7,
			4
		],
		[
			-7,
			4
		],
		[
			10,
			6
		],
		[
			9,
			-5
		],
		[
			0,
			-20
		],
		[
			-3,
			-4
		],
		[
			-4,
			11
		],
		[
			-9,
			-3
		],
		[
			-8,
			-23
		],
		[
			-9,
			-17
		],
		[
			-12,
			-6
		],
		[
			-3,
			-12
		],
		[
			-10,
			8
		],
		[
			0,
			-8
		],
		[
			8,
			-15
		],
		[
			5,
			-3
		],
		[
			11,
			-32
		],
		[
			7,
			-26
		],
		[
			-5,
			-8
		],
		[
			-1,
			-14
		],
		[
			13,
			-17
		],
		[
			-1,
			-9
		],
		[
			7,
			-3
		],
		[
			0,
			-15
		],
		[
			-4,
			-6
		],
		[
			-4,
			6
		],
		[
			-14,
			-7
		],
		[
			-2,
			-7
		],
		[
			2,
			-12
		],
		[
			-12,
			1
		],
		[
			-5,
			9
		],
		[
			1,
			25
		],
		[
			3,
			8
		],
		[
			-8,
			7
		],
		[
			-13,
			25
		],
		[
			0,
			9
		],
		[
			5,
			10
		],
		[
			1,
			26
		],
		[
			-8,
			8
		],
		[
			-17,
			-20
		],
		[
			6,
			-16
		],
		[
			0,
			-25
		],
		[
			-2,
			-12
		],
		[
			1,
			-36
		],
		[
			2,
			-7
		],
		[
			-4,
			-14
		],
		[
			-1,
			-14
		],
		[
			5,
			-24
		],
		[
			-15,
			-2
		],
		[
			-4,
			-8
		],
		[
			-11,
			16
		],
		[
			0,
			14
		],
		[
			3,
			7
		],
		[
			0,
			18
		],
		[
			4,
			19
		],
		[
			0,
			23
		],
		[
			-5,
			19
		],
		[
			2,
			12
		],
		[
			-6,
			3
		],
		[
			-10,
			-8
		],
		[
			-3,
			14
		],
		[
			2,
			27
		],
		[
			-4,
			0
		],
		[
			1,
			13
		],
		[
			3,
			-1
		],
		[
			7,
			11
		],
		[
			-1,
			15
		],
		[
			3,
			13
		],
		[
			4,
			2
		],
		[
			-2,
			14
		],
		[
			0,
			26
		],
		[
			5,
			11
		],
		[
			1,
			11
		],
		[
			7,
			11
		],
		[
			1,
			50
		],
		[
			3,
			16
		],
		[
			4,
			4
		],
		[
			-1,
			10
		],
		[
			9,
			8
		],
		[
			7,
			-3
		],
		[
			6,
			14
		],
		[
			0,
			15
		],
		[
			3,
			3
		],
		[
			10,
			-7
		],
		[
			5,
			3
		],
		[
			0,
			-9
		],
		[
			5,
			-4
		],
		[
			8,
			2
		],
		[
			8,
			-5
		],
		[
			7,
			1
		],
		[
			10,
			-12
		],
		[
			4,
			8
		],
		[
			19,
			-6
		],
		[
			8,
			1
		],
		[
			10,
			8
		],
		[
			9,
			23
		],
		[
			10,
			19
		],
		[
			2,
			-4
		]
	],
	[
		[
			7825,
			5301
		],
		[
			0,
			-16
		],
		[
			-7,
			-2
		],
		[
			-2,
			18
		],
		[
			9,
			0
		]
	],
	[
		[
			8556,
			5309
		],
		[
			-6,
			-20
		],
		[
			5,
			-6
		],
		[
			0,
			-25
		],
		[
			-11,
			-20
		],
		[
			3,
			-8
		],
		[
			6,
			3
		],
		[
			0,
			8
		],
		[
			7,
			8
		],
		[
			-3,
			5
		],
		[
			3,
			9
		],
		[
			11,
			11
		],
		[
			4,
			-1
		],
		[
			-1,
			-29
		],
		[
			-11,
			-9
		],
		[
			0,
			-14
		],
		[
			11,
			-6
		],
		[
			0,
			-13
		],
		[
			-20,
			8
		],
		[
			-3,
			-10
		],
		[
			1,
			-20
		],
		[
			5,
			-25
		],
		[
			10,
			-24
		],
		[
			-11,
			11
		],
		[
			-5,
			20
		],
		[
			-5,
			6
		],
		[
			1,
			34
		],
		[
			-4,
			4
		],
		[
			-2,
			38
		],
		[
			-3,
			10
		],
		[
			4,
			12
		],
		[
			0,
			12
		],
		[
			4,
			16
		],
		[
			10,
			15
		]
	],
	[
		[
			8571,
			5333
		],
		[
			3,
			-7
		],
		[
			-3,
			-21
		],
		[
			-8,
			-7
		],
		[
			-3,
			16
		],
		[
			5,
			13
		],
		[
			6,
			6
		]
	],
	[
		[
			7663,
			5350
		],
		[
			2,
			-7
		],
		[
			14,
			-20
		],
		[
			-5,
			0
		],
		[
			-14,
			13
		],
		[
			-4,
			9
		],
		[
			7,
			5
		]
	],
	[
		[
			8268,
			5370
		],
		[
			-4,
			6
		],
		[
			4,
			4
		],
		[
			0,
			-10
		]
	],
	[
		[
			8489,
			5385
		],
		[
			-4,
			-3
		],
		[
			0,
			16
		],
		[
			4,
			-13
		]
	],
	[
		[
			8269,
			5423
		],
		[
			5,
			-1
		]
	],
	[
		[
			8274,
			5422
		],
		[
			-2,
			-7
		],
		[
			-3,
			8
		]
	],
	[
		[
			8008,
			5418
		],
		[
			2,
			-16
		],
		[
			-2,
			-7
		],
		[
			-8,
			11
		],
		[
			-1,
			9
		],
		[
			7,
			11
		],
		[
			2,
			-8
		]
	],
	[
		[
			8265,
			5422
		],
		[
			-5,
			1
		],
		[
			11,
			-21
		],
		[
			-1,
			-10
		],
		[
			-15,
			-1
		],
		[
			7,
			-13
		],
		[
			-5,
			-10
		],
		[
			11,
			-13
		],
		[
			-4,
			-4
		],
		[
			16,
			-37
		],
		[
			-8,
			-15
		],
		[
			1,
			-8
		],
		[
			7,
			-13
		],
		[
			9,
			-10
		],
		[
			10,
			-16
		],
		[
			6,
			-14
		],
		[
			-7,
			-9
		],
		[
			-16,
			4
		],
		[
			-8,
			12
		],
		[
			4,
			-17
		],
		[
			-6,
			2
		],
		[
			-6,
			-18
		],
		[
			-4,
			-26
		],
		[
			2,
			-2
		],
		[
			-3,
			-17
		],
		[
			1,
			-14
		],
		[
			4,
			4
		],
		[
			-3,
			-14
		],
		[
			4,
			-4
		],
		[
			-9,
			-8
		],
		[
			-1,
			5
		],
		[
			-7,
			-22
		],
		[
			-14,
			-16
		],
		[
			1,
			-8
		],
		[
			-9,
			-10
		],
		[
			6,
			1
		],
		[
			-2,
			-24
		],
		[
			6,
			0
		],
		[
			-2,
			-19
		],
		[
			-4,
			-2
		],
		[
			0,
			-18
		],
		[
			-5,
			-7
		],
		[
			-6,
			-36
		],
		[
			-38,
			-32
		],
		[
			0,
			28
		],
		[
			-14,
			23
		],
		[
			-6,
			-9
		],
		[
			-9,
			3
		],
		[
			0,
			12
		],
		[
			-6,
			-6
		],
		[
			-9,
			20
		],
		[
			-3,
			-10
		],
		[
			3,
			-3
		],
		[
			-14,
			-16
		],
		[
			-9,
			6
		],
		[
			-7,
			-11
		],
		[
			-4,
			-1
		],
		[
			1,
			27
		],
		[
			-4,
			17
		],
		[
			0,
			-10
		],
		[
			-4,
			-4
		],
		[
			-7,
			5
		],
		[
			-9,
			-9
		],
		[
			-7,
			6
		],
		[
			-2,
			-5
		],
		[
			-3,
			12
		],
		[
			-7,
			-8
		],
		[
			-6,
			62
		],
		[
			-5,
			8
		],
		[
			3,
			3
		],
		[
			2,
			20
		],
		[
			-4,
			16
		],
		[
			-7,
			11
		],
		[
			-7,
			4
		],
		[
			-2,
			-4
		],
		[
			-7,
			21
		],
		[
			0,
			34
		],
		[
			5,
			-2
		],
		[
			-5,
			14
		],
		[
			-5,
			4
		],
		[
			0,
			20
		],
		[
			3,
			50
		],
		[
			7,
			9
		],
		[
			1,
			14
		],
		[
			9,
			9
		]
	],
	[
		[
			8045,
			5303
		],
		[
			-3,
			-16
		],
		[
			3,
			-12
		],
		[
			17,
			-35
		],
		[
			7,
			-8
		],
		[
			8,
			3
		],
		[
			2,
			6
		],
		[
			10,
			4
		],
		[
			7,
			-6
		],
		[
			9,
			2
		],
		[
			8,
			7
		],
		[
			2,
			18
		],
		[
			8,
			7
		],
		[
			15,
			0
		],
		[
			-2,
			-8
		],
		[
			9,
			-3
		],
		[
			11,
			-8
		],
		[
			7,
			12
		],
		[
			16,
			-1
		],
		[
			5,
			12
		],
		[
			1,
			13
		],
		[
			3,
			2
		],
		[
			-1,
			20
		],
		[
			12,
			14
		],
		[
			-4,
			12
		],
		[
			1,
			10
		],
		[
			5,
			10
		],
		[
			6,
			-1
		],
		[
			4,
			65
		],
		[
			5,
			11
		],
		[
			6,
			-4
		],
		[
			3,
			5
		],
		[
			7,
			-4
		],
		[
			10,
			4
		],
		[
			13,
			0
		],
		[
			10,
			-12
		]
	],
	[
		[
			8523,
			5442
		],
		[
			2,
			-13
		],
		[
			-3,
			-14
		],
		[
			-4,
			-2
		],
		[
			2,
			32
		],
		[
			3,
			-3
		]
	],
	[
		[
			7652,
			5506
		],
		[
			11,
			-6
		],
		[
			4,
			-11
		],
		[
			10,
			-6
		],
		[
			12,
			4
		],
		[
			10,
			-8
		],
		[
			9,
			6
		],
		[
			11,
			-21
		],
		[
			3,
			-16
		],
		[
			6,
			-9
		],
		[
			0,
			-16
		],
		[
			13,
			-17
		],
		[
			3,
			-9
		],
		[
			6,
			-5
		],
		[
			20,
			-26
		],
		[
			7,
			-15
		],
		[
			-1,
			-13
		],
		[
			3,
			-5
		],
		[
			3,
			6
		],
		[
			6,
			-23
		],
		[
			14,
			-21
		],
		[
			-2,
			19
		],
		[
			6,
			1
		],
		[
			8,
			-16
		],
		[
			1,
			-14
		],
		[
			10,
			-6
		],
		[
			12,
			-18
		],
		[
			1,
			-19
		],
		[
			7,
			-15
		],
		[
			13,
			-3
		],
		[
			5,
			-14
		],
		[
			-13,
			-13
		],
		[
			8,
			1
		],
		[
			12,
			15
		],
		[
			11,
			-13
		],
		[
			2,
			-18
		],
		[
			-7,
			0
		],
		[
			-6,
			-21
		],
		[
			7,
			-4
		],
		[
			-5,
			-5
		],
		[
			1,
			-12
		],
		[
			4,
			-12
		],
		[
			9,
			-1
		],
		[
			7,
			-6
		],
		[
			6,
			2
		],
		[
			2,
			-16
		],
		[
			1,
			-28
		],
		[
			4,
			-14
		],
		[
			7,
			-5
		],
		[
			-1,
			-9
		],
		[
			8,
			-5
		],
		[
			13,
			-1
		],
		[
			0,
			-13
		],
		[
			5,
			-6
		],
		[
			0,
			-10
		],
		[
			6,
			-4
		],
		[
			2,
			-14
		],
		[
			-6,
			-14
		],
		[
			-1,
			-15
		],
		[
			3,
			-5
		],
		[
			-4,
			-25
		],
		[
			2,
			-13
		],
		[
			0,
			-26
		],
		[
			-2,
			-53
		],
		[
			-7,
			2
		],
		[
			-7,
			19
		],
		[
			-3,
			-6
		],
		[
			0,
			-12
		],
		[
			-8,
			6
		],
		[
			-9,
			11
		],
		[
			-1,
			-4
		],
		[
			5,
			-19
		],
		[
			-4,
			-3
		],
		[
			-3,
			11
		],
		[
			-10,
			17
		],
		[
			-5,
			19
		],
		[
			-7,
			10
		],
		[
			-11,
			12
		],
		[
			-28,
			46
		],
		[
			-1,
			17
		],
		[
			-17,
			23
		],
		[
			-8,
			29
		],
		[
			-9,
			16
		],
		[
			-5,
			17
		],
		[
			2,
			7
		],
		[
			-9,
			34
		],
		[
			0,
			8
		],
		[
			-5,
			3
		],
		[
			1,
			11
		],
		[
			-9,
			30
		],
		[
			-9,
			14
		],
		[
			0,
			13
		],
		[
			-4,
			9
		],
		[
			-9,
			10
		],
		[
			-5,
			1
		],
		[
			-1,
			21
		],
		[
			-9,
			45
		],
		[
			0,
			20
		],
		[
			-3,
			0
		],
		[
			-7,
			14
		],
		[
			-5,
			2
		],
		[
			-9,
			14
		],
		[
			-7,
			6
		],
		[
			-2,
			27
		],
		[
			-5,
			5
		],
		[
			-4,
			14
		],
		[
			-3,
			5
		],
		[
			-8,
			23
		],
		[
			-11,
			6
		],
		[
			-8,
			21
		],
		[
			-6,
			5
		],
		[
			-13,
			28
		],
		[
			-5,
			27
		],
		[
			-3,
			6
		],
		[
			0,
			17
		],
		[
			8,
			2
		]
	],
	[
		[
			4872,
			8298
		],
		[
			-4,
			5
		],
		[
			8,
			13
		],
		[
			4,
			-7
		],
		[
			-8,
			-11
		]
	],
	[
		[
			7606,
			5598
		],
		[
			2,
			-16
		],
		[
			-2,
			-11
		],
		[
			-5,
			16
		],
		[
			0,
			9
		],
		[
			5,
			2
		]
	],
	[
		[
			7571,
			5804
		],
		[
			0,
			-12
		],
		[
			-5,
			0
		],
		[
			-1,
			12
		],
		[
			6,
			0
		]
	],
	[
		[
			7583,
			5964
		],
		[
			1,
			-29
		],
		[
			-3,
			1
		],
		[
			1,
			-36
		],
		[
			-3,
			-2
		],
		[
			1,
			-13
		],
		[
			-5,
			-6
		],
		[
			2,
			-9
		],
		[
			-2,
			-25
		],
		[
			-5,
			13
		],
		[
			5,
			34
		],
		[
			0,
			29
		],
		[
			2,
			1
		],
		[
			0,
			26
		],
		[
			6,
			16
		]
	],
	[
		[
			7448,
			6428
		],
		[
			-4,
			1
		],
		[
			4,
			13
		],
		[
			0,
			-14
		]
	],
	[
		[
			7248,
			6922
		],
		[
			-16,
			-24
		],
		[
			0,
			-12
		],
		[
			-5,
			-9
		],
		[
			1,
			-17
		],
		[
			-7,
			-14
		],
		[
			9,
			-14
		],
		[
			9,
			-1
		],
		[
			7,
			-10
		],
		[
			9,
			-6
		],
		[
			2,
			-11
		],
		[
			15,
			-17
		],
		[
			6,
			3
		],
		[
			11,
			-14
		],
		[
			7,
			2
		],
		[
			1,
			-11
		],
		[
			12,
			-4
		],
		[
			18,
			0
		],
		[
			8,
			4
		],
		[
			6,
			-8
		],
		[
			8,
			-2
		],
		[
			1,
			-18
		],
		[
			8,
			-3
		],
		[
			10,
			-14
		],
		[
			9,
			7
		],
		[
			7,
			-16
		],
		[
			4,
			5
		],
		[
			9,
			-3
		],
		[
			11,
			-11
		],
		[
			7,
			7
		],
		[
			9,
			-11
		],
		[
			13,
			6
		],
		[
			7,
			-5
		],
		[
			4,
			17
		],
		[
			0,
			13
		],
		[
			-6,
			11
		],
		[
			2,
			24
		],
		[
			3,
			21
		]
	],
	[
		[
			7703,
			6808
		],
		[
			0,
			-19
		],
		[
			-13,
			-15
		],
		[
			0,
			-11
		],
		[
			7,
			-21
		],
		[
			-7,
			6
		],
		[
			-4,
			10
		],
		[
			-21,
			-9
		],
		[
			-2,
			-10
		],
		[
			-14,
			-19
		],
		[
			-9,
			-5
		],
		[
			-2,
			-21
		],
		[
			4,
			-12
		],
		[
			-4,
			-6
		],
		[
			0,
			-10
		],
		[
			-10,
			-18
		],
		[
			-2,
			-16
		],
		[
			3,
			-3
		],
		[
			-2,
			-22
		],
		[
			-3,
			-2
		],
		[
			-6,
			-22
		],
		[
			-5,
			-27
		],
		[
			-11,
			9
		],
		[
			-11,
			-2
		],
		[
			4,
			-18
		],
		[
			-2,
			-30
		],
		[
			-9,
			-21
		],
		[
			2,
			-34
		],
		[
			-3,
			1
		],
		[
			-1,
			-12
		],
		[
			-8,
			9
		],
		[
			-3,
			-10
		]
	],
	[
		[
			7473,
			6457
		],
		[
			-4,
			-11
		],
		[
			5,
			-18
		],
		[
			-6,
			2
		],
		[
			-4,
			-6
		],
		[
			-2,
			22
		],
		[
			-5,
			-3
		],
		[
			-1,
			-16
		],
		[
			-7,
			0
		],
		[
			-1,
			26
		],
		[
			-8,
			-18
		],
		[
			-21,
			-14
		],
		[
			-8,
			-19
		],
		[
			6,
			-28
		],
		[
			-7,
			-10
		],
		[
			-4,
			-16
		],
		[
			-4,
			-3
		],
		[
			-6,
			-16
		],
		[
			-19,
			-10
		],
		[
			-5,
			9
		],
		[
			-5,
			-13
		],
		[
			5,
			1
		],
		[
			-15,
			-26
		],
		[
			-9,
			-26
		],
		[
			-13,
			-29
		],
		[
			-9,
			-8
		],
		[
			-6,
			-10
		],
		[
			-9,
			-22
		],
		[
			-21,
			-21
		],
		[
			-6,
			-16
		],
		[
			3,
			-5
		],
		[
			-1,
			-14
		],
		[
			-6,
			-9
		],
		[
			-11,
			-8
		],
		[
			-10,
			4
		],
		[
			-4,
			-3
		],
		[
			-1,
			-20
		],
		[
			-10,
			-15
		],
		[
			-1,
			10
		],
		[
			-6,
			-1
		],
		[
			-9,
			-10
		],
		[
			-3,
			-17
		],
		[
			-2,
			-18
		],
		[
			3,
			-24
		],
		[
			-1,
			-30
		],
		[
			3,
			-29
		],
		[
			-5,
			-4
		],
		[
			7,
			-9
		],
		[
			0,
			-14
		],
		[
			-3,
			-37
		],
		[
			-8,
			-24
		],
		[
			-4,
			-26
		],
		[
			2,
			-16
		],
		[
			0,
			-46
		],
		[
			1,
			-17
		],
		[
			-15,
			0
		],
		[
			-2,
			-15
		],
		[
			-8,
			-21
		],
		[
			-2,
			-13
		],
		[
			5,
			-9
		],
		[
			-20,
			-12
		],
		[
			-5,
			-12
		],
		[
			-2,
			-22
		],
		[
			-2,
			-8
		],
		[
			-16,
			-16
		],
		[
			-7,
			6
		],
		[
			-11,
			22
		],
		[
			-7,
			19
		],
		[
			-6,
			25
		],
		[
			-3,
			32
		],
		[
			4,
			-10
		],
		[
			0,
			11
		],
		[
			-6,
			7
		],
		[
			-2,
			18
		],
		[
			-6,
			30
		],
		[
			-1,
			14
		],
		[
			-9,
			36
		],
		[
			-9,
			17
		],
		[
			-6,
			25
		],
		[
			-6,
			34
		],
		[
			-2,
			33
		],
		[
			-8,
			39
		],
		[
			-1,
			14
		],
		[
			-7,
			14
		],
		[
			-2,
			12
		],
		[
			-4,
			5
		],
		[
			0,
			15
		],
		[
			-3,
			4
		],
		[
			-4,
			24
		],
		[
			-4,
			8
		],
		[
			-5,
			29
		],
		[
			-1,
			37
		],
		[
			-5,
			30
		],
		[
			-6,
			45
		],
		[
			1,
			7
		],
		[
			-3,
			22
		],
		[
			-1,
			23
		],
		[
			-3,
			24
		],
		[
			2,
			33
		],
		[
			4,
			12
		],
		[
			-2,
			36
		],
		[
			-3,
			-4
		],
		[
			-3,
			11
		],
		[
			2,
			16
		],
		[
			12,
			11
		],
		[
			-16,
			-3
		],
		[
			2,
			14
		],
		[
			-2,
			14
		],
		[
			9,
			5
		],
		[
			-13,
			4
		],
		[
			-2,
			-15
		],
		[
			-8,
			-7
		],
		[
			8,
			-18
		],
		[
			-6,
			-25
		],
		[
			-17,
			-17
		],
		[
			-14,
			-11
		],
		[
			-5,
			0
		],
		[
			-10,
			9
		],
		[
			-11,
			17
		],
		[
			-15,
			33
		],
		[
			-15,
			29
		],
		[
			0,
			10
		],
		[
			7,
			1
		],
		[
			0,
			-9
		],
		[
			14,
			12
		],
		[
			3,
			-3
		],
		[
			9,
			7
		],
		[
			7,
			23
		],
		[
			-10,
			-1
		],
		[
			-9,
			-10
		],
		[
			-13,
			5
		],
		[
			-11,
			10
		],
		[
			-9,
			15
		],
		[
			-4,
			19
		],
		[
			-6,
			14
		]
	],
	[
		[
			6893,
			6556
		],
		[
			5,
			7
		],
		[
			10,
			0
		],
		[
			0,
			19
		],
		[
			13,
			-3
		],
		[
			11,
			2
		],
		[
			5,
			-7
		],
		[
			6,
			0
		],
		[
			3,
			8
		],
		[
			13,
			7
		],
		[
			0,
			-8
		],
		[
			6,
			-3
		],
		[
			9,
			10
		],
		[
			-4,
			12
		],
		[
			3,
			3
		],
		[
			-5,
			27
		],
		[
			-6,
			14
		],
		[
			0,
			17
		],
		[
			-10,
			1
		],
		[
			-6,
			14
		],
		[
			2,
			35
		],
		[
			-9,
			2
		],
		[
			-10,
			11
		],
		[
			1,
			17
		],
		[
			10,
			20
		],
		[
			6,
			22
		],
		[
			7,
			12
		],
		[
			6,
			1
		],
		[
			4,
			-16
		],
		[
			4,
			-2
		],
		[
			9,
			7
		],
		[
			20,
			8
		],
		[
			0,
			9
		],
		[
			8,
			16
		],
		[
			5,
			21
		],
		[
			16,
			16
		],
		[
			9,
			29
		],
		[
			3,
			22
		],
		[
			12,
			8
		],
		[
			4,
			7
		],
		[
			-2,
			10
		],
		[
			6,
			11
		],
		[
			6,
			19
		],
		[
			10,
			12
		],
		[
			-4,
			2
		],
		[
			3,
			17
		],
		[
			-2,
			24
		],
		[
			7,
			10
		],
		[
			14,
			8
		],
		[
			1,
			10
		],
		[
			-8,
			8
		],
		[
			-11,
			2
		],
		[
			0,
			14
		],
		[
			-9,
			2
		],
		[
			0,
			13
		],
		[
			-9,
			10
		],
		[
			4,
			22
		],
		[
			-5,
			5
		],
		[
			1,
			10
		],
		[
			7,
			10
		],
		[
			-9,
			1
		],
		[
			1,
			16
		],
		[
			-5,
			3
		],
		[
			4,
			19
		],
		[
			13,
			6
		],
		[
			7,
			-5
		],
		[
			16,
			-2
		],
		[
			11,
			-9
		],
		[
			11,
			11
		],
		[
			17,
			3
		],
		[
			3,
			10
		],
		[
			5,
			1
		],
		[
			4,
			11
		]
	],
	[
		[
			7140,
			7205
		],
		[
			20,
			22
		]
	],
	[
		[
			4825,
			8298
		],
		[
			2,
			-37
		],
		[
			6,
			-29
		],
		[
			-6,
			-16
		],
		[
			-4,
			-28
		],
		[
			-10,
			1
		],
		[
			-8,
			-4
		],
		[
			-12,
			0
		],
		[
			-5,
			-10
		],
		[
			-7,
			0
		],
		[
			-4,
			-8
		],
		[
			-7,
			-1
		],
		[
			-12,
			-14
		],
		[
			-20,
			0
		],
		[
			-11,
			-8
		],
		[
			10,
			14
		],
		[
			-20,
			-4
		],
		[
			12,
			13
		],
		[
			-11,
			-6
		],
		[
			-7,
			10
		],
		[
			13,
			14
		],
		[
			-15,
			-2
		],
		[
			5,
			10
		],
		[
			13,
			-2
		],
		[
			-1,
			11
		],
		[
			8,
			12
		],
		[
			-10,
			-5
		],
		[
			12,
			12
		],
		[
			5,
			21
		],
		[
			10,
			8
		],
		[
			-16,
			-2
		],
		[
			-14,
			9
		],
		[
			-3,
			9
		],
		[
			6,
			13
		],
		[
			0,
			24
		],
		[
			-5,
			4
		],
		[
			22,
			4
		],
		[
			23,
			-3
		],
		[
			-5,
			4
		],
		[
			12,
			9
		],
		[
			3,
			8
		],
		[
			-15,
			-1
		],
		[
			-2,
			7
		],
		[
			10,
			6
		],
		[
			2,
			18
		],
		[
			15,
			2
		],
		[
			6,
			-6
		],
		[
			4,
			17
		],
		[
			13,
			-9
		],
		[
			-9,
			-9
		]
	],
	[
		[
			6560,
			6732
		],
		[
			-4,
			-9
		],
		[
			-5,
			0
		],
		[
			-16,
			-12
		],
		[
			0,
			7
		],
		[
			13,
			7
		],
		[
			13,
			13
		],
		[
			-1,
			-6
		]
	],
	[
		[
			6357,
			7396
		],
		[
			3,
			-38
		],
		[
			4,
			-9
		],
		[
			9,
			-7
		],
		[
			13,
			-2
		],
		[
			9,
			-5
		],
		[
			2,
			-13
		],
		[
			21,
			-24
		],
		[
			23,
			-9
		],
		[
			43,
			18
		],
		[
			16,
			-4
		],
		[
			-3,
			30
		]
	],
	[
		[
			6497,
			7333
		],
		[
			8,
			-1
		],
		[
			16,
			11
		],
		[
			1,
			13
		],
		[
			9,
			13
		],
		[
			9,
			7
		],
		[
			24,
			0
		],
		[
			3,
			10
		],
		[
			17,
			-4
		],
		[
			5,
			4
		],
		[
			3,
			-17
		],
		[
			23,
			-10
		],
		[
			8,
			-9
		],
		[
			10,
			3
		],
		[
			11,
			-10
		],
		[
			10,
			-21
		],
		[
			13,
			-7
		],
		[
			8,
			-22
		],
		[
			23,
			0
		],
		[
			2,
			-31
		],
		[
			-3,
			-8
		],
		[
			4,
			-5
		],
		[
			0,
			-15
		]
	],
	[
		[
			6689,
			6902
		],
		[
			14,
			-27
		],
		[
			0,
			-8
		],
		[
			6,
			-21
		],
		[
			10,
			-20
		],
		[
			14,
			-8
		],
		[
			5,
			-10
		],
		[
			5,
			-1
		],
		[
			-1,
			-12
		],
		[
			2,
			-18
		],
		[
			-1,
			-26
		],
		[
			11,
			2
		],
		[
			4,
			-8
		],
		[
			-4,
			-17
		],
		[
			0,
			-11
		],
		[
			-12,
			0
		],
		[
			-12,
			-7
		],
		[
			-2,
			-10
		],
		[
			-11,
			-7
		],
		[
			-7,
			-59
		]
	],
	[
		[
			6710,
			6634
		],
		[
			-5,
			-8
		],
		[
			-10,
			9
		],
		[
			-12,
			4
		],
		[
			-1,
			9
		],
		[
			-5,
			-6
		],
		[
			-24,
			3
		],
		[
			-2,
			4
		],
		[
			-12,
			-4
		],
		[
			-6,
			10
		],
		[
			-7,
			2
		],
		[
			-14,
			-2
		],
		[
			-4,
			8
		],
		[
			-17,
			5
		],
		[
			-4,
			19
		],
		[
			-4,
			42
		],
		[
			-6,
			17
		],
		[
			-11,
			3
		],
		[
			-8,
			-2
		],
		[
			-5,
			-8
		],
		[
			-9,
			-4
		],
		[
			-3,
			-11
		],
		[
			-6,
			2
		],
		[
			-13,
			-17
		],
		[
			-11,
			5
		],
		[
			-3,
			7
		],
		[
			-17,
			0
		],
		[
			-8,
			16
		],
		[
			-10,
			6
		],
		[
			-13,
			16
		],
		[
			-4,
			16
		],
		[
			-12,
			11
		],
		[
			-9,
			-1
		],
		[
			-8,
			6
		],
		[
			-9,
			35
		],
		[
			0,
			12
		],
		[
			-8,
			13
		],
		[
			2,
			10
		],
		[
			-6,
			0
		],
		[
			1,
			16
		],
		[
			-15,
			30
		],
		[
			0,
			10
		],
		[
			-5,
			6
		],
		[
			-11,
			-12
		],
		[
			-2,
			9
		],
		[
			-7,
			-1
		],
		[
			-9,
			13
		],
		[
			8,
			-1
		],
		[
			0,
			9
		],
		[
			-9,
			-8
		],
		[
			1,
			-20
		],
		[
			-11,
			-4
		]
	],
	[
		[
			6347,
			6908
		],
		[
			-3,
			15
		],
		[
			-11,
			14
		],
		[
			0,
			31
		],
		[
			-9,
			0
		],
		[
			0,
			23
		],
		[
			4,
			21
		],
		[
			-9,
			22
		],
		[
			-5,
			19
		],
		[
			-6,
			-1
		],
		[
			-14,
			21
		],
		[
			-16,
			15
		],
		[
			4,
			5
		],
		[
			-4,
			15
		],
		[
			-11,
			15
		],
		[
			-5,
			22
		],
		[
			3,
			14
		],
		[
			-4,
			8
		],
		[
			2,
			8
		],
		[
			6,
			-3
		],
		[
			-2,
			9
		],
		[
			7,
			21
		],
		[
			7,
			2
		],
		[
			1,
			7
		],
		[
			-6,
			16
		],
		[
			1,
			10
		],
		[
			6,
			2
		],
		[
			-4,
			9
		],
		[
			-6,
			-3
		],
		[
			-14,
			14
		],
		[
			-3,
			21
		],
		[
			-5,
			0
		],
		[
			-1,
			18
		],
		[
			-6,
			5
		],
		[
			2,
			12
		],
		[
			-3,
			7
		]
	],
	[
		[
			6243,
			7322
		],
		[
			0,
			10
		],
		[
			-6,
			6
		],
		[
			1,
			17
		],
		[
			-10,
			17
		],
		[
			6,
			20
		],
		[
			-4,
			0
		],
		[
			-3,
			45
		],
		[
			-5,
			13
		],
		[
			11,
			4
		],
		[
			4,
			19
		],
		[
			7,
			-7
		]
	],
	[
		[
			6347,
			6908
		],
		[
			-13,
			5
		],
		[
			-3,
			-3
		]
	],
	[
		[
			6331,
			6910
		],
		[
			-7,
			6
		],
		[
			-9,
			0
		],
		[
			-6,
			-5
		],
		[
			-8,
			-33
		],
		[
			-9,
			-20
		]
	],
	[
		[
			6292,
			6858
		],
		[
			-5,
			-2
		],
		[
			-46,
			8
		],
		[
			-62,
			91
		],
		[
			-11,
			18
		],
		[
			-47,
			49
		],
		[
			-34,
			10
		]
	],
	[
		[
			6087,
			7032
		],
		[
			4,
			8
		],
		[
			-7,
			3
		],
		[
			0,
			11
		],
		[
			-8,
			51
		]
	],
	[
		[
			6076,
			7105
		],
		[
			4,
			3
		],
		[
			43,
			44
		],
		[
			14,
			11
		],
		[
			7,
			22
		],
		[
			1,
			40
		],
		[
			3,
			8
		],
		[
			-2,
			23
		]
	],
	[
		[
			6146,
			7256
		],
		[
			0,
			0
		]
	],
	[
		[
			6146,
			7256
		],
		[
			0,
			20
		],
		[
			3,
			10
		],
		[
			13,
			5
		],
		[
			15,
			26
		],
		[
			-1,
			3
		]
	],
	[
		[
			6176,
			7320
		],
		[
			6,
			2
		],
		[
			6,
			13
		],
		[
			9,
			0
		],
		[
			10,
			-7
		],
		[
			12,
			-2
		],
		[
			8,
			4
		],
		[
			1,
			-18
		],
		[
			11,
			12
		],
		[
			4,
			-2
		]
	],
	[
		[
			4554,
			9014
		],
		[
			7,
			-14
		],
		[
			12,
			-7
		],
		[
			12,
			13
		],
		[
			-4,
			-20
		],
		[
			10,
			2
		],
		[
			-2,
			-20
		],
		[
			12,
			4
		],
		[
			0,
			-8
		],
		[
			21,
			-10
		],
		[
			-4,
			-10
		],
		[
			6,
			-8
		],
		[
			-13,
			-25
		],
		[
			-13,
			-4
		],
		[
			-2,
			-15
		],
		[
			-24,
			-8
		],
		[
			-39,
			-26
		],
		[
			-31,
			-6
		],
		[
			-1,
			-11
		],
		[
			-23,
			-7
		],
		[
			-27,
			8
		],
		[
			-12,
			0
		],
		[
			-28,
			20
		],
		[
			-42,
			-4
		],
		[
			4,
			9
		],
		[
			14,
			4
		],
		[
			10,
			10
		],
		[
			2,
			11
		],
		[
			-13,
			-6
		],
		[
			-9,
			29
		],
		[
			-32,
			1
		],
		[
			-11,
			-4
		],
		[
			-3,
			8
		],
		[
			23,
			2
		],
		[
			15,
			8
		],
		[
			25,
			-2
		],
		[
			-21,
			7
		],
		[
			22,
			16
		],
		[
			-39,
			7
		],
		[
			-20,
			-9
		],
		[
			-18,
			6
		],
		[
			7,
			8
		],
		[
			12,
			-7
		],
		[
			-8,
			15
		],
		[
			17,
			-5
		],
		[
			-9,
			12
		],
		[
			10,
			17
		],
		[
			20,
			-8
		],
		[
			-5,
			7
		],
		[
			9,
			16
		],
		[
			11,
			-11
		],
		[
			25,
			-14
		],
		[
			-2,
			-19
		],
		[
			9,
			-29
		],
		[
			0,
			13
		],
		[
			9,
			15
		],
		[
			9,
			-10
		],
		[
			5,
			13
		],
		[
			-5,
			20
		],
		[
			9,
			3
		],
		[
			13,
			-22
		],
		[
			6,
			-1
		],
		[
			-1,
			19
		],
		[
			22,
			6
		],
		[
			16,
			-26
		],
		[
			-6,
			27
		],
		[
			10,
			-1
		],
		[
			10,
			-11
		],
		[
			12,
			14
		],
		[
			6,
			-6
		],
		[
			13,
			3
		],
		[
			-3,
			19
		],
		[
			15,
			2
		]
	],
	[
		[
			5993,
			7068
		],
		[
			-6,
			-5
		],
		[
			0,
			-15
		]
	],
	[
		[
			5987,
			7048
		],
		[
			-10,
			8
		],
		[
			-6,
			-14
		],
		[
			0,
			-19
		],
		[
			6,
			-9
		],
		[
			-7,
			-11
		],
		[
			-2,
			-14
		],
		[
			10,
			1
		],
		[
			5,
			6
		]
	],
	[
		[
			5983,
			6996
		],
		[
			0,
			-9
		]
	],
	[
		[
			5983,
			6987
		],
		[
			0,
			-6
		]
	],
	[
		[
			5983,
			6981
		],
		[
			1,
			-8
		]
	],
	[
		[
			5984,
			6973
		],
		[
			-8,
			-34
		],
		[
			0,
			-21
		],
		[
			-6,
			-33
		]
	],
	[
		[
			5970,
			6885
		],
		[
			-2,
			-4
		]
	],
	[
		[
			5951,
			6980
		],
		[
			8,
			18
		],
		[
			-2,
			4
		]
	],
	[
		[
			5957,
			7002
		],
		[
			7,
			21
		],
		[
			6,
			44
		],
		[
			5,
			21
		]
	],
	[
		[
			5975,
			7088
		],
		[
			10,
			0
		],
		[
			1,
			9
		],
		[
			8,
			10
		]
	],
	[
		[
			5994,
			7107
		],
		[
			-1,
			-9
		],
		[
			3,
			-19
		],
		[
			-3,
			-11
		]
	],
	[
		[
			5434,
			7386
		],
		[
			-12,
			-29
		],
		[
			-3,
			-25
		],
		[
			6,
			-18
		],
		[
			-6,
			-11
		],
		[
			1,
			-8
		],
		[
			-10,
			1
		],
		[
			-8,
			6
		],
		[
			-3,
			10
		],
		[
			-7,
			8
		],
		[
			-7,
			-1
		],
		[
			-25,
			27
		],
		[
			-10,
			1
		],
		[
			-4,
			6
		],
		[
			0,
			19
		],
		[
			7,
			6
		],
		[
			6,
			-6
		],
		[
			4,
			10
		],
		[
			7,
			1
		],
		[
			10,
			-13
		],
		[
			9,
			4
		],
		[
			9,
			-2
		],
		[
			17,
			10
		],
		[
			4,
			-4
		],
		[
			12,
			11
		],
		[
			3,
			-3
		]
	],
	[
		[
			5256,
			7557
		],
		[
			8,
			-6
		],
		[
			8,
			-34
		],
		[
			-5,
			-14
		],
		[
			3,
			-13
		],
		[
			-2,
			-30
		],
		[
			-6,
			-24
		],
		[
			-10,
			6
		],
		[
			-5,
			-19
		],
		[
			-8,
			0
		],
		[
			-7,
			17
		],
		[
			5,
			39
		],
		[
			-4,
			1
		],
		[
			2,
			23
		],
		[
			-5,
			17
		],
		[
			-4,
			0
		],
		[
			2,
			16
		],
		[
			8,
			-2
		],
		[
			9,
			6
		],
		[
			11,
			17
		]
	],
	[
		[
			5380,
			7862
		],
		[
			-9,
			-16
		],
		[
			7,
			-7
		],
		[
			-4,
			-8
		],
		[
			3,
			-12
		],
		[
			8,
			-10
		],
		[
			-5,
			-1
		]
	],
	[
		[
			5380,
			7808
		],
		[
			1,
			7
		],
		[
			-18,
			1
		],
		[
			-3,
			-5
		],
		[
			-16,
			-12
		],
		[
			-4,
			2
		],
		[
			-1,
			-16
		],
		[
			9,
			-13
		],
		[
			-6,
			-7
		],
		[
			-2,
			-13
		],
		[
			2,
			-18
		],
		[
			8,
			-16
		],
		[
			9,
			-7
		],
		[
			19,
			-21
		],
		[
			12,
			-54
		],
		[
			18,
			-28
		],
		[
			12,
			-11
		],
		[
			25,
			0
		],
		[
			4,
			-9
		],
		[
			-8,
			-15
		],
		[
			19,
			-17
		],
		[
			13,
			-7
		],
		[
			14,
			-18
		],
		[
			13,
			-8
		],
		[
			0,
			-6
		],
		[
			12,
			-15
		],
		[
			2,
			-10
		],
		[
			-4,
			-18
		],
		[
			-9,
			6
		],
		[
			-5,
			23
		],
		[
			-11,
			0
		],
		[
			-14,
			11
		],
		[
			-11,
			-25
		],
		[
			-2,
			-21
		],
		[
			9,
			-5
		],
		[
			9,
			-11
		],
		[
			-1,
			-29
		],
		[
			-11,
			-1
		],
		[
			-5,
			-8
		],
		[
			1,
			-18
		],
		[
			-8,
			-10
		],
		[
			-8,
			-20
		],
		[
			-10,
			4
		],
		[
			0,
			15
		],
		[
			5,
			3
		],
		[
			3,
			12
		],
		[
			-3,
			8
		],
		[
			9,
			5
		],
		[
			2,
			12
		],
		[
			-4,
			8
		],
		[
			-2,
			21
		],
		[
			-4,
			6
		],
		[
			-2,
			20
		],
		[
			-7,
			11
		],
		[
			-5,
			-5
		],
		[
			-12,
			13
		],
		[
			2,
			8
		],
		[
			-6,
			18
		],
		[
			-8,
			1
		],
		[
			-5,
			8
		],
		[
			-7,
			3
		],
		[
			-10,
			22
		],
		[
			-10,
			1
		],
		[
			-8,
			-3
		],
		[
			-5,
			11
		],
		[
			-7,
			2
		],
		[
			-12,
			24
		],
		[
			-10,
			10
		],
		[
			-8,
			18
		],
		[
			-10,
			5
		],
		[
			-3,
			12
		],
		[
			-9,
			9
		],
		[
			1,
			6
		],
		[
			-8,
			2
		],
		[
			1,
			18
		],
		[
			-7,
			17
		],
		[
			0,
			14
		],
		[
			-5,
			13
		],
		[
			-7,
			1
		],
		[
			-16,
			17
		],
		[
			-15,
			5
		],
		[
			-14,
			-19
		],
		[
			-3,
			-11
		],
		[
			-17,
			-6
		]
	],
	[
		[
			5344,
			7711
		],
		[
			0,
			0
		]
	],
	[
		[
			5345,
			7596
		],
		[
			0,
			0
		]
	],
	[
		[
			2849,
			6246
		],
		[
			15,
			-3
		],
		[
			3,
			-8
		],
		[
			12,
			-7
		],
		[
			4,
			-14
		],
		[
			-9,
			-3
		],
		[
			-10,
			6
		],
		[
			-1,
			-7
		],
		[
			-6,
			3
		],
		[
			-1,
			-11
		],
		[
			-7,
			10
		],
		[
			-8,
			-1
		],
		[
			-7,
			10
		],
		[
			-3,
			10
		],
		[
			-8,
			2
		],
		[
			5,
			12
		],
		[
			10,
			5
		],
		[
			11,
			-4
		]
	],
	[
		[
			6087,
			7032
		],
		[
			-4,
			-6
		],
		[
			-57,
			-30
		],
		[
			15,
			-28
		],
		[
			13,
			-29
		],
		[
			-9,
			-10
		],
		[
			-4,
			-18
		],
		[
			-21,
			-8
		],
		[
			-7,
			-22
		],
		[
			-12,
			-17
		],
		[
			-31,
			9
		]
	],
	[
		[
			5970,
			6873
		],
		[
			0,
			12
		]
	],
	[
		[
			5984,
			6973
		],
		[
			-1,
			8
		]
	],
	[
		[
			5983,
			6987
		],
		[
			4,
			0
		],
		[
			0,
			25
		]
	],
	[
		[
			5987,
			7012
		],
		[
			0,
			36
		]
	],
	[
		[
			5993,
			7068
		],
		[
			7,
			-5
		],
		[
			10,
			-16
		],
		[
			12,
			-3
		],
		[
			54,
			61
		]
	],
	[
		[
			8563,
			6721
		],
		[
			-5,
			-10
		],
		[
			-7,
			-5
		],
		[
			-4,
			-21
		],
		[
			0,
			20
		],
		[
			7,
			8
		],
		[
			-3,
			7
		],
		[
			7,
			-1
		],
		[
			4,
			12
		],
		[
			1,
			-10
		]
	],
	[
		[
			8603,
			6820
		],
		[
			-13,
			-15
		],
		[
			0,
			9
		],
		[
			11,
			11
		],
		[
			2,
			-5
		]
	],
	[
		[
			8624,
			6937
		],
		[
			5,
			-5
		],
		[
			-7,
			-8
		],
		[
			2,
			13
		]
	],
	[
		[
			8639,
			6942
		],
		[
			-5,
			-5
		],
		[
			6,
			22
		],
		[
			-1,
			-17
		]
	],
	[
		[
			8616,
			7056
		],
		[
			0,
			-12
		],
		[
			-6,
			-7
		],
		[
			1,
			18
		],
		[
			5,
			1
		]
	],
	[
		[
			8578,
			7069
		],
		[
			-1,
			-10
		],
		[
			-6,
			2
		],
		[
			7,
			8
		]
	],
	[
		[
			8638,
			7135
		],
		[
			3,
			-16
		],
		[
			7,
			-3
		],
		[
			9,
			6
		],
		[
			1,
			-15
		],
		[
			-5,
			-9
		],
		[
			10,
			1
		],
		[
			0,
			-17
		],
		[
			5,
			-2
		],
		[
			-11,
			-22
		],
		[
			-6,
			-38
		],
		[
			0,
			-16
		],
		[
			-3,
			-14
		],
		[
			-7,
			5
		],
		[
			1,
			-11
		],
		[
			-12,
			-13
		],
		[
			2,
			20
		],
		[
			-5,
			12
		],
		[
			-2,
			-4
		],
		[
			0,
			-22
		],
		[
			-9,
			5
		],
		[
			4,
			18
		],
		[
			-5,
			12
		],
		[
			1,
			21
		],
		[
			2,
			-2
		],
		[
			8,
			19
		],
		[
			-2,
			11
		],
		[
			3,
			12
		],
		[
			-5,
			15
		],
		[
			-8,
			2
		],
		[
			7,
			-19
		],
		[
			-6,
			-11
		],
		[
			1,
			11
		],
		[
			-10,
			-10
		],
		[
			-6,
			18
		],
		[
			1,
			10
		],
		[
			4,
			-14
		],
		[
			5,
			-1
		],
		[
			-1,
			10
		],
		[
			-11,
			11
		],
		[
			1,
			10
		],
		[
			6,
			-2
		],
		[
			18,
			22
		],
		[
			2,
			9
		],
		[
			6,
			4
		],
		[
			7,
			-3
		]
	],
	[
		[
			8726,
			7162
		],
		[
			8,
			-9
		],
		[
			5,
			1
		],
		[
			-1,
			-13
		],
		[
			4,
			-10
		],
		[
			-10,
			-11
		],
		[
			-5,
			-23
		],
		[
			-8,
			15
		],
		[
			-5,
			2
		],
		[
			-13,
			-11
		],
		[
			0,
			-7
		],
		[
			-7,
			-11
		],
		[
			-1,
			-16
		],
		[
			-10,
			0
		],
		[
			3,
			9
		],
		[
			-6,
			1
		],
		[
			-6,
			31
		],
		[
			11,
			14
		],
		[
			2,
			17
		],
		[
			6,
			6
		],
		[
			5,
			-10
		],
		[
			10,
			2
		],
		[
			3,
			14
		],
		[
			8,
			9
		],
		[
			7,
			0
		]
	],
	[
		[
			8747,
			7160
		],
		[
			-3,
			-8
		],
		[
			-3,
			8
		],
		[
			8,
			15
		],
		[
			-2,
			-15
		]
	],
	[
		[
			8595,
			7181
		],
		[
			-2,
			-23
		],
		[
			-3,
			4
		],
		[
			1,
			16
		],
		[
			4,
			3
		]
	],
	[
		[
			8845,
			7375
		],
		[
			1,
			-10
		],
		[
			-6,
			-6
		],
		[
			-1,
			17
		],
		[
			8,
			13
		],
		[
			-2,
			-14
		]
	],
	[
		[
			8923,
			7564
		],
		[
			5,
			3
		],
		[
			-1,
			-34
		],
		[
			2,
			-14
		],
		[
			8,
			-11
		],
		[
			5,
			-22
		],
		[
			4,
			-26
		],
		[
			-5,
			-14
		],
		[
			0,
			-12
		],
		[
			-7,
			-6
		],
		[
			-5,
			-25
		],
		[
			1,
			-17
		],
		[
			-6,
			9
		],
		[
			-7,
			-6
		],
		[
			-3,
			-24
		],
		[
			3,
			-14
		],
		[
			-2,
			-39
		],
		[
			-5,
			-8
		],
		[
			-5,
			-19
		],
		[
			-1,
			-20
		],
		[
			8,
			-27
		],
		[
			-11,
			-7
		],
		[
			-2,
			-21
		],
		[
			-16,
			-17
		],
		[
			2,
			30
		],
		[
			5,
			11
		],
		[
			-8,
			0
		],
		[
			-4,
			-12
		],
		[
			1,
			-16
		],
		[
			-7,
			11
		],
		[
			-8,
			-5
		],
		[
			0,
			-21
		],
		[
			-9,
			-16
		],
		[
			-1,
			25
		],
		[
			-6,
			4
		],
		[
			-6,
			-11
		],
		[
			-4,
			-18
		],
		[
			-17,
			5
		],
		[
			-15,
			-6
		],
		[
			7,
			9
		],
		[
			-13,
			1
		],
		[
			0,
			16
		],
		[
			-5,
			-3
		],
		[
			-3,
			-22
		],
		[
			9,
			-9
		],
		[
			1,
			-10
		],
		[
			-7,
			3
		],
		[
			-10,
			-9
		],
		[
			0,
			-10
		],
		[
			-6,
			-8
		],
		[
			-3,
			-15
		],
		[
			-5,
			-7
		],
		[
			-10,
			5
		],
		[
			-1,
			8
		],
		[
			-9,
			11
		],
		[
			3,
			8
		],
		[
			-3,
			14
		],
		[
			10,
			17
		],
		[
			-2,
			9
		],
		[
			-11,
			-4
		],
		[
			-6,
			7
		],
		[
			-7,
			0
		],
		[
			-20,
			-18
		],
		[
			-10,
			1
		],
		[
			-3,
			-9
		],
		[
			-6,
			2
		],
		[
			-15,
			-9
		],
		[
			-1,
			9
		],
		[
			-8,
			-6
		],
		[
			-2,
			-24
		],
		[
			-11,
			13
		],
		[
			-16,
			-7
		],
		[
			-4,
			7
		],
		[
			-3,
			-8
		],
		[
			-1,
			25
		],
		[
			3,
			5
		],
		[
			12,
			-1
		],
		[
			3,
			10
		],
		[
			7,
			5
		],
		[
			17,
			28
		],
		[
			7,
			7
		],
		[
			-1,
			9
		],
		[
			17,
			8
		],
		[
			5,
			-8
		],
		[
			24,
			6
		],
		[
			7,
			7
		],
		[
			11,
			-2
		],
		[
			8,
			7
		],
		[
			-1,
			-12
		],
		[
			13,
			-4
		],
		[
			12,
			10
		],
		[
			-3,
			18
		],
		[
			5,
			16
		],
		[
			7,
			8
		],
		[
			10,
			28
		],
		[
			-1,
			26
		],
		[
			11,
			10
		],
		[
			6,
			1
		],
		[
			-3,
			-13
		],
		[
			-9,
			-5
		],
		[
			4,
			-6
		],
		[
			-2,
			-13
		],
		[
			10,
			-6
		],
		[
			3,
			10
		],
		[
			21,
			13
		],
		[
			10,
			12
		],
		[
			10,
			29
		],
		[
			14,
			15
		],
		[
			1,
			16
		],
		[
			9,
			23
		],
		[
			3,
			24
		],
		[
			4,
			10
		],
		[
			1,
			17
		],
		[
			-4,
			11
		],
		[
			-5,
			-3
		],
		[
			7,
			19
		],
		[
			1,
			11
		],
		[
			-5,
			13
		],
		[
			5,
			10
		],
		[
			7,
			3
		],
		[
			1,
			26
		],
		[
			9,
			-5
		],
		[
			3,
			-20
		],
		[
			3,
			9
		],
		[
			8,
			-6
		],
		[
			3,
			19
		],
		[
			-13,
			-5
		],
		[
			3,
			23
		],
		[
			10,
			-10
		]
	],
	[
		[
			8944,
			7799
		],
		[
			15,
			-24
		],
		[
			4,
			-13
		],
		[
			19,
			-27
		],
		[
			11,
			-7
		],
		[
			0,
			-6
		],
		[
			12,
			0
		],
		[
			3,
			-7
		],
		[
			13,
			-4
		],
		[
			15,
			25
		],
		[
			1,
			-8
		],
		[
			-7,
			-17
		],
		[
			-1,
			-9
		],
		[
			8,
			-28
		],
		[
			8,
			6
		],
		[
			-4,
			-12
		],
		[
			-6,
			0
		],
		[
			-8,
			-10
		],
		[
			-27,
			-4
		],
		[
			-11,
			-14
		],
		[
			-8,
			-20
		],
		[
			-3,
			-23
		],
		[
			-8,
			11
		],
		[
			-14,
			9
		],
		[
			-8,
			11
		],
		[
			-12,
			9
		],
		[
			-8,
			-3
		],
		[
			-12,
			-15
		],
		[
			-9,
			15
		],
		[
			-5,
			0
		],
		[
			-6,
			-18
		],
		[
			12,
			-8
		],
		[
			13,
			-20
		],
		[
			-13,
			-1
		],
		[
			-8,
			-7
		],
		[
			-6,
			-13
		],
		[
			-7,
			10
		],
		[
			5,
			14
		],
		[
			-3,
			17
		],
		[
			-7,
			6
		],
		[
			3,
			26
		],
		[
			12,
			7
		],
		[
			5,
			11
		],
		[
			-5,
			13
		],
		[
			6,
			8
		],
		[
			8,
			-9
		],
		[
			10,
			-3
		],
		[
			7,
			10
		],
		[
			-3,
			22
		],
		[
			9,
			14
		],
		[
			0,
			22
		],
		[
			3,
			6
		],
		[
			1,
			20
		],
		[
			-6,
			23
		],
		[
			3,
			12
		],
		[
			9,
			3
		]
	],
	[
		[
			6762,
			7807
		],
		[
			-15,
			8
		],
		[
			-3,
			11
		],
		[
			1,
			13
		],
		[
			12,
			14
		],
		[
			11,
			-3
		],
		[
			7,
			-11
		],
		[
			1,
			-13
		],
		[
			-4,
			-11
		],
		[
			-10,
			-8
		]
	],
	[
		[
			7140,
			7205
		],
		[
			-9,
			31
		]
	],
	[
		[
			6651,
			7782
		],
		[
			-20,
			19
		]
	],
	[
		[
			6631,
			7801
		],
		[
			12,
			18
		],
		[
			8,
			-37
		]
	],
	[
		[
			7227,
			7611
		],
		[
			-6,
			13
		],
		[
			-15,
			4
		],
		[
			-12,
			17
		],
		[
			-14,
			6
		],
		[
			-14,
			0
		],
		[
			-19,
			2
		],
		[
			-14,
			5
		],
		[
			-13,
			-5
		],
		[
			-16,
			1
		],
		[
			-3,
			-6
		],
		[
			-13,
			2
		],
		[
			-12,
			8
		],
		[
			-12,
			13
		],
		[
			-21,
			-10
		],
		[
			-5,
			-27
		],
		[
			3,
			-9
		],
		[
			-22,
			14
		],
		[
			-27,
			9
		],
		[
			-10,
			-1
		],
		[
			-10,
			-13
		],
		[
			-5,
			-15
		],
		[
			3,
			-3
		]
	],
	[
		[
			6970,
			7616
		],
		[
			-6,
			-3
		],
		[
			-4,
			-11
		],
		[
			-4,
			5
		],
		[
			-9,
			-16
		],
		[
			-20,
			-15
		],
		[
			0,
			-5
		],
		[
			-10,
			-5
		],
		[
			0,
			-10
		],
		[
			-13,
			-17
		],
		[
			1,
			-19
		],
		[
			-4,
			0
		],
		[
			-13,
			13
		],
		[
			4,
			14
		],
		[
			-5,
			7
		],
		[
			-33,
			-3
		],
		[
			-5,
			20
		],
		[
			-2,
			30
		],
		[
			-14,
			0
		],
		[
			2,
			57
		],
		[
			-8,
			-7
		],
		[
			-8,
			26
		],
		[
			-7,
			5
		],
		[
			-10,
			19
		],
		[
			-12,
			-10
		],
		[
			-37,
			4
		],
		[
			-32,
			-8
		],
		[
			-23,
			38
		],
		[
			-2,
			12
		],
		[
			-28,
			28
		]
	],
	[
		[
			6668,
			7765
		],
		[
			0,
			34
		],
		[
			-2,
			9
		],
		[
			-7,
			-1
		],
		[
			3,
			20
		],
		[
			17,
			-5
		],
		[
			8,
			16
		],
		[
			12,
			7
		],
		[
			2,
			14
		],
		[
			-11,
			2
		],
		[
			-3,
			9
		],
		[
			-13,
			3
		],
		[
			-8,
			-7
		],
		[
			4,
			-13
		],
		[
			17,
			0
		],
		[
			2,
			-11
		],
		[
			-4,
			-6
		],
		[
			-24,
			2
		],
		[
			-2,
			12
		],
		[
			-7,
			0
		],
		[
			7,
			-14
		],
		[
			-3,
			-17
		],
		[
			-8,
			-6
		],
		[
			-4,
			5
		],
		[
			4,
			13
		],
		[
			-15,
			-3
		],
		[
			-6,
			-23
		]
	],
	[
		[
			6627,
			7805
		],
		[
			-73,
			-31
		],
		[
			0,
			-212
		]
	],
	[
		[
			6554,
			7562
		],
		[
			-14,
			-3
		],
		[
			-15,
			32
		],
		[
			0,
			6
		],
		[
			-20,
			23
		],
		[
			-20,
			-3
		],
		[
			-14,
			-9
		],
		[
			-15,
			-21
		]
	],
	[
		[
			6456,
			7587
		],
		[
			-1,
			20
		],
		[
			6,
			15
		],
		[
			3,
			22
		],
		[
			-15,
			9
		],
		[
			-8,
			-3
		],
		[
			-6,
			18
		],
		[
			-12,
			0
		],
		[
			1,
			23
		],
		[
			-4,
			4
		],
		[
			-8,
			33
		],
		[
			-17,
			9
		],
		[
			1,
			17
		],
		[
			16,
			-1
		],
		[
			4,
			-6
		],
		[
			16,
			-2
		],
		[
			-17,
			20
		],
		[
			12,
			28
		],
		[
			9,
			5
		],
		[
			22,
			0
		],
		[
			11,
			-6
		],
		[
			10,
			2
		],
		[
			-15,
			10
		],
		[
			0,
			6
		],
		[
			9,
			18
		],
		[
			4,
			40
		],
		[
			-8,
			19
		],
		[
			-13,
			2
		],
		[
			-10,
			-10
		],
		[
			-16,
			14
		],
		[
			-9,
			3
		],
		[
			-12,
			-11
		],
		[
			-9,
			-2
		],
		[
			-18,
			-21
		],
		[
			-13,
			2
		],
		[
			-2,
			-14
		]
	],
	[
		[
			6367,
			7850
		],
		[
			-9,
			9
		],
		[
			-10,
			5
		],
		[
			0,
			12
		],
		[
			6,
			-6
		],
		[
			7,
			6
		],
		[
			-9,
			19
		],
		[
			-4,
			15
		],
		[
			-14,
			23
		],
		[
			-11,
			0
		],
		[
			-7,
			5
		],
		[
			-1,
			-9
		],
		[
			-7,
			7
		],
		[
			0,
			26
		],
		[
			-18,
			8
		],
		[
			8,
			30
		],
		[
			8,
			10
		],
		[
			-7,
			14
		],
		[
			3,
			28
		],
		[
			12,
			12
		],
		[
			-1,
			14
		],
		[
			9,
			9
		],
		[
			22,
			-37
		],
		[
			13,
			11
		],
		[
			-5,
			20
		],
		[
			0,
			13
		],
		[
			20,
			17
		],
		[
			0,
			15
		],
		[
			11,
			0
		],
		[
			15,
			12
		],
		[
			6,
			17
		],
		[
			5,
			6
		],
		[
			14,
			-3
		],
		[
			1,
			-11
		],
		[
			11,
			-1
		],
		[
			6,
			12
		],
		[
			11,
			6
		],
		[
			5,
			-16
		],
		[
			23,
			0
		],
		[
			9,
			-7
		],
		[
			1,
			-9
		],
		[
			7,
			-1
		],
		[
			6,
			-13
		],
		[
			10,
			-7
		],
		[
			-3,
			-16
		],
		[
			8,
			2
		],
		[
			1,
			24
		],
		[
			10,
			-13
		],
		[
			16,
			-15
		],
		[
			13,
			11
		],
		[
			11,
			20
		],
		[
			18,
			0
		],
		[
			5,
			-11
		],
		[
			11,
			1
		],
		[
			1,
			13
		],
		[
			22,
			-4
		],
		[
			0,
			-11
		],
		[
			10,
			-11
		],
		[
			16,
			-3
		],
		[
			1,
			-9
		],
		[
			7,
			4
		],
		[
			5,
			18
		],
		[
			9,
			-10
		],
		[
			15,
			-1
		],
		[
			17,
			10
		],
		[
			2,
			19
		],
		[
			4,
			6
		],
		[
			-7,
			11
		],
		[
			-10,
			1
		],
		[
			-3,
			8
		],
		[
			-16,
			3
		],
		[
			3,
			8
		],
		[
			-12,
			4
		],
		[
			11,
			15
		],
		[
			7,
			1
		],
		[
			10,
			11
		],
		[
			-10,
			23
		],
		[
			22,
			16
		],
		[
			17,
			-3
		],
		[
			1,
			7
		],
		[
			-13,
			9
		],
		[
			-14,
			3
		],
		[
			2,
			12
		],
		[
			-6,
			8
		],
		[
			5,
			11
		],
		[
			-6,
			3
		],
		[
			12,
			10
		],
		[
			4,
			-6
		],
		[
			43,
			7
		],
		[
			25,
			14
		],
		[
			25,
			5
		],
		[
			9,
			-4
		],
		[
			-1,
			10
		],
		[
			7,
			7
		],
		[
			15,
			-1
		],
		[
			15,
			6
		],
		[
			33,
			8
		],
		[
			13,
			6
		],
		[
			2,
			13
		],
		[
			10,
			0
		],
		[
			2,
			9
		],
		[
			8,
			-4
		],
		[
			-1,
			9
		],
		[
			8,
			-6
		],
		[
			13,
			0
		],
		[
			14,
			-11
		],
		[
			8,
			9
		],
		[
			14,
			-12
		],
		[
			1,
			-18
		],
		[
			6,
			-3
		],
		[
			-1,
			-23
		],
		[
			-6,
			0
		],
		[
			6,
			-13
		],
		[
			3,
			6
		],
		[
			11,
			-4
		],
		[
			10,
			5
		],
		[
			3,
			9
		],
		[
			9,
			-14
		],
		[
			-3,
			-13
		],
		[
			9,
			3
		],
		[
			-4,
			10
		],
		[
			11,
			-1
		],
		[
			3,
			-8
		],
		[
			11,
			-2
		],
		[
			8,
			7
		],
		[
			-3,
			-12
		],
		[
			-6,
			1
		],
		[
			-6,
			-17
		],
		[
			6,
			-8
		],
		[
			13,
			12
		],
		[
			14,
			-10
		],
		[
			1,
			12
		],
		[
			9,
			9
		],
		[
			7,
			-2
		],
		[
			12,
			11
		],
		[
			-2,
			4
		],
		[
			31,
			15
		],
		[
			12,
			8
		],
		[
			-7,
			-19
		],
		[
			-8,
			1
		],
		[
			3,
			-9
		],
		[
			34,
			-36
		],
		[
			7,
			-11
		],
		[
			42,
			-97
		],
		[
			12,
			-38
		],
		[
			15,
			7
		],
		[
			-1,
			14
		],
		[
			6,
			6
		],
		[
			15,
			-7
		],
		[
			-3,
			-15
		],
		[
			9,
			2
		],
		[
			2,
			-13
		],
		[
			11,
			3
		],
		[
			6,
			-4
		],
		[
			17,
			5
		],
		[
			18,
			12
		],
		[
			13,
			-7
		],
		[
			11,
			-20
		],
		[
			0,
			-15
		],
		[
			23,
			-14
		],
		[
			-2,
			-7
		],
		[
			9,
			-19
		],
		[
			19,
			-1
		],
		[
			6,
			-7
		],
		[
			12,
			20
		],
		[
			0,
			-10
		],
		[
			12,
			-22
		],
		[
			7,
			-9
		]
	],
	[
		[
			6163,
			5412
		],
		[
			-17,
			-50
		],
		[
			-9,
			-17
		],
		[
			0,
			-175
		],
		[
			1,
			-39
		],
		[
			15,
			-39
		],
		[
			0,
			-7
		]
	],
	[
		[
			6153,
			5085
		],
		[
			-6,
			-15
		],
		[
			-9,
			-4
		],
		[
			-4,
			-20
		],
		[
			-5,
			-9
		],
		[
			-5,
			0
		],
		[
			-9,
			-13
		],
		[
			2,
			-12
		],
		[
			-3,
			-18
		],
		[
			-6,
			-12
		],
		[
			-3,
			-25
		],
		[
			-4,
			-11
		],
		[
			-7,
			-30
		],
		[
			-6,
			-3
		]
	],
	[
		[
			6088,
			4913
		],
		[
			-21,
			33
		],
		[
			-19,
			27
		],
		[
			-5,
			13
		],
		[
			4,
			6
		],
		[
			-1,
			14
		],
		[
			-100,
			116
		]
	],
	[
		[
			5946,
			5122
		],
		[
			3,
			12
		],
		[
			-4,
			7
		],
		[
			0,
			10
		],
		[
			4,
			7
		],
		[
			9,
			-1
		],
		[
			-2,
			6
		],
		[
			11,
			4
		],
		[
			-4,
			11
		],
		[
			-10,
			-6
		],
		[
			2,
			-6
		],
		[
			-9,
			7
		],
		[
			-3,
			12
		],
		[
			1,
			12
		]
	],
	[
		[
			5944,
			5197
		],
		[
			4,
			21
		],
		[
			7,
			12
		],
		[
			2,
			15
		],
		[
			9,
			9
		],
		[
			2,
			18
		],
		[
			3,
			6
		],
		[
			0,
			26
		],
		[
			-3,
			18
		],
		[
			2,
			3
		],
		[
			-14,
			40
		],
		[
			-2,
			17
		],
		[
			2,
			13
		],
		[
			-8,
			5
		],
		[
			-3,
			24
		],
		[
			-2,
			2
		]
	],
	[
		[
			5943,
			5426
		],
		[
			11,
			23
		],
		[
			15,
			14
		],
		[
			14,
			9
		],
		[
			4,
			-7
		],
		[
			2,
			-16
		],
		[
			8,
			0
		]
	],
	[
		[
			7045,
			7454
		],
		[
			-13,
			-5
		],
		[
			-15,
			2
		],
		[
			-9,
			-5
		],
		[
			-2,
			-6
		],
		[
			-5,
			10
		],
		[
			-7,
			-7
		],
		[
			-2,
			12
		],
		[
			-8,
			8
		],
		[
			-12,
			-11
		],
		[
			-8,
			-1
		],
		[
			-4,
			11
		],
		[
			-36,
			-5
		],
		[
			-2,
			14
		],
		[
			7,
			20
		],
		[
			14,
			6
		],
		[
			18,
			-12
		],
		[
			1,
			7
		],
		[
			8,
			8
		]
	],
	[
		[
			6970,
			7500
		],
		[
			12,
			3
		],
		[
			11,
			-7
		],
		[
			9,
			15
		],
		[
			8,
			-3
		],
		[
			0,
			14
		],
		[
			7,
			-6
		],
		[
			4,
			9
		],
		[
			10,
			8
		],
		[
			-13,
			3
		],
		[
			-5,
			9
		],
		[
			-9,
			-1
		],
		[
			0,
			10
		],
		[
			-8,
			0
		],
		[
			-6,
			22
		],
		[
			-1,
			-10
		],
		[
			-6,
			-2
		],
		[
			0,
			-13
		],
		[
			-6,
			-1
		],
		[
			-12,
			7
		],
		[
			-4,
			14
		],
		[
			-4,
			-4
		],
		[
			-9,
			10
		],
		[
			8,
			7
		],
		[
			22,
			29
		],
		[
			-8,
			3
		]
	],
	[
		[
			6976,
			7489
		],
		[
			-6,
			4
		],
		[
			2,
			-14
		],
		[
			4,
			10
		]
	],
	[
		[
			6993,
			7480
		],
		[
			0,
			0
		]
	],
	[
		[
			6961,
			7477
		],
		[
			0,
			0
		]
	],
	[
		[
			7901,
			5783
		],
		[
			-6,
			7
		],
		[
			-11,
			2
		],
		[
			-7,
			-4
		],
		[
			-3,
			5
		],
		[
			5,
			13
		],
		[
			0,
			15
		],
		[
			-4,
			5
		],
		[
			-3,
			-16
		],
		[
			-9,
			2
		],
		[
			-2,
			38
		],
		[
			-3,
			3
		]
	],
	[
		[
			7858,
			5853
		],
		[
			0,
			7
		],
		[
			-6,
			22
		],
		[
			0,
			22
		],
		[
			-6,
			7
		],
		[
			0,
			21
		],
		[
			-3,
			7
		],
		[
			-2,
			25
		],
		[
			6,
			0
		],
		[
			10,
			26
		],
		[
			1,
			11
		],
		[
			9,
			8
		],
		[
			12,
			5
		],
		[
			9,
			-5
		],
		[
			5,
			3
		],
		[
			11,
			-2
		],
		[
			5,
			4
		],
		[
			6,
			-3
		],
		[
			2,
			-10
		],
		[
			4,
			8
		]
	],
	[
		[
			7921,
			6009
		],
		[
			3,
			-14
		],
		[
			13,
			-1
		],
		[
			3,
			-9
		],
		[
			6,
			-1
		],
		[
			2,
			7
		],
		[
			-6,
			19
		],
		[
			7,
			7
		],
		[
			6,
			-2
		],
		[
			3,
			6
		],
		[
			8,
			-14
		],
		[
			4,
			0
		],
		[
			8,
			11
		],
		[
			5,
			2
		],
		[
			2,
			10
		]
	],
	[
		[
			7985,
			6030
		],
		[
			0,
			-14
		],
		[
			-3,
			-2
		],
		[
			-2,
			-19
		],
		[
			3,
			-10
		],
		[
			0,
			-10
		],
		[
			5,
			-22
		],
		[
			-5,
			-20
		],
		[
			4,
			-24
		],
		[
			-2,
			-15
		],
		[
			-2,
			-6
		],
		[
			-4,
			5
		],
		[
			-8,
			-14
		],
		[
			-8,
			-7
		],
		[
			-8,
			-1
		],
		[
			0,
			-17
		],
		[
			-11,
			7
		],
		[
			-4,
			-13
		],
		[
			-1,
			-15
		],
		[
			9,
			-13
		],
		[
			1,
			-17
		],
		[
			-9,
			3
		],
		[
			-3,
			10
		],
		[
			-10,
			-2
		],
		[
			-3,
			-7
		],
		[
			-7,
			6
		],
		[
			1,
			-11
		],
		[
			-6,
			-13
		],
		[
			-9,
			0
		],
		[
			-2,
			-6
		]
	],
	[
		[
			627,
			5299
		],
		[
			5,
			-18
		],
		[
			-8,
			8
		],
		[
			3,
			10
		]
	],
	[
		[
			8522,
			7115
		],
		[
			1,
			-14
		],
		[
			-17,
			-6
		],
		[
			-2,
			8
		],
		[
			5,
			8
		],
		[
			13,
			4
		]
	],
	[
		[
			8508,
			7172
		],
		[
			1,
			-8
		],
		[
			-7,
			2
		],
		[
			6,
			6
		]
	],
	[
		[
			8575,
			7196
		],
		[
			-1,
			-14
		],
		[
			-5,
			11
		],
		[
			6,
			3
		]
	],
	[
		[
			8518,
			7361
		],
		[
			8,
			22
		],
		[
			5,
			6
		],
		[
			27,
			0
		],
		[
			7,
			17
		]
	],
	[
		[
			8565,
			7406
		],
		[
			7,
			-27
		],
		[
			14,
			-31
		],
		[
			6,
			-25
		],
		[
			4,
			-25
		],
		[
			-2,
			-7
		],
		[
			-1,
			-33
		],
		[
			4,
			-6
		],
		[
			-2,
			-25
		],
		[
			-9,
			-23
		],
		[
			-18,
			0
		],
		[
			-1,
			-15
		],
		[
			-3,
			6
		],
		[
			-17,
			1
		],
		[
			-2,
			-20
		],
		[
			-4,
			14
		],
		[
			0,
			-13
		],
		[
			-5,
			-9
		],
		[
			-3,
			13
		],
		[
			-6,
			-5
		],
		[
			-3,
			-11
		],
		[
			-4,
			3
		],
		[
			-4,
			-10
		],
		[
			-2,
			15
		],
		[
			-7,
			2
		],
		[
			0,
			9
		],
		[
			6,
			-7
		],
		[
			2,
			11
		],
		[
			-4,
			1
		],
		[
			-2,
			18
		],
		[
			2,
			17
		],
		[
			6,
			9
		],
		[
			-4,
			4
		],
		[
			8,
			7
		],
		[
			-7,
			10
		],
		[
			5,
			1
		],
		[
			-5,
			11
		],
		[
			-1,
			31
		],
		[
			-3,
			8
		],
		[
			3,
			12
		],
		[
			7,
			-1
		],
		[
			-6,
			42
		],
		[
			4,
			3
		]
	],
	[
		[
			5598,
			7616
		],
		[
			-9,
			-9
		],
		[
			-3,
			6
		],
		[
			-10,
			-8
		],
		[
			0,
			-11
		],
		[
			-5,
			0
		]
	],
	[
		[
			5557,
			7633
		],
		[
			8,
			15
		]
	],
	[
		[
			5565,
			7648
		],
		[
			9,
			17
		],
		[
			-2,
			6
		],
		[
			14,
			-7
		],
		[
			8,
			-19
		],
		[
			10,
			-5
		],
		[
			-6,
			-24
		]
	],
	[
		[
			6338,
			6909
		],
		[
			5,
			-15
		],
		[
			-4,
			-7
		],
		[
			-5,
			12
		],
		[
			4,
			10
		]
	],
	[
		[
			6345,
			6826
		],
		[
			-22,
			0
		],
		[
			-6,
			27
		],
		[
			-25,
			5
		]
	],
	[
		[
			6331,
			6910
		],
		[
			7,
			-26
		],
		[
			-6,
			2
		],
		[
			-7,
			-12
		],
		[
			10,
			-1
		],
		[
			2,
			-19
		],
		[
			8,
			-28
		]
	],
	[
		[
			7836,
			6473
		],
		[
			2,
			-9
		],
		[
			8,
			-12
		],
		[
			6,
			-22
		],
		[
			2,
			9
		],
		[
			5,
			-5
		],
		[
			0,
			-9
		],
		[
			-2,
			-23
		],
		[
			7,
			-19
		],
		[
			15,
			-11
		],
		[
			2,
			8
		],
		[
			9,
			10
		],
		[
			5,
			-4
		],
		[
			9,
			-13
		],
		[
			-1,
			-9
		],
		[
			-6,
			-3
		],
		[
			9,
			-6
		],
		[
			0,
			-8
		],
		[
			7,
			-2
		],
		[
			0,
			-11
		],
		[
			-2,
			-10
		],
		[
			-9,
			-12
		],
		[
			-8,
			6
		],
		[
			-4,
			-15
		],
		[
			-6,
			-7
		],
		[
			18,
			-21
		],
		[
			4,
			-8
		],
		[
			9,
			-5
		],
		[
			5,
			-6
		],
		[
			-2,
			-12
		],
		[
			6,
			-14
		],
		[
			5,
			0
		],
		[
			7,
			-30
		],
		[
			13,
			-24
		],
		[
			9,
			-17
		],
		[
			0,
			-18
		],
		[
			4,
			-11
		],
		[
			5,
			5
		],
		[
			4,
			-14
		],
		[
			8,
			-12
		],
		[
			4,
			-1
		],
		[
			-1,
			-8
		],
		[
			-6,
			-5
		],
		[
			2,
			-12
		],
		[
			7,
			-8
		],
		[
			5,
			-12
		],
		[
			-5,
			-33
		]
	],
	[
		[
			7921,
			6009
		],
		[
			9,
			11
		],
		[
			0,
			20
		],
		[
			1,
			5
		],
		[
			-3,
			11
		],
		[
			3,
			6
		],
		[
			2,
			24
		],
		[
			-5,
			5
		],
		[
			0,
			13
		],
		[
			-11,
			7
		],
		[
			0,
			8
		],
		[
			-8,
			15
		],
		[
			0,
			29
		],
		[
			2,
			20
		],
		[
			-3,
			9
		],
		[
			-7,
			7
		],
		[
			-6,
			14
		],
		[
			-7,
			24
		],
		[
			-18,
			8
		],
		[
			-2,
			-10
		],
		[
			-9,
			-15
		],
		[
			-9,
			-6
		],
		[
			-16,
			16
		],
		[
			-4,
			-9
		],
		[
			-19,
			-26
		],
		[
			-4,
			-7
		],
		[
			-5,
			6
		],
		[
			3,
			19
		],
		[
			4,
			9
		],
		[
			0,
			17
		],
		[
			-3,
			3
		],
		[
			5,
			14
		],
		[
			0,
			15
		],
		[
			3,
			7
		],
		[
			-3,
			6
		],
		[
			-1,
			19
		],
		[
			2,
			7
		],
		[
			-12,
			2
		],
		[
			-2,
			-7
		],
		[
			-7,
			0
		],
		[
			-3,
			9
		],
		[
			3,
			29
		],
		[
			-5,
			15
		],
		[
			-6,
			-5
		]
	],
	[
		[
			7780,
			6353
		],
		[
			0,
			15
		],
		[
			7,
			14
		],
		[
			4,
			-1
		],
		[
			0,
			13
		],
		[
			6,
			16
		],
		[
			3,
			0
		],
		[
			9,
			14
		]
	],
	[
		[
			5975,
			7088
		],
		[
			14,
			52
		],
		[
			1,
			19
		],
		[
			9,
			12
		],
		[
			0,
			7
		]
	],
	[
		[
			5999,
			7178
		],
		[
			13,
			-3
		],
		[
			4,
			-23
		],
		[
			-9,
			-14
		],
		[
			2,
			-8
		],
		[
			-6,
			2
		],
		[
			-6,
			-12
		],
		[
			3,
			-5
		],
		[
			-6,
			-8
		]
	],
	[
		[
			4790,
			5433
		],
		[
			-19,
			13
		],
		[
			-21,
			22
		],
		[
			-9,
			12
		],
		[
			-21,
			40
		],
		[
			-9,
			19
		],
		[
			-12,
			7
		],
		[
			-1,
			10
		],
		[
			-14,
			13
		],
		[
			-3,
			12
		]
	],
	[
		[
			4681,
			5581
		],
		[
			3,
			14
		],
		[
			6,
			12
		],
		[
			15,
			23
		],
		[
			0,
			16
		],
		[
			8,
			8
		],
		[
			1,
			17
		]
	],
	[
		[
			5693,
			6449
		],
		[
			0,
			-115
		],
		[
			-27,
			0
		],
		[
			0,
			-28
		]
	],
	[
		[
			5666,
			6306
		],
		[
			-66,
			66
		],
		[
			-3,
			4
		],
		[
			-45,
			45
		],
		[
			-34,
			36
		],
		[
			-45,
			45
		],
		[
			-30,
			31
		],
		[
			-27,
			-26
		]
	],
	[
		[
			5416,
			6507
		],
		[
			-22,
			-22
		],
		[
			-20,
			33
		],
		[
			-42,
			19
		]
	],
	[
		[
			5264,
			6924
		],
		[
			10,
			7
		],
		[
			11,
			30
		],
		[
			-5,
			31
		],
		[
			6,
			17
		],
		[
			5,
			1
		],
		[
			10,
			22
		],
		[
			19,
			18
		],
		[
			-2,
			10
		],
		[
			1,
			34
		]
	],
	[
		[
			5319,
			7094
		],
		[
			10,
			-6
		],
		[
			12,
			-14
		],
		[
			15,
			-2
		],
		[
			14,
			6
		],
		[
			6,
			-6
		],
		[
			17,
			-5
		],
		[
			8,
			-12
		],
		[
			20,
			-6
		],
		[
			5,
			-13
		],
		[
			0,
			-14
		],
		[
			7,
			-25
		],
		[
			4,
			-7
		],
		[
			17,
			-9
		],
		[
			10,
			0
		],
		[
			18,
			-8
		],
		[
			23,
			-18
		],
		[
			3,
			-7
		],
		[
			18,
			-22
		],
		[
			8,
			0
		],
		[
			14,
			14
		],
		[
			10,
			24
		],
		[
			1,
			18
		],
		[
			-6,
			24
		],
		[
			0,
			16
		],
		[
			3,
			12
		],
		[
			15,
			24
		],
		[
			14,
			13
		],
		[
			10,
			1
		],
		[
			5,
			7
		],
		[
			21,
			-3
		],
		[
			21,
			-14
		],
		[
			-1,
			-18
		],
		[
			6,
			-6
		],
		[
			19,
			-7
		],
		[
			2,
			-5
		],
		[
			25,
			-2
		],
		[
			5,
			-18
		]
	],
	[
		[
			3307,
			5973
		],
		[
			-4,
			11
		],
		[
			5,
			10
		],
		[
			-1,
			-21
		]
	],
	[
		[
			7235,
			5735
		],
		[
			7,
			-13
		],
		[
			17,
			-49
		],
		[
			5,
			-36
		],
		[
			5,
			-8
		],
		[
			4,
			-24
		],
		[
			0,
			-20
		],
		[
			-2,
			-22
		],
		[
			-12,
			-22
		],
		[
			-22,
			-17
		],
		[
			-9,
			5
		],
		[
			-4,
			7
		],
		[
			-7,
			43
		],
		[
			-1,
			50
		],
		[
			1,
			40
		],
		[
			2,
			10
		],
		[
			0,
			17
		],
		[
			6,
			17
		],
		[
			-2,
			7
		],
		[
			4,
			10
		],
		[
			6,
			1
		],
		[
			-14,
			10
		],
		[
			2,
			7
		],
		[
			7,
			-3
		],
		[
			7,
			-10
		]
	],
	[
		[
			5798,
			3530
		],
		[
			6,
			-12
		],
		[
			10,
			-10
		],
		[
			3,
			-14
		],
		[
			-4,
			-17
		],
		[
			-5,
			-7
		],
		[
			1,
			-10
		],
		[
			-8,
			-9
		],
		[
			-13,
			-4
		],
		[
			-5,
			-7
		],
		[
			-4,
			-22
		],
		[
			-8,
			2
		],
		[
			-16,
			35
		],
		[
			-5,
			22
		],
		[
			8,
			6
		],
		[
			12,
			35
		],
		[
			8,
			2
		],
		[
			4,
			10
		],
		[
			13,
			8
		],
		[
			3,
			-8
		]
	],
	[
		[
			5582,
			8366
		],
		[
			-1,
			0
		]
	],
	[
		[
			5581,
			8366
		],
		[
			1,
			0
		]
	],
	[
		[
			5652,
			8289
		],
		[
			0,
			9
		],
		[
			-14,
			16
		],
		[
			-6,
			-1
		]
	],
	[
		[
			5632,
			8313
		],
		[
			-3,
			6
		],
		[
			5,
			24
		],
		[
			-8,
			11
		],
		[
			-15,
			1
		],
		[
			-21,
			9
		]
	],
	[
		[
			5590,
			8364
		],
		[
			-6,
			32
		],
		[
			0,
			16
		]
	],
	[
		[
			5584,
			8412
		],
		[
			8,
			9
		],
		[
			22,
			11
		],
		[
			15,
			-4
		],
		[
			8,
			3
		],
		[
			29,
			-5
		],
		[
			4,
			-4
		],
		[
			22,
			8
		],
		[
			5,
			-12
		],
		[
			15,
			-2
		],
		[
			26,
			-28
		]
	],
	[
		[
			5759,
			8496
		],
		[
			14,
			-14
		],
		[
			-6,
			-26
		],
		[
			14,
			-17
		],
		[
			0,
			-23
		]
	],
	[
		[
			5584,
			8412
		],
		[
			-2,
			19
		],
		[
			2,
			24
		],
		[
			10,
			12
		],
		[
			0,
			15
		],
		[
			8,
			15
		],
		[
			22,
			11
		],
		[
			18,
			-21
		],
		[
			4,
			-17
		],
		[
			12,
			-7
		],
		[
			19,
			15
		],
		[
			-2,
			37
		]
	],
	[
		[
			3249,
			6221
		],
		[
			-2,
			2
		]
	],
	[
		[
			3247,
			6223
		],
		[
			2,
			-2
		]
	],
	[
		[
			4851,
			7247
		],
		[
			2,
			-14
		],
		[
			14,
			-21
		],
		[
			11,
			-5
		],
		[
			19,
			8
		],
		[
			6,
			-5
		],
		[
			15,
			7
		]
	],
	[
		[
			4919,
			7214
		],
		[
			2,
			-9
		],
		[
			17,
			-2
		]
	],
	[
		[
			4758,
			6776
		],
		[
			-3,
			0
		],
		[
			1,
			-30
		],
		[
			-18,
			-3
		],
		[
			-7,
			-11
		],
		[
			-16,
			-2
		],
		[
			-9,
			7
		],
		[
			-10,
			1
		],
		[
			-13,
			-7
		],
		[
			2,
			-15
		],
		[
			-4,
			-6
		],
		[
			-8,
			-25
		],
		[
			-8,
			-3
		],
		[
			-4,
			-23
		],
		[
			-3,
			-30
		],
		[
			-3,
			-13
		],
		[
			-6,
			-12
		],
		[
			-12,
			-16
		],
		[
			-6,
			-22
		],
		[
			-16,
			-16
		],
		[
			-4,
			-13
		],
		[
			-6,
			-53
		],
		[
			0,
			-16
		],
		[
			-12,
			-26
		],
		[
			1,
			-7
		],
		[
			-4,
			-14
		],
		[
			-11,
			-4
		],
		[
			-22,
			4
		],
		[
			-18,
			-1
		],
		[
			-12,
			-4
		]
	],
	[
		[
			4527,
			6416
		],
		[
			1,
			21
		],
		[
			4,
			20
		],
		[
			10,
			13
		],
		[
			4,
			26
		],
		[
			5,
			11
		],
		[
			-2,
			5
		],
		[
			13,
			42
		],
		[
			-4,
			0
		],
		[
			8,
			12
		],
		[
			11,
			26
		],
		[
			5,
			4
		],
		[
			5,
			17
		],
		[
			0,
			22
		],
		[
			10,
			45
		],
		[
			0,
			9
		],
		[
			9,
			16
		],
		[
			7,
			4
		],
		[
			10,
			14
		],
		[
			10,
			53
		],
		[
			7,
			16
		],
		[
			24,
			8
		],
		[
			16,
			14
		],
		[
			11,
			23
		],
		[
			15,
			15
		],
		[
			21,
			49
		],
		[
			5,
			19
		],
		[
			1,
			14
		],
		[
			-7,
			13
		],
		[
			0,
			26
		],
		[
			2,
			26
		],
		[
			3,
			11
		],
		[
			9,
			18
		],
		[
			3,
			24
		],
		[
			-1,
			7
		],
		[
			11,
			17
		],
		[
			10,
			23
		],
		[
			26,
			19
		],
		[
			21,
			25
		],
		[
			15,
			48
		],
		[
			2,
			15
		],
		[
			9,
			39
		],
		[
			14,
			7
		]
	],
	[
		[
			5206,
			7702
		],
		[
			-2,
			-1
		]
	],
	[
		[
			5783,
			7801
		],
		[
			-3,
			21
		],
		[
			1,
			26
		],
		[
			3,
			22
		],
		[
			-4,
			18
		],
		[
			-6,
			5
		],
		[
			-17,
			36
		],
		[
			-10,
			30
		],
		[
			-8,
			3
		]
	],
	[
		[
			5739,
			7962
		],
		[
			20,
			10
		],
		[
			14,
			-2
		],
		[
			6,
			-9
		],
		[
			21,
			-8
		],
		[
			10,
			-13
		],
		[
			-1,
			-25
		],
		[
			7,
			-10
		],
		[
			5,
			2
		],
		[
			0,
			-20
		],
		[
			10,
			-9
		],
		[
			-1,
			-16
		],
		[
			6,
			-9
		],
		[
			-15,
			0
		],
		[
			-3,
			6
		],
		[
			-7,
			-6
		],
		[
			-1,
			9
		],
		[
			-7,
			-4
		],
		[
			1,
			-26
		],
		[
			-13,
			-19
		],
		[
			0,
			-11
		],
		[
			-8,
			-1
		]
	],
	[
		[
			6384,
			4200
		],
		[
			0,
			8
		],
		[
			5,
			14
		],
		[
			-5,
			-22
		]
	],
	[
		[
			6370,
			4487
		],
		[
			-2,
			-11
		],
		[
			7,
			-4
		],
		[
			1,
			-18
		],
		[
			7,
			-8
		],
		[
			4,
			-13
		],
		[
			-1,
			-9
		],
		[
			5,
			-25
		],
		[
			3,
			-37
		],
		[
			0,
			-29
		],
		[
			8,
			-27
		],
		[
			-4,
			-34
		],
		[
			-3,
			-9
		],
		[
			-6,
			7
		],
		[
			-3,
			25
		],
		[
			-8,
			-7
		],
		[
			3,
			-23
		],
		[
			-2,
			-5
		],
		[
			5,
			-11
		],
		[
			-1,
			-25
		],
		[
			-5,
			-13
		],
		[
			-6,
			-24
		],
		[
			2,
			-29
		],
		[
			-4,
			-39
		],
		[
			-3,
			-11
		],
		[
			-10,
			-59
		],
		[
			-2,
			-19
		],
		[
			-7,
			-32
		],
		[
			-3,
			-29
		],
		[
			-10,
			-57
		],
		[
			-4,
			-16
		],
		[
			-2,
			-24
		],
		[
			-7,
			-48
		],
		[
			-1,
			-16
		],
		[
			-4,
			-13
		],
		[
			-8,
			-47
		],
		[
			-14,
			-15
		],
		[
			-11,
			-2
		],
		[
			-13,
			-11
		],
		[
			-6,
			-9
		],
		[
			-12,
			-2
		],
		[
			-11,
			17
		],
		[
			-10,
			2
		],
		[
			-10,
			15
		],
		[
			-2,
			20
		],
		[
			-7,
			14
		],
		[
			-1,
			45
		],
		[
			3,
			10
		],
		[
			-4,
			6
		],
		[
			-1,
			16
		],
		[
			-6,
			12
		],
		[
			-4,
			36
		],
		[
			3,
			27
		],
		[
			4,
			6
		],
		[
			0,
			17
		],
		[
			7,
			4
		],
		[
			11,
			46
		],
		[
			4,
			7
		],
		[
			6,
			29
		],
		[
			-3,
			4
		],
		[
			2,
			24
		],
		[
			-6,
			18
		],
		[
			1,
			16
		],
		[
			-6,
			22
		],
		[
			-1,
			35
		],
		[
			-3,
			15
		],
		[
			15,
			49
		],
		[
			0,
			30
		],
		[
			12,
			-1
		],
		[
			11,
			16
		],
		[
			10,
			-2
		],
		[
			0,
			7
		],
		[
			8,
			4
		],
		[
			4,
			-6
		],
		[
			1,
			9
		],
		[
			6,
			5
		],
		[
			18,
			25
		],
		[
			3,
			-7
		],
		[
			-3,
			-10
		],
		[
			7,
			2
		],
		[
			-4,
			18
		],
		[
			4,
			5
		],
		[
			2,
			12
		],
		[
			6,
			8
		],
		[
			-3,
			-22
		],
		[
			11,
			28
		],
		[
			-3,
			11
		],
		[
			3,
			11
		],
		[
			4,
			-2
		],
		[
			3,
			11
		],
		[
			-4,
			9
		],
		[
			0,
			19
		],
		[
			7,
			-1
		],
		[
			1,
			-10
		],
		[
			4,
			-1
		],
		[
			0,
			14
		],
		[
			5,
			1
		],
		[
			-1,
			9
		],
		[
			6,
			-4
		],
		[
			3,
			5
		],
		[
			1,
			16
		],
		[
			3,
			8
		],
		[
			-2,
			22
		],
		[
			3,
			13
		],
		[
			5,
			4
		],
		[
			3,
			18
		],
		[
			2,
			-8
		]
	],
	[
		[
			2590,
			6367
		],
		[
			-7,
			-17
		],
		[
			2,
			17
		],
		[
			5,
			0
		]
	],
	[
		[
			1889,
			6595
		],
		[
			7,
			-4
		],
		[
			1,
			-9
		],
		[
			-8,
			13
		]
	],
	[
		[
			1800,
			6801
		],
		[
			-5,
			-1
		],
		[
			5,
			12
		],
		[
			0,
			-11
		]
	],
	[
		[
			1880,
			6866
		],
		[
			3,
			-12
		],
		[
			-3,
			-16
		],
		[
			-7,
			7
		],
		[
			2,
			17
		],
		[
			5,
			4
		]
	],
	[
		[
			1847,
			6884
		],
		[
			4,
			-14
		],
		[
			5,
			-1
		],
		[
			2,
			-17
		],
		[
			-11,
			17
		],
		[
			-3,
			9
		],
		[
			3,
			6
		]
	],
	[
		[
			2186,
			6889
		],
		[
			0,
			-8
		],
		[
			7,
			-2
		]
	],
	[
		[
			2193,
			6879
		],
		[
			11,
			-20
		],
		[
			1,
			-12
		],
		[
			9,
			-31
		],
		[
			6,
			-12
		],
		[
			9,
			-27
		],
		[
			7,
			-6
		],
		[
			-1,
			-15
		],
		[
			2,
			-15
		]
	],
	[
		[
			2237,
			6741
		],
		[
			3,
			-16
		],
		[
			3,
			2
		],
		[
			2,
			-14
		]
	],
	[
		[
			2245,
			6713
		],
		[
			2,
			-9
		],
		[
			20,
			-12
		],
		[
			4,
			-8
		],
		[
			16,
			-2
		],
		[
			9,
			-10
		],
		[
			5,
			6
		]
	],
	[
		[
			2301,
			6678
		],
		[
			0,
			-14
		],
		[
			-8,
			-31
		],
		[
			-6,
			-38
		],
		[
			-2,
			-30
		],
		[
			-1,
			-43
		],
		[
			1,
			-16
		],
		[
			-4,
			-22
		],
		[
			3,
			-29
		],
		[
			5,
			-34
		],
		[
			15,
			-57
		],
		[
			9,
			-17
		],
		[
			9,
			-27
		],
		[
			3,
			-25
		],
		[
			5,
			-5
		],
		[
			1,
			-9
		],
		[
			7,
			-19
		],
		[
			7,
			-4
		],
		[
			11,
			2
		],
		[
			5,
			-9
		],
		[
			6,
			-2
		],
		[
			8,
			-21
		],
		[
			10,
			3
		],
		[
			16,
			11
		],
		[
			17,
			3
		],
		[
			15,
			13
		],
		[
			10,
			2
		],
		[
			6,
			-12
		],
		[
			10,
			-3
		],
		[
			6,
			17
		],
		[
			-5,
			8
		],
		[
			14,
			16
		],
		[
			5,
			11
		],
		[
			1,
			21
		],
		[
			7,
			14
		],
		[
			-1,
			6
		],
		[
			1,
			39
		],
		[
			3,
			15
		],
		[
			16,
			17
		],
		[
			19,
			4
		],
		[
			17,
			12
		],
		[
			14,
			2
		],
		[
			20,
			-9
		],
		[
			6,
			9
		],
		[
			6,
			-10
		],
		[
			2,
			-17
		],
		[
			-3,
			-16
		],
		[
			-9,
			-18
		],
		[
			-7,
			-19
		],
		[
			-1,
			-19
		],
		[
			-8,
			-16
		],
		[
			9,
			-8
		],
		[
			-6,
			-40
		],
		[
			-3,
			-10
		],
		[
			-2,
			-23
		],
		[
			-3,
			14
		],
		[
			-4,
			3
		],
		[
			2,
			18
		],
		[
			-5,
			-4
		],
		[
			-3,
			-15
		]
	],
	[
		[
			2437,
			6020
		],
		[
			-20,
			42
		],
		[
			-19,
			33
		],
		[
			-11,
			16
		],
		[
			-10,
			10
		],
		[
			-1,
			-6
		],
		[
			-8,
			1
		],
		[
			-4,
			13
		],
		[
			-5,
			-9
		],
		[
			9,
			-4
		],
		[
			-11,
			-1
		],
		[
			-8,
			-12
		],
		[
			-15,
			-9
		],
		[
			-7,
			-8
		],
		[
			-8,
			-2
		],
		[
			-15,
			10
		],
		[
			-4,
			6
		],
		[
			-17,
			3
		],
		[
			-8,
			13
		],
		[
			-13,
			6
		],
		[
			-6,
			14
		],
		[
			-5,
			0
		],
		[
			-15,
			8
		],
		[
			-5,
			0
		],
		[
			-5,
			9
		],
		[
			-31,
			22
		],
		[
			-6,
			11
		],
		[
			-13,
			14
		],
		[
			-4,
			13
		],
		[
			-7,
			6
		],
		[
			-5,
			-4
		],
		[
			-32,
			20
		],
		[
			-8,
			21
		],
		[
			-9,
			14
		],
		[
			-12,
			13
		],
		[
			-15,
			12
		],
		[
			-3,
			14
		],
		[
			-5,
			6
		],
		[
			-8,
			22
		],
		[
			0,
			10
		],
		[
			-4,
			8
		],
		[
			3,
			8
		],
		[
			10,
			6
		],
		[
			-7,
			15
		],
		[
			7,
			12
		],
		[
			1,
			22
		],
		[
			-6,
			8
		],
		[
			-7,
			23
		],
		[
			-2,
			32
		],
		[
			-9,
			17
		],
		[
			-15,
			34
		],
		[
			-12,
			32
		],
		[
			-21,
			28
		],
		[
			7,
			-7
		],
		[
			0,
			9
		],
		[
			-5,
			-1
		],
		[
			-9,
			13
		],
		[
			-6,
			18
		],
		[
			7,
			0
		],
		[
			-22,
			24
		],
		[
			0,
			5
		],
		[
			-9,
			-3
		],
		[
			6,
			9
		],
		[
			-7,
			-1
		],
		[
			-8,
			9
		],
		[
			0,
			14
		],
		[
			4,
			9
		],
		[
			0,
			19
		],
		[
			-4,
			9
		],
		[
			-10,
			3
		],
		[
			-5,
			23
		],
		[
			-9,
			2
		],
		[
			-7,
			13
		],
		[
			-2,
			26
		],
		[
			2,
			3
		],
		[
			-14,
			4
		],
		[
			-8,
			12
		],
		[
			-5,
			13
		],
		[
			-5,
			5
		],
		[
			-13,
			29
		],
		[
			-2,
			20
		],
		[
			-5,
			2
		],
		[
			1,
			9
		],
		[
			-11,
			23
		],
		[
			0,
			16
		],
		[
			-10,
			36
		],
		[
			3,
			20
		],
		[
			-16,
			10
		],
		[
			-1,
			10
		],
		[
			-7,
			6
		],
		[
			-9,
			-6
		],
		[
			-10,
			15
		],
		[
			-8,
			2
		],
		[
			0,
			-41
		],
		[
			4,
			-8
		],
		[
			3,
			-27
		],
		[
			-1,
			-19
		],
		[
			7,
			-21
		],
		[
			4,
			-1
		],
		[
			17,
			-27
		],
		[
			3,
			-23
		],
		[
			7,
			-3
		],
		[
			11,
			-32
		],
		[
			3,
			-25
		],
		[
			4,
			-12
		],
		[
			8,
			-6
		],
		[
			4,
			-20
		],
		[
			6,
			-7
		],
		[
			-1,
			-6
		],
		[
			8,
			-25
		],
		[
			-3,
			20
		],
		[
			8,
			-10
		],
		[
			0,
			-9
		],
		[
			5,
			-13
		],
		[
			1,
			-29
		],
		[
			9,
			-25
		],
		[
			10,
			-36
		],
		[
			-2,
			-15
		],
		[
			3,
			-15
		],
		[
			8,
			-8
		],
		[
			0,
			13
		],
		[
			14,
			-16
		],
		[
			4,
			-23
		],
		[
			7,
			-10
		],
		[
			0,
			-14
		],
		[
			-11,
			-19
		],
		[
			-7,
			0
		],
		[
			-6,
			36
		],
		[
			-8,
			9
		],
		[
			-12,
			22
		],
		[
			-14,
			16
		],
		[
			-5,
			14
		],
		[
			-4,
			-3
		],
		[
			-4,
			14
		],
		[
			-3,
			-1
		],
		[
			-2,
			25
		],
		[
			3,
			3
		],
		[
			0,
			27
		],
		[
			-9,
			30
		],
		[
			-3,
			0
		],
		[
			-17,
			21
		],
		[
			-1,
			21
		],
		[
			-4,
			-13
		],
		[
			-10,
			-1
		],
		[
			-5,
			13
		],
		[
			-8,
			9
		],
		[
			-10,
			6
		],
		[
			0,
			9
		],
		[
			-16,
			20
		],
		[
			-1,
			8
		],
		[
			15,
			-5
		],
		[
			7,
			6
		],
		[
			5,
			-13
		],
		[
			-1,
			17
		],
		[
			2,
			28
		],
		[
			-9,
			26
		],
		[
			-4,
			3
		],
		[
			-12,
			26
		],
		[
			-6,
			2
		],
		[
			-14,
			19
		],
		[
			-4,
			12
		],
		[
			0,
			19
		],
		[
			-5,
			4
		],
		[
			-1,
			26
		],
		[
			-7,
			9
		],
		[
			0,
			11
		],
		[
			-10,
			22
		],
		[
			1,
			15
		],
		[
			-8,
			14
		],
		[
			-6,
			28
		]
	],
	[
		[
			1746,
			7056
		],
		[
			66,
			10
		],
		[
			-1,
			-12
		],
		[
			46,
			-30
		],
		[
			58,
			-37
		],
		[
			79,
			0
		],
		[
			0,
			26
		],
		[
			46,
			0
		],
		[
			11,
			-20
		],
		[
			8,
			-8
		],
		[
			14,
			-26
		],
		[
			6,
			-4
		],
		[
			7,
			-12
		],
		[
			6,
			-21
		],
		[
			-1,
			-10
		],
		[
			5,
			-21
		],
		[
			14,
			-20
		],
		[
			25,
			-19
		],
		[
			8,
			14
		],
		[
			4,
			30
		],
		[
			8,
			2
		],
		[
			3,
			6
		],
		[
			5,
			-5
		],
		[
			20,
			-2
		],
		[
			3,
			-8
		]
	],
	[
		[
			2290,
			6649
		],
		[
			-4,
			-5
		],
		[
			0,
			-32
		],
		[
			-2,
			-53
		],
		[
			6,
			67
		],
		[
			4,
			13
		],
		[
			-4,
			10
		]
	],
	[
		[
			5582,
			7536
		],
		[
			0,
			0
		]
	],
	[
		[
			5586,
			7536
		],
		[
			-4,
			1
		]
	],
	[
		[
			5581,
			7537
		],
		[
			0,
			0
		]
	],
	[
		[
			5575,
			7539
		],
		[
			-2,
			10
		]
	],
	[
		[
			5598,
			7616
		],
		[
			20,
			7
		],
		[
			2,
			-4
		]
	],
	[
		[
			5117,
			6285
		],
		[
			0,
			-124
		],
		[
			-1,
			-33
		],
		[
			-4,
			-7
		],
		[
			-4,
			-29
		],
		[
			-11,
			-17
		],
		[
			0,
			-8
		],
		[
			-14,
			4
		],
		[
			0,
			-5
		],
		[
			-47,
			-3
		],
		[
			-9,
			-17
		],
		[
			-9,
			-3
		],
		[
			-13,
			3
		],
		[
			1,
			-5
		]
	],
	[
		[
			4683,
			5897
		],
		[
			-1,
			36
		],
		[
			-6,
			21
		],
		[
			-5,
			-5
		],
		[
			-8,
			23
		],
		[
			4,
			5
		],
		[
			-2,
			28
		],
		[
			-5,
			6
		],
		[
			1,
			18
		],
		[
			-2,
			5
		]
	],
	[
		[
			4659,
			6034
		],
		[
			5,
			-2
		],
		[
			7,
			8
		],
		[
			0,
			24
		],
		[
			3,
			11
		],
		[
			6,
			7
		],
		[
			14,
			-22
		],
		[
			3,
			-2
		],
		[
			4,
			13
		],
		[
			12,
			1
		],
		[
			14,
			-4
		],
		[
			13,
			7
		],
		[
			65,
			0
		],
		[
			41,
			0
		],
		[
			5,
			45
		],
		[
			-8,
			15
		],
		[
			-1,
			33
		],
		[
			-2,
			21
		],
		[
			-1,
			36
		],
		[
			-2,
			22
		],
		[
			-6,
			109
		],
		[
			0,
			17
		],
		[
			-3,
			39
		],
		[
			-6,
			104
		],
		[
			0,
			14
		],
		[
			-3,
			39
		],
		[
			0,
			16
		],
		[
			-3,
			37
		],
		[
			50,
			0
		]
	],
	[
		[
			7737,
			5862
		],
		[
			0,
			-11
		],
		[
			-4,
			-2
		],
		[
			-1,
			13
		],
		[
			5,
			0
		]
	],
	[
		[
			7733,
			5907
		],
		[
			-2,
			-14
		],
		[
			-1,
			20
		],
		[
			3,
			-6
		]
	],
	[
		[
			7622,
			6095
		],
		[
			-2,
			9
		],
		[
			7,
			13
		],
		[
			2,
			-6
		],
		[
			-7,
			-16
		]
	],
	[
		[
			7710,
			6117
		],
		[
			-4,
			12
		],
		[
			2,
			5
		],
		[
			2,
			-17
		]
	],
	[
		[
			7602,
			6269
		],
		[
			-2,
			-10
		],
		[
			-5,
			9
		],
		[
			7,
			1
		]
	],
	[
		[
			7604,
			6305
		],
		[
			6,
			-6
		],
		[
			-6,
			-6
		],
		[
			-3,
			10
		],
		[
			3,
			2
		]
	],
	[
		[
			7780,
			6353
		],
		[
			-9,
			6
		],
		[
			0,
			-6
		],
		[
			-10,
			2
		],
		[
			3,
			-11
		],
		[
			-6,
			-6
		],
		[
			-8,
			1
		],
		[
			-1,
			-17
		],
		[
			-21,
			-7
		],
		[
			-6,
			8
		],
		[
			0,
			-9
		],
		[
			-5,
			-4
		],
		[
			-2,
			-10
		],
		[
			1,
			-18
		],
		[
			-4,
			-10
		],
		[
			3,
			-19
		],
		[
			-10,
			-8
		],
		[
			5,
			-6
		],
		[
			5,
			-22
		],
		[
			-2,
			-10
		],
		[
			11,
			-23
		],
		[
			4,
			-17
		],
		[
			7,
			-8
		],
		[
			-1,
			-11
		],
		[
			6,
			-28
		],
		[
			6,
			5
		],
		[
			-2,
			-15
		],
		[
			-7,
			-3
		],
		[
			0,
			-40
		],
		[
			-9,
			-4
		],
		[
			-2,
			-12
		],
		[
			2,
			-16
		],
		[
			6,
			-13
		],
		[
			3,
			-15
		],
		[
			11,
			-14
		],
		[
			4,
			-11
		],
		[
			3,
			-67
		],
		[
			6,
			-9
		],
		[
			1,
			-25
		],
		[
			2,
			1
		],
		[
			3,
			-19
		],
		[
			-6,
			-12
		],
		[
			-1,
			-12
		],
		[
			-5,
			-17
		],
		[
			-6,
			-8
		],
		[
			0,
			-8
		],
		[
			-5,
			-4
		],
		[
			-2,
			-23
		]
	],
	[
		[
			7742,
			5779
		],
		[
			-7,
			-20
		],
		[
			0,
			24
		],
		[
			-1,
			18
		],
		[
			7,
			10
		],
		[
			1,
			45
		],
		[
			-5,
			2
		],
		[
			4,
			20
		],
		[
			-6,
			11
		],
		[
			5,
			21
		],
		[
			-3,
			32
		],
		[
			-9,
			31
		],
		[
			-4,
			-1
		],
		[
			0,
			27
		],
		[
			-3,
			9
		],
		[
			-5,
			30
		],
		[
			0,
			32
		],
		[
			-2,
			26
		],
		[
			-4,
			14
		],
		[
			2,
			25
		],
		[
			-8,
			-2
		],
		[
			-5,
			13
		],
		[
			0,
			18
		],
		[
			-3,
			12
		],
		[
			-6,
			8
		],
		[
			0,
			-23
		],
		[
			-2,
			-16
		],
		[
			-5,
			-11
		],
		[
			-11,
			3
		],
		[
			2,
			-12
		],
		[
			-16,
			-8
		],
		[
			-2,
			-16
		],
		[
			-7,
			-13
		],
		[
			-9,
			8
		],
		[
			-6,
			-4
		],
		[
			0,
			12
		],
		[
			-5,
			-9
		],
		[
			-3,
			5
		],
		[
			3,
			21
		],
		[
			-12,
			-19
		],
		[
			-1,
			11
		],
		[
			4,
			22
		],
		[
			2,
			38
		],
		[
			4,
			9
		],
		[
			0,
			22
		],
		[
			-2,
			3
		],
		[
			-2,
			30
		],
		[
			-6,
			24
		],
		[
			-5,
			8
		],
		[
			0,
			20
		],
		[
			-2,
			-4
		],
		[
			-1,
			-16
		],
		[
			-7,
			9
		],
		[
			-6,
			22
		],
		[
			9,
			-10
		],
		[
			6,
			14
		],
		[
			-11,
			14
		],
		[
			3,
			13
		],
		[
			-4,
			-3
		],
		[
			-6,
			11
		],
		[
			-10,
			-1
		],
		[
			2,
			16
		],
		[
			-4,
			-12
		],
		[
			-5,
			6
		],
		[
			5,
			4
		],
		[
			-5,
			9
		],
		[
			0,
			-11
		],
		[
			-7,
			22
		],
		[
			-3,
			3
		],
		[
			-3,
			21
		]
	],
	[
		[
			5533,
			7690
		],
		[
			8,
			-17
		],
		[
			11,
			-8
		],
		[
			13,
			-12
		],
		[
			0,
			-5
		]
	],
	[
		[
			5538,
			7620
		],
		[
			0,
			-3
		]
	],
	[
		[
			5537,
			7617
		],
		[
			-6,
			0
		],
		[
			7,
			-10
		]
	],
	[
		[
			5537,
			7593
		],
		[
			-14,
			24
		],
		[
			-10,
			8
		]
	],
	[
		[
			8263,
			7933
		],
		[
			2,
			-6
		],
		[
			9,
			9
		],
		[
			-4,
			10
		]
	],
	[
		[
			7439,
			8014
		],
		[
			9,
			6
		],
		[
			1,
			10
		],
		[
			19,
			0
		],
		[
			8,
			3
		],
		[
			15,
			13
		],
		[
			-2,
			11
		],
		[
			25,
			18
		],
		[
			5,
			0
		],
		[
			8,
			12
		],
		[
			11,
			0
		],
		[
			12,
			16
		],
		[
			9,
			-2
		],
		[
			7,
			10
		],
		[
			7,
			-10
		],
		[
			9,
			6
		],
		[
			2,
			-10
		],
		[
			33,
			-2
		],
		[
			3,
			-22
		],
		[
			8,
			-10
		],
		[
			8,
			1
		],
		[
			15,
			-8
		],
		[
			9,
			7
		],
		[
			21,
			-9
		],
		[
			11,
			2
		],
		[
			9,
			-10
		],
		[
			7,
			11
		],
		[
			15,
			6
		],
		[
			5,
			15
		],
		[
			2,
			14
		],
		[
			-8,
			6
		],
		[
			-6,
			22
		],
		[
			7,
			27
		],
		[
			5,
			0
		],
		[
			3,
			14
		],
		[
			8,
			4
		],
		[
			7,
			20
		],
		[
			11,
			-11
		],
		[
			11,
			-3
		],
		[
			9,
			-10
		],
		[
			14,
			0
		],
		[
			23,
			-15
		],
		[
			7,
			1
		],
		[
			17,
			-9
		],
		[
			2,
			-43
		],
		[
			17,
			-15
		],
		[
			11,
			-7
		],
		[
			20,
			-3
		],
		[
			13,
			10
		],
		[
			19,
			4
		],
		[
			4,
			6
		],
		[
			21,
			-6
		],
		[
			4,
			-6
		],
		[
			13,
			3
		],
		[
			14,
			-20
		],
		[
			22,
			-3
		],
		[
			-1,
			-15
		],
		[
			17,
			-20
		],
		[
			16,
			1
		],
		[
			31,
			-10
		],
		[
			3,
			4
		],
		[
			9,
			-6
		],
		[
			20,
			14
		],
		[
			18,
			1
		],
		[
			11,
			8
		],
		[
			10,
			-2
		],
		[
			8,
			5
		],
		[
			3,
			12
		],
		[
			27,
			27
		],
		[
			17,
			-1
		],
		[
			17,
			-20
		],
		[
			9,
			-1
		],
		[
			12,
			8
		],
		[
			12,
			-5
		],
		[
			3,
			-6
		]
	],
	[
		[
			5913,
			3637
		],
		[
			-22,
			0
		]
	],
	[
		[
			5891,
			3637
		],
		[
			1,
			15
		],
		[
			-3,
			17
		],
		[
			1,
			16
		],
		[
			-3,
			3
		]
	],
	[
		[
			5887,
			3688
		],
		[
			1,
			16
		],
		[
			0,
			71
		],
		[
			-4,
			30
		],
		[
			-3,
			5
		],
		[
			-6,
			24
		],
		[
			1,
			14
		],
		[
			-7,
			44
		]
	],
	[
		[
			5869,
			3892
		],
		[
			31,
			64
		],
		[
			-2,
			10
		],
		[
			4,
			10
		],
		[
			-1,
			17
		],
		[
			6,
			7
		],
		[
			9,
			29
		],
		[
			1,
			14
		],
		[
			-6,
			6
		],
		[
			1,
			36
		],
		[
			-5,
			2
		],
		[
			0,
			11
		],
		[
			6,
			3
		],
		[
			-1,
			14
		],
		[
			4,
			4
		],
		[
			-2,
			36
		],
		[
			3,
			14
		],
		[
			-1,
			17
		],
		[
			-5,
			22
		],
		[
			4,
			14
		],
		[
			-7,
			-1
		],
		[
			-1,
			6
		],
		[
			-13,
			9
		],
		[
			-9,
			1
		],
		[
			-5,
			12
		],
		[
			-5,
			1
		],
		[
			-7,
			10
		],
		[
			-9,
			-2
		],
		[
			-2,
			4
		],
		[
			-13,
			-1
		],
		[
			0,
			21
		]
	],
	[
		[
			5844,
			4282
		],
		[
			-1,
			18
		],
		[
			-4,
			20
		],
		[
			19,
			14
		],
		[
			14,
			6
		],
		[
			19,
			16
		],
		[
			4,
			1
		],
		[
			27,
			19
		]
	],
	[
		[
			5922,
			4376
		],
		[
			6,
			-21
		],
		[
			7,
			-13
		],
		[
			1,
			6
		],
		[
			17,
			6
		],
		[
			5,
			-11
		],
		[
			2,
			-41
		],
		[
			-5,
			-11
		],
		[
			0,
			-9
		],
		[
			-5,
			-10
		],
		[
			5,
			-13
		],
		[
			1,
			-14
		],
		[
			9,
			-15
		],
		[
			5,
			-13
		],
		[
			5,
			-4
		],
		[
			0,
			-17
		],
		[
			5,
			0
		],
		[
			-2,
			38
		],
		[
			4,
			19
		],
		[
			9,
			2
		],
		[
			3,
			5
		],
		[
			1,
			35
		],
		[
			-1,
			16
		],
		[
			3,
			15
		],
		[
			-2,
			14
		],
		[
			-21,
			54
		],
		[
			-6,
			11
		]
	],
	[
		[
			5968,
			4405
		],
		[
			-2,
			10
		],
		[
			-1,
			28
		],
		[
			2,
			8
		],
		[
			-4,
			14
		],
		[
			0,
			16
		],
		[
			6,
			10
		],
		[
			2,
			25
		]
	],
	[
		[
			5971,
			4516
		],
		[
			19,
			0
		],
		[
			5,
			10
		],
		[
			9,
			-10
		],
		[
			1,
			-7
		],
		[
			15,
			1
		],
		[
			7,
			6
		],
		[
			12,
			-8
		],
		[
			11,
			10
		],
		[
			1,
			13
		],
		[
			7,
			4
		],
		[
			11,
			-8
		],
		[
			11,
			13
		],
		[
			11,
			0
		],
		[
			5,
			9
		],
		[
			9,
			4
		],
		[
			18,
			27
		]
	],
	[
		[
			6123,
			4580
		],
		[
			6,
			-13
		],
		[
			-7,
			-32
		],
		[
			0,
			-23
		],
		[
			3,
			-18
		],
		[
			0,
			-28
		],
		[
			3,
			-20
		],
		[
			-6,
			-8
		],
		[
			5,
			-1
		],
		[
			-2,
			-39
		],
		[
			4,
			-23
		],
		[
			-4,
			-8
		],
		[
			6,
			-2
		],
		[
			-3,
			-8
		],
		[
			6,
			-5
		],
		[
			0,
			-22
		],
		[
			-5,
			-7
		],
		[
			1,
			-8
		],
		[
			-3,
			-24
		],
		[
			-13,
			-26
		],
		[
			-3,
			-14
		],
		[
			-7,
			-7
		],
		[
			3,
			-7
		],
		[
			-21,
			-26
		],
		[
			-1,
			-7
		],
		[
			-11,
			-2
		],
		[
			-16,
			-16
		],
		[
			-6,
			-3
		],
		[
			-20,
			-22
		],
		[
			-11,
			-32
		],
		[
			-8,
			-15
		],
		[
			-2,
			-13
		],
		[
			-5,
			5
		],
		[
			1,
			-12
		],
		[
			-4,
			6
		],
		[
			-13,
			-18
		],
		[
			-6,
			-17
		],
		[
			-16,
			-26
		],
		[
			-3,
			4
		],
		[
			0,
			-25
		],
		[
			-3,
			-12
		],
		[
			6,
			-15
		],
		[
			3,
			0
		],
		[
			4,
			-39
		],
		[
			4,
			-16
		],
		[
			2,
			-20
		],
		[
			-1,
			-24
		],
		[
			5,
			16
		],
		[
			2,
			-16
		],
		[
			-2,
			-10
		],
		[
			3,
			-20
		],
		[
			-7,
			-50
		],
		[
			6,
			-4
		],
		[
			-3,
			-17
		],
		[
			-9,
			-26
		],
		[
			-13,
			-11
		],
		[
			-26,
			-17
		],
		[
			-11,
			-10
		],
		[
			-12,
			-16
		],
		[
			-5,
			-18
		],
		[
			-4,
			-6
		],
		[
			3,
			-12
		],
		[
			7,
			-5
		],
		[
			-1,
			-33
		]
	],
	[
		[
			4659,
			6034
		],
		[
			-6,
			12
		],
		[
			-12,
			16
		],
		[
			-1,
			13
		],
		[
			-8,
			8
		],
		[
			-2,
			17
		],
		[
			-5,
			13
		],
		[
			-10,
			-2
		],
		[
			-6,
			16
		],
		[
			-8,
			14
		],
		[
			-16,
			0
		],
		[
			-20,
			-9
		],
		[
			-19,
			1
		],
		[
			-1,
			-15
		],
		[
			-3,
			-3
		],
		[
			-2,
			-22
		]
	],
	[
		[
			4540,
			6093
		],
		[
			0,
			30
		],
		[
			2,
			18
		],
		[
			8,
			33
		],
		[
			4,
			26
		],
		[
			0,
			28
		],
		[
			-3,
			40
		],
		[
			-5,
			20
		],
		[
			-6,
			11
		],
		[
			9,
			24
		],
		[
			0,
			28
		],
		[
			-9,
			26
		],
		[
			0,
			-9
		],
		[
			-5,
			11
		],
		[
			-4,
			19
		],
		[
			-4,
			-3
		],
		[
			-1,
			-16
		]
	],
	[
		[
			4526,
			6379
		],
		[
			-1,
			6
		],
		[
			3,
			26
		],
		[
			55,
			0
		],
		[
			55,
			0
		],
		[
			0,
			15
		],
		[
			-4,
			71
		],
		[
			3,
			10
		],
		[
			12,
			16
		],
		[
			17,
			11
		],
		[
			0,
			146
		],
		[
			56,
			0
		],
		[
			36,
			0
		],
		[
			0,
			74
		]
	],
	[
		[
			6603,
			4026
		],
		[
			2,
			-11
		],
		[
			-3,
			-12
		],
		[
			-9,
			-1
		],
		[
			0,
			15
		],
		[
			4,
			13
		],
		[
			6,
			-4
		]
	],
	[
		[
			5969,
			4525
		],
		[
			0,
			2
		]
	],
	[
		[
			5969,
			4527
		],
		[
			0,
			-2
		]
	],
	[
		[
			5964,
			4534
		],
		[
			0,
			2
		]
	],
	[
		[
			5964,
			4536
		],
		[
			0,
			-2
		]
	],
	[
		[
			5952,
			4624
		],
		[
			-3,
			6
		]
	],
	[
		[
			5949,
			4630
		],
		[
			3,
			-6
		]
	],
	[
		[
			5946,
			4634
		],
		[
			0,
			1
		]
	],
	[
		[
			5946,
			4635
		],
		[
			0,
			-1
		]
	],
	[
		[
			5941,
			4623
		],
		[
			2,
			-16
		],
		[
			8,
			-22
		],
		[
			-1,
			-51
		],
		[
			3,
			-25
		],
		[
			-8,
			-21
		],
		[
			0,
			-15
		],
		[
			4,
			-4
		],
		[
			0,
			-16
		],
		[
			4,
			-12
		],
		[
			-1,
			-26
		],
		[
			2,
			-9
		],
		[
			7,
			-10
		],
		[
			-2,
			-24
		],
		[
			7,
			-10
		],
		[
			2,
			11
		],
		[
			8,
			-16
		],
		[
			4,
			0
		],
		[
			-6,
			34
		],
		[
			-6,
			2
		],
		[
			0,
			12
		]
	],
	[
		[
			5922,
			4376
		],
		[
			-7,
			-1
		],
		[
			-2,
			12
		],
		[
			-6,
			14
		],
		[
			6,
			8
		],
		[
			4,
			49
		],
		[
			9,
			3
		],
		[
			5,
			11
		],
		[
			-4,
			0
		],
		[
			-4,
			11
		],
		[
			2,
			15
		],
		[
			-3,
			27
		],
		[
			5,
			15
		],
		[
			-4,
			17
		],
		[
			7,
			6
		],
		[
			5,
			11
		],
		[
			-4,
			20
		],
		[
			-6,
			8
		],
		[
			1,
			15
		],
		[
			-4,
			12
		],
		[
			-7,
			1
		],
		[
			-1,
			11
		]
	],
	[
		[
			5914,
			4641
		],
		[
			10,
			-5
		],
		[
			4,
			-7
		],
		[
			9,
			1
		],
		[
			4,
			-7
		]
	],
	[
		[
			8093,
			5320
		],
		[
			-2,
			3
		],
		[
			0,
			20
		],
		[
			2,
			-2
		],
		[
			0,
			-21
		]
	],
	[
		[
			8269,
			5423
		],
		[
			5,
			-1
		]
	],
	[
		[
			7786,
			5497
		],
		[
			-1,
			-11
		],
		[
			-3,
			11
		],
		[
			4,
			0
		]
	],
	[
		[
			7773,
			5553
		],
		[
			-3,
			-8
		],
		[
			-3,
			8
		],
		[
			6,
			0
		]
	],
	[
		[
			7834,
			5543
		],
		[
			9,
			-7
		],
		[
			3,
			-14
		],
		[
			18,
			-29
		],
		[
			9,
			-33
		],
		[
			1,
			-32
		],
		[
			-4,
			-8
		],
		[
			0,
			-23
		],
		[
			4,
			-12
		],
		[
			-2,
			-6
		],
		[
			1,
			-32
		],
		[
			10,
			-15
		],
		[
			3,
			-23
		],
		[
			8,
			-23
		],
		[
			1,
			-24
		],
		[
			-16,
			4
		],
		[
			-4,
			-10
		],
		[
			-5,
			15
		],
		[
			-15,
			19
		],
		[
			-7,
			11
		],
		[
			-10,
			9
		],
		[
			-11,
			21
		],
		[
			-14,
			15
		],
		[
			2,
			9
		],
		[
			-2,
			17
		],
		[
			-6,
			17
		],
		[
			-11,
			19
		],
		[
			2,
			9
		],
		[
			-4,
			6
		],
		[
			1,
			21
		],
		[
			-2,
			19
		],
		[
			-6,
			11
		],
		[
			2,
			6
		],
		[
			-2,
			23
		],
		[
			0,
			26
		],
		[
			-7,
			25
		]
	],
	[
		[
			7780,
			5554
		],
		[
			2,
			15
		],
		[
			4,
			-9
		],
		[
			12,
			-7
		],
		[
			2,
			-11
		],
		[
			7,
			1
		],
		[
			0,
			-19
		],
		[
			-3,
			-9
		],
		[
			3,
			-8
		],
		[
			5,
			9
		],
		[
			9,
			7
		],
		[
			6,
			-10
		],
		[
			7,
			30
		]
	],
	[
		[
			8045,
			5303
		],
		[
			0,
			-10
		],
		[
			8,
			-13
		],
		[
			9,
			1
		],
		[
			16,
			-8
		],
		[
			6,
			-6
		],
		[
			0,
			16
		],
		[
			5,
			22
		],
		[
			0,
			18
		],
		[
			4,
			0
		],
		[
			2,
			16
		],
		[
			5,
			8
		],
		[
			11,
			2
		],
		[
			20,
			10
		],
		[
			9,
			9
		],
		[
			12,
			33
		],
		[
			7,
			12
		],
		[
			6,
			19
		],
		[
			1,
			16
		]
	],
	[
		[
			8193,
			5464
		],
		[
			1,
			-4
		]
	],
	[
		[
			8198,
			5465
		],
		[
			6,
			1
		],
		[
			6,
			15
		],
		[
			-6,
			9
		],
		[
			6,
			11
		],
		[
			6,
			0
		],
		[
			3,
			14
		],
		[
			4,
			4
		],
		[
			1,
			17
		],
		[
			6,
			6
		],
		[
			1,
			8
		],
		[
			8,
			18
		],
		[
			3,
			19
		],
		[
			3,
			-3
		],
		[
			-2,
			-22
		],
		[
			6,
			8
		],
		[
			3,
			15
		],
		[
			4,
			-2
		],
		[
			1,
			-18
		],
		[
			7,
			-3
		],
		[
			6,
			-10
		],
		[
			-4,
			-13
		],
		[
			5,
			-16
		],
		[
			6,
			9
		],
		[
			3,
			-14
		],
		[
			8,
			-1
		],
		[
			9,
			-15
		],
		[
			15,
			-10
		],
		[
			0,
			-11
		],
		[
			-15,
			-13
		],
		[
			-7,
			-1
		],
		[
			-2,
			6
		],
		[
			-7,
			-8
		],
		[
			5,
			-14
		],
		[
			9,
			-13
		],
		[
			-18,
			-12
		],
		[
			-11,
			10
		],
		[
			-1,
			-14
		]
	],
	[
		[
			8256,
			5598
		],
		[
			-5,
			-6
		],
		[
			0,
			10
		],
		[
			6,
			4
		],
		[
			-1,
			-8
		]
	],
	[
		[
			5649,
			4167
		],
		[
			22,
			9
		],
		[
			17,
			-1
		],
		[
			7,
			-5
		],
		[
			6,
			-12
		]
	],
	[
		[
			5554,
			3757
		],
		[
			1,
			-13
		],
		[
			0,
			-196
		],
		[
			-12,
			-8
		],
		[
			-2,
			-9
		],
		[
			-7,
			-5
		],
		[
			-3,
			-11
		],
		[
			-11,
			7
		],
		[
			-16,
			-4
		],
		[
			-16,
			13
		],
		[
			-5,
			-1
		],
		[
			-2,
			28
		],
		[
			-4,
			0
		],
		[
			-3,
			11
		],
		[
			-5,
			-2
		],
		[
			-4,
			-12
		],
		[
			0,
			-11
		],
		[
			-8,
			-7
		]
	],
	[
		[
			5457,
			3537
		],
		[
			-5,
			4
		],
		[
			-15,
			27
		],
		[
			-12,
			41
		],
		[
			-2,
			21
		],
		[
			-5,
			18
		],
		[
			2,
			11
		],
		[
			-5,
			7
		],
		[
			0,
			21
		],
		[
			-3,
			11
		],
		[
			-1,
			23
		],
		[
			1,
			20
		],
		[
			-11,
			53
		],
		[
			1,
			33
		],
		[
			-2,
			25
		],
		[
			3,
			10
		],
		[
			-1,
			27
		],
		[
			-14,
			39
		],
		[
			-4,
			18
		],
		[
			-13,
			37
		],
		[
			-5,
			37
		],
		[
			-3,
			3
		],
		[
			-4,
			20
		],
		[
			-7,
			22
		],
		[
			-3,
			18
		],
		[
			-8,
			23
		],
		[
			-8,
			14
		],
		[
			-5,
			21
		],
		[
			-3,
			36
		],
		[
			1,
			12
		]
	],
	[
		[
			9665,
			3952
		],
		[
			5,
			-3
		],
		[
			-1,
			-13
		],
		[
			-7,
			3
		],
		[
			-2,
			12
		],
		[
			5,
			1
		]
	],
	[
		[
			9646,
			3990
		],
		[
			4,
			-27
		],
		[
			-9,
			7
		],
		[
			-1,
			8
		],
		[
			6,
			12
		]
	],
	[
		[
			9555,
			4026
		],
		[
			7,
			-13
		],
		[
			6,
			0
		],
		[
			16,
			-24
		],
		[
			5,
			-3
		],
		[
			11,
			-30
		],
		[
			7,
			-3
		],
		[
			15,
			-20
		],
		[
			4,
			-10
		],
		[
			11,
			-14
		],
		[
			2,
			-10
		],
		[
			-3,
			-5
		],
		[
			-12,
			8
		],
		[
			-2,
			-4
		],
		[
			-6,
			8
		],
		[
			-2,
			13
		],
		[
			-4,
			-1
		],
		[
			-7,
			14
		],
		[
			-13,
			7
		],
		[
			-4,
			13
		],
		[
			-12,
			16
		],
		[
			-1,
			8
		],
		[
			-6,
			6
		],
		[
			-12,
			44
		]
	],
	[
		[
			5416,
			6507
		],
		[
			4,
			-53
		],
		[
			1,
			-34
		],
		[
			12,
			-31
		],
		[
			-1,
			-12
		],
		[
			11,
			-21
		],
		[
			-7,
			-29
		],
		[
			0,
			-21
		],
		[
			-6,
			-142
		],
		[
			-1,
			-9
		],
		[
			-22,
			-46
		],
		[
			-12,
			-29
		],
		[
			-13,
			-39
		],
		[
			0,
			-11
		],
		[
			-9,
			-19
		],
		[
			4,
			-39
		]
	],
	[
		[
			5377,
			5972
		],
		[
			-6,
			1
		],
		[
			-4,
			-10
		],
		[
			-5,
			0
		],
		[
			-14,
			-18
		],
		[
			-2,
			-10
		],
		[
			-10,
			2
		],
		[
			-7,
			9
		],
		[
			-12,
			6
		],
		[
			-22,
			1
		],
		[
			-13,
			-6
		],
		[
			-7,
			-7
		],
		[
			-8,
			-20
		],
		[
			-18,
			2
		],
		[
			-10,
			7
		],
		[
			-15,
			20
		],
		[
			-9,
			1
		],
		[
			-10,
			-12
		],
		[
			-6,
			0
		],
		[
			-3,
			-7
		],
		[
			-7,
			4
		],
		[
			-4,
			15
		],
		[
			-12,
			21
		],
		[
			-3,
			-3
		],
		[
			-16,
			14
		],
		[
			-8,
			-8
		],
		[
			-12,
			2
		],
		[
			-11,
			-6
		],
		[
			-9,
			-11
		],
		[
			-1,
			-28
		],
		[
			-4,
			-14
		],
		[
			-8,
			-13
		],
		[
			-1,
			-25
		],
		[
			1,
			-21
		],
		[
			-2,
			-2
		]
	],
	[
		[
			5377,
			5972
		],
		[
			13,
			-36
		]
	],
	[
		[
			5238,
			5460
		],
		[
			-5,
			-4
		],
		[
			-6,
			14
		],
		[
			5,
			-21
		],
		[
			-2,
			-4
		],
		[
			-17,
			-3
		],
		[
			-14,
			10
		],
		[
			0,
			-10
		],
		[
			-4,
			-4
		],
		[
			0,
			13
		],
		[
			-4,
			2
		],
		[
			3,
			-18
		],
		[
			-25,
			-6
		],
		[
			-7,
			6
		],
		[
			-8,
			17
		],
		[
			-3,
			12
		],
		[
			-3,
			27
		],
		[
			-4,
			8
		],
		[
			-3,
			17
		],
		[
			-6,
			13
		],
		[
			-13,
			20
		],
		[
			-15,
			4
		],
		[
			-12,
			-1
		],
		[
			4,
			6
		],
		[
			-5,
			2
		],
		[
			0,
			-9
		],
		[
			-19,
			-1
		]
	],
	[
		[
			2691,
			6046
		],
		[
			-6,
			-4
		],
		[
			4,
			-35
		],
		[
			-7,
			-20
		],
		[
			-4,
			-40
		],
		[
			2,
			-21
		],
		[
			-1,
			-19
		],
		[
			2,
			-10
		],
		[
			-4,
			-2
		],
		[
			1,
			15
		],
		[
			-5,
			-4
		],
		[
			4,
			-12
		],
		[
			-5,
			-31
		],
		[
			3,
			2
		],
		[
			1,
			-14
		],
		[
			-6,
			-11
		],
		[
			1,
			-16
		],
		[
			5,
			-12
		]
	],
	[
		[
			2619,
			5821
		],
		[
			-6,
			13
		],
		[
			-12,
			18
		],
		[
			-7,
			15
		],
		[
			-4,
			17
		],
		[
			-26,
			41
		],
		[
			4,
			10
		],
		[
			6,
			-5
		]
	],
	[
		[
			5093,
			8141
		],
		[
			24,
			0
		]
	],
	[
		[
			5162,
			8210
		],
		[
			-10,
			-17
		],
		[
			-10,
			7
		],
		[
			15,
			13
		],
		[
			5,
			-3
		]
	],
	[
		[
			5118,
			8141
		],
		[
			-21,
			6
		],
		[
			1,
			7
		],
		[
			9,
			1
		],
		[
			7,
			-11
		],
		[
			-3,
			33
		],
		[
			8,
			7
		],
		[
			6,
			13
		],
		[
			6,
			36
		],
		[
			10,
			-1
		],
		[
			14,
			21
		],
		[
			11,
			5
		],
		[
			24,
			3
		],
		[
			9,
			-12
		]
	],
	[
		[
			5140,
			8230
		],
		[
			7,
			-10
		],
		[
			-8,
			-8
		],
		[
			0,
			-15
		],
		[
			12,
			-5
		],
		[
			12,
			14
		],
		[
			-12,
			20
		],
		[
			-2,
			13
		],
		[
			-9,
			-9
		]
	],
	[
		[
			5157,
			8665
		],
		[
			-10,
			4
		],
		[
			10,
			9
		],
		[
			0,
			-13
		]
	],
	[
		[
			5249,
			8849
		],
		[
			3,
			-8
		],
		[
			-16,
			-5
		],
		[
			-3,
			7
		],
		[
			16,
			6
		]
	],
	[
		[
			5244,
			8857
		],
		[
			-2,
			-7
		],
		[
			-13,
			0
		],
		[
			15,
			7
		]
	],
	[
		[
			5344,
			8955
		],
		[
			3,
			-6
		],
		[
			-12,
			-11
		],
		[
			9,
			17
		]
	],
	[
		[
			5387,
			9114
		],
		[
			3,
			-5
		],
		[
			-17,
			-6
		],
		[
			5,
			13
		],
		[
			9,
			-2
		]
	],
	[
		[
			5420,
			9124
		],
		[
			-11,
			-11
		],
		[
			-15,
			-6
		],
		[
			9,
			15
		],
		[
			17,
			2
		]
	],
	[
		[
			5441,
			9154
		],
		[
			2,
			-15
		],
		[
			8,
			12
		],
		[
			8,
			-5
		],
		[
			-1,
			-15
		],
		[
			-21,
			-8
		],
		[
			-4,
			-7
		],
		[
			-17,
			-3
		],
		[
			6,
			18
		],
		[
			6,
			0
		],
		[
			6,
			23
		],
		[
			7,
			0
		]
	],
	[
		[
			5421,
			9152
		],
		[
			6,
			-15
		],
		[
			-9,
			-5
		],
		[
			-18,
			7
		],
		[
			21,
			13
		]
	],
	[
		[
			5439,
			9158
		],
		[
			-11,
			-3
		],
		[
			20,
			19
		],
		[
			-9,
			-16
		]
	],
	[
		[
			5492,
			9188
		],
		[
			10,
			-7
		],
		[
			-3,
			-14
		],
		[
			-32,
			-8
		],
		[
			9,
			12
		],
		[
			-6,
			8
		],
		[
			22,
			9
		]
	],
	[
		[
			5523,
			9207
		],
		[
			6,
			-7
		],
		[
			-8,
			-11
		],
		[
			-17,
			-2
		],
		[
			5,
			15
		],
		[
			14,
			5
		]
	],
	[
		[
			5533,
			9218
		],
		[
			12,
			-6
		],
		[
			-15,
			-10
		],
		[
			-9,
			7
		],
		[
			12,
			9
		]
	],
	[
		[
			5652,
			9249
		],
		[
			5,
			-8
		],
		[
			-16,
			-11
		],
		[
			-6,
			7
		],
		[
			17,
			12
		]
	],
	[
		[
			5649,
			9262
		],
		[
			-11,
			-16
		],
		[
			-24,
			-4
		],
		[
			7,
			13
		],
		[
			17,
			-3
		],
		[
			11,
			10
		]
	],
	[
		[
			5856,
			9203
		],
		[
			2,
			-15
		],
		[
			-17,
			4
		],
		[
			-10,
			-15
		],
		[
			-16,
			-3
		],
		[
			-11,
			-16
		]
	],
	[
		[
			5572,
			9158
		],
		[
			-14,
			0
		],
		[
			7,
			-8
		],
		[
			-11,
			-20
		],
		[
			0,
			-11
		],
		[
			-42,
			13
		],
		[
			-8,
			-3
		],
		[
			1,
			-19
		],
		[
			-8,
			-13
		],
		[
			-16,
			8
		],
		[
			-15,
			-11
		],
		[
			-5,
			-16
		],
		[
			-14,
			-13
		],
		[
			9,
			-12
		],
		[
			-1,
			-10
		],
		[
			-27,
			-31
		],
		[
			2,
			-13
		],
		[
			-12,
			-7
		],
		[
			-15,
			-1
		],
		[
			3,
			-17
		],
		[
			-3,
			-30
		],
		[
			-5,
			-12
		],
		[
			-20,
			-30
		],
		[
			14,
			-8
		],
		[
			1,
			-15
		],
		[
			-5,
			-10
		],
		[
			-21,
			5
		],
		[
			-15,
			-8
		],
		[
			-14,
			-21
		],
		[
			-5,
			-18
		],
		[
			6,
			-16
		],
		[
			-4,
			-24
		],
		[
			7,
			-20
		],
		[
			-5,
			-30
		],
		[
			20,
			-20
		],
		[
			-4,
			-18
		],
		[
			-13,
			-4
		],
		[
			10,
			-29
		],
		[
			-3,
			-21
		],
		[
			-10,
			-13
		],
		[
			-7,
			0
		],
		[
			-6,
			-16
		],
		[
			4,
			-21
		],
		[
			-6,
			-21
		],
		[
			-5,
			6
		]
	],
	[
		[
			5317,
			8580
		],
		[
			-2,
			7
		],
		[
			-16,
			4
		],
		[
			-5,
			22
		],
		[
			-5,
			-3
		],
		[
			1,
			-15
		],
		[
			-5,
			-12
		],
		[
			-15,
			-2
		],
		[
			-28,
			-36
		],
		[
			-16,
			-16
		],
		[
			-15,
			-5
		],
		[
			-30,
			5
		],
		[
			4,
			7
		],
		[
			-19,
			9
		],
		[
			-10,
			9
		],
		[
			-4,
			11
		],
		[
			2,
			18
		],
		[
			14,
			-10
		],
		[
			-5,
			13
		],
		[
			9,
			14
		],
		[
			-12,
			11
		],
		[
			2,
			-11
		],
		[
			-10,
			-4
		],
		[
			-8,
			9
		],
		[
			8,
			18
		],
		[
			11,
			0
		],
		[
			-5,
			7
		],
		[
			7,
			5
		],
		[
			5,
			15
		],
		[
			10,
			13
		],
		[
			-13,
			-9
		],
		[
			-6,
			-16
		],
		[
			-6,
			16
		],
		[
			-6,
			-8
		],
		[
			-6,
			8
		],
		[
			3,
			14
		],
		[
			12,
			-3
		],
		[
			-1,
			14
		],
		[
			-10,
			-9
		],
		[
			-10,
			14
		],
		[
			3,
			16
		],
		[
			10,
			0
		],
		[
			-13,
			10
		],
		[
			0,
			10
		],
		[
			11,
			7
		],
		[
			-11,
			5
		],
		[
			11,
			16
		],
		[
			33,
			-6
		],
		[
			-31,
			8
		],
		[
			-7,
			-3
		],
		[
			7,
			17
		],
		[
			13,
			1
		],
		[
			25,
			16
		],
		[
			-12,
			-3
		],
		[
			12,
			13
		],
		[
			22,
			-8
		],
		[
			-1,
			10
		],
		[
			-16,
			2
		],
		[
			-2,
			12
		],
		[
			10,
			5
		],
		[
			7,
			-6
		],
		[
			16,
			2
		],
		[
			4,
			11
		],
		[
			12,
			-2
		],
		[
			-5,
			11
		],
		[
			34,
			19
		],
		[
			7,
			-14
		],
		[
			24,
			5
		],
		[
			-2,
			8
		],
		[
			19,
			14
		],
		[
			2,
			9
		],
		[
			-18,
			-7
		],
		[
			2,
			-9
		],
		[
			-26,
			-14
		],
		[
			-12,
			16
		],
		[
			15,
			11
		],
		[
			-3,
			9
		],
		[
			14,
			10
		],
		[
			12,
			17
		],
		[
			13,
			-11
		],
		[
			0,
			17
		],
		[
			11,
			5
		],
		[
			4,
			17
		],
		[
			19,
			3
		],
		[
			-10,
			6
		],
		[
			10,
			12
		],
		[
			-8,
			12
		],
		[
			27,
			33
		],
		[
			-8,
			8
		],
		[
			9,
			16
		],
		[
			12,
			10
		],
		[
			-7,
			6
		],
		[
			20,
			4
		],
		[
			10,
			13
		],
		[
			22,
			-3
		],
		[
			0,
			5
		],
		[
			-28,
			1
		],
		[
			28,
			31
		],
		[
			-15,
			-9
		],
		[
			4,
			15
		],
		[
			30,
			7
		],
		[
			-22,
			1
		],
		[
			23,
			8
		],
		[
			5,
			-17
		],
		[
			6,
			8
		],
		[
			-11,
			14
		],
		[
			17,
			8
		],
		[
			32,
			-1
		],
		[
			-9,
			8
		],
		[
			-29,
			-5
		],
		[
			2,
			11
		],
		[
			24,
			6
		],
		[
			6,
			22
		],
		[
			10,
			6
		],
		[
			4,
			14
		],
		[
			19,
			5
		],
		[
			11,
			13
		],
		[
			26,
			10
		],
		[
			8,
			-11
		],
		[
			15,
			2
		],
		[
			11,
			14
		],
		[
			19,
			-17
		],
		[
			-5,
			14
		],
		[
			-18,
			15
		],
		[
			28,
			3
		],
		[
			20,
			-6
		],
		[
			5,
			-14
		],
		[
			11,
			25
		],
		[
			29,
			23
		],
		[
			0,
			11
		],
		[
			37,
			-7
		],
		[
			-19,
			-17
		],
		[
			-9,
			-26
		],
		[
			8,
			-1
		],
		[
			6,
			15
		],
		[
			33,
			35
		],
		[
			-3,
			-34
		],
		[
			17,
			22
		],
		[
			11,
			6
		],
		[
			-8,
			10
		],
		[
			28,
			3
		],
		[
			8,
			-5
		],
		[
			-19,
			-29
		],
		[
			14,
			2
		],
		[
			11,
			20
		],
		[
			9,
			1
		],
		[
			21,
			-14
		],
		[
			8,
			4
		],
		[
			27,
			-25
		],
		[
			-16,
			-2
		],
		[
			-10,
			-10
		],
		[
			-39,
			6
		],
		[
			-3,
			-4
		],
		[
			29,
			-8
		],
		[
			-2,
			-12
		],
		[
			34,
			3
		]
	],
	[
		[
			5713,
			9281
		],
		[
			11,
			-11
		],
		[
			-15,
			-3
		],
		[
			-6,
			9
		],
		[
			10,
			5
		]
	],
	[
		[
			4778,
			9282
		],
		[
			-1,
			-9
		],
		[
			-15,
			-2
		],
		[
			16,
			11
		]
	],
	[
		[
			5647,
			9686
		],
		[
			-7,
			-11
		],
		[
			38,
			-10
		],
		[
			-33,
			-33
		],
		[
			-23,
			0
		],
		[
			10,
			17
		],
		[
			-53,
			-6
		],
		[
			22,
			27
		],
		[
			-22,
			9
		],
		[
			23,
			8
		],
		[
			45,
			-1
		]
	],
	[
		[
			5596,
			9708
		],
		[
			21,
			-5
		],
		[
			1,
			-13
		],
		[
			-43,
			-4
		],
		[
			-15,
			17
		],
		[
			36,
			5
		]
	],
	[
		[
			5313,
			9706
		],
		[
			24,
			-18
		],
		[
			-29,
			12
		],
		[
			-16,
			19
		],
		[
			13,
			4
		],
		[
			8,
			-17
		]
	],
	[
		[
			5467,
			9783
		],
		[
			4,
			5
		],
		[
			53,
			-31
		],
		[
			2,
			-16
		],
		[
			23,
			1
		],
		[
			8,
			-9
		],
		[
			40,
			-9
		],
		[
			-5,
			-12
		],
		[
			-44,
			-1
		],
		[
			-22,
			-10
		],
		[
			3,
			-21
		],
		[
			-18,
			-4
		],
		[
			-5,
			-31
		],
		[
			-14,
			1
		],
		[
			-11,
			-30
		],
		[
			-12,
			-11
		],
		[
			3,
			-11
		],
		[
			-20,
			6
		],
		[
			-35,
			25
		],
		[
			-18,
			3
		],
		[
			-9,
			22
		],
		[
			50,
			-2
		],
		[
			-31,
			7
		],
		[
			59,
			9
		],
		[
			-36,
			4
		],
		[
			-50,
			-9
		],
		[
			-5,
			19
		],
		[
			40,
			3
		],
		[
			17,
			12
		],
		[
			27,
			1
		],
		[
			-3,
			22
		],
		[
			-14,
			-14
		],
		[
			-16,
			-1
		],
		[
			-1,
			23
		],
		[
			-28,
			-21
		],
		[
			10,
			-6
		],
		[
			-25,
			-10
		],
		[
			-23,
			-1
		],
		[
			-17,
			20
		],
		[
			-20,
			10
		],
		[
			21,
			16
		],
		[
			-19,
			4
		],
		[
			10,
			14
		],
		[
			-23,
			-12
		],
		[
			-16,
			26
		],
		[
			31,
			17
		],
		[
			9,
			-10
		],
		[
			47,
			12
		],
		[
			-3,
			-10
		],
		[
			-33,
			-9
		],
		[
			37,
			-1
		],
		[
			19,
			16
		],
		[
			20,
			-12
		],
		[
			5,
			-15
		],
		[
			28,
			-25
		],
		[
			-14,
			23
		],
		[
			-7,
			33
		],
		[
			24,
			9
		],
		[
			7,
			-9
		]
	],
	[
		[
			5642,
			9812
		],
		[
			113,
			-16
		],
		[
			-1,
			-15
		],
		[
			-37,
			-13
		],
		[
			-5,
			-13
		],
		[
			-38,
			-5
		],
		[
			-6,
			-7
		],
		[
			-32,
			2
		],
		[
			-1,
			11
		],
		[
			-57,
			-2
		],
		[
			-32,
			10
		],
		[
			22,
			8
		],
		[
			39,
			1
		],
		[
			0,
			7
		],
		[
			-66,
			-7
		],
		[
			-28,
			4
		],
		[
			-12,
			23
		],
		[
			33,
			-5
		],
		[
			33,
			19
		],
		[
			53,
			-25
		],
		[
			3,
			26
		],
		[
			19,
			-3
		]
	],
	[
		[
			9617,
			2273
		],
		[
			0,
			-19
		],
		[
			-6,
			6
		],
		[
			6,
			13
		]
	],
	[
		[
			9665,
			2494
		],
		[
			6,
			-10
		],
		[
			0,
			-14
		],
		[
			-12,
			-2
		],
		[
			-5,
			-8
		],
		[
			1,
			13
		],
		[
			5,
			6
		],
		[
			-1,
			14
		],
		[
			6,
			1
		]
	],
	[
		[
			96,
			2665
		],
		[
			10,
			-1
		],
		[
			-9,
			-6
		],
		[
			6,
			-11
		],
		[
			-9,
			-5
		],
		[
			3,
			13
		],
		[
			-9,
			8
		],
		[
			8,
			2
		]
	],
	[
		[
			9802,
			2850
		],
		[
			-4,
			0
		],
		[
			-2,
			-14
		],
		[
			9,
			-2
		],
		[
			1,
			-21
		],
		[
			4,
			-9
		],
		[
			10,
			14
		],
		[
			6,
			3
		],
		[
			3,
			-10
		],
		[
			3,
			13
		],
		[
			9,
			-2
		],
		[
			-4,
			-7
		],
		[
			3,
			-10
		],
		[
			-6,
			-8
		],
		[
			6,
			-18
		],
		[
			-8,
			-17
		],
		[
			-3,
			-13
		],
		[
			-9,
			-13
		],
		[
			-6,
			-23
		],
		[
			-15,
			-16
		],
		[
			-1,
			-24
		],
		[
			9,
			-5
		],
		[
			1,
			-9
		],
		[
			-7,
			-4
		],
		[
			-10,
			10
		],
		[
			-7,
			-9
		],
		[
			-25,
			-22
		],
		[
			-4,
			-20
		],
		[
			0,
			-17
		],
		[
			-7,
			-15
		],
		[
			-5,
			-25
		],
		[
			0,
			-16
		],
		[
			-8,
			-3
		],
		[
			-17,
			-24
		],
		[
			-4,
			-11
		],
		[
			-13,
			-7
		],
		[
			-11,
			0
		],
		[
			-1,
			6
		],
		[
			-13,
			-4
		],
		[
			-5,
			16
		],
		[
			-11,
			-2
		],
		[
			-2,
			10
		],
		[
			-8,
			3
		],
		[
			-3,
			-7
		],
		[
			-16,
			3
		],
		[
			1,
			13
		],
		[
			-9,
			0
		],
		[
			0,
			10
		],
		[
			9,
			6
		],
		[
			-2,
			8
		],
		[
			4,
			17
		],
		[
			8,
			-7
		],
		[
			-4,
			16
		],
		[
			36,
			56
		],
		[
			2,
			7
		],
		[
			10,
			1
		],
		[
			19,
			21
		],
		[
			8,
			4
		],
		[
			16,
			27
		],
		[
			14,
			12
		],
		[
			13,
			29
		],
		[
			6,
			37
		],
		[
			9,
			4
		],
		[
			8,
			16
		],
		[
			1,
			31
		],
		[
			15,
			21
		],
		[
			7,
			0
		]
	],
	[
		[
			9872,
			3102
		],
		[
			4,
			-10
		],
		[
			-7,
			5
		],
		[
			3,
			5
		]
	],
	[
		[
			9807,
			3201
		],
		[
			-1,
			-14
		],
		[
			3,
			-11
		],
		[
			8,
			-8
		],
		[
			8,
			2
		],
		[
			10,
			-9
		],
		[
			2,
			-9
		],
		[
			5,
			4
		],
		[
			1,
			-13
		],
		[
			5,
			-10
		],
		[
			-2,
			-23
		],
		[
			9,
			-16
		],
		[
			-3,
			-21
		],
		[
			7,
			-17
		],
		[
			8,
			0
		],
		[
			4,
			-17
		],
		[
			5,
			3
		],
		[
			-4,
			18
		],
		[
			3,
			20
		],
		[
			3,
			-14
		],
		[
			7,
			-9
		],
		[
			1,
			-35
		],
		[
			2,
			-7
		],
		[
			14,
			-7
		],
		[
			19,
			-13
		],
		[
			10,
			4
		],
		[
			5,
			14
		],
		[
			8,
			7
		],
		[
			8,
			0
		],
		[
			7,
			-10
		],
		[
			-6,
			-15
		],
		[
			-1,
			-32
		],
		[
			-10,
			-9
		],
		[
			-2,
			-34
		],
		[
			-1,
			12
		],
		[
			-12,
			1
		],
		[
			-10,
			-8
		],
		[
			-4,
			-10
		],
		[
			1,
			-13
		],
		[
			4,
			-3
		],
		[
			-5,
			-25
		],
		[
			-8,
			-21
		],
		[
			-6,
			-9
		],
		[
			-9,
			-30
		],
		[
			-8,
			-14
		],
		[
			-13,
			-14
		],
		[
			-3,
			11
		],
		[
			-9,
			-1
		],
		[
			-8,
			12
		],
		[
			4,
			4
		],
		[
			10,
			24
		],
		[
			4,
			27
		],
		[
			-5,
			17
		],
		[
			-15,
			10
		],
		[
			-6,
			12
		],
		[
			-9,
			4
		],
		[
			-6,
			8
		],
		[
			1,
			14
		],
		[
			22,
			19
		],
		[
			3,
			41
		],
		[
			4,
			20
		],
		[
			-3,
			30
		],
		[
			4,
			10
		],
		[
			-3,
			8
		],
		[
			-8,
			-6
		],
		[
			-2,
			16
		],
		[
			-6,
			19
		],
		[
			7,
			-12
		],
		[
			-2,
			22
		],
		[
			-11,
			8
		],
		[
			1,
			-9
		],
		[
			-26,
			61
		],
		[
			2,
			16
		],
		[
			-12,
			29
		],
		[
			10,
			1
		]
	],
	[
		[
			6629,
			6344
		],
		[
			-1,
			12
		],
		[
			8,
			19
		],
		[
			-7,
			-31
		]
	],
	[
		[
			6474,
			6141
		],
		[
			-8,
			37
		],
		[
			-2,
			0
		],
		[
			-11,
			55
		],
		[
			-10,
			44
		]
	],
	[
		[
			6443,
			6277
		],
		[
			13,
			8
		],
		[
			52,
			37
		],
		[
			19,
			12
		],
		[
			9,
			56
		],
		[
			9,
			61
		],
		[
			-13,
			39
		]
	],
	[
		[
			6566,
			6621
		],
		[
			6,
			-28
		],
		[
			6,
			-15
		],
		[
			10,
			-17
		],
		[
			31,
			-18
		],
		[
			8,
			2
		],
		[
			6,
			-11
		],
		[
			13,
			-39
		],
		[
			7,
			-13
		],
		[
			8,
			-2
		],
		[
			0,
			-17
		],
		[
			-9,
			-27
		],
		[
			-4,
			-19
		],
		[
			-12,
			-17
		],
		[
			-11,
			-42
		],
		[
			-8,
			1
		],
		[
			1,
			11
		],
		[
			-5,
			-3
		],
		[
			-3,
			-13
		],
		[
			-4,
			-4
		],
		[
			-1,
			-20
		],
		[
			-3,
			-10
		],
		[
			2,
			-31
		],
		[
			2,
			-11
		],
		[
			-3,
			-4
		],
		[
			-15,
			-2
		],
		[
			-8,
			-6
		],
		[
			-7,
			-12
		],
		[
			-3,
			-28
		],
		[
			-5,
			-10
		],
		[
			-5,
			1
		],
		[
			-21,
			-7
		],
		[
			-6,
			-19
		],
		[
			2,
			-9
		],
		[
			-7,
			-20
		],
		[
			-8,
			-3
		],
		[
			-4,
			5
		],
		[
			-16,
			-3
		],
		[
			-12,
			-14
		],
		[
			-7,
			0
		],
		[
			-7,
			-6
		]
	],
	[
		[
			6557,
			6684
		],
		[
			2,
			8
		],
		[
			9,
			-6
		],
		[
			-5,
			-27
		]
	],
	[
		[
			6893,
			6556
		],
		[
			-1,
			-9
		],
		[
			-8,
			10
		],
		[
			-6,
			-3
		],
		[
			-8,
			15
		],
		[
			-5,
			42
		],
		[
			-13,
			5
		],
		[
			1,
			20
		],
		[
			-5,
			7
		],
		[
			-3,
			13
		],
		[
			-7,
			1
		],
		[
			2,
			-7
		],
		[
			-16,
			-8
		],
		[
			-13,
			2
		],
		[
			-1,
			-4
		],
		[
			-23,
			-1
		],
		[
			-19,
			6
		],
		[
			-4,
			-11
		],
		[
			-28,
			4
		],
		[
			-5,
			-6
		],
		[
			-17,
			-8
		],
		[
			1,
			8
		],
		[
			-5,
			2
		]
	],
	[
		[
			2729,
			5623
		],
		[
			3,
			-19
		],
		[
			-7,
			12
		],
		[
			4,
			7
		]
	],
	[
		[
			2836,
			5599
		],
		[
			-8,
			16
		],
		[
			-7,
			31
		],
		[
			5,
			4
		],
		[
			0,
			10
		],
		[
			5,
			8
		],
		[
			-5,
			3
		],
		[
			-4,
			-7
		],
		[
			-3,
			16
		],
		[
			-10,
			15
		],
		[
			-6,
			5
		],
		[
			-10,
			2
		],
		[
			-9,
			-12
		],
		[
			0,
			-13
		],
		[
			-8,
			-11
		],
		[
			-12,
			-10
		],
		[
			0,
			-8
		],
		[
			10,
			-19
		],
		[
			4,
			-14
		],
		[
			-10,
			-6
		],
		[
			-2,
			-9
		],
		[
			-13,
			-2
		],
		[
			0,
			7
		],
		[
			-8,
			30
		],
		[
			-1,
			-14
		],
		[
			-10,
			8
		],
		[
			-3,
			19
		],
		[
			-9,
			8
		],
		[
			-6,
			-1
		],
		[
			0,
			8
		],
		[
			-8,
			-4
		],
		[
			-9,
			2
		],
		[
			-2,
			-16
		]
	],
	[
		[
			2706,
			5734
		],
		[
			6,
			-10
		],
		[
			3,
			-23
		],
		[
			13,
			-4
		],
		[
			-4,
			11
		],
		[
			5,
			-3
		],
		[
			6,
			-15
		],
		[
			10,
			-1
		],
		[
			9,
			5
		],
		[
			7,
			12
		],
		[
			14,
			8
		],
		[
			14,
			22
		],
		[
			10,
			-4
		],
		[
			7,
			2
		],
		[
			-2,
			-7
		],
		[
			16,
			-2
		],
		[
			17,
			-19
		],
		[
			3,
			-9
		],
		[
			10,
			-15
		]
	],
	[
		[
			3073,
			4289
		],
		[
			-8,
			13
		],
		[
			-7,
			0
		],
		[
			2,
			-20
		],
		[
			-3,
			4
		],
		[
			-3,
			-15
		],
		[
			17,
			-10
		],
		[
			-2,
			-8
		],
		[
			7,
			-8
		],
		[
			4,
			3
		]
	],
	[
		[
			3084,
			4249
		],
		[
			-2,
			-19
		]
	],
	[
		[
			3044,
			4127
		],
		[
			-14,
			19
		],
		[
			0,
			3
		],
		[
			-13,
			15
		],
		[
			0,
			13
		],
		[
			-3,
			10
		],
		[
			-18,
			16
		],
		[
			-6,
			15
		],
		[
			-10,
			5
		],
		[
			-17,
			20
		],
		[
			-17,
			13
		],
		[
			-3,
			8
		],
		[
			-32,
			34
		],
		[
			-1,
			9
		],
		[
			-9,
			19
		],
		[
			-10,
			12
		],
		[
			-6,
			25
		],
		[
			-4,
			2
		],
		[
			0,
			15
		],
		[
			3,
			23
		],
		[
			-10,
			34
		],
		[
			0,
			7
		],
		[
			-8,
			20
		],
		[
			1,
			6
		],
		[
			-7,
			9
		],
		[
			-3,
			11
		],
		[
			-2,
			23
		],
		[
			-4,
			10
		],
		[
			-8,
			9
		],
		[
			1,
			11
		],
		[
			-4,
			20
		],
		[
			-12,
			36
		],
		[
			-1,
			20
		],
		[
			-4,
			9
		],
		[
			-2,
			18
		],
		[
			-5,
			8
		],
		[
			-4,
			33
		],
		[
			-6,
			23
		],
		[
			-14,
			29
		],
		[
			-6,
			35
		],
		[
			-7,
			12
		],
		[
			-6,
			16
		],
		[
			-16,
			16
		],
		[
			-11,
			17
		],
		[
			0,
			11
		],
		[
			8,
			6
		],
		[
			-2,
			16
		],
		[
			-7,
			11
		],
		[
			3,
			15
		],
		[
			-8,
			19
		],
		[
			2,
			25
		],
		[
			12,
			23
		],
		[
			0,
			5
		],
		[
			14,
			21
		]
	],
	[
		[
			8339,
			5486
		],
		[
			-9,
			-12
		],
		[
			-3,
			4
		],
		[
			12,
			8
		]
	],
	[
		[
			8361,
			5534
		],
		[
			5,
			-6
		],
		[
			-8,
			-6
		],
		[
			3,
			12
		]
	],
	[
		[
			8390,
			5552
		],
		[
			-3,
			0
		],
		[
			-4,
			14
		],
		[
			7,
			5
		],
		[
			7,
			-7
		],
		[
			-7,
			-12
		]
	],
	[
		[
			8493,
			5581
		],
		[
			-3,
			9
		],
		[
			3,
			5
		],
		[
			0,
			-14
		]
	],
	[
		[
			8251,
			5645
		],
		[
			-2,
			-13
		],
		[
			-1,
			14
		],
		[
			3,
			-1
		]
	],
	[
		[
			8489,
			5736
		],
		[
			9,
			-8
		],
		[
			3,
			-13
		],
		[
			4,
			4
		],
		[
			-1,
			-13
		],
		[
			4,
			-7
		],
		[
			0,
			-10
		],
		[
			-6,
			-9
		],
		[
			8,
			-6
		],
		[
			-1,
			-20
		],
		[
			3,
			3
		],
		[
			-2,
			-23
		],
		[
			5,
			-6
		],
		[
			1,
			-27
		],
		[
			-4,
			-16
		],
		[
			-6,
			-12
		],
		[
			-1,
			-28
		],
		[
			-4,
			20
		],
		[
			1,
			8
		],
		[
			-6,
			19
		],
		[
			-1,
			14
		],
		[
			-5,
			-4
		],
		[
			0,
			-9
		],
		[
			-5,
			-8
		],
		[
			-3,
			-22
		],
		[
			6,
			-6
		],
		[
			3,
			-20
		],
		[
			-1,
			-12
		],
		[
			-7,
			-21
		],
		[
			-7,
			13
		],
		[
			3,
			8
		],
		[
			-3,
			9
		],
		[
			-3,
			-14
		],
		[
			-10,
			5
		],
		[
			-13,
			14
		],
		[
			-5,
			15
		],
		[
			0,
			20
		],
		[
			-2,
			0
		],
		[
			1,
			19
		],
		[
			6,
			8
		],
		[
			0,
			9
		],
		[
			-5,
			11
		],
		[
			-15,
			13
		],
		[
			-3,
			-12
		],
		[
			1,
			-15
		],
		[
			-4,
			9
		],
		[
			-4,
			-1
		],
		[
			0,
			12
		],
		[
			-4,
			-14
		],
		[
			-6,
			0
		],
		[
			1,
			16
		],
		[
			-9,
			-3
		],
		[
			-7,
			-26
		],
		[
			-2,
			-17
		],
		[
			-3,
			-3
		],
		[
			-5,
			9
		],
		[
			7,
			30
		],
		[
			-1,
			11
		],
		[
			7,
			16
		],
		[
			16,
			6
		],
		[
			3,
			21
		],
		[
			8,
			1
		],
		[
			2,
			11
		],
		[
			3,
			-6
		],
		[
			6,
			1
		],
		[
			4,
			-13
		],
		[
			0,
			-15
		],
		[
			11,
			6
		],
		[
			2,
			17
		],
		[
			3,
			4
		],
		[
			6,
			-8
		],
		[
			3,
			5
		],
		[
			0,
			23
		],
		[
			4,
			1
		],
		[
			5,
			-9
		],
		[
			5,
			10
		],
		[
			7,
			1
		],
		[
			0,
			17
		],
		[
			-4,
			21
		],
		[
			2,
			8
		],
		[
			5,
			-12
		]
	],
	[
		[
			8503,
			5750
		],
		[
			-4,
			-2
		],
		[
			2,
			14
		],
		[
			2,
			-12
		]
	],
	[
		[
			8453,
			5767
		],
		[
			7,
			-6
		],
		[
			-1,
			-12
		],
		[
			-7,
			-13
		],
		[
			-12,
			2
		],
		[
			-2,
			9
		],
		[
			7,
			10
		],
		[
			3,
			10
		],
		[
			5,
			0
		]
	],
	[
		[
			8479,
			5754
		],
		[
			-4,
			9
		],
		[
			3,
			3
		],
		[
			1,
			-12
		]
	],
	[
		[
			8490,
			5782
		],
		[
			1,
			-31
		],
		[
			-5,
			11
		],
		[
			0,
			15
		],
		[
			4,
			5
		]
	],
	[
		[
			8332,
			5791
		],
		[
			-6,
			-5
		],
		[
			2,
			10
		],
		[
			4,
			-5
		]
	],
	[
		[
			8408,
			5792
		],
		[
			-5,
			-9
		],
		[
			0,
			11
		],
		[
			4,
			7
		],
		[
			1,
			-9
		]
	],
	[
		[
			8423,
			5815
		],
		[
			8,
			-4
		],
		[
			1,
			-7
		],
		[
			-7,
			-25
		],
		[
			-1,
			-15
		],
		[
			-4,
			-13
		],
		[
			0,
			-19
		],
		[
			5,
			-11
		],
		[
			-2,
			-12
		],
		[
			-7,
			-5
		],
		[
			-3,
			15
		],
		[
			-9,
			8
		],
		[
			-5,
			15
		],
		[
			2,
			15
		],
		[
			11,
			6
		],
		[
			-1,
			23
		],
		[
			4,
			23
		],
		[
			8,
			6
		]
	],
	[
		[
			8444,
			5821
		],
		[
			1,
			-35
		],
		[
			-2,
			-9
		],
		[
			-9,
			-14
		],
		[
			0,
			-7
		],
		[
			-6,
			-27
		],
		[
			-3,
			-4
		],
		[
			2,
			34
		],
		[
			9,
			27
		],
		[
			5,
			33
		],
		[
			3,
			2
		]
	],
	[
		[
			8319,
			5836
		],
		[
			0,
			-30
		],
		[
			6,
			-17
		],
		[
			-10,
			-11
		],
		[
			-4,
			-14
		],
		[
			-13,
			-9
		],
		[
			1,
			-12
		],
		[
			-9,
			-26
		],
		[
			-10,
			-10
		],
		[
			-1,
			-9
		],
		[
			-8,
			-14
		],
		[
			-6,
			-2
		],
		[
			-1,
			-9
		],
		[
			-9,
			0
		],
		[
			19,
			43
		],
		[
			4,
			0
		],
		[
			9,
			23
		],
		[
			7,
			11
		],
		[
			6,
			20
		],
		[
			12,
			17
		],
		[
			4,
			32
		],
		[
			0,
			14
		],
		[
			3,
			3
		]
	],
	[
		[
			8456,
			5842
		],
		[
			7,
			-8
		],
		[
			4,
			7
		],
		[
			6,
			-10
		],
		[
			-1,
			-30
		],
		[
			5,
			-8
		],
		[
			2,
			-19
		],
		[
			-8,
			-4
		],
		[
			2,
			-10
		],
		[
			-8,
			7
		],
		[
			-1,
			14
		],
		[
			2,
			19
		],
		[
			-2,
			11
		],
		[
			-5,
			5
		],
		[
			-4,
			-4
		],
		[
			1,
			30
		]
	],
	[
		[
			8456,
			5856
		],
		[
			5,
			-12
		],
		[
			-5,
			0
		],
		[
			0,
			12
		]
	],
	[
		[
			8396,
			5860
		],
		[
			10,
			-14
		],
		[
			4,
			6
		],
		[
			3,
			-11
		],
		[
			7,
			8
		],
		[
			-1,
			-24
		],
		[
			-9,
			-10
		],
		[
			-1,
			-11
		],
		[
			-6,
			-6
		],
		[
			-9,
			-2
		],
		[
			-6,
			-13
		],
		[
			-2,
			20
		],
		[
			4,
			17
		],
		[
			0,
			39
		],
		[
			-6,
			1
		],
		[
			3,
			10
		],
		[
			9,
			-10
		]
	],
	[
		[
			8332,
			5870
		],
		[
			2,
			-13
		],
		[
			-3,
			-2
		],
		[
			-2,
			15
		],
		[
			3,
			0
		]
	],
	[
		[
			8331,
			5890
		],
		[
			11,
			-11
		],
		[
			0,
			-5
		],
		[
			-10,
			1
		],
		[
			-1,
			15
		]
	],
	[
		[
			8405,
			5890
		],
		[
			-5,
			12
		],
		[
			6,
			0
		],
		[
			-1,
			-12
		]
	],
	[
		[
			8469,
			5906
		],
		[
			10,
			-3
		],
		[
			2,
			-13
		],
		[
			5,
			-4
		],
		[
			-2,
			-6
		],
		[
			1,
			-33
		],
		[
			6,
			-24
		],
		[
			-14,
			0
		],
		[
			-2,
			10
		],
		[
			-4,
			0
		],
		[
			-4,
			10
		],
		[
			6,
			17
		],
		[
			-5,
			0
		],
		[
			-6,
			16
		],
		[
			-8,
			11
		],
		[
			-3,
			20
		],
		[
			7,
			-3
		],
		[
			11,
			2
		]
	],
	[
		[
			8426,
			5905
		],
		[
			6,
			-6
		],
		[
			5,
			-13
		],
		[
			4,
			-1
		],
		[
			4,
			-15
		],
		[
			0,
			-12
		],
		[
			-17,
			28
		],
		[
			-8,
			-17
		],
		[
			3,
			13
		],
		[
			-1,
			26
		],
		[
			4,
			-3
		]
	],
	[
		[
			8392,
			5910
		],
		[
			-3,
			-30
		],
		[
			-3,
			11
		],
		[
			2,
			17
		],
		[
			4,
			2
		]
	],
	[
		[
			8434,
			5912
		],
		[
			3,
			-18
		],
		[
			-5,
			16
		],
		[
			2,
			2
		]
	],
	[
		[
			8421,
			5926
		],
		[
			-7,
			8
		],
		[
			2,
			6
		],
		[
			5,
			-14
		]
	],
	[
		[
			8360,
			5962
		],
		[
			15,
			-22
		],
		[
			-1,
			-23
		],
		[
			-3,
			-26
		],
		[
			-4,
			-5
		],
		[
			-9,
			17
		],
		[
			-4,
			15
		],
		[
			0,
			14
		],
		[
			-7,
			12
		],
		[
			-4,
			18
		],
		[
			10,
			-4
		],
		[
			7,
			4
		]
	],
	[
		[
			8385,
			5963
		],
		[
			7,
			-9
		],
		[
			-4,
			-11
		],
		[
			-5,
			8
		],
		[
			2,
			12
		]
	],
	[
		[
			8450,
			5993
		],
		[
			5,
			-11
		],
		[
			0,
			-12
		],
		[
			-7,
			-8
		],
		[
			-4,
			7
		],
		[
			3,
			5
		],
		[
			0,
			20
		],
		[
			3,
			-1
		]
	],
	[
		[
			8387,
			6049
		],
		[
			2,
			-18
		],
		[
			-3,
			-5
		],
		[
			-3,
			23
		],
		[
			4,
			0
		]
	],
	[
		[
			8358,
			6252
		],
		[
			7,
			4
		],
		[
			10,
			-14
		],
		[
			13,
			-6
		],
		[
			4,
			13
		],
		[
			3,
			0
		],
		[
			2,
			-15
		],
		[
			-4,
			-8
		],
		[
			-1,
			-29
		],
		[
			3,
			-15
		],
		[
			4,
			0
		],
		[
			2,
			-28
		],
		[
			-8,
			-32
		],
		[
			1,
			-4
		],
		[
			-18,
			-18
		],
		[
			2,
			-10
		],
		[
			-7,
			-28
		],
		[
			9,
			-32
		],
		[
			-3,
			-1
		],
		[
			4,
			-30
		],
		[
			5,
			-10
		],
		[
			10,
			-2
		],
		[
			-3,
			13
		],
		[
			8,
			9
		],
		[
			8,
			-1
		],
		[
			9,
			-20
		],
		[
			-1,
			-12
		],
		[
			5,
			-3
		],
		[
			3,
			17
		],
		[
			17,
			-13
		],
		[
			1,
			-4
		],
		[
			-12,
			-1
		],
		[
			0,
			-8
		],
		[
			5,
			-8
		],
		[
			4,
			-16
		],
		[
			6,
			-8
		],
		[
			2,
			-12
		],
		[
			-2,
			-14
		],
		[
			-6,
			5
		],
		[
			-1,
			13
		],
		[
			-7,
			1
		],
		[
			-8,
			7
		],
		[
			0,
			14
		],
		[
			-3,
			11
		],
		[
			-7,
			6
		],
		[
			-5,
			16
		],
		[
			-9,
			7
		],
		[
			2,
			-18
		],
		[
			5,
			-15
		],
		[
			-3,
			-12
		],
		[
			-7,
			25
		],
		[
			-17,
			19
		],
		[
			-8,
			-8
		],
		[
			1,
			-6
		],
		[
			-11,
			-4
		],
		[
			-4,
			16
		],
		[
			-6,
			2
		],
		[
			-2,
			-7
		],
		[
			-1,
			24
		],
		[
			11,
			17
		],
		[
			-4,
			14
		],
		[
			-9,
			-4
		],
		[
			2,
			-13
		],
		[
			-4,
			-3
		],
		[
			-4,
			23
		],
		[
			-7,
			4
		],
		[
			-1,
			23
		],
		[
			-4,
			8
		],
		[
			1,
			26
		],
		[
			-4,
			3
		],
		[
			0,
			23
		],
		[
			9,
			-15
		],
		[
			9,
			5
		],
		[
			-3,
			17
		],
		[
			0,
			21
		],
		[
			4,
			10
		],
		[
			-1,
			11
		],
		[
			0,
			43
		],
		[
			5,
			23
		],
		[
			-1,
			10
		],
		[
			10,
			4
		]
	],
	[
		[
			8740,
			5620
		],
		[
			-2,
			-13
		],
		[
			-3,
			3
		],
		[
			5,
			10
		]
	],
	[
		[
			9256,
			4529
		],
		[
			13,
			-10
		],
		[
			0,
			-5
		],
		[
			-10,
			3
		],
		[
			-3,
			12
		]
	],
	[
		[
			9195,
			4611
		],
		[
			7,
			-2
		],
		[
			-2,
			-10
		],
		[
			-8,
			2
		],
		[
			-5,
			23
		],
		[
			8,
			-13
		]
	],
	[
		[
			9184,
			4640
		],
		[
			3,
			2
		],
		[
			5,
			-15
		],
		[
			-14,
			1
		],
		[
			0,
			16
		],
		[
			6,
			-4
		]
	],
	[
		[
			9176,
			4644
		],
		[
			-1,
			-9
		],
		[
			-5,
			5
		],
		[
			-1,
			9
		],
		[
			6,
			1
		],
		[
			1,
			-6
		]
	],
	[
		[
			9234,
			4667
		],
		[
			10,
			-3
		],
		[
			5,
			-11
		],
		[
			-10,
			2
		],
		[
			-5,
			12
		]
	],
	[
		[
			8989,
			4680
		],
		[
			-11,
			16
		],
		[
			11,
			-11
		],
		[
			0,
			-5
		]
	],
	[
		[
			8981,
			4701
		],
		[
			6,
			0
		],
		[
			1,
			-7
		],
		[
			-7,
			7
		]
	],
	[
		[
			9105,
			4867
		],
		[
			7,
			-7
		],
		[
			-1,
			-11
		],
		[
			-7,
			10
		],
		[
			1,
			8
		]
	],
	[
		[
			9299,
			4867
		],
		[
			8,
			-4
		],
		[
			3,
			-17
		],
		[
			6,
			-8
		],
		[
			1,
			-9
		],
		[
			5,
			-4
		],
		[
			8,
			-16
		],
		[
			2,
			-14
		],
		[
			-7,
			-8
		],
		[
			-5,
			1
		],
		[
			-10,
			17
		],
		[
			1,
			14
		],
		[
			-14,
			25
		],
		[
			0,
			19
		],
		[
			2,
			4
		]
	],
	[
		[
			9089,
			4870
		],
		[
			-4,
			0
		],
		[
			-2,
			11
		],
		[
			3,
			3
		],
		[
			3,
			-14
		]
	],
	[
		[
			9296,
			4889
		],
		[
			-2,
			-21
		],
		[
			-1,
			25
		],
		[
			3,
			-4
		]
	],
	[
		[
			9228,
			4941
		],
		[
			-2,
			-6
		],
		[
			7,
			-2
		],
		[
			0,
			-17
		],
		[
			-5,
			-20
		],
		[
			-8,
			-1
		],
		[
			5,
			-25
		],
		[
			-8,
			-9
		],
		[
			-11,
			3
		],
		[
			2,
			-8
		],
		[
			-14,
			-21
		],
		[
			-15,
			-13
		],
		[
			-24,
			-2
		],
		[
			-3,
			10
		],
		[
			-6,
			4
		],
		[
			-6,
			-5
		],
		[
			-2,
			7
		],
		[
			-10,
			12
		],
		[
			-9,
			7
		],
		[
			4,
			14
		],
		[
			11,
			-5
		],
		[
			3,
			4
		],
		[
			7,
			-8
		],
		[
			20,
			6
		],
		[
			2,
			24
		],
		[
			4,
			-27
		],
		[
			8,
			6
		],
		[
			8,
			-5
		],
		[
			8,
			6
		],
		[
			0,
			10
		],
		[
			10,
			20
		],
		[
			7,
			-3
		],
		[
			2,
			5
		],
		[
			-2,
			23
		],
		[
			-3,
			16
		],
		[
			7,
			0
		],
		[
			5,
			-8
		],
		[
			2,
			8
		],
		[
			6,
			0
		]
	],
	[
		[
			8915,
			5033
		],
		[
			7,
			-1
		],
		[
			25,
			-25
		],
		[
			25,
			-17
		],
		[
			13,
			-4
		],
		[
			9,
			-11
		],
		[
			5,
			-11
		],
		[
			15,
			-2
		],
		[
			0,
			-8
		],
		[
			9,
			-6
		],
		[
			5,
			-15
		],
		[
			8,
			-3
		],
		[
			13,
			-25
		],
		[
			-1,
			-38
		],
		[
			14,
			-4
		],
		[
			18,
			-16
		],
		[
			5,
			-7
		],
		[
			12,
			-3
		],
		[
			9,
			-22
		],
		[
			0,
			-18
		],
		[
			-25,
			-3
		],
		[
			0,
			-12
		],
		[
			5,
			-13
		],
		[
			1,
			-15
		],
		[
			7,
			-6
		],
		[
			8,
			-21
		],
		[
			12,
			-8
		],
		[
			3,
			-30
		],
		[
			7,
			-9
		],
		[
			2,
			-19
		],
		[
			21,
			3
		],
		[
			-4,
			-19
		],
		[
			1,
			-9
		],
		[
			7,
			-6
		],
		[
			15,
			-2
		],
		[
			1,
			-5
		],
		[
			-9,
			-5
		],
		[
			8,
			-16
		],
		[
			10,
			-7
		],
		[
			12,
			-3
		],
		[
			-4,
			-5
		],
		[
			-9,
			-1
		],
		[
			10,
			-10
		],
		[
			-7,
			-9
		],
		[
			-13,
			6
		],
		[
			2,
			7
		],
		[
			-9,
			8
		],
		[
			-7,
			-1
		],
		[
			-8,
			6
		],
		[
			-12,
			0
		],
		[
			1,
			5
		],
		[
			-11,
			-3
		],
		[
			-2,
			5
		],
		[
			-17,
			1
		],
		[
			-11,
			33
		],
		[
			-5,
			2
		],
		[
			-7,
			22
		],
		[
			-8,
			6
		],
		[
			-4,
			23
		],
		[
			-10,
			30
		],
		[
			-13,
			9
		],
		[
			-5,
			-1
		],
		[
			-7,
			8
		],
		[
			-9,
			2
		],
		[
			-6,
			12
		],
		[
			-6,
			-1
		],
		[
			2,
			-13
		],
		[
			-7,
			10
		],
		[
			1,
			-8
		],
		[
			-13,
			8
		],
		[
			4,
			-19
		],
		[
			-11,
			-4
		],
		[
			1,
			-12
		],
		[
			-18,
			-5
		],
		[
			-6,
			1
		],
		[
			11,
			-10
		],
		[
			7,
			-15
		],
		[
			1,
			-11
		],
		[
			-22,
			-23
		],
		[
			-11,
			10
		],
		[
			-20,
			-3
		],
		[
			-6,
			4
		],
		[
			-3,
			-5
		],
		[
			-6,
			7
		]
	],
	[
		[
			9195,
			5027
		],
		[
			10,
			-11
		],
		[
			11,
			-17
		],
		[
			7,
			-3
		],
		[
			14,
			-33
		],
		[
			11,
			-10
		],
		[
			5,
			-22
		],
		[
			-2,
			-14
		],
		[
			-5,
			-10
		],
		[
			-6,
			14
		],
		[
			1,
			21
		],
		[
			-5,
			19
		],
		[
			-10,
			21
		],
		[
			-6,
			2
		],
		[
			-9,
			16
		],
		[
			-5,
			4
		],
		[
			-9,
			15
		],
		[
			-10,
			7
		],
		[
			8,
			1
		]
	],
	[
		[
			9172,
			5046
		],
		[
			6,
			-5
		],
		[
			0,
			-12
		],
		[
			-8,
			0
		],
		[
			-3,
			9
		],
		[
			5,
			8
		]
	],
	[
		[
			9079,
			5070
		],
		[
			12,
			-5
		],
		[
			-3,
			-8
		],
		[
			-17,
			0
		],
		[
			0,
			11
		],
		[
			8,
			2
		]
	],
	[
		[
			9154,
			5105
		],
		[
			6,
			-13
		],
		[
			-6,
			5
		],
		[
			0,
			8
		]
	],
	[
		[
			5544,
			8319
		],
		[
			0,
			-1
		]
	],
	[
		[
			5544,
			8318
		],
		[
			4,
			-1
		]
	],
	[
		[
			5548,
			8317
		],
		[
			63,
			-4
		],
		[
			21,
			0
		]
	],
	[
		[
			5655,
			8150
		],
		[
			1,
			-13
		],
		[
			14,
			-27
		],
		[
			-5,
			0
		],
		[
			4,
			-18
		],
		[
			-10,
			-8
		],
		[
			-18,
			-24
		],
		[
			-13,
			-25
		],
		[
			4,
			-28
		],
		[
			-6,
			2
		]
	],
	[
		[
			5626,
			8009
		],
		[
			-15,
			8
		],
		[
			-11,
			12
		],
		[
			-16,
			-2
		],
		[
			-4,
			-6
		],
		[
			-6,
			6
		],
		[
			-10,
			0
		],
		[
			-14,
			-12
		],
		[
			-1,
			12
		],
		[
			-10,
			11
		],
		[
			-7,
			-11
		],
		[
			-9,
			7
		]
	],
	[
		[
			5396,
			8275
		],
		[
			8,
			-3
		],
		[
			0,
			13
		],
		[
			-10,
			0
		]
	],
	[
		[
			5394,
			8289
		],
		[
			54,
			20
		],
		[
			12,
			16
		],
		[
			10,
			2
		],
		[
			11,
			9
		],
		[
			27,
			5
		],
		[
			7,
			-23
		],
		[
			12,
			-6
		],
		[
			17,
			7
		]
	],
	[
		[
			3138,
			6248
		],
		[
			29,
			-2
		],
		[
			9,
			-6
		],
		[
			2,
			-7
		],
		[
			-7,
			-13
		],
		[
			-9,
			-5
		],
		[
			-17,
			3
		],
		[
			-12,
			-1
		],
		[
			1,
			15
		],
		[
			-3,
			7
		],
		[
			3,
			10
		],
		[
			4,
			-1
		]
	],
	[
		[
			8625,
			7631
		],
		[
			5,
			-14
		]
	],
	[
		[
			8630,
			7617
		],
		[
			-7,
			4
		],
		[
			-11,
			-15
		],
		[
			-11,
			-27
		],
		[
			4,
			-15
		],
		[
			-3,
			-11
		],
		[
			1,
			-19
		],
		[
			-11,
			-5
		],
		[
			-7,
			-16
		],
		[
			-13,
			-11
		],
		[
			-8,
			-14
		],
		[
			-9,
			1
		],
		[
			-4,
			-9
		],
		[
			-10,
			-8
		],
		[
			2,
			-9
		],
		[
			-6,
			-13
		],
		[
			2,
			-13
		],
		[
			9,
			-2
		],
		[
			17,
			-29
		]
	],
	[
		[
			8518,
			7361
		],
		[
			-8,
			4
		],
		[
			-8,
			-9
		],
		[
			-8,
			15
		],
		[
			-7,
			1
		],
		[
			2,
			-14
		],
		[
			-10,
			9
		],
		[
			-7,
			-2
		],
		[
			3,
			9
		],
		[
			-13,
			4
		],
		[
			9,
			5
		],
		[
			-3,
			9
		],
		[
			10,
			20
		],
		[
			-3,
			4
		],
		[
			4,
			21
		],
		[
			5,
			14
		],
		[
			-4,
			8
		],
		[
			-16,
			7
		],
		[
			-11,
			14
		],
		[
			1,
			12
		]
	],
	[
		[
			4525,
			7072
		],
		[
			11,
			-2
		],
		[
			-3,
			-7
		],
		[
			-10,
			3
		],
		[
			2,
			6
		]
	],
	[
		[
			4286,
			7362
		],
		[
			15,
			1
		],
		[
			0,
			-6
		],
		[
			-10,
			-3
		],
		[
			-5,
			8
		]
	],
	[
		[
			4220,
			7396
		],
		[
			-11,
			-2
		],
		[
			-2,
			9
		],
		[
			13,
			-7
		]
	],
	[
		[
			4248,
			7409
		],
		[
			-8,
			0
		],
		[
			0,
			8
		],
		[
			6,
			0
		],
		[
			2,
			-8
		]
	],
	[
		[
			4794,
			7325
		],
		[
			-12,
			-12
		],
		[
			-21,
			8
		],
		[
			-10,
			-7
		],
		[
			4,
			24
		],
		[
			1,
			44
		],
		[
			-4,
			18
		],
		[
			-8,
			-2
		],
		[
			-1,
			11
		],
		[
			8,
			6
		],
		[
			-2,
			7
		],
		[
			-4,
			-11
		],
		[
			-9,
			1
		],
		[
			4,
			38
		],
		[
			6,
			7
		],
		[
			7,
			36
		],
		[
			-1,
			3
		],
		[
			7,
			47
		],
		[
			-6,
			50
		],
		[
			3,
			7
		]
	],
	[
		[
			3492,
			3797
		],
		[
			-1,
			-17
		],
		[
			-4,
			-23
		],
		[
			-1,
			-22
		],
		[
			-3,
			-17
		]
	],
	[
		[
			5949,
			6986
		],
		[
			8,
			16
		]
	],
	[
		[
			5987,
			7012
		],
		[
			-4,
			-16
		]
	],
	[
		[
			853,
			4163
		],
		[
			-9,
			-2
		],
		[
			-1,
			11
		],
		[
			5,
			3
		],
		[
			5,
			-12
		]
	],
	[
		[
			6422,
			6601
		],
		[
			-8,
			-2
		],
		[
			-3,
			9
		]
	],
	[
		[
			6411,
			6608
		],
		[
			1,
			10
		],
		[
			-3,
			15
		],
		[
			1,
			20
		],
		[
			3,
			6
		],
		[
			4,
			24
		],
		[
			6,
			6
		],
		[
			4,
			-12
		],
		[
			5,
			-2
		],
		[
			1,
			-9
		],
		[
			-4,
			-14
		],
		[
			4,
			-14
		],
		[
			0,
			-15
		],
		[
			-4,
			-17
		],
		[
			-7,
			-5
		]
	],
	[
		[
			5783,
			7801
		],
		[
			3,
			-8
		],
		[
			11,
			-6
		],
		[
			14,
			12
		],
		[
			10,
			-3
		],
		[
			2,
			-9
		]
	],
	[
		[
			5823,
			7787
		],
		[
			-1,
			-22
		],
		[
			-14,
			-4
		],
		[
			-3,
			13
		],
		[
			-4,
			-3
		],
		[
			-6,
			-35
		],
		[
			1,
			-21
		],
		[
			-3,
			-13
		]
	],
	[
		[
			5630,
			7730
		],
		[
			-6,
			15
		],
		[
			8,
			5
		],
		[
			-10,
			9
		],
		[
			-6,
			-14
		],
		[
			-5,
			9
		],
		[
			-10,
			2
		],
		[
			-9,
			9
		],
		[
			5,
			16
		],
		[
			-15,
			12
		],
		[
			-6,
			9
		],
		[
			1,
			16
		],
		[
			-13,
			13
		],
		[
			-2,
			7
		]
	],
	[
		[
			5635,
			7944
		],
		[
			10,
			8
		],
		[
			7,
			-5
		],
		[
			20,
			-6
		],
		[
			10,
			3
		],
		[
			9,
			-14
		],
		[
			10,
			11
		],
		[
			26,
			6
		],
		[
			3,
			12
		],
		[
			9,
			3
		]
	],
	[
		[
			9064,
			7741
		],
		[
			7,
			1
		],
		[
			-12,
			-10
		],
		[
			-16,
			-24
		],
		[
			15,
			37
		],
		[
			6,
			-4
		]
	],
	[
		[
			9133,
			7793
		],
		[
			-15,
			-6
		],
		[
			-10,
			-15
		],
		[
			-5,
			0
		],
		[
			-7,
			-11
		],
		[
			-18,
			-19
		],
		[
			10,
			17
		],
		[
			-3,
			3
		],
		[
			25,
			28
		],
		[
			9,
			0
		],
		[
			12,
			15
		],
		[
			2,
			-12
		]
	],
	[
		[
			9182,
			7845
		],
		[
			-21,
			-27
		],
		[
			-10,
			-9
		],
		[
			15,
			27
		],
		[
			16,
			9
		]
	],
	[
		[
			9227,
			7898
		],
		[
			-1,
			-8
		],
		[
			-10,
			-14
		],
		[
			11,
			22
		]
	],
	[
		[
			9301,
			8041
		],
		[
			-1,
			-17
		],
		[
			-6,
			3
		],
		[
			7,
			14
		]
	],
	[
		[
			9336,
			8091
		],
		[
			-7,
			-15
		],
		[
			-9,
			-4
		],
		[
			-5,
			-11
		],
		[
			-5,
			16
		],
		[
			15,
			9
		],
		[
			4,
			15
		],
		[
			7,
			3
		],
		[
			0,
			-13
		]
	],
	[
		[
			9344,
			8100
		],
		[
			-7,
			6
		],
		[
			7,
			7
		],
		[
			0,
			-13
		]
	],
	[
		[
			8967,
			8309
		],
		[
			5,
			-11
		],
		[
			-3,
			-7
		],
		[
			8,
			-35
		],
		[
			4,
			-38
		],
		[
			-6,
			-46
		],
		[
			5,
			-11
		],
		[
			-2,
			-12
		],
		[
			6,
			0
		],
		[
			9,
			-69
		],
		[
			10,
			-33
		],
		[
			0,
			-7
		],
		[
			8,
			-36
		],
		[
			-9,
			14
		],
		[
			-23,
			9
		],
		[
			3,
			-6
		],
		[
			-10,
			-7
		],
		[
			-2,
			-16
		],
		[
			-12,
			-57
		],
		[
			6,
			-26
		],
		[
			8,
			-11
		],
		[
			0,
			-11
		],
		[
			5,
			-21
		],
		[
			9,
			4
		],
		[
			1,
			-28
		],
		[
			-3,
			-6
		],
		[
			-2,
			22
		],
		[
			-17,
			3
		],
		[
			-2,
			6
		],
		[
			-7,
			-5
		],
		[
			-6,
			-32
		],
		[
			-5,
			-9
		],
		[
			-3,
			6
		],
		[
			-4,
			29
		],
		[
			7,
			30
		],
		[
			-3,
			31
		],
		[
			7,
			21
		],
		[
			-3,
			26
		],
		[
			-5,
			12
		],
		[
			7,
			55
		],
		[
			0,
			46
		],
		[
			-3,
			10
		],
		[
			1,
			17
		],
		[
			5,
			19
		],
		[
			-5,
			18
		],
		[
			-11,
			14
		],
		[
			-1,
			38
		],
		[
			4,
			5
		],
		[
			3,
			26
		],
		[
			-4,
			26
		],
		[
			13,
			9
		],
		[
			1,
			-9
		],
		[
			10,
			9
		],
		[
			-4,
			8
		],
		[
			9,
			2
		],
		[
			-2,
			12
		],
		[
			-10,
			21
		],
		[
			5,
			-2
		],
		[
			5,
			11
		],
		[
			3,
			-8
		]
	],
	[
		[
			9669,
			8321
		],
		[
			-19,
			19
		],
		[
			4,
			0
		],
		[
			15,
			-19
		]
	],
	[
		[
			8810,
			8355
		],
		[
			-14,
			-11
		],
		[
			8,
			11
		],
		[
			6,
			0
		]
	],
	[
		[
			8827,
			8358
		],
		[
			9,
			-8
		],
		[
			-12,
			-22
		],
		[
			-6,
			15
		],
		[
			-6,
			1
		],
		[
			8,
			17
		],
		[
			7,
			-3
		]
	],
	[
		[
			5548,
			8317
		],
		[
			18,
			15
		],
		[
			-10,
			2
		],
		[
			-12,
			-16
		]
	],
	[
		[
			5544,
			8319
		],
		[
			10,
			17
		],
		[
			0,
			12
		],
		[
			12,
			-1
		],
		[
			15,
			19
		]
	],
	[
		[
			5582,
			8366
		],
		[
			-12,
			-19
		],
		[
			12,
			-3
		],
		[
			7,
			5
		],
		[
			1,
			15
		]
	],
	[
		[
			9609,
			8371
		],
		[
			18,
			-27
		],
		[
			1,
			-11
		],
		[
			-13,
			14
		],
		[
			-4,
			13
		],
		[
			-7,
			6
		],
		[
			5,
			5
		]
	],
	[
		[
			9571,
			8591
		],
		[
			3,
			-16
		],
		[
			-8,
			-2
		],
		[
			-23,
			-18
		],
		[
			9,
			26
		],
		[
			19,
			10
		]
	],
	[
		[
			5777,
			8600
		],
		[
			3,
			-1
		]
	],
	[
		[
			6924,
			9029
		],
		[
			21,
			-5
		],
		[
			-5,
			-13
		],
		[
			-16,
			18
		]
	],
	[
		[
			6396,
			9167
		],
		[
			-24,
			-22
		],
		[
			-23,
			-4
		],
		[
			-10,
			9
		],
		[
			1,
			19
		],
		[
			15,
			16
		],
		[
			13,
			1
		],
		[
			28,
			-19
		]
	],
	[
		[
			9482,
			9188
		],
		[
			-3,
			-8
		],
		[
			6,
			-25
		],
		[
			-10,
			6
		],
		[
			-2,
			19
		],
		[
			9,
			8
		]
	],
	[
		[
			9705,
			9201
		],
		[
			-6,
			-12
		],
		[
			-29,
			7
		],
		[
			-11,
			8
		],
		[
			14,
			11
		],
		[
			32,
			-8
		],
		[
			0,
			-6
		]
	],
	[
		[
			6648,
			9234
		],
		[
			5,
			-8
		],
		[
			26,
			-17
		],
		[
			0,
			-11
		],
		[
			-25,
			-1
		],
		[
			-5,
			11
		],
		[
			-10,
			-2
		],
		[
			-13,
			12
		],
		[
			-1,
			15
		],
		[
			13,
			8
		],
		[
			10,
			-7
		]
	],
	[
		[
			6464,
			9295
		],
		[
			14,
			-14
		],
		[
			-6,
			-11
		],
		[
			-7,
			12
		],
		[
			-15,
			9
		],
		[
			14,
			4
		]
	],
	[
		[
			0,
			9271
		],
		[
			9990,
			-7
		],
		[
			-25,
			-4
		],
		[
			-4,
			14
		],
		[
			8,
			11
		],
		[
			30,
			17
		],
		[
			-9999,
			-31
		]
	],
	[
		[
			8829,
			9305
		],
		[
			-3,
			-9
		],
		[
			-20,
			5
		],
		[
			23,
			4
		]
	],
	[
		[
			0,
			9302
		],
		[
			26,
			4
		],
		[
			18,
			-3
		],
		[
			27,
			-17
		],
		[
			-12,
			-12
		],
		[
			-42,
			-8
		],
		[
			-17,
			5
		],
		[
			0,
			31
		]
	],
	[
		[
			7160,
			9347
		],
		[
			-27,
			1
		],
		[
			22,
			18
		],
		[
			21,
			-9
		],
		[
			-16,
			-10
		]
	],
	[
		[
			8580,
			9366
		],
		[
			-7,
			-7
		],
		[
			-15,
			7
		],
		[
			22,
			0
		]
	],
	[
		[
			8592,
			9374
		],
		[
			-28,
			2
		],
		[
			18,
			7
		],
		[
			10,
			-9
		]
	],
	[
		[
			7209,
			9382
		],
		[
			0,
			-11
		],
		[
			-19,
			1
		],
		[
			-8,
			7
		],
		[
			16,
			13
		],
		[
			11,
			-10
		]
	],
	[
		[
			7078,
			9392
		],
		[
			-5,
			-14
		],
		[
			-16,
			10
		],
		[
			21,
			4
		]
	],
	[
		[
			6536,
			9406
		],
		[
			31,
			-6
		],
		[
			-8,
			-26
		],
		[
			-15,
			-9
		],
		[
			-7,
			-32
		],
		[
			5,
			-18
		],
		[
			16,
			-29
		],
		[
			23,
			-20
		],
		[
			19,
			-10
		],
		[
			-49,
			-5
		],
		[
			-16,
			3
		],
		[
			-2,
			-8
		],
		[
			-14,
			12
		],
		[
			-18,
			-1
		],
		[
			-11,
			7
		],
		[
			-11,
			34
		],
		[
			-11,
			-4
		],
		[
			-10,
			10
		],
		[
			-19,
			-6
		],
		[
			-8,
			6
		],
		[
			-3,
			22
		],
		[
			11,
			12
		],
		[
			15,
			-5
		],
		[
			9,
			22
		],
		[
			11,
			9
		],
		[
			-20,
			7
		],
		[
			7,
			8
		],
		[
			21,
			1
		],
		[
			-7,
			12
		],
		[
			17,
			12
		],
		[
			13,
			-2
		],
		[
			20,
			9
		],
		[
			11,
			-5
		]
	],
	[
		[
			6970,
			9416
		],
		[
			1,
			-13
		],
		[
			11,
			-6
		],
		[
			-42,
			-7
		],
		[
			3,
			20
		],
		[
			27,
			6
		]
	],
	[
		[
			8951,
			9436
		],
		[
			32,
			-18
		],
		[
			0,
			-21
		],
		[
			-33,
			3
		],
		[
			-40,
			10
		],
		[
			-27,
			-4
		],
		[
			2,
			8
		],
		[
			17,
			1
		],
		[
			17,
			22
		],
		[
			32,
			-1
		]
	],
	[
		[
			8903,
			9439
		],
		[
			-10,
			16
		],
		[
			20,
			5
		],
		[
			2,
			-17
		],
		[
			-12,
			-4
		]
	],
	[
		[
			8148,
			9464
		],
		[
			-16,
			-15
		],
		[
			-37,
			13
		],
		[
			18,
			14
		],
		[
			34,
			-4
		],
		[
			1,
			-8
		]
	],
	[
		[
			7281,
			9528
		],
		[
			-4,
			-16
		],
		[
			-14,
			11
		],
		[
			18,
			5
		]
	],
	[
		[
			9075,
			9530
		],
		[
			47,
			-4
		],
		[
			5,
			-12
		],
		[
			15,
			3
		],
		[
			49,
			-6
		],
		[
			-8,
			-15
		],
		[
			-25,
			-8
		],
		[
			-43,
			2
		],
		[
			-58,
			24
		],
		[
			7,
			20
		],
		[
			11,
			-4
		]
	],
	[
		[
			8773,
			9524
		],
		[
			-11,
			-1
		],
		[
			6,
			29
		],
		[
			14,
			-16
		],
		[
			-9,
			-12
		]
	],
	[
		[
			8863,
			9565
		],
		[
			40,
			-20
		],
		[
			10,
			14
		],
		[
			19,
			1
		],
		[
			-8,
			10
		],
		[
			35,
			-19
		],
		[
			29,
			1
		],
		[
			50,
			-20
		],
		[
			-19,
			-5
		],
		[
			5,
			-8
		],
		[
			-16,
			-15
		],
		[
			-40,
			6
		],
		[
			-11,
			13
		],
		[
			15,
			13
		],
		[
			-3,
			8
		],
		[
			-25,
			-4
		],
		[
			5,
			-18
		],
		[
			12,
			-15
		],
		[
			30,
			-9
		],
		[
			-38,
			-6
		],
		[
			-14,
			10
		],
		[
			-49,
			-10
		],
		[
			-6,
			8
		],
		[
			-17,
			-18
		],
		[
			-33,
			8
		],
		[
			-25,
			20
		],
		[
			-2,
			34
		],
		[
			18,
			1
		],
		[
			-9,
			9
		],
		[
			42,
			18
		],
		[
			5,
			-7
		]
	],
	[
		[
			7674,
			9577
		],
		[
			3,
			-9
		],
		[
			-30,
			3
		],
		[
			27,
			6
		]
	],
	[
		[
			8125,
			9595
		],
		[
			2,
			-10
		],
		[
			-18,
			11
		],
		[
			16,
			-1
		]
	],
	[
		[
			9145,
			9596
		],
		[
			-23,
			0
		],
		[
			29,
			8
		],
		[
			-6,
			-8
		]
	],
	[
		[
			6893,
			9615
		],
		[
			24,
			-15
		],
		[
			-21,
			-24
		],
		[
			-51,
			-17
		],
		[
			-116,
			-32
		],
		[
			-47,
			-18
		],
		[
			0,
			-15
		],
		[
			-22,
			-8
		],
		[
			-2,
			-8
		],
		[
			-17,
			8
		],
		[
			1,
			-16
		],
		[
			-26,
			8
		],
		[
			15,
			-17
		],
		[
			-16,
			-8
		],
		[
			-16,
			-31
		],
		[
			-24,
			-20
		],
		[
			-36,
			4
		],
		[
			-11,
			6
		],
		[
			-20,
			-6
		],
		[
			-4,
			9
		],
		[
			24,
			12
		],
		[
			-30,
			-4
		],
		[
			-2,
			8
		],
		[
			26,
			12
		],
		[
			-3,
			6
		],
		[
			26,
			13
		],
		[
			-3,
			20
		],
		[
			24,
			4
		],
		[
			-14,
			7
		],
		[
			18,
			4
		],
		[
			-18,
			4
		],
		[
			-3,
			9
		],
		[
			21,
			-4
		],
		[
			14,
			19
		],
		[
			19,
			-4
		],
		[
			-5,
			11
		],
		[
			38,
			20
		],
		[
			23,
			3
		],
		[
			14,
			11
		],
		[
			23,
			-2
		],
		[
			0,
			12
		],
		[
			52,
			-5
		],
		[
			61,
			15
		],
		[
			49,
			28
		],
		[
			35,
			1
		]
	],
	[
		[
			7679,
			9622
		],
		[
			-33,
			-4
		],
		[
			35,
			11
		],
		[
			-2,
			-7
		]
	],
	[
		[
			8666,
			7787
		],
		[
			3,
			-13
		],
		[
			-2,
			-13
		],
		[
			9,
			-14
		],
		[
			7,
			9
		],
		[
			6,
			22
		]
	],
	[
		[
			6367,
			7850
		],
		[
			-12,
			-15
		],
		[
			-2,
			-14
		],
		[
			-4,
			9
		],
		[
			-10,
			-14
		],
		[
			-17,
			0
		],
		[
			-7,
			-31
		],
		[
			-8,
			-23
		],
		[
			-10,
			-8
		],
		[
			0,
			-13
		],
		[
			14,
			-11
		],
		[
			8,
			-28
		],
		[
			-2,
			-14
		],
		[
			6,
			19
		],
		[
			-5,
			-26
		],
		[
			0,
			-21
		],
		[
			7,
			-10
		],
		[
			4,
			-16
		],
		[
			12,
			-26
		],
		[
			2,
			-11
		],
		[
			6,
			-4
		]
	],
	[
		[
			6110,
			7681
		],
		[
			-15,
			21
		],
		[
			-1,
			6
		],
		[
			-18,
			24
		],
		[
			-15,
			7
		],
		[
			-11,
			15
		],
		[
			-9,
			1
		],
		[
			-8,
			19
		],
		[
			-17,
			11
		],
		[
			8,
			3
		],
		[
			-1,
			11
		],
		[
			8,
			-6
		],
		[
			11,
			2
		],
		[
			5,
			-4
		],
		[
			0,
			16
		],
		[
			-4,
			2
		],
		[
			8,
			10
		],
		[
			2,
			14
		],
		[
			4,
			-6
		],
		[
			2,
			11
		],
		[
			11,
			0
		],
		[
			-13,
			17
		],
		[
			-5,
			0
		],
		[
			-4,
			15
		],
		[
			6,
			-3
		],
		[
			13,
			14
		],
		[
			24,
			9
		],
		[
			0,
			13
		],
		[
			-30,
			-8
		]
	],
	[
		[
			6061,
			7895
		],
		[
			-1,
			12
		],
		[
			5,
			17
		],
		[
			11,
			5
		],
		[
			3,
			10
		],
		[
			25,
			-3
		],
		[
			0,
			13
		],
		[
			6,
			12
		],
		[
			-8,
			29
		],
		[
			10,
			5
		],
		[
			-8,
			3
		],
		[
			11,
			26
		],
		[
			-1,
			14
		],
		[
			-10,
			-2
		],
		[
			-5,
			10
		],
		[
			-7,
			0
		],
		[
			-5,
			9
		],
		[
			-6,
			-5
		],
		[
			-8,
			10
		],
		[
			-18,
			-4
		],
		[
			-8,
			11
		],
		[
			-8,
			20
		],
		[
			-16,
			-6
		],
		[
			-6,
			-7
		],
		[
			-10,
			4
		],
		[
			-5,
			8
		],
		[
			-13,
			-5
		],
		[
			-6,
			10
		],
		[
			2,
			10
		],
		[
			-4,
			19
		],
		[
			-7,
			12
		],
		[
			-11,
			-3
		],
		[
			-13,
			12
		],
		[
			-3,
			17
		],
		[
			8,
			9
		],
		[
			-8,
			8
		],
		[
			-1,
			10
		],
		[
			-11,
			13
		],
		[
			-13,
			1
		],
		[
			-9,
			-8
		],
		[
			-15,
			5
		],
		[
			-1,
			-11
		],
		[
			-12,
			-7
		],
		[
			-3,
			5
		]
	],
	[
		[
			5767,
			8523
		],
		[
			9,
			-9
		],
		[
			6,
			9
		],
		[
			-6,
			10
		],
		[
			-10,
			-2
		],
		[
			7,
			19
		],
		[
			-4,
			30
		]
	],
	[
		[
			5773,
			8590
		],
		[
			9,
			11
		]
	],
	[
		[
			5778,
			8608
		],
		[
			-1,
			16
		],
		[
			11,
			-5
		],
		[
			3,
			11
		],
		[
			10,
			-4
		],
		[
			7,
			12
		],
		[
			29,
			-8
		],
		[
			2,
			8
		],
		[
			-9,
			9
		],
		[
			-25,
			2
		],
		[
			-10,
			28
		],
		[
			-16,
			-9
		],
		[
			-7,
			2
		]
	],
	[
		[
			5856,
			9203
		],
		[
			15,
			-9
		],
		[
			19,
			18
		],
		[
			16,
			-11
		],
		[
			14,
			-3
		],
		[
			-7,
			-8
		],
		[
			-20,
			4
		],
		[
			6,
			-7
		],
		[
			19,
			-3
		],
		[
			-6,
			-7
		],
		[
			19,
			4
		],
		[
			5,
			-5
		],
		[
			35,
			-7
		],
		[
			23,
			-1
		],
		[
			52,
			-28
		],
		[
			21,
			-21
		],
		[
			14,
			-2
		],
		[
			16,
			-14
		],
		[
			13,
			-3
		],
		[
			30,
			-21
		],
		[
			1,
			-23
		],
		[
			7,
			-2
		],
		[
			-5,
			-24
		],
		[
			-21,
			-24
		],
		[
			-30,
			-15
		],
		[
			-22,
			-4
		],
		[
			-28,
			5
		],
		[
			-22,
			9
		],
		[
			-27,
			3
		],
		[
			-27,
			15
		],
		[
			-36,
			7
		],
		[
			-24,
			23
		],
		[
			-11,
			0
		],
		[
			8,
			-15
		],
		[
			18,
			-11
		],
		[
			3,
			-9
		],
		[
			13,
			-6
		],
		[
			-4,
			-7
		],
		[
			14,
			-3
		],
		[
			21,
			-20
		],
		[
			-4,
			-21
		],
		[
			-6,
			-7
		],
		[
			13,
			-46
		],
		[
			-6,
			-4
		],
		[
			16,
			-15
		],
		[
			15,
			2
		],
		[
			12,
			-18
		],
		[
			31,
			-13
		],
		[
			16,
			9
		],
		[
			1,
			21
		],
		[
			-25,
			5
		],
		[
			-16,
			19
		],
		[
			-3,
			12
		],
		[
			10,
			2
		],
		[
			7,
			12
		],
		[
			18,
			-9
		],
		[
			10,
			-13
		],
		[
			0,
			-9
		],
		[
			10,
			10
		],
		[
			31,
			-15
		],
		[
			9,
			7
		],
		[
			18,
			-7
		],
		[
			-4,
			22
		],
		[
			-19,
			30
		],
		[
			4,
			9
		],
		[
			18,
			12
		],
		[
			6,
			9
		],
		[
			18,
			5
		],
		[
			22,
			27
		],
		[
			11,
			-8
		],
		[
			20,
			3
		],
		[
			22,
			-21
		],
		[
			1,
			11
		],
		[
			11,
			23
		],
		[
			0,
			16
		],
		[
			-20,
			19
		],
		[
			10,
			28
		],
		[
			3,
			31
		],
		[
			-25,
			18
		],
		[
			18,
			-4
		],
		[
			37,
			0
		],
		[
			18,
			-6
		],
		[
			16,
			-18
		],
		[
			5,
			-18
		],
		[
			-38,
			-5
		],
		[
			-12,
			-22
		],
		[
			17,
			-9
		],
		[
			8,
			-17
		],
		[
			20,
			-5
		],
		[
			34,
			13
		],
		[
			5,
			22
		],
		[
			-3,
			11
		],
		[
			26,
			7
		],
		[
			1,
			6
		],
		[
			24,
			9
		],
		[
			31,
			22
		],
		[
			8,
			-1
		],
		[
			31,
			13
		],
		[
			-1,
			-12
		],
		[
			16,
			4
		],
		[
			-12,
			10
		],
		[
			32,
			18
		],
		[
			15,
			-3
		],
		[
			-7,
			-14
		],
		[
			6,
			-13
		],
		[
			-21,
			-8
		],
		[
			29,
			-3
		],
		[
			7,
			6
		],
		[
			11,
			-7
		],
		[
			1,
			12
		],
		[
			29,
			14
		],
		[
			38,
			-5
		],
		[
			18,
			17
		],
		[
			25,
			8
		],
		[
			15,
			-13
		],
		[
			-10,
			-8
		],
		[
			1,
			-13
		],
		[
			16,
			-4
		],
		[
			8,
			10
		],
		[
			-6,
			7
		],
		[
			20,
			5
		],
		[
			13,
			11
		],
		[
			0,
			10
		],
		[
			-22,
			28
		],
		[
			15,
			6
		],
		[
			2,
			10
		],
		[
			74,
			-10
		],
		[
			20,
			-7
		],
		[
			19,
			-15
		],
		[
			62,
			-29
		],
		[
			33,
			-25
		],
		[
			2,
			-9
		],
		[
			17,
			25
		],
		[
			7,
			19
		],
		[
			-21,
			2
		],
		[
			-10,
			16
		],
		[
			-1,
			12
		],
		[
			-35,
			14
		],
		[
			3,
			16
		],
		[
			12,
			3
		],
		[
			-6,
			9
		],
		[
			6,
			15
		],
		[
			-1,
			20
		],
		[
			-16,
			-3
		],
		[
			-2,
			17
		],
		[
			8,
			14
		],
		[
			28,
			12
		],
		[
			15,
			17
		],
		[
			14,
			51
		],
		[
			12,
			16
		],
		[
			5,
			-5
		],
		[
			52,
			1
		],
		[
			39,
			-11
		],
		[
			1,
			-25
		],
		[
			-16,
			-26
		],
		[
			1,
			-7
		],
		[
			-15,
			-11
		],
		[
			8,
			-13
		],
		[
			16,
			-10
		],
		[
			5,
			-15
		],
		[
			-2,
			-25
		],
		[
			-10,
			-9
		],
		[
			8,
			-25
		],
		[
			-5,
			-11
		],
		[
			3,
			-21
		],
		[
			-3,
			-16
		],
		[
			5,
			-8
		],
		[
			26,
			-20
		],
		[
			-15,
			-16
		],
		[
			3,
			-22
		],
		[
			-18,
			-13
		],
		[
			-9,
			-27
		],
		[
			-20,
			-14
		],
		[
			2,
			-15
		],
		[
			-15,
			-1
		],
		[
			-10,
			-7
		],
		[
			-22,
			21
		],
		[
			-22,
			-6
		],
		[
			8,
			-15
		],
		[
			27,
			-10
		],
		[
			22,
			2
		],
		[
			24,
			-8
		],
		[
			10,
			6
		],
		[
			2,
			16
		],
		[
			13,
			2
		],
		[
			26,
			20
		],
		[
			1,
			17
		],
		[
			24,
			24
		],
		[
			-1,
			25
		],
		[
			-11,
			15
		],
		[
			3,
			17
		],
		[
			29,
			12
		],
		[
			31,
			4
		],
		[
			1,
			-11
		],
		[
			19,
			-15
		],
		[
			-5,
			-15
		],
		[
			5,
			-20
		],
		[
			-7,
			-7
		],
		[
			18,
			-13
		],
		[
			18,
			-1
		],
		[
			-25,
			13
		],
		[
			0,
			18
		],
		[
			20,
			10
		],
		[
			-11,
			14
		],
		[
			-5,
			24
		],
		[
			-19,
			5
		],
		[
			-24,
			13
		],
		[
			-17,
			1
		],
		[
			-20,
			-10
		],
		[
			-27,
			5
		],
		[
			3,
			18
		],
		[
			-10,
			15
		],
		[
			6,
			25
		],
		[
			17,
			20
		],
		[
			-21,
			41
		],
		[
			-15,
			12
		],
		[
			14,
			22
		],
		[
			39,
			16
		],
		[
			5,
			17
		],
		[
			-4,
			28
		],
		[
			15,
			-7
		],
		[
			6,
			-30
		],
		[
			-13,
			-17
		],
		[
			7,
			-17
		],
		[
			-5,
			-18
		],
		[
			11,
			-4
		],
		[
			57,
			-7
		],
		[
			6,
			-11
		],
		[
			12,
			0
		],
		[
			-4,
			17
		],
		[
			-17,
			2
		],
		[
			-39,
			16
		],
		[
			-8,
			20
		],
		[
			27,
			8
		],
		[
			17,
			-13
		],
		[
			15,
			3
		],
		[
			-5,
			14
		],
		[
			-15,
			-2
		],
		[
			15,
			14
		],
		[
			16,
			5
		],
		[
			28,
			-3
		],
		[
			51,
			-35
		],
		[
			23,
			-3
		],
		[
			18,
			5
		],
		[
			14,
			-7
		],
		[
			-14,
			-16
		],
		[
			-16,
			-6
		],
		[
			-2,
			-17
		],
		[
			7,
			-12
		],
		[
			-10,
			-12
		],
		[
			11,
			2
		],
		[
			0,
			11
		],
		[
			10,
			11
		],
		[
			9,
			-6
		],
		[
			-4,
			-27
		],
		[
			-10,
			-9
		],
		[
			14,
			-10
		],
		[
			-7,
			14
		],
		[
			18,
			0
		],
		[
			6,
			8
		],
		[
			-17,
			44
		],
		[
			13,
			23
		],
		[
			-6,
			11
		],
		[
			-32,
			15
		],
		[
			-3,
			11
		],
		[
			-26,
			4
		],
		[
			-14,
			11
		],
		[
			4,
			23
		],
		[
			-11,
			9
		],
		[
			2,
			28
		],
		[
			39,
			5
		],
		[
			43,
			-1
		],
		[
			59,
			10
		],
		[
			40,
			3
		],
		[
			-23,
			-18
		],
		[
			25,
			2
		],
		[
			10,
			13
		],
		[
			-19,
			21
		],
		[
			-22,
			4
		],
		[
			14,
			18
		],
		[
			-21,
			4
		],
		[
			13,
			10
		],
		[
			16,
			-7
		],
		[
			68,
			47
		],
		[
			67,
			8
		],
		[
			66,
			16
		],
		[
			-28,
			9
		],
		[
			19,
			3
		],
		[
			22,
			-5
		],
		[
			25,
			7
		],
		[
			21,
			-3
		],
		[
			-16,
			-13
		],
		[
			58,
			10
		],
		[
			32,
			12
		],
		[
			29,
			-10
		],
		[
			-29,
			24
		],
		[
			18,
			-3
		],
		[
			40,
			4
		],
		[
			1,
			26
		],
		[
			63,
			39
		],
		[
			43,
			3
		],
		[
			33,
			-17
		],
		[
			-21,
			-13
		],
		[
			-24,
			-3
		],
		[
			82,
			-7
		],
		[
			6,
			-6
		],
		[
			-27,
			-21
		],
		[
			36,
			-1
		],
		[
			4,
			12
		],
		[
			38,
			1
		],
		[
			19,
			-4
		],
		[
			27,
			5
		],
		[
			47,
			-24
		],
		[
			3,
			-16
		],
		[
			19,
			4
		],
		[
			3,
			-28
		],
		[
			-21,
			5
		],
		[
			1,
			-12
		],
		[
			22,
			-1
		],
		[
			-2,
			-14
		],
		[
			-20,
			-17
		],
		[
			-20,
			-6
		],
		[
			-12,
			-13
		],
		[
			-47,
			-16
		],
		[
			-2,
			-9
		],
		[
			-32,
			-15
		],
		[
			-20,
			-19
		],
		[
			-27,
			-1
		],
		[
			-12,
			-18
		],
		[
			-17,
			-2
		],
		[
			-6,
			-15
		],
		[
			-15,
			-12
		],
		[
			23,
			6
		],
		[
			7,
			17
		],
		[
			37,
			-2
		],
		[
			15,
			8
		],
		[
			51,
			12
		],
		[
			23,
			10
		],
		[
			-7,
			6
		],
		[
			-25,
			-5
		],
		[
			-6,
			8
		],
		[
			13,
			10
		],
		[
			25,
			-6
		],
		[
			7,
			7
		],
		[
			8,
			-13
		],
		[
			19,
			-6
		],
		[
			22,
			5
		],
		[
			-2,
			12
		],
		[
			16,
			-20
		],
		[
			-8,
			-12
		],
		[
			44,
			9
		],
		[
			19,
			7
		],
		[
			100,
			-13
		],
		[
			-18,
			-4
		],
		[
			1,
			-11
		],
		[
			38,
			-12
		],
		[
			36,
			-5
		],
		[
			25,
			2
		],
		[
			21,
			-8
		],
		[
			-7,
			11
		],
		[
			19,
			-6
		],
		[
			11,
			17
		],
		[
			-8,
			10
		],
		[
			3,
			16
		],
		[
			17,
			-2
		],
		[
			10,
			10
		],
		[
			23,
			-14
		],
		[
			29,
			0
		],
		[
			12,
			-16
		],
		[
			7,
			15
		],
		[
			30,
			-4
		],
		[
			7,
			-12
		],
		[
			34,
			-14
		],
		[
			-34,
			-12
		],
		[
			30,
			-6
		],
		[
			-39,
			-3
		],
		[
			20,
			-10
		],
		[
			18,
			-1
		],
		[
			6,
			-12
		],
		[
			-15,
			-11
		],
		[
			-19,
			8
		],
		[
			27,
			-37
		],
		[
			13,
			-27
		],
		[
			40,
			-21
		],
		[
			13,
			12
		],
		[
			18,
			43
		],
		[
			10,
			14
		],
		[
			13,
			-19
		],
		[
			23,
			-12
		],
		[
			22,
			0
		],
		[
			4,
			6
		],
		[
			31,
			8
		],
		[
			22,
			-6
		],
		[
			19,
			-11
		],
		[
			11,
			-13
		],
		[
			7,
			27
		],
		[
			16,
			4
		],
		[
			12,
			-13
		],
		[
			17,
			2
		],
		[
			-3,
			27
		],
		[
			15,
			17
		],
		[
			-29,
			0
		],
		[
			12,
			16
		],
		[
			37,
			2
		],
		[
			4,
			10
		],
		[
			-12,
			9
		],
		[
			23,
			-1
		],
		[
			23,
			-9
		],
		[
			38,
			0
		],
		[
			50,
			-8
		],
		[
			39,
			-12
		],
		[
			-37,
			1
		],
		[
			-16,
			4
		],
		[
			-13,
			-15
		],
		[
			27,
			6
		],
		[
			42,
			2
		],
		[
			-26,
			-26
		],
		[
			10,
			16
		],
		[
			-12,
			4
		],
		[
			-3,
			-17
		],
		[
			-23,
			-12
		],
		[
			29,
			4
		],
		[
			30,
			31
		],
		[
			36,
			0
		],
		[
			34,
			-9
		],
		[
			13,
			-13
		],
		[
			-12,
			-9
		],
		[
			-7,
			7
		],
		[
			-9,
			-11
		],
		[
			25,
			-2
		],
		[
			-2,
			-11
		],
		[
			20,
			2
		],
		[
			0,
			-13
		],
		[
			24,
			3
		],
		[
			18,
			-20
		],
		[
			-13,
			0
		],
		[
			26,
			-9
		],
		[
			28,
			3
		],
		[
			65,
			12
		],
		[
			45,
			-1
		],
		[
			26,
			-6
		],
		[
			33,
			-17
		],
		[
			11,
			-25
		],
		[
			-11,
			-19
		],
		[
			3,
			-8
		],
		[
			31,
			-8
		],
		[
			3,
			-28
		],
		[
			11,
			-11
		],
		[
			-10,
			-25
		],
		[
			14,
			22
		],
		[
			-2,
			26
		],
		[
			19,
			17
		],
		[
			51,
			7
		],
		[
			23,
			-12
		],
		[
			23,
			2
		],
		[
			11,
			-5
		],
		[
			24,
			-1
		],
		[
			21,
			16
		],
		[
			16,
			-13
		],
		[
			2,
			-19
		],
		[
			29,
			-8
		],
		[
			7,
			-18
		],
		[
			22,
			4
		],
		[
			17,
			12
		],
		[
			-13,
			32
		],
		[
			-11,
			-1
		],
		[
			11,
			11
		],
		[
			-1,
			19
		],
		[
			41,
			-7
		],
		[
			22,
			-1
		],
		[
			17,
			-10
		],
		[
			1,
			9
		],
		[
			37,
			-6
		],
		[
			20,
			2
		],
		[
			28,
			-7
		],
		[
			71,
			-27
		],
		[
			17,
			-16
		],
		[
			-9958,
			-15
		],
		[
			3,
			-12
		],
		[
			28,
			-11
		],
		[
			2,
			-9
		],
		[
			12,
			1
		],
		[
			20,
			-19
		],
		[
			16,
			-2
		],
		[
			-10,
			-7
		],
		[
			12,
			-5
		],
		[
			0,
			10
		],
		[
			12,
			-7
		],
		[
			8,
			-20
		],
		[
			10,
			-2
		],
		[
			-3,
			-18
		],
		[
			5,
			-13
		],
		[
			-7,
			-6
		],
		[
			14,
			-8
		],
		[
			-1,
			-14
		],
		[
			17,
			13
		],
		[
			-11,
			3
		],
		[
			9,
			6
		],
		[
			-2,
			17
		],
		[
			-9,
			6
		],
		[
			27,
			1
		],
		[
			20,
			-12
		],
		[
			-5,
			9
		],
		[
			32,
			-6
		],
		[
			10,
			-17
		],
		[
			13,
			-7
		],
		[
			10,
			-17
		],
		[
			5,
			4
		],
		[
			17,
			-14
		],
		[
			-9,
			0
		],
		[
			-14,
			-11
		],
		[
			-5,
			-15
		],
		[
			-21,
			13
		],
		[
			11,
			-20
		],
		[
			-32,
			3
		],
		[
			4,
			-27
		],
		[
			-19,
			-12
		],
		[
			-8,
			-11
		],
		[
			16,
			-5
		],
		[
			6,
			-9
		],
		[
			-13,
			-1
		],
		[
			-12,
			-9
		],
		[
			-23,
			10
		],
		[
			-2,
			8
		],
		[
			-16,
			10
		],
		[
			-33,
			12
		],
		[
			-4,
			29
		],
		[
			-29,
			10
		],
		[
			-12,
			-10
		],
		[
			-30,
			4
		],
		[
			-11,
			27
		],
		[
			9,
			7
		],
		[
			2,
			15
		],
		[
			-7,
			-11
		],
		[
			-28,
			-4
		],
		[
			0,
			-16
		],
		[
			13,
			-11
		],
		[
			-7,
			-23
		],
		[
			9982,
			-11
		],
		[
			-10,
			-13
		],
		[
			-34,
			-9
		],
		[
			-21,
			8
		],
		[
			-1,
			8
		],
		[
			-16,
			9
		],
		[
			12,
			-16
		],
		[
			-24,
			2
		],
		[
			-11,
			7
		],
		[
			20,
			-23
		],
		[
			20,
			12
		],
		[
			-3,
			-16
		],
		[
			17,
			-17
		],
		[
			8,
			8
		],
		[
			12,
			-25
		],
		[
			2,
			-16
		],
		[
			-5,
			-13
		],
		[
			18,
			-9
		],
		[
			2,
			-20
		],
		[
			7,
			-16
		],
		[
			-12,
			-7
		],
		[
			0,
			-10
		],
		[
			-28,
			12
		],
		[
			-22,
			3
		],
		[
			-10,
			16
		],
		[
			2,
			-16
		],
		[
			-21,
			-16
		],
		[
			-25,
			-11
		],
		[
			-25,
			-18
		],
		[
			-12,
			2
		],
		[
			-7,
			-10
		],
		[
			-8,
			4
		],
		[
			-1,
			-10
		],
		[
			-10,
			-10
		],
		[
			-11,
			2
		],
		[
			5,
			-8
		],
		[
			-22,
			-13
		],
		[
			-3,
			-12
		],
		[
			-17,
			-4
		],
		[
			-1,
			-9
		],
		[
			-15,
			-7
		],
		[
			-10,
			-16
		],
		[
			-6,
			-18
		],
		[
			-8,
			8
		],
		[
			-7,
			21
		],
		[
			-13,
			9
		],
		[
			-32,
			0
		],
		[
			-35,
			-20
		],
		[
			-16,
			-23
		],
		[
			-4,
			0
		],
		[
			8,
			39
		],
		[
			-33,
			-24
		],
		[
			-5,
			-14
		],
		[
			-7,
			-2
		],
		[
			-2,
			11
		],
		[
			-30,
			3
		],
		[
			2,
			-9
		],
		[
			-9,
			-4
		],
		[
			-5,
			-19
		],
		[
			4,
			-12
		],
		[
			-12,
			-10
		],
		[
			4,
			-10
		],
		[
			-18,
			-16
		],
		[
			-10,
			-26
		],
		[
			1,
			-19
		],
		[
			13,
			-7
		],
		[
			1,
			11
		],
		[
			18,
			-8
		],
		[
			3,
			-6
		],
		[
			-15,
			-21
		],
		[
			1,
			-36
		],
		[
			11,
			1
		],
		[
			4,
			-32
		],
		[
			-9,
			-10
		],
		[
			-12,
			13
		],
		[
			8,
			11
		],
		[
			-6,
			4
		],
		[
			-8,
			-7
		],
		[
			6,
			-6
		],
		[
			-16,
			-12
		],
		[
			-7,
			-25
		],
		[
			-1,
			-16
		],
		[
			11,
			-34
		],
		[
			-11,
			-14
		],
		[
			-13,
			-1
		],
		[
			-6,
			6
		],
		[
			-15,
			-9
		],
		[
			-13,
			-15
		],
		[
			-6,
			-22
		],
		[
			4,
			-13
		],
		[
			-3,
			-6
		],
		[
			5,
			-22
		],
		[
			-13,
			10
		],
		[
			-9,
			-5
		],
		[
			-21,
			-25
		],
		[
			1,
			-26
		],
		[
			-7,
			-19
		],
		[
			-10,
			-20
		],
		[
			-11,
			-7
		],
		[
			-2,
			-8
		],
		[
			-17,
			-22
		],
		[
			-9,
			17
		],
		[
			-1,
			40
		],
		[
			-4,
			33
		],
		[
			-7,
			23
		],
		[
			-4,
			46
		],
		[
			-9,
			60
		],
		[
			-2,
			29
		],
		[
			4,
			46
		],
		[
			6,
			29
		],
		[
			6,
			15
		],
		[
			17,
			15
		],
		[
			7,
			17
		],
		[
			-5,
			22
		],
		[
			16,
			0
		],
		[
			7,
			14
		],
		[
			15,
			0
		],
		[
			20,
			19
		],
		[
			24,
			33
		],
		[
			3,
			13
		],
		[
			13,
			12
		],
		[
			5,
			12
		],
		[
			8,
			2
		],
		[
			18,
			25
		],
		[
			14,
			14
		],
		[
			-1,
			8
		],
		[
			30,
			21
		],
		[
			21,
			9
		],
		[
			-8,
			4
		],
		[
			15,
			18
		],
		[
			-7,
			9
		],
		[
			8,
			12
		],
		[
			2,
			33
		],
		[
			14,
			12
		],
		[
			17,
			-5
		],
		[
			-18,
			17
		],
		[
			-15,
			-1
		],
		[
			-22,
			-8
		],
		[
			3,
			-11
		],
		[
			-8,
			-6
		],
		[
			3,
			-9
		],
		[
			-6,
			-15
		],
		[
			10,
			-9
		],
		[
			-10,
			-7
		],
		[
			-5,
			11
		],
		[
			-10,
			-2
		],
		[
			-12,
			-18
		],
		[
			-32,
			-32
		],
		[
			-19,
			-14
		],
		[
			8,
			27
		],
		[
			-17,
			-7
		],
		[
			5,
			11
		],
		[
			-3,
			9
		],
		[
			14,
			29
		],
		[
			-3,
			10
		],
		[
			-12,
			-14
		],
		[
			-10,
			-2
		],
		[
			-3,
			12
		],
		[
			-13,
			2
		],
		[
			-26,
			-10
		],
		[
			-15,
			3
		],
		[
			-22,
			-15
		],
		[
			-1,
			-18
		],
		[
			-20,
			-20
		],
		[
			0,
			-9
		],
		[
			-27,
			-20
		],
		[
			-13,
			-28
		],
		[
			-7,
			-1
		],
		[
			-2,
			-23
		],
		[
			14,
			5
		],
		[
			16,
			-14
		],
		[
			-1,
			-7
		],
		[
			-11,
			-3
		],
		[
			-8,
			5
		],
		[
			-13,
			-10
		],
		[
			-19,
			11
		],
		[
			0,
			-8
		],
		[
			-10,
			-2
		],
		[
			-2,
			-8
		],
		[
			-16,
			8
		],
		[
			-9,
			-11
		],
		[
			-17,
			-2
		],
		[
			-9,
			15
		],
		[
			10,
			4
		],
		[
			18,
			-1
		],
		[
			6,
			4
		],
		[
			-15,
			8
		],
		[
			-10,
			14
		],
		[
			-13,
			-8
		],
		[
			-12,
			2
		],
		[
			-2,
			7
		],
		[
			-23,
			8
		],
		[
			-16,
			-8
		],
		[
			5,
			-5
		],
		[
			-14,
			-5
		],
		[
			6,
			-12
		],
		[
			-14,
			2
		],
		[
			-2,
			7
		],
		[
			-12,
			0
		],
		[
			-10,
			-9
		],
		[
			-31,
			13
		],
		[
			-3,
			-16
		],
		[
			-8,
			-3
		],
		[
			-6,
			9
		],
		[
			4,
			6
		],
		[
			-27,
			-1
		],
		[
			-32,
			2
		],
		[
			-19,
			-3
		],
		[
			-25,
			-13
		],
		[
			-19,
			-30
		],
		[
			-17,
			-11
		],
		[
			-8,
			-13
		],
		[
			-5,
			-20
		],
		[
			-15,
			-9
		],
		[
			-4,
			-11
		],
		[
			-11,
			-12
		],
		[
			-14,
			-9
		],
		[
			-22,
			-32
		],
		[
			-12,
			-26
		],
		[
			-26,
			-27
		],
		[
			-8,
			-4
		],
		[
			-15,
			-23
		],
		[
			-19,
			-15
		],
		[
			0,
			-12
		],
		[
			14,
			-9
		],
		[
			30,
			5
		],
		[
			0,
			-28
		],
		[
			-4,
			-21
		],
		[
			12,
			0
		],
		[
			5,
			14
		],
		[
			-6,
			6
		],
		[
			10,
			10
		],
		[
			8,
			-2
		],
		[
			-8,
			-11
		],
		[
			9,
			-11
		],
		[
			-12,
			-22
		],
		[
			16,
			4
		],
		[
			11,
			9
		],
		[
			7,
			14
		],
		[
			1,
			-9
		],
		[
			-10,
			-15
		],
		[
			7,
			-3
		],
		[
			8,
			26
		],
		[
			-1,
			20
		],
		[
			16,
			-8
		],
		[
			9,
			5
		],
		[
			17,
			-12
		],
		[
			0,
			-11
		],
		[
			27,
			-32
		],
		[
			6,
			-10
		],
		[
			-13,
			-12
		],
		[
			8,
			-5
		],
		[
			1,
			-15
		],
		[
			-4,
			-13
		],
		[
			11,
			-12
		],
		[
			-6,
			-3
		],
		[
			3,
			-9
		],
		[
			-9,
			-16
		],
		[
			-6,
			-3
		],
		[
			0,
			-12
		],
		[
			-6,
			-8
		],
		[
			0,
			-18
		],
		[
			-4,
			-4
		],
		[
			-3,
			-20
		],
		[
			1,
			-32
		],
		[
			3,
			-23
		],
		[
			-6,
			-17
		],
		[
			1,
			-17
		],
		[
			-6,
			-17
		],
		[
			0,
			-14
		],
		[
			-26,
			-38
		],
		[
			-7,
			-28
		],
		[
			-13,
			-18
		],
		[
			-5,
			-27
		],
		[
			-18,
			-41
		],
		[
			-15,
			-25
		],
		[
			-10,
			-11
		],
		[
			-8,
			-20
		],
		[
			-6,
			-6
		],
		[
			-5,
			-15
		],
		[
			-7,
			-5
		],
		[
			-11,
			-25
		],
		[
			-3,
			-14
		],
		[
			-5,
			0
		],
		[
			-1,
			-12
		],
		[
			-18,
			-20
		],
		[
			-9,
			-6
		],
		[
			-7,
			-11
		],
		[
			-8,
			0
		],
		[
			-12,
			-10
		],
		[
			-6,
			7
		],
		[
			-4,
			-4
		],
		[
			-12,
			10
		],
		[
			-3,
			-4
		],
		[
			-1,
			23
		],
		[
			-9,
			-11
		],
		[
			1,
			15
		],
		[
			-16,
			-21
		],
		[
			-1,
			-11
		],
		[
			-14,
			-11
		],
		[
			-4,
			-17
		]
	],
	[
		[
			7858,
			9748
		],
		[
			0,
			-12
		],
		[
			30,
			4
		],
		[
			14,
			-16
		],
		[
			16,
			-1
		],
		[
			8,
			-19
		],
		[
			-16,
			-10
		],
		[
			-31,
			-5
		],
		[
			-68,
			-3
		],
		[
			-33,
			-14
		],
		[
			-21,
			5
		],
		[
			21,
			17
		],
		[
			6,
			19
		],
		[
			36,
			39
		],
		[
			19,
			-6
		],
		[
			2,
			11
		],
		[
			17,
			-9
		]
	],
	[
		[
			7118,
			9769
		],
		[
			37,
			-6
		],
		[
			-27,
			-3
		],
		[
			-10,
			9
		]
	],
	[
		[
			7523,
			9794
		],
		[
			79,
			-8
		],
		[
			-18,
			-13
		],
		[
			-55,
			8
		],
		[
			-6,
			13
		]
	],
	[
		[
			6659,
			9787
		],
		[
			-27,
			3
		],
		[
			21,
			7
		],
		[
			6,
			-10
		]
	],
	[
		[
			7715,
			9797
		],
		[
			-5,
			-21
		],
		[
			25,
			17
		],
		[
			20,
			0
		],
		[
			24,
			-16
		],
		[
			-9,
			-24
		],
		[
			-19,
			-5
		],
		[
			25,
			-18
		],
		[
			-39,
			-10
		],
		[
			-38,
			4
		],
		[
			-11,
			8
		],
		[
			-50,
			2
		],
		[
			-18,
			12
		],
		[
			-1,
			14
		],
		[
			-33,
			3
		],
		[
			29,
			14
		],
		[
			23,
			19
		],
		[
			77,
			1
		]
	],
	[
		[
			6585,
			9810
		],
		[
			-4,
			-16
		],
		[
			-28,
			0
		],
		[
			1,
			14
		],
		[
			31,
			2
		]
	],
	[
		[
			6481,
			9813
		],
		[
			15,
			-7
		],
		[
			-35,
			-6
		],
		[
			20,
			13
		]
	],
	[
		[
			6646,
			9809
		],
		[
			-52,
			-12
		],
		[
			-13,
			20
		],
		[
			42,
			0
		],
		[
			23,
			-8
		]
	],
	[
		[
			6329,
			9836
		],
		[
			-38,
			-20
		],
		[
			-39,
			11
		],
		[
			77,
			9
		]
	],
	[
		[
			6729,
			9835
		],
		[
			-5,
			-10
		],
		[
			-29,
			-12
		],
		[
			-38,
			1
		],
		[
			-13,
			13
		],
		[
			14,
			11
		],
		[
			65,
			2
		],
		[
			6,
			-5
		]
	],
	[
		[
			6537,
			9839
		],
		[
			-13,
			-8
		],
		[
			-22,
			8
		],
		[
			35,
			0
		]
	],
	[
		[
			6388,
			9840
		],
		[
			7,
			-8
		],
		[
			30,
			3
		],
		[
			-9,
			-14
		],
		[
			-60,
			-9
		],
		[
			4,
			-14
		],
		[
			-38,
			-4
		],
		[
			16,
			15
		],
		[
			-22,
			8
		],
		[
			63,
			10
		],
		[
			-18,
			7
		],
		[
			27,
			6
		]
	],
	[
		[
			7225,
			9845
		],
		[
			-28,
			-9
		],
		[
			2,
			9
		],
		[
			26,
			0
		]
	],
	[
		[
			6560,
			9854
		],
		[
			57,
			-11
		],
		[
			-29,
			-1
		],
		[
			-28,
			12
		]
	],
	[
		[
			6542,
			9848
		],
		[
			13,
			2
		],
		[
			47,
			-13
		],
		[
			-19,
			-7
		],
		[
			-41,
			18
		]
	],
	[
		[
			6797,
			9859
		],
		[
			20,
			-16
		],
		[
			-28,
			-11
		],
		[
			-36,
			-3
		],
		[
			-17,
			9
		],
		[
			46,
			10
		],
		[
			15,
			11
		]
	],
	[
		[
			7536,
			9852
		],
		[
			-37,
			1
		],
		[
			2,
			7
		],
		[
			38,
			-2
		],
		[
			-3,
			-6
		]
	],
	[
		[
			7665,
			9859
		],
		[
			54,
			-29
		],
		[
			-20,
			-3
		],
		[
			0,
			-24
		],
		[
			-75,
			-6
		],
		[
			-22,
			-7
		],
		[
			-63,
			20
		],
		[
			36,
			9
		],
		[
			15,
			17
		],
		[
			-22,
			-3
		],
		[
			16,
			14
		],
		[
			81,
			12
		]
	],
	[
		[
			6577,
			9869
		],
		[
			28,
			-6
		],
		[
			-38,
			-6
		],
		[
			10,
			12
		]
	],
	[
		[
			6605,
			9878
		],
		[
			14,
			-9
		],
		[
			-44,
			4
		],
		[
			30,
			5
		]
	],
	[
		[
			5846,
			5121
		],
		[
			2,
			-14
		],
		[
			5,
			-5
		],
		[
			3,
			-11
		],
		[
			1,
			-26
		],
		[
			-1,
			-18
		],
		[
			-8,
			-2
		]
	],
	[
		[
			5801,
			5040
		],
		[
			6,
			7
		],
		[
			8,
			22
		],
		[
			-4,
			17
		]
	],
	[
		[
			5821,
			5103
		],
		[
			7,
			4
		],
		[
			4,
			-9
		],
		[
			5,
			7
		],
		[
			5,
			16
		],
		[
			4,
			0
		]
	],
	[
		[
			4526,
			6379
		],
		[
			-1,
			15
		],
		[
			2,
			22
		]
	],
	[
		[
			6163,
			6147
		],
		[
			4,
			4
		],
		[
			4,
			-6
		],
		[
			-8,
			2
		]
	],
	[
		[
			6345,
			6826
		],
		[
			6,
			-29
		],
		[
			6,
			-11
		],
		[
			0,
			-14
		],
		[
			11,
			-4
		],
		[
			-4,
			-5
		],
		[
			5,
			-5
		],
		[
			11,
			-23
		],
		[
			8,
			-6
		],
		[
			0,
			-16
		],
		[
			6,
			-10
		],
		[
			-2,
			-18
		],
		[
			-4,
			4
		],
		[
			7,
			-31
		],
		[
			8,
			-17
		],
		[
			0,
			-12
		],
		[
			8,
			-21
		]
	],
	[
		[
			6422,
			6601
		],
		[
			7,
			-4
		],
		[
			-5,
			-9
		],
		[
			8,
			-8
		]
	],
	[
		[
			6443,
			6277
		],
		[
			-4,
			-2
		],
		[
			-58,
			-16
		],
		[
			-17,
			-4
		],
		[
			-27,
			-27
		],
		[
			-16,
			-40
		],
		[
			-3,
			-19
		],
		[
			-9,
			-11
		],
		[
			-5,
			1
		],
		[
			-7,
			19
		],
		[
			-11,
			-3
		],
		[
			-25,
			5
		],
		[
			-5,
			6
		],
		[
			-16,
			1
		],
		[
			-15,
			-5
		],
		[
			-11,
			0
		],
		[
			-7,
			10
		],
		[
			-9,
			-11
		],
		[
			-1,
			-24
		],
		[
			2,
			-15
		],
		[
			-11,
			-16
		]
	],
	[
		[
			6188,
			6126
		],
		[
			-2,
			21
		],
		[
			-5,
			8
		],
		[
			0,
			8
		],
		[
			-6,
			9
		],
		[
			0,
			15
		],
		[
			-15,
			23
		],
		[
			-9,
			25
		],
		[
			0,
			8
		],
		[
			-7,
			16
		],
		[
			-2,
			14
		],
		[
			-11,
			49
		],
		[
			-18,
			29
		],
		[
			-9,
			3
		],
		[
			-6,
			13
		],
		[
			-13,
			43
		],
		[
			3,
			7
		],
		[
			-7,
			28
		],
		[
			4,
			20
		],
		[
			0,
			19
		],
		[
			-8,
			23
		],
		[
			0,
			8
		],
		[
			-14,
			46
		],
		[
			-18,
			21
		],
		[
			-2,
			-3
		],
		[
			-12,
			35
		],
		[
			3,
			0
		],
		[
			0,
			20
		],
		[
			-4,
			7
		],
		[
			-4,
			18
		],
		[
			-8,
			11
		],
		[
			1,
			11
		],
		[
			-5,
			5
		],
		[
			-8,
			30
		],
		[
			-4,
			7
		],
		[
			-8,
			26
		],
		[
			-7,
			15
		],
		[
			-6,
			24
		],
		[
			-8,
			14
		],
		[
			-6,
			-3
		],
		[
			-6,
			7
		],
		[
			5,
			20
		],
		[
			4,
			47
		]
	],
	[
		[
			6024,
			6449
		],
		[
			0,
			-20
		],
		[
			6,
			-21
		],
		[
			2,
			-34
		],
		[
			2,
			-65
		],
		[
			5,
			-40
		],
		[
			4,
			-8
		],
		[
			10,
			-8
		],
		[
			5,
			-9
		],
		[
			1,
			-10
		],
		[
			10,
			-6
		],
		[
			3,
			-8
		]
	],
	[
		[
			5946,
			5727
		],
		[
			-6,
			5
		],
		[
			3,
			17
		],
		[
			-2,
			21
		],
		[
			-20,
			35
		],
		[
			-3,
			45
		],
		[
			2,
			5
		],
		[
			2,
			31
		],
		[
			-13,
			0
		],
		[
			0,
			-12
		],
		[
			-18,
			0
		],
		[
			7,
			-17
		],
		[
			0,
			-27
		],
		[
			2,
			-11
		],
		[
			-14,
			-24
		],
		[
			-1,
			-9
		],
		[
			-18,
			-39
		],
		[
			-13,
			-4
		],
		[
			-14,
			23
		],
		[
			-7,
			8
		],
		[
			-11,
			-12
		],
		[
			-4,
			-17
		],
		[
			-13,
			-9
		],
		[
			-5,
			-10
		],
		[
			1,
			-6
		],
		[
			-23,
			0
		],
		[
			-4,
			15
		],
		[
			-22,
			1
		],
		[
			-14,
			-7
		],
		[
			-11,
			27
		],
		[
			-8,
			12
		],
		[
			-2,
			15
		],
		[
			-21,
			-7
		],
		[
			-3,
			-21
		],
		[
			-5,
			-6
		],
		[
			0,
			-19
		],
		[
			-3,
			-6
		],
		[
			-3,
			-29
		],
		[
			-11,
			-12
		]
	],
	[
		[
			5634,
			5812
		],
		[
			3,
			13
		],
		[
			-1,
			15
		],
		[
			-4,
			-1
		],
		[
			-7,
			16
		],
		[
			3,
			23
		],
		[
			-5,
			-2
		],
		[
			0,
			34
		],
		[
			-7,
			7
		],
		[
			-6,
			-7
		],
		[
			-5,
			9
		],
		[
			6,
			21
		],
		[
			7,
			14
		],
		[
			-5,
			25
		],
		[
			4,
			9
		],
		[
			9,
			9
		],
		[
			-4,
			7
		],
		[
			-1,
			18
		],
		[
			8,
			6
		],
		[
			0,
			10
		],
		[
			7,
			15
		],
		[
			2,
			15
		],
		[
			-2,
			11
		],
		[
			7,
			9
		],
		[
			12,
			2
		],
		[
			11,
			-2
		],
		[
			0,
			218
		]
	],
	[
		[
			5943,
			5426
		],
		[
			-14,
			-28
		],
		[
			-9,
			2
		],
		[
			-3,
			6
		],
		[
			-5,
			-5
		],
		[
			-13,
			-3
		],
		[
			-6,
			-13
		],
		[
			-7,
			5
		],
		[
			-4,
			12
		],
		[
			-7,
			-8
		],
		[
			-11,
			7
		],
		[
			-8,
			-17
		]
	],
	[
		[
			4535,
			5893
		],
		[
			-1,
			42
		]
	],
	[
		[
			4540,
			5965
		],
		[
			-5,
			11
		],
		[
			-1,
			13
		],
		[
			-14,
			41
		],
		[
			-8,
			3
		],
		[
			11,
			9
		],
		[
			8,
			18
		],
		[
			9,
			33
		]
	],
	[
		[
			7884,
			5266
		],
		[
			4,
			-3
		],
		[
			-4,
			-7
		],
		[
			-7,
			2
		],
		[
			7,
			8
		]
	],
	[
		[
			3953,
			2073
		],
		[
			22,
			-4
		],
		[
			11,
			-7
		],
		[
			17,
			-21
		],
		[
			3,
			-11
		],
		[
			-10,
			-7
		],
		[
			-10,
			20
		],
		[
			-12,
			11
		],
		[
			-22,
			11
		],
		[
			1,
			8
		]
	],
	[
		[
			9445,
			4521
		],
		[
			15,
			-17
		],
		[
			-6,
			0
		],
		[
			-3,
			9
		],
		[
			-8,
			4
		],
		[
			2,
			4
		]
	],
	[
		[
			9612,
			4569
		],
		[
			-6,
			-12
		],
		[
			-3,
			7
		],
		[
			9,
			5
		]
	],
	[
		[
			9481,
			4595
		],
		[
			13,
			-14
		],
		[
			8,
			0
		],
		[
			5,
			-13
		],
		[
			0,
			-8
		],
		[
			-12,
			4
		],
		[
			-9,
			10
		],
		[
			-1,
			11
		],
		[
			-6,
			3
		],
		[
			2,
			7
		]
	],
	[
		[
			9483,
			4641
		],
		[
			4,
			-12
		],
		[
			0,
			-10
		],
		[
			-5,
			7
		],
		[
			1,
			15
		]
	],
	[
		[
			9442,
			4640
		],
		[
			13,
			0
		],
		[
			11,
			-20
		],
		[
			-4,
			-9
		],
		[
			-10,
			7
		],
		[
			-13,
			1
		],
		[
			-6,
			13
		],
		[
			0,
			16
		],
		[
			3,
			2
		],
		[
			6,
			-10
		]
	],
	[
		[
			9388,
			4691
		],
		[
			3,
			-9
		],
		[
			-6,
			0
		],
		[
			3,
			9
		]
	],
	[
		[
			9371,
			4689
		],
		[
			-5,
			3
		],
		[
			5,
			6
		],
		[
			0,
			-9
		]
	],
	[
		[
			9466,
			4701
		],
		[
			6,
			-16
		],
		[
			-2,
			-11
		],
		[
			5,
			-5
		],
		[
			7,
			-34
		],
		[
			-14,
			21
		],
		[
			-3,
			10
		],
		[
			-5,
			37
		],
		[
			6,
			-2
		]
	],
	[
		[
			9378,
			4711
		],
		[
			4,
			-3
		],
		[
			3,
			-19
		],
		[
			-7,
			4
		],
		[
			-2,
			13
		],
		[
			-9,
			-2
		],
		[
			-1,
			6
		],
		[
			6,
			13
		],
		[
			5,
			-1
		],
		[
			1,
			-11
		]
	],
	[
		[
			9365,
			4716
		],
		[
			-5,
			1
		],
		[
			-1,
			9
		],
		[
			4,
			5
		],
		[
			2,
			-15
		]
	],
	[
		[
			9349,
			4747
		],
		[
			6,
			-9
		],
		[
			-4,
			-9
		],
		[
			-5,
			14
		],
		[
			3,
			4
		]
	],
	[
		[
			9405,
			4746
		],
		[
			4,
			0
		],
		[
			9,
			-16
		],
		[
			12,
			-12
		],
		[
			9,
			-15
		],
		[
			1,
			-13
		],
		[
			-7,
			12
		],
		[
			-11,
			9
		],
		[
			-18,
			25
		],
		[
			-3,
			13
		],
		[
			4,
			-3
		]
	],
	[
		[
			9349,
			4800
		],
		[
			13,
			-15
		],
		[
			3,
			-16
		],
		[
			10,
			-7
		],
		[
			-2,
			-7
		],
		[
			-15,
			13
		],
		[
			-7,
			18
		],
		[
			-6,
			9
		],
		[
			4,
			5
		]
	],
	[
		[
			4650,
			5621
		],
		[
			2,
			-12
		],
		[
			-12,
			10
		],
		[
			10,
			2
		]
	],
	[
		[
			4681,
			5581
		],
		[
			-6,
			9
		],
		[
			-23,
			18
		],
		[
			1,
			15
		],
		[
			-7,
			4
		],
		[
			-6,
			10
		],
		[
			2,
			3
		],
		[
			-3,
			18
		],
		[
			-5,
			-4
		],
		[
			-3,
			18
		],
		[
			7,
			1
		],
		[
			-6,
			7
		],
		[
			0,
			11
		],
		[
			4,
			7
		],
		[
			-6,
			5
		]
	],
	[
		[
			2560,
			5955
		],
		[
			-2,
			-14
		],
		[
			-12,
			0
		],
		[
			-13,
			5
		],
		[
			-14,
			14
		],
		[
			-14,
			2
		],
		[
			-8,
			11
		]
	],
	[
		[
			6359,
			5831
		],
		[
			0,
			-104
		],
		[
			-27,
			-84
		]
	],
	[
		[
			6201,
			5844
		],
		[
			18,
			-44
		],
		[
			13,
			-18
		],
		[
			15,
			0
		],
		[
			11,
			15
		],
		[
			4,
			0
		],
		[
			10,
			12
		],
		[
			11,
			-4
		],
		[
			6,
			-7
		],
		[
			6,
			4
		],
		[
			21,
			25
		],
		[
			8,
			-5
		],
		[
			14,
			3
		],
		[
			9,
			10
		],
		[
			12,
			-4
		]
	],
	[
		[
			6359,
			5831
		],
		[
			14,
			5
		],
		[
			4,
			7
		],
		[
			7,
			0
		],
		[
			12,
			7
		],
		[
			13,
			23
		],
		[
			15,
			-9
		],
		[
			-5,
			-19
		],
		[
			-1,
			-18
		],
		[
			2,
			-35
		],
		[
			8,
			-8
		],
		[
			-14,
			-6
		],
		[
			-3,
			-53
		],
		[
			-4,
			-8
		],
		[
			-1,
			-12
		],
		[
			-6,
			-10
		],
		[
			-3,
			-22
		],
		[
			-6,
			-20
		],
		[
			-8,
			-13
		],
		[
			0,
			-11
		],
		[
			-6,
			-25
		],
		[
			-10,
			-29
		],
		[
			-4,
			-29
		],
		[
			-12,
			-48
		],
		[
			-13,
			-33
		],
		[
			-7,
			-26
		],
		[
			-12,
			-30
		],
		[
			-14,
			-28
		],
		[
			-10,
			-24
		],
		[
			-9,
			-15
		],
		[
			-8,
			-19
		],
		[
			-21,
			-26
		],
		[
			-8,
			-7
		],
		[
			-18,
			-27
		],
		[
			-8,
			-17
		],
		[
			-10,
			-15
		],
		[
			-22,
			-48
		],
		[
			-11,
			-21
		],
		[
			-18,
			-49
		],
		[
			-9,
			-28
		]
	],
	[
		[
			5183,
			5187
		],
		[
			-3,
			-2
		],
		[
			-1,
			13
		],
		[
			5,
			8
		],
		[
			3,
			-11
		],
		[
			-4,
			-8
		]
	],
	[
		[
			3409,
			5499
		],
		[
			3,
			3
		],
		[
			1,
			20
		],
		[
			5,
			7
		],
		[
			8,
			-2
		],
		[
			20,
			-10
		],
		[
			2,
			10
		],
		[
			33,
			0
		],
		[
			18,
			-8
		],
		[
			-1,
			-20
		],
		[
			-3,
			-8
		]
	],
	[
		[
			5626,
			8009
		],
		[
			-12,
			-39
		]
	],
	[
		[
			5377,
			7802
		],
		[
			3,
			6
		]
	],
	[
		[
			5474,
			8485
		],
		[
			-7,
			-30
		],
		[
			-12,
			-34
		],
		[
			0,
			19
		],
		[
			19,
			45
		]
	],
	[
		[
			5521,
			8514
		],
		[
			8,
			1
		],
		[
			-8,
			-14
		],
		[
			-2,
			-22
		],
		[
			-10,
			-8
		],
		[
			-5,
			7
		],
		[
			-1,
			19
		],
		[
			10,
			16
		],
		[
			8,
			1
		]
	],
	[
		[
			5327,
			8537
		],
		[
			-2,
			-9
		],
		[
			-9,
			3
		],
		[
			11,
			6
		]
	],
	[
		[
			5671,
			8973
		],
		[
			-41,
			-2
		],
		[
			-9,
			5
		],
		[
			1,
			-19
		],
		[
			-16,
			0
		],
		[
			3,
			-8
		],
		[
			-13,
			0
		],
		[
			4,
			-13
		],
		[
			-10,
			-13
		],
		[
			-4,
			-15
		],
		[
			12,
			-15
		],
		[
			-17,
			-17
		],
		[
			-4,
			-15
		],
		[
			-13,
			-13
		],
		[
			-8,
			1
		],
		[
			-11,
			-13
		],
		[
			-32,
			-24
		],
		[
			0,
			-9
		],
		[
			-17,
			-3
		],
		[
			5,
			-11
		],
		[
			-5,
			-7
		],
		[
			-15,
			-2
		],
		[
			5,
			-14
		],
		[
			-5,
			-29
		],
		[
			-7,
			-9
		],
		[
			5,
			-32
		],
		[
			0,
			-18
		],
		[
			10,
			-10
		],
		[
			10,
			4
		],
		[
			14,
			-25
		],
		[
			9,
			-2
		],
		[
			6,
			-19
		],
		[
			-20,
			-23
		],
		[
			-6,
			3
		],
		[
			8,
			-16
		],
		[
			-17,
			-16
		],
		[
			-18,
			-13
		],
		[
			-13,
			-2
		],
		[
			8,
			-8
		],
		[
			-6,
			-3
		],
		[
			3,
			-15
		],
		[
			-10,
			-16
		],
		[
			6,
			-8
		],
		[
			0,
			-17
		],
		[
			-6,
			-10
		],
		[
			-3,
			-37
		],
		[
			-3,
			0
		],
		[
			-6,
			-23
		],
		[
			-5,
			-8
		],
		[
			-6,
			5
		],
		[
			-27,
			-3
		],
		[
			-11,
			-14
		],
		[
			-2,
			-11
		],
		[
			5,
			-10
		],
		[
			-6,
			-9
		],
		[
			-11,
			3
		],
		[
			-10,
			-5
		],
		[
			-14,
			2
		],
		[
			4,
			15
		],
		[
			-14,
			31
		],
		[
			8,
			6
		],
		[
			-6,
			8
		],
		[
			8,
			2
		],
		[
			-15,
			26
		],
		[
			-18,
			47
		],
		[
			4,
			27
		],
		[
			-4,
			8
		],
		[
			-9,
			-4
		],
		[
			-4,
			9
		],
		[
			-1,
			39
		],
		[
			6,
			-6
		]
	],
	[
		[
			5891,
			3637
		],
		[
			-3,
			2
		],
		[
			-1,
			-29
		],
		[
			-12,
			0
		],
		[
			-11,
			7
		],
		[
			-9,
			22
		],
		[
			0,
			24
		],
		[
			7,
			17
		],
		[
			1,
			10
		],
		[
			8,
			11
		],
		[
			14,
			-15
		],
		[
			2,
			2
		]
	],
	[
		[
			3249,
			6221
		],
		[
			-2,
			2
		]
	],
	[
		[
			5999,
			7178
		],
		[
			-3,
			27
		],
		[
			1,
			18
		],
		[
			-4,
			4
		],
		[
			1,
			20
		],
		[
			3,
			4
		]
	],
	[
		[
			5997,
			7251
		],
		[
			7,
			-5
		],
		[
			5,
			9
		],
		[
			0,
			11
		],
		[
			9,
			3
		],
		[
			-4,
			14
		],
		[
			4,
			21
		],
		[
			8,
			-5
		],
		[
			2,
			-7
		],
		[
			12,
			0
		],
		[
			5,
			6
		],
		[
			18,
			10
		],
		[
			10,
			-11
		],
		[
			16,
			-3
		],
		[
			21,
			8
		],
		[
			20,
			17
		],
		[
			22,
			-1
		],
		[
			16,
			7
		],
		[
			4,
			7
		],
		[
			4,
			-12
		]
	],
	[
		[
			5402,
			5930
		],
		[
			5,
			0
		],
		[
			0,
			13
		],
		[
			-4,
			3
		],
		[
			-6,
			-5
		],
		[
			2,
			-5
		]
	],
	[
		[
			5398,
			5936
		],
		[
			-1,
			0
		]
	],
	[
		[
			5044,
			5541
		],
		[
			-12,
			-7
		]
	],
	[
		[
			7728,
			5654
		],
		[
			6,
			-7
		],
		[
			0,
			-10
		],
		[
			-6,
			-6
		],
		[
			0,
			23
		]
	],
	[
		[
			7840,
			5883
		],
		[
			5,
			-11
		],
		[
			-4,
			1
		],
		[
			-1,
			10
		]
	],
	[
		[
			7858,
			5853
		],
		[
			-4,
			22
		],
		[
			-5,
			11
		],
		[
			-1,
			-7
		],
		[
			-12,
			18
		],
		[
			0,
			8
		],
		[
			-5,
			0
		],
		[
			-8,
			10
		],
		[
			-7,
			-5
		],
		[
			-16,
			5
		],
		[
			3,
			15
		],
		[
			-3,
			7
		],
		[
			4,
			21
		],
		[
			-11,
			5
		],
		[
			-15,
			-8
		],
		[
			-2,
			-9
		],
		[
			4,
			-13
		],
		[
			-4,
			-16
		],
		[
			0,
			-27
		],
		[
			2,
			-5
		],
		[
			-7,
			-15
		],
		[
			0,
			-11
		],
		[
			-4,
			-13
		],
		[
			-5,
			-20
		],
		[
			0,
			-15
		],
		[
			-9,
			-32
		],
		[
			2,
			-7
		],
		[
			-2,
			-27
		],
		[
			5,
			-21
		],
		[
			-3,
			-10
		],
		[
			16,
			5
		],
		[
			4,
			-12
		],
		[
			1,
			-29
		],
		[
			9,
			-16
		],
		[
			0,
			-12
		],
		[
			4,
			-37
		],
		[
			4,
			-16
		],
		[
			-4,
			4
		],
		[
			-3,
			29
		],
		[
			-6,
			-2
		],
		[
			2,
			-13
		],
		[
			6,
			-18
		],
		[
			6,
			0
		],
		[
			9,
			-18
		],
		[
			12,
			1
		],
		[
			6,
			-4
		],
		[
			6,
			-21
		],
		[
			7,
			-12
		]
	],
	[
		[
			7780,
			5554
		],
		[
			-4,
			13
		],
		[
			-8,
			12
		],
		[
			2,
			14
		],
		[
			-6,
			2
		],
		[
			-5,
			10
		],
		[
			-2,
			18
		],
		[
			-7,
			5
		],
		[
			1,
			7
		],
		[
			-5,
			11
		],
		[
			-4,
			1
		],
		[
			-3,
			18
		],
		[
			-5,
			-2
		],
		[
			-2,
			-12
		],
		[
			-4,
			5
		],
		[
			-2,
			18
		],
		[
			2,
			14
		],
		[
			4,
			19
		],
		[
			0,
			16
		],
		[
			3,
			16
		],
		[
			7,
			40
		]
	],
	[
		[
			6962,
			7540
		],
		[
			0,
			0
		]
	],
	[
		[
			6882,
			7324
		],
		[
			1,
			20
		],
		[
			12,
			24
		],
		[
			3,
			15
		],
		[
			-7,
			12
		],
		[
			-2,
			14
		],
		[
			4,
			10
		],
		[
			-2,
			9
		],
		[
			-12,
			1
		],
		[
			0,
			7
		],
		[
			-9,
			4
		],
		[
			2,
			16
		],
		[
			8,
			9
		],
		[
			18,
			-6
		],
		[
			7,
			6
		],
		[
			0,
			11
		],
		[
			8,
			4
		],
		[
			1,
			14
		],
		[
			-10,
			2
		],
		[
			13,
			4
		],
		[
			7,
			-3
		],
		[
			1,
			9
		],
		[
			-4,
			11
		],
		[
			5,
			14
		],
		[
			8,
			-8
		],
		[
			18,
			14
		],
		[
			5,
			7
		],
		[
			8,
			-18
		],
		[
			-11,
			-19
		],
		[
			7,
			-10
		],
		[
			9,
			3
		]
	],
	[
		[
			6497,
			7333
		],
		[
			-3,
			23
		],
		[
			2,
			30
		],
		[
			-1,
			22
		],
		[
			4,
			15
		],
		[
			-12,
			17
		],
		[
			0,
			9
		],
		[
			-11,
			0
		],
		[
			1,
			8
		],
		[
			14,
			2
		],
		[
			-9,
			14
		],
		[
			6,
			10
		],
		[
			-5,
			3
		],
		[
			-14,
			-3
		],
		[
			-5,
			6
		],
		[
			0,
			25
		],
		[
			4,
			9
		],
		[
			2,
			19
		],
		[
			4,
			-11
		],
		[
			13,
			-1
		],
		[
			5,
			-8
		],
		[
			16,
			6
		],
		[
			1,
			12
		],
		[
			8,
			-6
		],
		[
			3,
			14
		],
		[
			-19,
			23
		],
		[
			-4,
			34
		],
		[
			-6,
			5
		],
		[
			-16,
			-3
		],
		[
			-5,
			-6
		],
		[
			-5,
			-17
		],
		[
			4,
			0
		],
		[
			-3,
			-19
		],
		[
			-7,
			9
		],
		[
			-3,
			13
		]
	],
	[
		[
			6554,
			7562
		],
		[
			29,
			-5
		],
		[
			4,
			7
		],
		[
			-4,
			7
		],
		[
			-2,
			23
		],
		[
			4,
			3
		]
	],
	[
		[
			6585,
			7597
		],
		[
			4,
			-18
		],
		[
			11,
			-2
		],
		[
			7,
			14
		],
		[
			-6,
			6
		],
		[
			0,
			13
		]
	],
	[
		[
			6601,
			7610
		],
		[
			5,
			1
		],
		[
			4,
			19
		],
		[
			7,
			-2
		],
		[
			-3,
			10
		],
		[
			11,
			1
		],
		[
			2,
			6
		],
		[
			8,
			-12
		],
		[
			7,
			-2
		],
		[
			7,
			-14
		],
		[
			13,
			2
		],
		[
			5,
			-8
		],
		[
			-1,
			-12
		],
		[
			6,
			-8
		],
		[
			-5,
			-4
		],
		[
			4,
			-10
		],
		[
			-3,
			-10
		],
		[
			11,
			-11
		],
		[
			18,
			1
		],
		[
			6,
			-3
		],
		[
			7,
			6
		],
		[
			9,
			-10
		],
		[
			8,
			-36
		],
		[
			4,
			-2
		],
		[
			5,
			-29
		],
		[
			27,
			-31
		],
		[
			4,
			-10
		],
		[
			13,
			-16
		],
		[
			5,
			2
		],
		[
			10,
			-14
		],
		[
			27,
			-29
		],
		[
			7,
			1
		],
		[
			19,
			-14
		],
		[
			3,
			-4
		],
		[
			-4,
			-9
		],
		[
			0,
			-25
		]
	],
	[
		[
			8444,
			4645
		],
		[
			12,
			9
		]
	],
	[
		[
			8469,
			4667
		],
		[
			5,
			9
		],
		[
			1,
			10
		],
		[
			20,
			8
		],
		[
			10,
			-1
		],
		[
			6,
			5
		],
		[
			3,
			-4
		],
		[
			11,
			10
		],
		[
			11,
			-6
		],
		[
			-13,
			-19
		],
		[
			-8,
			-3
		],
		[
			-4,
			-9
		],
		[
			-7,
			-2
		],
		[
			-6,
			-8
		],
		[
			-10,
			-3
		],
		[
			-15,
			-17
		]
	],
	[
		[
			130,
			3966
		],
		[
			6,
			0
		],
		[
			-1,
			-7
		],
		[
			-5,
			7
		]
	],
	[
		[
			3308,
			5807
		],
		[
			-4,
			-9
		],
		[
			1,
			-31
		],
		[
			-4,
			-4
		],
		[
			-14,
			-1
		],
		[
			-5,
			4
		],
		[
			10,
			7
		],
		[
			0,
			20
		],
		[
			-5,
			5
		],
		[
			8,
			7
		],
		[
			13,
			2
		]
	],
	[
		[
			5303,
			7135
		],
		[
			4,
			-6
		],
		[
			-9,
			-6
		],
		[
			0,
			11
		],
		[
			5,
			1
		]
	],
	[
		[
			5238,
			7310
		],
		[
			7,
			2
		],
		[
			10,
			15
		],
		[
			13,
			6
		],
		[
			17,
			-9
		],
		[
			-4,
			-1
		],
		[
			6,
			-17
		],
		[
			-5,
			-4
		],
		[
			10,
			-3
		],
		[
			14,
			20
		],
		[
			3,
			-14
		],
		[
			-10,
			-23
		],
		[
			-6,
			-4
		],
		[
			-3,
			-16
		],
		[
			6,
			-18
		],
		[
			11,
			-10
		],
		[
			-1,
			-16
		],
		[
			3,
			-7
		],
		[
			-3,
			-11
		],
		[
			-12,
			-28
		],
		[
			-14,
			-14
		],
		[
			-2,
			-16
		],
		[
			4,
			-12
		],
		[
			9,
			-10
		],
		[
			6,
			4
		],
		[
			0,
			-13
		],
		[
			11,
			4
		],
		[
			2,
			-20
		],
		[
			9,
			-1
		]
	],
	[
		[
			5778,
			7600
		],
		[
			-2,
			-9
		],
		[
			6,
			-15
		],
		[
			20,
			-17
		],
		[
			6,
			-2
		],
		[
			-3,
			-13
		],
		[
			-14,
			-1
		],
		[
			-9,
			6
		],
		[
			-6,
			-7
		],
		[
			-12,
			1
		],
		[
			-9,
			-20
		],
		[
			-14,
			-10
		],
		[
			-15,
			-24
		],
		[
			2,
			17
		],
		[
			13,
			10
		],
		[
			3,
			7
		],
		[
			-20,
			-3
		],
		[
			-1,
			9
		]
	],
	[
		[
			5997,
			7251
		],
		[
			2,
			5
		],
		[
			-6,
			17
		],
		[
			12,
			18
		],
		[
			0,
			11
		],
		[
			-6,
			7
		],
		[
			-10,
			-18
		],
		[
			-8,
			-3
		],
		[
			-18,
			15
		],
		[
			-11,
			-13
		],
		[
			-17,
			-26
		],
		[
			-7,
			1
		],
		[
			-17,
			-8
		],
		[
			-13,
			9
		],
		[
			-7,
			18
		],
		[
			-21,
			18
		],
		[
			-18,
			5
		],
		[
			-3,
			-3
		],
		[
			0,
			-18
		],
		[
			-5,
			-18
		],
		[
			-4,
			6
		],
		[
			-13,
			-10
		],
		[
			-12,
			5
		],
		[
			-7,
			9
		],
		[
			0,
			16
		],
		[
			-7,
			-1
		],
		[
			-7,
			9
		],
		[
			-10,
			3
		],
		[
			-3,
			-6
		],
		[
			-11,
			1
		],
		[
			-2,
			-6
		],
		[
			-9,
			3
		],
		[
			8,
			5
		],
		[
			12,
			0
		],
		[
			-1,
			7
		],
		[
			8,
			7
		],
		[
			-15,
			-3
		],
		[
			-12,
			2
		],
		[
			-1,
			8
		],
		[
			7,
			-2
		],
		[
			-10,
			13
		],
		[
			0,
			14
		],
		[
			-5,
			5
		],
		[
			7,
			4
		],
		[
			-1,
			13
		],
		[
			-17,
			7
		],
		[
			-11,
			9
		],
		[
			7,
			6
		],
		[
			-4,
			14
		],
		[
			4,
			3
		],
		[
			5,
			-20
		],
		[
			14,
			8
		],
		[
			-7,
			0
		],
		[
			-5,
			16
		],
		[
			6,
			2
		],
		[
			3,
			10
		],
		[
			-6,
			-2
		],
		[
			0,
			14
		],
		[
			-6,
			9
		],
		[
			9,
			16
		],
		[
			-24,
			-6
		],
		[
			2,
			29
		],
		[
			16,
			25
		],
		[
			16,
			3
		],
		[
			2,
			-7
		],
		[
			11,
			-1
		],
		[
			-1,
			11
		],
		[
			8,
			-2
		],
		[
			-2,
			-7
		],
		[
			11,
			3
		],
		[
			19,
			-3
		],
		[
			1,
			7
		],
		[
			-8,
			3
		],
		[
			5,
			6
		],
		[
			27,
			5
		],
		[
			-15,
			3
		],
		[
			-11,
			13
		],
		[
			6,
			13
		],
		[
			19,
			-6
		],
		[
			11,
			5
		],
		[
			15,
			-8
		],
		[
			9,
			1
		],
		[
			7,
			11
		],
		[
			29,
			28
		],
		[
			14,
			6
		],
		[
			10,
			9
		],
		[
			28,
			-6
		],
		[
			10,
			0
		],
		[
			10,
			9
		],
		[
			1,
			-10
		],
		[
			6,
			-11
		],
		[
			9,
			-5
		],
		[
			10,
			6
		],
		[
			4,
			-16
		],
		[
			8,
			-13
		],
		[
			5,
			8
		],
		[
			12,
			-5
		],
		[
			0,
			-6
		],
		[
			13,
			-8
		],
		[
			8,
			0
		],
		[
			15,
			-7
		],
		[
			32,
			11
		],
		[
			4,
			-6
		],
		[
			14,
			-5
		],
		[
			12,
			7
		],
		[
			24,
			20
		],
		[
			3,
			7
		]
	],
	[
		[
			8378,
			6635
		],
		[
			10,
			-12
		],
		[
			-5,
			-8
		],
		[
			1,
			-22
		],
		[
			-6,
			-18
		],
		[
			-4,
			-43
		],
		[
			-3,
			-19
		],
		[
			-6,
			-20
		],
		[
			-4,
			-5
		],
		[
			-4,
			-17
		],
		[
			-1,
			-27
		],
		[
			-5,
			7
		],
		[
			-1,
			16
		],
		[
			-11,
			20
		],
		[
			-2,
			22
		],
		[
			-3,
			0
		],
		[
			2,
			15
		],
		[
			0,
			20
		],
		[
			17,
			58
		],
		[
			3,
			3
		],
		[
			4,
			18
		],
		[
			12,
			7
		],
		[
			2,
			9
		],
		[
			4,
			-4
		]
	],
	[
		[
			6108,
			4736
		],
		[
			-7,
			-14
		],
		[
			1,
			11
		],
		[
			6,
			3
		]
	],
	[
		[
			6093,
			4842
		],
		[
			6,
			-26
		],
		[
			-4,
			-4
		],
		[
			-7,
			16
		],
		[
			0,
			15
		],
		[
			5,
			-1
		]
	],
	[
		[
			6102,
			4899
		],
		[
			5,
			-11
		],
		[
			-3,
			-19
		],
		[
			-2,
			30
		]
	],
	[
		[
			5914,
			5071
		],
		[
			5,
			-1
		],
		[
			2,
			-12
		],
		[
			-9,
			7
		],
		[
			2,
			6
		]
	],
	[
		[
			5882,
			5125
		],
		[
			1,
			0
		]
	],
	[
		[
			5883,
			5125
		],
		[
			1,
			0
		]
	],
	[
		[
			5884,
			5125
		],
		[
			-1,
			-28
		],
		[
			-2,
			0
		],
		[
			-1,
			-30
		],
		[
			-2,
			-20
		],
		[
			4,
			2
		],
		[
			0,
			-28
		],
		[
			2,
			8
		],
		[
			4,
			-3
		],
		[
			0,
			13
		],
		[
			5,
			-3
		],
		[
			-3,
			10
		],
		[
			7,
			6
		],
		[
			2,
			-10
		],
		[
			12,
			-2
		],
		[
			8,
			5
		],
		[
			3,
			-7
		],
		[
			17,
			17
		],
		[
			-2,
			8
		],
		[
			-4,
			-6
		],
		[
			-10,
			4
		],
		[
			5,
			8
		],
		[
			-3,
			9
		],
		[
			5,
			-1
		],
		[
			5,
			9
		],
		[
			-1,
			12
		],
		[
			6,
			0
		],
		[
			-2,
			7
		],
		[
			8,
			17
		]
	],
	[
		[
			6088,
			4913
		],
		[
			1,
			-10
		],
		[
			-4,
			-16
		],
		[
			-3,
			-25
		],
		[
			-5,
			-21
		],
		[
			2,
			-26
		],
		[
			5,
			-5
		],
		[
			12,
			-22
		],
		[
			2,
			-15
		],
		[
			-4,
			-5
		],
		[
			-4,
			-23
		],
		[
			1,
			-10
		],
		[
			4,
			-2
		],
		[
			0,
			-13
		],
		[
			-4,
			-14
		],
		[
			2,
			-25
		],
		[
			4,
			-7
		],
		[
			0,
			-16
		],
		[
			4,
			-4
		],
		[
			0,
			-15
		],
		[
			4,
			-21
		],
		[
			-2,
			-8
		],
		[
			15,
			-16
		],
		[
			5,
			-14
		]
	],
	[
		[
			5971,
			4516
		],
		[
			-2,
			9
		]
	],
	[
		[
			5969,
			4527
		],
		[
			-5,
			7
		]
	],
	[
		[
			5964,
			4536
		],
		[
			-4,
			14
		],
		[
			2,
			20
		],
		[
			-2,
			4
		],
		[
			-1,
			30
		],
		[
			-7,
			20
		]
	],
	[
		[
			5949,
			4630
		],
		[
			-3,
			4
		]
	],
	[
		[
			5946,
			4635
		],
		[
			-4,
			-2
		],
		[
			-1,
			-10
		]
	],
	[
		[
			5914,
			4641
		],
		[
			-12,
			10
		],
		[
			-3,
			6
		],
		[
			-13,
			6
		],
		[
			-6,
			6
		],
		[
			-4,
			13
		],
		[
			-11,
			6
		]
	],
	[
		[
			5865,
			4688
		],
		[
			0,
			10
		],
		[
			-4,
			5
		],
		[
			-1,
			11
		],
		[
			-11,
			36
		],
		[
			1,
			11
		],
		[
			-3,
			8
		],
		[
			2,
			12
		],
		[
			-5,
			9
		],
		[
			-7,
			21
		],
		[
			-6,
			-1
		],
		[
			-6,
			12
		],
		[
			0,
			13
		],
		[
			6,
			7
		],
		[
			-5,
			32
		],
		[
			1,
			21
		],
		[
			-6,
			5
		],
		[
			2,
			27
		]
	],
	[
		[
			5846,
			5121
		],
		[
			10,
			4
		],
		[
			26,
			0
		]
	],
	[
		[
			5883,
			5125
		],
		[
			1,
			0
		]
	],
	[
		[
			5944,
			5197
		],
		[
			-8,
			-3
		],
		[
			1,
			8
		],
		[
			-8,
			-8
		],
		[
			-3,
			15
		],
		[
			-5,
			-3
		],
		[
			-2,
			-12
		],
		[
			-6,
			-7
		],
		[
			0,
			7
		],
		[
			-6,
			-6
		],
		[
			0,
			10
		],
		[
			-8,
			-17
		],
		[
			-9,
			0
		],
		[
			-4,
			-9
		],
		[
			3,
			-7
		],
		[
			-9,
			-26
		],
		[
			2,
			-14
		]
	],
	[
		[
			5823,
			5155
		],
		[
			5,
			6
		],
		[
			2,
			14
		],
		[
			-6,
			2
		]
	],
	[
		[
			5846,
			5254
		],
		[
			4,
			-12
		],
		[
			9,
			28
		],
		[
			10,
			11
		],
		[
			3,
			11
		],
		[
			-1,
			25
		],
		[
			-3,
			-9
		]
	],
	[
		[
			6061,
			7895
		],
		[
			-18,
			0
		],
		[
			-6,
			-11
		],
		[
			-4,
			2
		],
		[
			-12,
			-13
		],
		[
			-4,
			3
		],
		[
			-22,
			-8
		],
		[
			-14,
			-18
		],
		[
			-4,
			3
		],
		[
			-11,
			-12
		],
		[
			4,
			-22
		],
		[
			15,
			-28
		],
		[
			18,
			10
		],
		[
			13,
			-3
		],
		[
			-5,
			-9
		],
		[
			1,
			-11
		],
		[
			-17,
			-4
		],
		[
			-9,
			7
		],
		[
			-4,
			-10
		],
		[
			-23,
			-12
		],
		[
			-12,
			-18
		],
		[
			-10,
			-2
		],
		[
			-11,
			11
		],
		[
			5,
			5
		],
		[
			1,
			24
		],
		[
			-8,
			3
		],
		[
			-11,
			13
		],
		[
			-9,
			-2
		],
		[
			-1,
			8
		],
		[
			24,
			21
		],
		[
			8,
			2
		],
		[
			-1,
			14
		],
		[
			-6,
			-3
		],
		[
			-5,
			10
		],
		[
			-3,
			-6
		],
		[
			-18,
			-3
		],
		[
			-17,
			14
		],
		[
			4,
			8
		],
		[
			-7,
			6
		],
		[
			17,
			-5
		],
		[
			4,
			9
		],
		[
			-11,
			-4
		],
		[
			-6,
			5
		],
		[
			-25,
			-2
		],
		[
			-24,
			-46
		],
		[
			-5,
			1
		],
		[
			-10,
			-23
		],
		[
			4,
			2
		],
		[
			-3,
			-14
		]
	],
	[
		[
			5836,
			7853
		],
		[
			9,
			-17
		],
		[
			2,
			3
		],
		[
			-11,
			14
		]
	],
	[
		[
			5948,
			7848
		],
		[
			0,
			-9
		],
		[
			-11,
			7
		],
		[
			3,
			-13
		],
		[
			4,
			5
		],
		[
			21,
			-17
		],
		[
			6,
			-8
		],
		[
			4,
			-20
		],
		[
			9,
			-4
		],
		[
			-12,
			23
		],
		[
			-7,
			26
		],
		[
			-10,
			-6
		],
		[
			-7,
			16
		]
	],
	[
		[
			3523,
			3302
		],
		[
			-5,
			-5
		],
		[
			0,
			-12
		],
		[
			-8,
			-5
		],
		[
			3,
			-30
		]
	],
	[
		[
			3517,
			3240
		],
		[
			-4,
			-18
		],
		[
			-7,
			-13
		],
		[
			0,
			-7
		],
		[
			-13,
			-16
		],
		[
			-20,
			-17
		],
		[
			-12,
			10
		],
		[
			-14,
			0
		],
		[
			-7,
			-8
		],
		[
			-20,
			15
		],
		[
			-8,
			13
		],
		[
			-18,
			-1
		],
		[
			-16,
			29
		],
		[
			-2,
			10
		],
		[
			3,
			27
		],
		[
			-1,
			10
		],
		[
			9,
			9
		],
		[
			-4,
			31
		]
	],
	[
		[
			677,
			6342
		],
		[
			13,
			-11
		],
		[
			2,
			-12
		],
		[
			8,
			-13
		],
		[
			-6,
			-10
		],
		[
			-16,
			-13
		],
		[
			-3,
			-11
		],
		[
			-7,
			9
		],
		[
			1,
			15
		],
		[
			-4,
			25
		],
		[
			5,
			12
		],
		[
			-1,
			17
		],
		[
			8,
			-8
		]
	],
	[
		[
			649,
			6394
		],
		[
			3,
			-7
		],
		[
			7,
			2
		],
		[
			8,
			-8
		],
		[
			0,
			-7
		],
		[
			-9,
			-6
		],
		[
			-4,
			2
		],
		[
			0,
			10
		],
		[
			-7,
			7
		],
		[
			2,
			7
		]
	],
	[
		[
			631,
			6405
		],
		[
			16,
			-4
		],
		[
			-2,
			-5
		],
		[
			-15,
			2
		],
		[
			1,
			7
		]
	],
	[
		[
			613,
			6427
		],
		[
			6,
			-8
		],
		[
			1,
			-12
		],
		[
			-13,
			2
		],
		[
			-3,
			14
		],
		[
			7,
			10
		],
		[
			2,
			-6
		]
	],
	[
		[
			571,
			6463
		],
		[
			4,
			-3
		],
		[
			-1,
			-14
		],
		[
			-8,
			-3
		],
		[
			-6,
			11
		],
		[
			11,
			9
		]
	],
	[
		[
			2301,
			6687
		],
		[
			-6,
			35
		],
		[
			0,
			12
		],
		[
			6,
			-47
		]
	],
	[
		[
			2761,
			6828
		],
		[
			-2,
			-18
		],
		[
			-2,
			17
		],
		[
			4,
			1
		]
	],
	[
		[
			2366,
			6873
		],
		[
			3,
			-1
		],
		[
			-11,
			-13
		],
		[
			8,
			14
		]
	],
	[
		[
			1707,
			7111
		],
		[
			7,
			-9
		],
		[
			-6,
			0
		],
		[
			-1,
			9
		]
	],
	[
		[
			1671,
			7144
		],
		[
			8,
			-4
		],
		[
			-8,
			-2
		],
		[
			0,
			6
		]
	],
	[
		[
			2993,
			7551
		],
		[
			-6,
			-11
		],
		[
			8,
			7
		],
		[
			8,
			-1
		],
		[
			-20,
			-15
		],
		[
			-36,
			-12
		],
		[
			-4,
			1
		],
		[
			4,
			11
		],
		[
			7,
			6
		],
		[
			29,
			6
		],
		[
			10,
			8
		]
	],
	[
		[
			2582,
			7791
		],
		[
			0,
			-10
		],
		[
			-7,
			-17
		],
		[
			-3,
			8
		],
		[
			10,
			19
		]
	],
	[
		[
			2679,
			7836
		],
		[
			1,
			-8
		],
		[
			-10,
			3
		],
		[
			9,
			5
		]
	],
	[
		[
			2563,
			7913
		],
		[
			-19,
			-17
		],
		[
			-6,
			0
		],
		[
			5,
			14
		],
		[
			8,
			6
		],
		[
			12,
			-3
		]
	],
	[
		[
			2541,
			7956
		],
		[
			-2,
			-6
		],
		[
			-15,
			-14
		],
		[
			0,
			8
		],
		[
			17,
			12
		]
	],
	[
		[
			1595,
			7969
		],
		[
			-3,
			-9
		],
		[
			8,
			-13
		],
		[
			-1,
			-5
		],
		[
			-9,
			17
		],
		[
			5,
			10
		]
	],
	[
		[
			1582,
			8004
		],
		[
			-1,
			0
		]
	],
	[
		[
			2511,
			7947
		],
		[
			-14,
			-11
		],
		[
			-19,
			-11
		],
		[
			-20,
			-29
		],
		[
			-17,
			-21
		],
		[
			9,
			-3
		],
		[
			22,
			14
		],
		[
			6,
			0
		],
		[
			-5,
			-19
		],
		[
			14,
			-2
		],
		[
			11,
			5
		],
		[
			7,
			9
		],
		[
			14,
			4
		],
		[
			10,
			7
		],
		[
			7,
			13
		],
		[
			7,
			-14
		],
		[
			-1,
			-10
		],
		[
			10,
			6
		],
		[
			9,
			-1
		],
		[
			12,
			-22
		],
		[
			11,
			0
		],
		[
			9,
			-4
		],
		[
			14,
			14
		],
		[
			18,
			-2
		],
		[
			13,
			6
		],
		[
			0,
			-17
		],
		[
			15,
			-1
		]
	],
	[
		[
			2663,
			7852
		],
		[
			-3,
			-10
		],
		[
			9,
			-12
		],
		[
			-16,
			1
		],
		[
			-5,
			4
		],
		[
			-2,
			-11
		],
		[
			-7,
			9
		],
		[
			-15,
			5
		],
		[
			-3,
			-7
		],
		[
			-25,
			-7
		],
		[
			-13,
			0
		],
		[
			-15,
			-39
		],
		[
			-3,
			-12
		],
		[
			-10,
			-17
		],
		[
			2,
			-8
		],
		[
			10,
			17
		],
		[
			7,
			-3
		],
		[
			-11,
			-49
		],
		[
			1,
			-13
		],
		[
			-6,
			-26
		],
		[
			0,
			-14
		],
		[
			4,
			-15
		],
		[
			-2,
			-28
		],
		[
			9,
			-33
		],
		[
			8,
			-4
		],
		[
			16,
			14
		],
		[
			7,
			22
		],
		[
			5,
			26
		],
		[
			0,
			15
		],
		[
			-9,
			37
		],
		[
			3,
			10
		],
		[
			-3,
			17
		],
		[
			8,
			20
		],
		[
			0,
			14
		],
		[
			5,
			15
		],
		[
			7,
			2
		],
		[
			7,
			15
		],
		[
			-3,
			-22
		],
		[
			4,
			-4
		],
		[
			4,
			14
		],
		[
			0,
			16
		],
		[
			11,
			5
		],
		[
			-3,
			15
		],
		[
			9,
			10
		],
		[
			13,
			-8
		],
		[
			6,
			-11
		],
		[
			16,
			-7
		],
		[
			6,
			-13
		],
		[
			-4,
			-11
		],
		[
			4,
			-6
		],
		[
			-1,
			-28
		],
		[
			-6,
			-5
		],
		[
			-1,
			-13
		],
		[
			-7,
			-2
		],
		[
			-3,
			-18
		],
		[
			6,
			-5
		],
		[
			7,
			6
		],
		[
			6,
			16
		],
		[
			9,
			5
		],
		[
			7,
			-10
		],
		[
			4,
			-37
		],
		[
			3,
			-14
		]
	],
	[
		[
			2704,
			7634
		],
		[
			-5,
			5
		],
		[
			-3,
			-17
		],
		[
			-6,
			-8
		],
		[
			-3,
			-17
		],
		[
			-6,
			-12
		],
		[
			15,
			-11
		],
		[
			7,
			0
		],
		[
			5,
			-7
		],
		[
			9,
			4
		],
		[
			14,
			3
		],
		[
			9,
			12
		],
		[
			24,
			15
		],
		[
			26,
			21
		],
		[
			14,
			21
		],
		[
			5,
			2
		],
		[
			-1,
			17
		],
		[
			-5,
			3
		]
	],
	[
		[
			2804,
			7674
		],
		[
			10,
			6
		],
		[
			16,
			2
		],
		[
			13,
			-8
		],
		[
			18,
			0
		],
		[
			8,
			5
		],
		[
			15,
			19
		],
		[
			-3,
			9
		],
		[
			4,
			4
		],
		[
			-7,
			11
		],
		[
			15,
			16
		],
		[
			1,
			7
		]
	],
	[
		[
			3116,
			7818
		],
		[
			10,
			-9
		]
	],
	[
		[
			3134,
			7784
		],
		[
			3,
			-9
		],
		[
			-3,
			-20
		],
		[
			-20,
			-16
		],
		[
			-6,
			5
		],
		[
			-13,
			-5
		],
		[
			1,
			-9
		],
		[
			-12,
			11
		],
		[
			-3,
			-22
		],
		[
			-14,
			-14
		],
		[
			-10,
			3
		],
		[
			-8,
			-8
		],
		[
			1,
			-9
		],
		[
			-11,
			-15
		],
		[
			-6,
			-22
		],
		[
			1,
			-15
		],
		[
			5,
			1
		],
		[
			-13,
			-19
		],
		[
			9,
			-7
		],
		[
			5,
			-23
		],
		[
			17,
			-8
		],
		[
			-14,
			-3
		],
		[
			-6,
			-6
		],
		[
			0,
			11
		],
		[
			-15,
			-14
		],
		[
			0,
			12
		],
		[
			-5,
			5
		],
		[
			-1,
			-17
		],
		[
			-12,
			-9
		],
		[
			-29,
			-2
		],
		[
			-6,
			-9
		],
		[
			-8,
			-1
		],
		[
			-23,
			-27
		],
		[
			-1,
			-10
		],
		[
			8,
			-1
		],
		[
			-2,
			-29
		],
		[
			-3,
			-14
		],
		[
			-7,
			-9
		],
		[
			-1,
			-11
		],
		[
			-12,
			-24
		],
		[
			-1,
			15
		],
		[
			-7,
			2
		],
		[
			-10,
			13
		],
		[
			3,
			-23
		],
		[
			9,
			-21
		],
		[
			1,
			-16
		],
		[
			-10,
			-31
		],
		[
			-7,
			-13
		],
		[
			-8,
			-30
		],
		[
			-2,
			11
		],
		[
			4,
			20
		],
		[
			6,
			17
		],
		[
			-6,
			-2
		],
		[
			1,
			9
		],
		[
			-13,
			21
		],
		[
			-1,
			17
		],
		[
			4,
			11
		],
		[
			-2,
			15
		],
		[
			11,
			15
		],
		[
			-5,
			0
		],
		[
			-11,
			-10
		],
		[
			2,
			-16
		],
		[
			-4,
			-6
		],
		[
			0,
			-23
		],
		[
			4,
			-6
		],
		[
			1,
			-20
		],
		[
			-9,
			11
		],
		[
			-8,
			-2
		],
		[
			9,
			-4
		],
		[
			11,
			-13
		],
		[
			-2,
			-17
		],
		[
			-6,
			3
		],
		[
			8,
			-12
		],
		[
			-7,
			-12
		],
		[
			6,
			-8
		],
		[
			-4,
			-8
		],
		[
			12,
			-4
		],
		[
			5,
			-35
		],
		[
			7,
			-23
		],
		[
			-5,
			9
		],
		[
			-6,
			38
		],
		[
			-2,
			-15
		],
		[
			6,
			-17
		],
		[
			-9,
			5
		],
		[
			0,
			-7
		],
		[
			-15,
			-4
		],
		[
			-2,
			-6
		],
		[
			15,
			3
		],
		[
			13,
			-8
		],
		[
			-1,
			-17
		],
		[
			-3,
			2
		],
		[
			-5,
			-13
		],
		[
			-13,
			1
		],
		[
			-2,
			9
		],
		[
			-4,
			-8
		],
		[
			7,
			-6
		],
		[
			-2,
			-11
		],
		[
			-11,
			-8
		],
		[
			17,
			-2
		],
		[
			-7,
			-11
		],
		[
			-15,
			-4
		],
		[
			-15,
			-18
		],
		[
			-9,
			-27
		],
		[
			-11,
			1
		],
		[
			-13,
			-12
		],
		[
			-5,
			-10
		],
		[
			-4,
			-21
		],
		[
			-22,
			-32
		],
		[
			-14,
			-8
		],
		[
			1,
			-8
		],
		[
			-12,
			-15
		],
		[
			1,
			-5
		],
		[
			-11,
			-14
		],
		[
			-3,
			-12
		],
		[
			2,
			-18
		],
		[
			-4,
			-5
		],
		[
			-3,
			-19
		],
		[
			8,
			-63
		],
		[
			9,
			-38
		],
		[
			9,
			-26
		],
		[
			-5,
			0
		],
		[
			0,
			-10
		],
		[
			18,
			-75
		],
		[
			3,
			-31
		],
		[
			-2,
			-12
		],
		[
			-1,
			-28
		],
		[
			-4,
			-11
		],
		[
			-4,
			-29
		],
		[
			-12,
			-1
		],
		[
			-7,
			-4
		],
		[
			0,
			14
		],
		[
			-6,
			25
		],
		[
			-6,
			7
		],
		[
			-6,
			0
		],
		[
			-3,
			31
		],
		[
			-6,
			5
		],
		[
			0,
			20
		],
		[
			-7,
			-2
		],
		[
			-6,
			21
		],
		[
			-3,
			18
		],
		[
			7,
			15
		],
		[
			-1,
			8
		],
		[
			-7,
			6
		],
		[
			0,
			-19
		],
		[
			-5,
			8
		],
		[
			2,
			21
		],
		[
			4,
			14
		],
		[
			0,
			26
		],
		[
			-4,
			16
		],
		[
			-7,
			0
		],
		[
			-10,
			20
		],
		[
			-6,
			20
		],
		[
			-11,
			14
		],
		[
			-10,
			-4
		],
		[
			-10,
			-15
		],
		[
			-16,
			-5
		],
		[
			0,
			7
		],
		[
			-11,
			20
		],
		[
			-22,
			14
		],
		[
			-15,
			-1
		],
		[
			-2,
			9
		],
		[
			-4,
			-11
		],
		[
			-14,
			-5
		],
		[
			-4,
			7
		],
		[
			-1,
			16
		],
		[
			-3,
			2
		],
		[
			-2,
			-22
		],
		[
			-5,
			5
		],
		[
			-5,
			-5
		],
		[
			-10,
			6
		],
		[
			-14,
			-7
		],
		[
			-7,
			-9
		],
		[
			-11,
			7
		],
		[
			-4,
			7
		],
		[
			-8,
			-12
		],
		[
			2,
			-7
		],
		[
			10,
			-1
		],
		[
			3,
			4
		],
		[
			6,
			-14
		],
		[
			5,
			12
		],
		[
			3,
			-3
		],
		[
			-8,
			-29
		],
		[
			4,
			-8
		],
		[
			11,
			-5
		],
		[
			3,
			-9
		],
		[
			-4,
			-9
		],
		[
			-3,
			10
		],
		[
			-15,
			9
		],
		[
			2,
			4
		],
		[
			-12,
			11
		],
		[
			4,
			-9
		],
		[
			-2,
			-16
		],
		[
			-10,
			12
		],
		[
			-8,
			-14
		],
		[
			-15,
			9
		],
		[
			0,
			13
		],
		[
			-7,
			3
		],
		[
			-3,
			12
		],
		[
			-6,
			5
		],
		[
			-9,
			-8
		],
		[
			4,
			-6
		],
		[
			-13,
			-2
		],
		[
			-21,
			13
		],
		[
			-16,
			-5
		],
		[
			2,
			17
		],
		[
			-8,
			-18
		],
		[
			-17,
			-13
		],
		[
			-1,
			19
		],
		[
			-8,
			-5
		],
		[
			-1,
			-9
		],
		[
			4,
			-12
		],
		[
			-8,
			-12
		],
		[
			1,
			-4
		],
		[
			-14,
			-18
		],
		[
			-16,
			-9
		],
		[
			-12,
			8
		],
		[
			1,
			-9
		],
		[
			6,
			-8
		],
		[
			-7,
			-6
		],
		[
			-5,
			6
		],
		[
			1,
			-12
		],
		[
			-12,
			-8
		],
		[
			1,
			-14
		],
		[
			-7,
			-33
		],
		[
			-3,
			-26
		],
		[
			7,
			-32
		],
		[
			1,
			-16
		],
		[
			3,
			-1
		]
	],
	[
		[
			2245,
			6713
		],
		[
			1,
			7
		],
		[
			-9,
			21
		]
	],
	[
		[
			2193,
			6879
		],
		[
			-7,
			10
		]
	],
	[
		[
			1746,
			7056
		],
		[
			-4,
			10
		],
		[
			-2,
			27
		],
		[
			-8,
			16
		],
		[
			-15,
			18
		],
		[
			-6,
			2
		],
		[
			-3,
			12
		],
		[
			-9,
			0
		],
		[
			-10,
			6
		],
		[
			-10,
			18
		],
		[
			-21,
			3
		],
		[
			-9,
			5
		],
		[
			0,
			33
		],
		[
			-7,
			5
		],
		[
			0,
			12
		],
		[
			-12,
			15
		],
		[
			-5,
			18
		],
		[
			-9,
			13
		],
		[
			-4,
			23
		],
		[
			5,
			9
		],
		[
			-3,
			11
		],
		[
			-6,
			-1
		],
		[
			-8,
			13
		],
		[
			-3,
			21
		],
		[
			3,
			5
		],
		[
			9,
			-11
		],
		[
			-10,
			29
		],
		[
			8,
			6
		],
		[
			-7,
			6
		],
		[
			-2,
			-19
		],
		[
			-16,
			13
		],
		[
			5,
			3
		],
		[
			-7,
			20
		],
		[
			-7,
			6
		],
		[
			-10,
			20
		],
		[
			1,
			10
		],
		[
			-4,
			16
		],
		[
			2,
			10
		],
		[
			-2,
			15
		],
		[
			-7,
			17
		],
		[
			-8,
			9
		],
		[
			0,
			19
		],
		[
			8,
			15
		],
		[
			-2,
			17
		],
		[
			3,
			16
		],
		[
			-2,
			16
		],
		[
			-5,
			5
		],
		[
			3,
			12
		],
		[
			-5,
			8
		],
		[
			-1,
			32
		],
		[
			-5,
			10
		],
		[
			9,
			41
		],
		[
			4,
			25
		],
		[
			2,
			52
		],
		[
			2,
			11
		],
		[
			1,
			62
		],
		[
			13,
			7
		],
		[
			-14,
			-2
		],
		[
			1,
			29
		],
		[
			-4,
			-2
		],
		[
			6,
			13
		],
		[
			-7,
			6
		],
		[
			-10,
			44
		],
		[
			-7,
			20
		],
		[
			6,
			11
		],
		[
			15,
			-11
		],
		[
			24,
			0
		],
		[
			7,
			-6
		],
		[
			4,
			-14
		],
		[
			-9,
			-15
		],
		[
			12,
			8
		],
		[
			2,
			-20
		],
		[
			-7,
			-10
		],
		[
			2,
			-4
		],
		[
			10,
			14
		],
		[
			-1,
			29
		],
		[
			5,
			8
		],
		[
			-5,
			18
		],
		[
			-9,
			6
		],
		[
			8,
			12
		],
		[
			-10,
			16
		],
		[
			1,
			6
		]
	],
	[
		[
			60,
			8169
		],
		[
			1,
			-9
		],
		[
			-11,
			9
		],
		[
			10,
			0
		]
	],
	[
		[
			80,
			8161
		],
		[
			-11,
			0
		],
		[
			12,
			11
		],
		[
			-1,
			-11
		]
	],
	[
		[
			96,
			8175
		],
		[
			2,
			-14
		],
		[
			-10,
			0
		],
		[
			1,
			14
		],
		[
			7,
			0
		]
	],
	[
		[
			177,
			8186
		],
		[
			18,
			-5
		],
		[
			-12,
			-3
		],
		[
			-15,
			5
		],
		[
			9,
			3
		]
	],
	[
		[
			162,
			8200
		],
		[
			5,
			-4
		],
		[
			-4,
			-12
		],
		[
			-7,
			-4
		],
		[
			-27,
			-2
		],
		[
			22,
			6
		],
		[
			9,
			7
		],
		[
			-7,
			4
		],
		[
			9,
			5
		]
	],
	[
		[
			9827,
			8206
		],
		[
			-2,
			-8
		],
		[
			-9,
			2
		],
		[
			11,
			6
		]
	],
	[
		[
			9802,
			8235
		],
		[
			12,
			-10
		],
		[
			-11,
			-5
		],
		[
			-1,
			15
		]
	],
	[
		[
			332,
			8268
		],
		[
			5,
			-12
		],
		[
			-32,
			-29
		],
		[
			11,
			24
		],
		[
			7,
			1
		],
		[
			-1,
			9
		],
		[
			10,
			7
		]
	],
	[
		[
			367,
			8291
		],
		[
			6,
			-8
		],
		[
			9,
			8
		],
		[
			-9,
			-15
		],
		[
			8,
			1
		],
		[
			-14,
			-16
		],
		[
			-4,
			1
		],
		[
			-20,
			-13
		],
		[
			-6,
			4
		],
		[
			19,
			9
		],
		[
			1,
			25
		],
		[
			10,
			4
		]
	],
	[
		[
			391,
			8303
		],
		[
			7,
			-5
		],
		[
			-10,
			-3
		],
		[
			3,
			8
		]
	],
	[
		[
			451,
			8354
		],
		[
			5,
			-1
		],
		[
			6,
			-16
		],
		[
			-8,
			-9
		],
		[
			-16,
			0
		],
		[
			-4,
			-9
		],
		[
			-14,
			-3
		],
		[
			-3,
			11
		],
		[
			7,
			3
		],
		[
			10,
			16
		],
		[
			3,
			-2
		],
		[
			14,
			10
		]
	],
	[
		[
			1304,
			8361
		],
		[
			8,
			-30
		],
		[
			-14,
			25
		],
		[
			6,
			5
		]
	],
	[
		[
			558,
			8363
		],
		[
			-9,
			-20
		],
		[
			4,
			19
		],
		[
			5,
			1
		]
	],
	[
		[
			1355,
			8404
		],
		[
			7,
			-16
		],
		[
			-1,
			-16
		],
		[
			-6,
			-11
		],
		[
			-13,
			9
		],
		[
			-5,
			8
		],
		[
			5,
			20
		],
		[
			13,
			6
		]
	],
	[
		[
			1295,
			8417
		],
		[
			2,
			-9
		],
		[
			-14,
			-4
		],
		[
			5,
			11
		],
		[
			7,
			2
		]
	],
	[
		[
			1319,
			8419
		],
		[
			9,
			-1
		],
		[
			0,
			-12
		],
		[
			-13,
			5
		],
		[
			4,
			8
		]
	],
	[
		[
			1289,
			8428
		],
		[
			10,
			-1
		],
		[
			4,
			-16
		],
		[
			13,
			-7
		],
		[
			9,
			-30
		],
		[
			9,
			-9
		],
		[
			-1,
			-33
		],
		[
			-16,
			17
		],
		[
			2,
			8
		],
		[
			-21,
			10
		],
		[
			8,
			20
		],
		[
			-11,
			-1
		],
		[
			6,
			13
		],
		[
			-3,
			17
		],
		[
			-9,
			2
		],
		[
			0,
			10
		]
	],
	[
		[
			1315,
			8433
		],
		[
			-5,
			-12
		],
		[
			-6,
			8
		],
		[
			11,
			4
		]
	],
	[
		[
			1328,
			8428
		],
		[
			4,
			-13
		],
		[
			-9,
			9
		],
		[
			0,
			12
		],
		[
			5,
			-8
		]
	],
	[
		[
			1308,
			8454
		],
		[
			9,
			-14
		],
		[
			-10,
			-3
		],
		[
			1,
			17
		]
	],
	[
		[
			1278,
			8457
		],
		[
			7,
			-4
		],
		[
			1,
			-11
		],
		[
			-6,
			-6
		],
		[
			-6,
			-28
		],
		[
			-3,
			4
		],
		[
			0,
			20
		],
		[
			-4,
			26
		],
		[
			11,
			-1
		]
	],
	[
		[
			1283,
			8470
		],
		[
			24,
			-10
		],
		[
			-2,
			-17
		],
		[
			-9,
			13
		],
		[
			7,
			-18
		],
		[
			-16,
			-4
		],
		[
			0,
			23
		],
		[
			-10,
			9
		],
		[
			6,
			4
		]
	],
	[
		[
			745,
			8475
		],
		[
			8,
			0
		],
		[
			-14,
			-10
		],
		[
			6,
			10
		]
	],
	[
		[
			1234,
			8479
		],
		[
			-1,
			-12
		],
		[
			-6,
			-2
		],
		[
			-1,
			19
		],
		[
			8,
			-5
		]
	],
	[
		[
			1237,
			8491
		],
		[
			8,
			2
		],
		[
			9,
			-14
		],
		[
			7,
			-29
		],
		[
			-1,
			-30
		],
		[
			-5,
			0
		],
		[
			-13,
			33
		],
		[
			-1,
			15
		],
		[
			-10,
			18
		],
		[
			6,
			5
		]
	],
	[
		[
			749,
			8519
		],
		[
			11,
			0
		],
		[
			7,
			-8
		],
		[
			-2,
			-10
		],
		[
			8,
			0
		],
		[
			-4,
			-10
		],
		[
			-18,
			4
		],
		[
			10,
			-7
		],
		[
			-18,
			-9
		],
		[
			-14,
			-22
		],
		[
			-10,
			-6
		],
		[
			6,
			10
		],
		[
			-12,
			-1
		],
		[
			-12,
			22
		],
		[
			3,
			14
		],
		[
			7,
			7
		],
		[
			10,
			0
		],
		[
			7,
			-19
		],
		[
			-4,
			28
		],
		[
			5,
			5
		],
		[
			16,
			-5
		],
		[
			-3,
			10
		],
		[
			7,
			-3
		]
	],
	[
		[
			1229,
			8536
		],
		[
			23,
			-12
		],
		[
			-1,
			-13
		],
		[
			-7,
			-1
		],
		[
			-18,
			12
		],
		[
			14,
			-15
		],
		[
			13,
			1
		],
		[
			1,
			-16
		],
		[
			-7,
			0
		],
		[
			-19,
			17
		],
		[
			7,
			-17
		],
		[
			-4,
			-6
		],
		[
			-8,
			6
		],
		[
			-1,
			10
		],
		[
			-12,
			12
		],
		[
			1,
			20
		],
		[
			18,
			2
		]
	],
	[
		[
			1252,
			8544
		],
		[
			6,
			-11
		],
		[
			14,
			-6
		],
		[
			8,
			-16
		],
		[
			-2,
			-5
		],
		[
			2,
			-21
		],
		[
			-19,
			-19
		],
		[
			-1,
			12
		],
		[
			4,
			10
		],
		[
			-5,
			13
		],
		[
			-7,
			43
		]
	],
	[
		[
			761,
			8550
		],
		[
			18,
			-11
		],
		[
			-6,
			-8
		],
		[
			-18,
			-4
		],
		[
			-10,
			2
		],
		[
			1,
			9
		],
		[
			10,
			1
		],
		[
			5,
			11
		]
	],
	[
		[
			913,
			8659
		],
		[
			5,
			-3
		],
		[
			-25,
			-29
		],
		[
			20,
			32
		]
	],
	[
		[
			385,
			8661
		],
		[
			13,
			-6
		],
		[
			2,
			-22
		],
		[
			-19,
			-5
		],
		[
			-10,
			2
		],
		[
			-19,
			13
		],
		[
			-4,
			7
		],
		[
			16,
			0
		],
		[
			9,
			9
		],
		[
			12,
			2
		]
	],
	[
		[
			929,
			8665
		],
		[
			13,
			-4
		],
		[
			-15,
			-9
		],
		[
			2,
			13
		]
	],
	[
		[
			897,
			8667
		],
		[
			-2,
			-19
		],
		[
			-4,
			10
		],
		[
			6,
			9
		]
	],
	[
		[
			231,
			8857
		],
		[
			0,
			-6
		],
		[
			17,
			-7
		],
		[
			20,
			7
		],
		[
			23,
			-20
		],
		[
			21,
			-2
		],
		[
			-2,
			-9
		],
		[
			-15,
			1
		],
		[
			-9,
			-13
		],
		[
			-3,
			10
		],
		[
			-28,
			19
		],
		[
			-17,
			-8
		],
		[
			-13,
			10
		],
		[
			6,
			18
		]
	],
	[
		[
			1387,
			8402
		],
		[
			-3,
			-8
		],
		[
			4,
			-28
		],
		[
			-10,
			-21
		],
		[
			-9,
			-8
		],
		[
			-7,
			2
		],
		[
			-3,
			23
		],
		[
			6,
			6
		],
		[
			-1,
			24
		],
		[
			-15,
			16
		],
		[
			-8,
			-7
		],
		[
			-7,
			-22
		],
		[
			-9,
			13
		],
		[
			7,
			4
		],
		[
			5,
			24
		],
		[
			-18,
			22
		],
		[
			-11,
			25
		],
		[
			-19,
			8
		],
		[
			12,
			9
		],
		[
			-11,
			10
		],
		[
			-3,
			12
		],
		[
			14,
			-6
		],
		[
			-15,
			12
		],
		[
			-15,
			23
		],
		[
			-16,
			11
		],
		[
			-4,
			24
		],
		[
			-6,
			1
		],
		[
			-1,
			17
		],
		[
			-6,
			-11
		],
		[
			7,
			-17
		],
		[
			1,
			-24
		],
		[
			-13,
			11
		],
		[
			-8,
			-2
		],
		[
			2,
			13
		],
		[
			-8,
			12
		],
		[
			-3,
			-4
		],
		[
			-17,
			8
		],
		[
			19,
			-18
		],
		[
			2,
			-12
		],
		[
			-9,
			-4
		],
		[
			-20,
			5
		],
		[
			-23,
			23
		],
		[
			-9,
			16
		],
		[
			-34,
			19
		],
		[
			-11,
			9
		],
		[
			12,
			10
		],
		[
			-5,
			11
		],
		[
			-18,
			-12
		],
		[
			-9,
			0
		],
		[
			-21,
			9
		],
		[
			3,
			11
		],
		[
			-13,
			-5
		],
		[
			-31,
			8
		],
		[
			-30,
			-6
		],
		[
			-12,
			12
		],
		[
			-16,
			5
		],
		[
			3,
			18
		],
		[
			-11,
			-14
		],
		[
			-21,
			5
		],
		[
			9,
			13
		],
		[
			-18,
			-1
		],
		[
			-16,
			19
		],
		[
			-12,
			1
		],
		[
			-2,
			-7
		],
		[
			-15,
			-3
		],
		[
			-3,
			6
		],
		[
			9,
			19
		],
		[
			-17,
			-18
		],
		[
			2,
			-20
		],
		[
			8,
			-8
		],
		[
			-6,
			-3
		],
		[
			-8,
			-27
		],
		[
			-18,
			1
		],
		[
			-5,
			-5
		],
		[
			-2,
			13
		],
		[
			-12,
			-25
		],
		[
			-13,
			3
		],
		[
			-7,
			-13
		],
		[
			-19,
			-17
		],
		[
			-16,
			-2
		],
		[
			-6,
			6
		],
		[
			3,
			9
		],
		[
			19,
			10
		],
		[
			2,
			8
		],
		[
			-11,
			-6
		],
		[
			-10,
			7
		],
		[
			4,
			16
		],
		[
			8,
			10
		],
		[
			5,
			19
		],
		[
			-5,
			8
		],
		[
			27,
			21
		],
		[
			6,
			-6
		],
		[
			18,
			3
		],
		[
			-14,
			10
		],
		[
			4,
			5
		],
		[
			-19,
			4
		],
		[
			-15,
			-15
		],
		[
			-9,
			-2
		],
		[
			-20,
			-27
		],
		[
			-7,
			-16
		],
		[
			-11,
			-2
		],
		[
			9,
			-10
		],
		[
			-18,
			-24
		],
		[
			-11,
			0
		],
		[
			-4,
			-11
		],
		[
			-9,
			-5
		],
		[
			-3,
			-20
		],
		[
			10,
			3
		],
		[
			13,
			-8
		],
		[
			2,
			-6
		],
		[
			-11,
			-12
		],
		[
			-5,
			0
		],
		[
			-14,
			-31
		],
		[
			-4,
			7
		],
		[
			-2,
			-11
		],
		[
			-12,
			1
		],
		[
			-9,
			-17
		],
		[
			-9,
			2
		],
		[
			-2,
			-13
		],
		[
			-10,
			-1
		],
		[
			-14,
			-15
		],
		[
			7,
			-5
		],
		[
			-7,
			-12
		],
		[
			-5,
			4
		],
		[
			-12,
			-16
		],
		[
			-17,
			-5
		],
		[
			-2,
			-11
		],
		[
			-13,
			-1
		],
		[
			-4,
			-8
		],
		[
			7,
			-10
		],
		[
			-10,
			-4
		],
		[
			-1,
			-7
		],
		[
			-22,
			-6
		],
		[
			-5,
			-17
		],
		[
			-6,
			16
		],
		[
			-20,
			-21
		],
		[
			-10,
			2
		],
		[
			-12,
			-10
		],
		[
			-5,
			2
		],
		[
			6,
			12
		],
		[
			-10,
			1
		],
		[
			-6,
			-22
		],
		[
			-9,
			-11
		],
		[
			-12,
			8
		],
		[
			-4,
			-14
		],
		[
			-7,
			2
		],
		[
			-9,
			-9
		],
		[
			0,
			18
		],
		[
			10,
			3
		],
		[
			22,
			30
		],
		[
			12,
			12
		],
		[
			9,
			3
		],
		[
			34,
			-7
		],
		[
			-10,
			9
		],
		[
			5,
			17
		],
		[
			16,
			15
		],
		[
			24,
			17
		],
		[
			9,
			-4
		],
		[
			-1,
			15
		],
		[
			10,
			16
		],
		[
			18,
			15
		],
		[
			2,
			46
		],
		[
			12,
			18
		],
		[
			5,
			16
		],
		[
			-8,
			-7
		],
		[
			-25,
			-13
		],
		[
			-11,
			12
		],
		[
			1,
			10
		],
		[
			-9,
			-10
		],
		[
			4,
			-20
		],
		[
			-11,
			-2
		],
		[
			-14,
			29
		],
		[
			-8,
			-10
		],
		[
			-12,
			17
		],
		[
			-19,
			-11
		],
		[
			-20,
			-18
		],
		[
			-11,
			4
		],
		[
			11,
			7
		],
		[
			-1,
			13
		],
		[
			6,
			7
		],
		[
			-12,
			2
		],
		[
			0,
			15
		],
		[
			7,
			6
		],
		[
			-20,
			46
		],
		[
			-1,
			-17
		],
		[
			-16,
			-8
		],
		[
			-23,
			-4
		],
		[
			-9,
			6
		],
		[
			-13,
			23
		],
		[
			-19,
			12
		],
		[
			20,
			19
		],
		[
			18,
			-3
		],
		[
			7,
			-12
		],
		[
			9,
			7
		],
		[
			-4,
			7
		],
		[
			-29,
			2
		],
		[
			-20,
			20
		],
		[
			-7,
			-6
		],
		[
			-9,
			14
		],
		[
			0,
			21
		],
		[
			-6,
			7
		],
		[
			15,
			2
		],
		[
			-4,
			13
		],
		[
			18,
			26
		],
		[
			8,
			-3
		],
		[
			-3,
			14
		],
		[
			5,
			17
		],
		[
			11,
			0
		],
		[
			-8,
			7
		],
		[
			7,
			5
		],
		[
			17,
			0
		],
		[
			2,
			-11
		],
		[
			17,
			1
		],
		[
			20,
			24
		],
		[
			25,
			-1
		],
		[
			18,
			17
		],
		[
			-6,
			30
		],
		[
			-13,
			9
		],
		[
			10,
			4
		],
		[
			9,
			13
		],
		[
			-10,
			12
		],
		[
			-41,
			-24
		],
		[
			-17,
			-5
		],
		[
			-12,
			9
		],
		[
			-18,
			0
		],
		[
			-19,
			-8
		],
		[
			-33,
			8
		],
		[
			-8,
			6
		],
		[
			3,
			12
		],
		[
			-11,
			10
		],
		[
			7,
			9
		],
		[
			13,
			2
		],
		[
			-38,
			8
		],
		[
			-18,
			10
		],
		[
			37,
			28
		],
		[
			24,
			9
		],
		[
			16,
			13
		],
		[
			16,
			7
		],
		[
			29,
			2
		],
		[
			-7,
			-11
		],
		[
			7,
			-19
		],
		[
			26,
			2
		],
		[
			24,
			-8
		],
		[
			11,
			18
		],
		[
			13,
			-3
		],
		[
			-13,
			10
		],
		[
			-11,
			-2
		],
		[
			-2,
			11
		],
		[
			-15,
			10
		],
		[
			-5,
			9
		],
		[
			9,
			3
		],
		[
			7,
			-17
		],
		[
			12,
			-11
		],
		[
			10,
			4
		],
		[
			14,
			-9
		],
		[
			16,
			2
		],
		[
			-3,
			14
		],
		[
			-23,
			0
		],
		[
			-9,
			-7
		],
		[
			-10,
			10
		],
		[
			2,
			20
		],
		[
			-23,
			-2
		],
		[
			-30,
			5
		],
		[
			-10,
			27
		],
		[
			-34,
			25
		],
		[
			-20,
			9
		],
		[
			-16,
			11
		],
		[
			9,
			17
		],
		[
			0,
			14
		],
		[
			16,
			-2
		],
		[
			37,
			4
		],
		[
			19,
			11
		],
		[
			15,
			16
		],
		[
			2,
			19
		],
		[
			29,
			33
		],
		[
			26,
			0
		],
		[
			45,
			27
		],
		[
			39,
			4
		],
		[
			21,
			14
		],
		[
			12,
			13
		],
		[
			33,
			-7
		],
		[
			-12,
			-12
		],
		[
			11,
			-6
		],
		[
			16,
			16
		],
		[
			13,
			-7
		],
		[
			2,
			-12
		],
		[
			19,
			5
		],
		[
			38,
			-1
		],
		[
			9,
			-4
		],
		[
			-12,
			-15
		],
		[
			24,
			0
		],
		[
			-6,
			-6
		],
		[
			32,
			3
		],
		[
			11,
			-5
		],
		[
			30,
			5
		],
		[
			31,
			-8
		],
		[
			27,
			-11
		],
		[
			40,
			0
		],
		[
			30,
			-12
		],
		[
			40,
			9
		],
		[
			52,
			-27
		],
		[
			12,
			0
		]
	],
	[
		[
			2912,
			6333
		],
		[
			-2,
			-4
		]
	],
	[
		[
			2914,
			6329
		],
		[
			-1,
			4
		]
	],
	[
		[
			6651,
			7782
		],
		[
			-7,
			-26
		],
		[
			12,
			-19
		],
		[
			-3,
			-12
		],
		[
			11,
			5
		],
		[
			3,
			8
		],
		[
			-2,
			16
		],
		[
			3,
			11
		]
	],
	[
		[
			6601,
			7610
		],
		[
			-7,
			11
		],
		[
			-5,
			-2
		],
		[
			-4,
			-22
		]
	],
	[
		[
			6627,
			7805
		],
		[
			-10,
			-35
		],
		[
			2,
			-18
		],
		[
			4,
			-10
		],
		[
			9,
			17
		],
		[
			-3,
			20
		],
		[
			3,
			6
		],
		[
			-1,
			16
		]
	],
	[
		[
			3301,
			5940
		],
		[
			-4,
			4
		],
		[
			5,
			8
		],
		[
			-1,
			-12
		]
	],
	[
		[
			3313,
			5694
		],
		[
			1,
			-6
		],
		[
			-5,
			-8
		],
		[
			-9,
			-2
		],
		[
			1,
			7
		],
		[
			12,
			9
		]
	],
	[
		[
			3303,
			5691
		],
		[
			4,
			12
		],
		[
			2,
			-5
		],
		[
			-6,
			-7
		]
	],
	[
		[
			3228,
			5816
		],
		[
			-8,
			-8
		],
		[
			-9,
			6
		],
		[
			4,
			7
		],
		[
			6,
			-5
		],
		[
			4,
			10
		],
		[
			3,
			-10
		]
	],
	[
		[
			3018,
			5865
		],
		[
			-3,
			-7
		],
		[
			-14,
			-7
		],
		[
			0,
			-13
		],
		[
			10,
			-38
		],
		[
			-1,
			-16
		],
		[
			-4,
			-6
		],
		[
			-10,
			-30
		],
		[
			5,
			-18
		],
		[
			6,
			-7
		],
		[
			-1,
			-15
		],
		[
			6,
			-5
		],
		[
			9,
			7
		],
		[
			5,
			10
		],
		[
			-1,
			32
		],
		[
			-11,
			30
		],
		[
			-2,
			23
		],
		[
			3,
			10
		],
		[
			4,
			0
		],
		[
			12,
			13
		],
		[
			18,
			8
		],
		[
			5,
			9
		],
		[
			8,
			-2
		],
		[
			-2,
			13
		],
		[
			-11,
			-5
		],
		[
			-2,
			13
		],
		[
			2,
			16
		],
		[
			5,
			5
		],
		[
			6,
			-10
		],
		[
			2,
			-22
		],
		[
			4,
			-10
		],
		[
			12,
			3
		],
		[
			15,
			-10
		],
		[
			7,
			-12
		],
		[
			4,
			-15
		],
		[
			-2,
			-7
		],
		[
			5,
			-15
		],
		[
			8,
			-1
		],
		[
			17,
			4
		],
		[
			6,
			4
		],
		[
			21,
			2
		],
		[
			11,
			-20
		],
		[
			11,
			-9
		],
		[
			11,
			-5
		],
		[
			8,
			2
		],
		[
			4,
			9
		],
		[
			5,
			0
		],
		[
			2,
			8
		],
		[
			20,
			5
		],
		[
			-5,
			5
		],
		[
			-9,
			1
		],
		[
			10,
			6
		],
		[
			7,
			-3
		],
		[
			11,
			6
		],
		[
			12,
			1
		],
		[
			16,
			-4
		],
		[
			8,
			4
		],
		[
			-2,
			-6
		],
		[
			-10,
			-6
		],
		[
			-16,
			0
		],
		[
			1,
			-9
		],
		[
			5,
			-5
		],
		[
			1,
			-12
		],
		[
			-9,
			-1
		],
		[
			5,
			-4
		],
		[
			8,
			8
		],
		[
			5,
			-25
		],
		[
			2,
			17
		],
		[
			11,
			-10
		],
		[
			7,
			-3
		],
		[
			-2,
			7
		],
		[
			13,
			-19
		],
		[
			4,
			1
		],
		[
			7,
			-12
		],
		[
			-9,
			-24
		],
		[
			-3,
			-22
		],
		[
			-12,
			0
		],
		[
			10,
			-11
		],
		[
			3,
			6
		],
		[
			14,
			6
		],
		[
			6,
			-4
		],
		[
			3,
			6
		],
		[
			9,
			-4
		]
	],
	[
		[
			7888,
			5785
		],
		[
			0,
			-17
		],
		[
			-4,
			12
		],
		[
			4,
			5
		]
	],
	[
		[
			7999,
			6420
		],
		[
			-7,
			1
		],
		[
			-4,
			-12
		],
		[
			-7,
			-3
		],
		[
			1,
			-12
		],
		[
			-6,
			-6
		],
		[
			-5,
			4
		],
		[
			-9,
			-2
		],
		[
			4,
			-16
		],
		[
			-8,
			-8
		],
		[
			2,
			-17
		],
		[
			-7,
			-4
		],
		[
			-4,
			-11
		],
		[
			-7,
			-4
		],
		[
			-3,
			-15
		],
		[
			-1,
			-23
		],
		[
			-5,
			-13
		],
		[
			7,
			-30
		],
		[
			7,
			-15
		],
		[
			11,
			-17
		],
		[
			-1,
			-15
		],
		[
			8,
			-21
		],
		[
			9,
			-14
		],
		[
			4,
			-12
		],
		[
			16,
			-29
		],
		[
			6,
			-2
		],
		[
			16,
			-47
		],
		[
			8,
			-11
		],
		[
			1,
			-21
		],
		[
			5,
			-18
		],
		[
			-2,
			-5
		],
		[
			6,
			-25
		],
		[
			0,
			-35
		],
		[
			2,
			-3
		],
		[
			0,
			-23
		],
		[
			3,
			-13
		],
		[
			-6,
			-10
		],
		[
			0,
			-42
		],
		[
			-3,
			-5
		],
		[
			4,
			-7
		],
		[
			-4,
			-10
		],
		[
			-2,
			4
		],
		[
			0,
			-16
		],
		[
			-7,
			-2
		],
		[
			-2,
			-8
		],
		[
			-4,
			0
		],
		[
			-8,
			-14
		],
		[
			-6,
			-1
		],
		[
			-2,
			-13
		],
		[
			-5,
			0
		],
		[
			-11,
			-13
		],
		[
			-13,
			0
		],
		[
			-5,
			12
		],
		[
			1,
			-23
		],
		[
			-11,
			2
		],
		[
			11,
			-9
		],
		[
			-4,
			-11
		],
		[
			-6,
			4
		],
		[
			7,
			-11
		],
		[
			-3,
			-2
		],
		[
			-12,
			24
		],
		[
			0,
			-5
		],
		[
			10,
			-18
		],
		[
			2,
			-11
		],
		[
			-5,
			-6
		],
		[
			-10,
			15
		],
		[
			4,
			-19
		],
		[
			-1,
			-6
		],
		[
			-17,
			-13
		],
		[
			-12,
			-29
		],
		[
			-11,
			-2
		],
		[
			5,
			9
		],
		[
			-2,
			10
		],
		[
			0,
			36
		],
		[
			2,
			17
		],
		[
			6,
			7
		],
		[
			-10,
			15
		],
		[
			-5,
			-5
		],
		[
			-3,
			16
		]
	],
	[
		[
			9706,
			4050
		],
		[
			-7,
			13
		],
		[
			4,
			7
		],
		[
			3,
			-20
		]
	],
	[
		[
			9699,
			4104
		],
		[
			2,
			-14
		],
		[
			-8,
			6
		],
		[
			0,
			12
		],
		[
			6,
			-4
		]
	],
	[
		[
			9675,
			4172
		],
		[
			7,
			-8
		],
		[
			-6,
			-8
		],
		[
			-6,
			7
		],
		[
			5,
			9
		]
	],
	[
		[
			9671,
			4228
		],
		[
			8,
			-15
		],
		[
			-7,
			1
		],
		[
			-1,
			14
		]
	],
	[
		[
			9675,
			4243
		],
		[
			-6,
			-2
		],
		[
			-6,
			7
		],
		[
			7,
			9
		],
		[
			5,
			-14
		]
	],
	[
		[
			9650,
			4255
		],
		[
			10,
			-14
		],
		[
			1,
			-7
		],
		[
			-10,
			-6
		],
		[
			-4,
			27
		],
		[
			-5,
			1
		],
		[
			1,
			12
		],
		[
			4,
			-1
		],
		[
			3,
			-12
		]
	],
	[
		[
			9672,
			4262
		],
		[
			-3,
			21
		],
		[
			1,
			9
		],
		[
			3,
			-20
		],
		[
			-1,
			-10
		]
	],
	[
		[
			9662,
			4292
		],
		[
			-5,
			2
		],
		[
			9,
			9
		],
		[
			-4,
			-11
		]
	],
	[
		[
			9671,
			4298
		],
		[
			-2,
			1
		],
		[
			-1,
			24
		],
		[
			2,
			-2
		],
		[
			1,
			-23
		]
	],
	[
		[
			9633,
			4310
		],
		[
			4,
			2
		],
		[
			0,
			11
		],
		[
			5,
			-11
		],
		[
			3,
			-23
		],
		[
			-11,
			-7
		],
		[
			-7,
			15
		],
		[
			1,
			11
		],
		[
			-3,
			15
		],
		[
			1,
			17
		],
		[
			5,
			-11
		],
		[
			2,
			-19
		]
	],
	[
		[
			9653,
			4368
		],
		[
			1,
			-9
		],
		[
			-5,
			0
		],
		[
			4,
			9
		]
	],
	[
		[
			9654,
			4385
		],
		[
			-4,
			-3
		],
		[
			-1,
			10
		],
		[
			5,
			-7
		]
	],
	[
		[
			5917,
			7177
		],
		[
			-8,
			1
		]
	],
	[
		[
			233,
			4380
		],
		[
			5,
			-6
		],
		[
			-14,
			2
		],
		[
			-4,
			7
		],
		[
			7,
			5
		],
		[
			6,
			-8
		]
	],
	[
		[
			213,
			4406
		],
		[
			3,
			-6
		],
		[
			-1,
			-12
		],
		[
			-9,
			0
		],
		[
			-5,
			15
		],
		[
			12,
			3
		]
	],
	[
		[
			6488,
			5914
		],
		[
			7,
			-6
		],
		[
			7,
			6
		],
		[
			10,
			-9
		],
		[
			-9,
			-11
		],
		[
			-10,
			-3
		],
		[
			-6,
			2
		],
		[
			-5,
			12
		],
		[
			6,
			9
		]
	],
	[
		[
			6474,
			6141
		],
		[
			-14,
			-9
		],
		[
			-10,
			-18
		],
		[
			-2,
			-12
		],
		[
			2,
			-20
		],
		[
			-10,
			-7
		],
		[
			-13,
			-15
		],
		[
			-23,
			-11
		],
		[
			-11,
			-11
		],
		[
			-4,
			0
		],
		[
			-25,
			-18
		],
		[
			-3,
			-12
		],
		[
			-8,
			-16
		],
		[
			-6,
			-3
		],
		[
			-14,
			3
		],
		[
			-10,
			-9
		],
		[
			-6,
			-13
		],
		[
			-15,
			-8
		],
		[
			-5,
			-6
		],
		[
			-14,
			0
		],
		[
			-16,
			-6
		],
		[
			-7,
			-15
		],
		[
			-15,
			-17
		],
		[
			-7,
			3
		],
		[
			-4,
			-8
		],
		[
			-14,
			-5
		],
		[
			-10,
			9
		],
		[
			-3,
			-4
		],
		[
			-7,
			35
		],
		[
			2,
			25
		],
		[
			-6,
			21
		],
		[
			-2,
			16
		],
		[
			-3,
			43
		],
		[
			-6,
			7
		],
		[
			4,
			2
		],
		[
			-3,
			17
		],
		[
			3,
			18
		],
		[
			-1,
			29
		]
	],
	[
		[
			5913,
			3637
		],
		[
			-1,
			-16
		],
		[
			-5,
			-23
		],
		[
			-3,
			-38
		],
		[
			-5,
			-21
		],
		[
			-10,
			-19
		],
		[
			-7,
			-3
		],
		[
			-13,
			-27
		],
		[
			-21,
			-68
		],
		[
			-4,
			-16
		],
		[
			-15,
			-32
		],
		[
			-4,
			-4
		],
		[
			-16,
			-28
		],
		[
			-9,
			-21
		],
		[
			-13,
			-22
		],
		[
			-25,
			-35
		],
		[
			-27,
			-26
		],
		[
			-15,
			4
		],
		[
			-9,
			-9
		],
		[
			0,
			-11
		],
		[
			-17,
			5
		],
		[
			-4,
			-12
		],
		[
			-11,
			1
		],
		[
			-8,
			6
		],
		[
			-16,
			4
		],
		[
			-6,
			-7
		],
		[
			-23,
			6
		],
		[
			-10,
			-4
		],
		[
			-12,
			-19
		],
		[
			-7,
			3
		],
		[
			-6,
			-5
		],
		[
			-11,
			4
		],
		[
			-1,
			-6
		],
		[
			-11,
			0
		],
		[
			-14,
			-20
		],
		[
			-9,
			3
		],
		[
			-9,
			9
		],
		[
			0,
			11
		],
		[
			-6,
			4
		],
		[
			-8,
			-2
		],
		[
			0,
			17
		],
		[
			-10,
			-2
		],
		[
			0,
			-13
		],
		[
			-4,
			19
		],
		[
			5,
			10
		],
		[
			-2,
			12
		],
		[
			-7,
			16
		],
		[
			-4,
			20
		],
		[
			-4,
			-1
		],
		[
			1,
			18
		],
		[
			7,
			-2
		],
		[
			4,
			8
		],
		[
			1,
			20
		],
		[
			-2,
			22
		],
		[
			-4,
			17
		],
		[
			-9,
			20
		],
		[
			-7,
			28
		],
		[
			-8,
			24
		],
		[
			-6,
			42
		],
		[
			-6,
			29
		],
		[
			-7,
			15
		],
		[
			-3,
			15
		]
	],
	[
		[
			5815,
			3905
		],
		[
			12,
			3
		],
		[
			14,
			-12
		],
		[
			15,
			3
		],
		[
			13,
			-7
		]
	],
	[
		[
			5844,
			4282
		],
		[
			-15,
			1
		],
		[
			-13,
			-5
		],
		[
			-15,
			-18
		],
		[
			0,
			-21
		],
		[
			-3,
			-8
		]
	],
	[
		[
			5798,
			4231
		],
		[
			-3,
			3
		],
		[
			-13,
			-9
		],
		[
			-5,
			-13
		],
		[
			-12,
			-14
		],
		[
			-13,
			-38
		],
		[
			-2,
			-11
		]
	],
	[
		[
			5750,
			4149
		],
		[
			-9,
			-7
		],
		[
			-14,
			11
		],
		[
			-7,
			-7
		],
		[
			-7,
			11
		],
		[
			-12,
			1
		]
	],
	[
		[
			5792,
			4643
		],
		[
			5,
			5
		],
		[
			9,
			23
		],
		[
			3,
			15
		],
		[
			-7,
			8
		]
	],
	[
		[
			5849,
			4709
		],
		[
			-4,
			-14
		],
		[
			7,
			-1
		],
		[
			9,
			-18
		],
		[
			5,
			4
		],
		[
			-1,
			8
		]
	],
	[
		[
			5750,
			4149
		],
		[
			10,
			22
		],
		[
			5,
			5
		],
		[
			4,
			17
		],
		[
			11,
			9
		],
		[
			0,
			11
		],
		[
			8,
			0
		],
		[
			8,
			9
		],
		[
			1,
			-7
		],
		[
			8,
			12
		],
		[
			-7,
			4
		]
	]
];
var objects$1 = {
	units: {
		geometries: [
			{
				arcs: [
					[
						0,
						1,
						2,
						3,
						4,
						5
					]
				],
				id: "AFG",
				properties: {
					name: "Afghanistan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							6,
							7,
							8,
							9
						]
					],
					[
						[
							10,
							11,
							12
						]
					]
				],
				id: "AGO",
				properties: {
					name: "Angola"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							13,
							14
						]
					],
					[
						[
							15,
							16
						]
					],
					[
						[
							17,
							18,
							19,
							20,
							21,
							22,
							23,
							24,
							25,
							26,
							27,
							28,
							29,
							30
						]
					]
				],
				id: "ALB",
				properties: {
					name: "Albania"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							31
						]
					]
				],
				id: "ALD",
				properties: {
					name: "Aland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						32,
						33
					]
				],
				id: "AND",
				properties: {
					name: "Andorra"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							34
						]
					],
					[
						[
							35,
							36,
							37,
							38,
							39
						],
						[
							40
						]
					]
				],
				id: "ARE",
				properties: {
					name: "United Arab Emirates"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							41,
							42
						]
					],
					[
						[
							43,
							44
						]
					],
					[
						[
							45,
							46,
							47,
							48,
							49,
							50
						]
					]
				],
				id: "ARG",
				properties: {
					name: "Argentina"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							51
						]
					],
					[
						[
							52,
							53,
							54,
							55,
							56
						],
						[
							57
						],
						[
							58
						]
					]
				],
				id: "ARM",
				properties: {
					name: "Armenia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							59
						]
					],
					[
						[
							60
						]
					],
					[
						[
							61
						]
					],
					[
						[
							62
						]
					],
					[
						[
							63
						]
					],
					[
						[
							64
						]
					],
					[
						[
							65
						]
					],
					[
						[
							66
						]
					],
					[
						[
							67
						]
					],
					[
						[
							68
						]
					],
					[
						[
							69
						]
					],
					[
						[
							70
						]
					],
					[
						[
							71
						]
					],
					[
						[
							72
						]
					],
					[
						[
							73
						]
					],
					[
						[
							74
						]
					],
					[
						[
							75
						]
					],
					[
						[
							76
						]
					],
					[
						[
							77
						]
					],
					[
						[
							78
						]
					],
					[
						[
							79
						]
					],
					[
						[
							80
						]
					],
					[
						[
							81
						]
					],
					[
						[
							82
						]
					],
					[
						[
							83
						]
					],
					[
						[
							84
						]
					],
					[
						[
							85
						]
					],
					[
						[
							86
						]
					],
					[
						[
							87
						]
					],
					[
						[
							88
						]
					],
					[
						[
							89
						]
					],
					[
						[
							90
						]
					],
					[
						[
							91
						]
					],
					[
						[
							92
						]
					],
					[
						[
							93
						]
					],
					[
						[
							94
						]
					],
					[
						[
							95
						]
					],
					[
						[
							96
						]
					],
					[
						[
							97
						]
					],
					[
						[
							98
						]
					],
					[
						[
							99
						]
					],
					[
						[
							100
						]
					],
					[
						[
							101
						]
					],
					[
						[
							102
						]
					],
					[
						[
							103
						]
					],
					[
						[
							104
						]
					],
					[
						[
							105
						]
					],
					[
						[
							106
						]
					],
					[
						[
							107
						]
					],
					[
						[
							108
						]
					],
					[
						[
							109
						]
					],
					[
						[
							110
						]
					],
					[
						[
							111
						]
					],
					[
						[
							112
						]
					],
					[
						[
							113
						]
					],
					[
						[
							114
						]
					],
					[
						[
							115
						]
					],
					[
						[
							116
						]
					],
					[
						[
							117
						]
					],
					[
						[
							118
						]
					],
					[
						[
							119
						]
					],
					[
						[
							120
						]
					]
				],
				id: "ATA",
				properties: {
					name: "Antarctica"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							121
						]
					]
				],
				id: "ATF",
				properties: {
					name: "Fr. S. Antarctic Lands"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							122
						]
					],
					[
						[
							123
						]
					],
					[
						[
							124
						]
					],
					[
						[
							125
						]
					],
					[
						[
							126
						]
					],
					[
						[
							127
						]
					],
					[
						[
							128
						]
					],
					[
						[
							129
						]
					],
					[
						[
							130
						]
					],
					[
						[
							131
						]
					],
					[
						[
							132
						]
					],
					[
						[
							133
						]
					],
					[
						[
							134
						]
					],
					[
						[
							135
						]
					],
					[
						[
							136
						]
					],
					[
						[
							137
						]
					],
					[
						[
							138
						]
					],
					[
						[
							139
						]
					],
					[
						[
							140
						]
					]
				],
				id: "AUS",
				properties: {
					name: "Australia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						141,
						142,
						143,
						144,
						145,
						146,
						147,
						148,
						149,
						150
					]
				],
				id: "AUT",
				properties: {
					name: "Austria"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							151,
							152,
							-55
						]
					],
					[
						[
							-59
						]
					],
					[
						[
							-58
						]
					],
					[
						[
							153,
							154,
							155,
							-53,
							156
						],
						[
							-52
						]
					]
				],
				id: "AZE",
				properties: {
					name: "Azerbaijan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						157,
						158,
						159,
						160
					]
				],
				id: "BDI",
				properties: {
					name: "Burundi"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						161,
						162,
						163,
						164,
						165,
						166,
						167
					]
				],
				id: "BEL",
				properties: {
					name: "Belgium"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						168,
						169,
						170,
						171,
						172
					]
				],
				id: "BEN",
				properties: {
					name: "Benin"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						173,
						-172,
						174,
						175,
						176,
						177
					]
				],
				id: "BFA",
				properties: {
					name: "Burkina Faso"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							178
						]
					],
					[
						[
							179
						]
					],
					[
						[
							180,
							181,
							182
						]
					]
				],
				id: "BGD",
				properties: {
					name: "Bangladesh"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						183,
						184,
						185,
						186,
						187,
						188
					]
				],
				id: "BGR",
				properties: {
					name: "Bulgaria"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						189
					]
				],
				id: "BHR",
				properties: {
					name: "Bahrain"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							190
						]
					],
					[
						[
							191
						]
					],
					[
						[
							192
						]
					],
					[
						[
							193
						]
					],
					[
						[
							194
						]
					],
					[
						[
							195
						]
					],
					[
						[
							196
						]
					],
					[
						[
							197
						]
					],
					[
						[
							198
						]
					],
					[
						[
							199
						]
					],
					[
						[
							200
						]
					]
				],
				id: "BHS",
				properties: {
					name: "Bahamas"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						201,
						202,
						203,
						204,
						205
					]
				],
				id: "BIH",
				properties: {
					name: "Bosnia and Herz."
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						206,
						207,
						208,
						209,
						210
					]
				],
				id: "BLR",
				properties: {
					name: "Belarus"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							211,
							212,
							213
						]
					]
				],
				id: "BLZ",
				properties: {
					name: "Belize"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							214,
							215
						]
					],
					[
						[
							216,
							-51,
							217,
							218,
							219,
							220,
							221
						]
					]
				],
				id: "BOL",
				properties: {
					name: "Bolivia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							222
						]
					],
					[
						[
							223
						]
					],
					[
						[
							224
						]
					],
					[
						[
							225
						]
					],
					[
						[
							226
						]
					],
					[
						[
							227
						]
					],
					[
						[
							228
						]
					],
					[
						[
							229
						]
					],
					[
						[
							230
						]
					],
					[
						[
							231
						]
					],
					[
						[
							232
						]
					],
					[
						[
							233
						]
					],
					[
						[
							234
						]
					],
					[
						[
							235
						]
					],
					[
						[
							236
						]
					],
					[
						[
							237
						]
					],
					[
						[
							238,
							239,
							240,
							241,
							242,
							243,
							-47,
							244,
							245,
							246,
							-222,
							247,
							248,
							249,
							250
						]
					]
				],
				id: "BRA",
				properties: {
					name: "Brazil"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						251
					]
				],
				id: "BRB",
				properties: {
					name: "Barbados"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							252,
							253
						]
					],
					[
						[
							254,
							255
						]
					]
				],
				id: "BRN",
				properties: {
					name: "Brunei"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						256,
						257
					]
				],
				id: "BTN",
				properties: {
					name: "Bhutan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						258,
						259,
						260
					]
				],
				id: "BWA",
				properties: {
					name: "Botswana"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						261,
						262,
						263,
						264,
						265,
						266
					]
				],
				id: "CAF",
				properties: {
					name: "Central African Rep."
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							267
						]
					],
					[
						[
							268
						]
					],
					[
						[
							269
						]
					],
					[
						[
							270
						]
					],
					[
						[
							271
						]
					],
					[
						[
							272
						]
					],
					[
						[
							273
						]
					],
					[
						[
							274,
							275,
							276,
							277
						]
					],
					[
						[
							278
						]
					],
					[
						[
							279
						]
					],
					[
						[
							280
						]
					],
					[
						[
							281
						]
					],
					[
						[
							282
						]
					],
					[
						[
							283
						]
					],
					[
						[
							284
						]
					],
					[
						[
							285
						]
					],
					[
						[
							286
						]
					],
					[
						[
							287
						]
					],
					[
						[
							288
						]
					],
					[
						[
							289
						]
					],
					[
						[
							290
						]
					],
					[
						[
							291
						]
					],
					[
						[
							292
						]
					],
					[
						[
							293
						]
					],
					[
						[
							294
						]
					],
					[
						[
							295
						]
					],
					[
						[
							296
						]
					],
					[
						[
							297
						]
					],
					[
						[
							298
						]
					],
					[
						[
							299
						]
					],
					[
						[
							300
						]
					],
					[
						[
							301
						]
					],
					[
						[
							302
						]
					],
					[
						[
							303
						]
					],
					[
						[
							304
						]
					],
					[
						[
							305
						]
					],
					[
						[
							306
						]
					],
					[
						[
							307
						]
					],
					[
						[
							308
						]
					],
					[
						[
							309
						]
					],
					[
						[
							310
						]
					],
					[
						[
							311
						]
					],
					[
						[
							312
						]
					],
					[
						[
							313
						]
					],
					[
						[
							314
						]
					],
					[
						[
							315
						]
					],
					[
						[
							316
						]
					],
					[
						[
							317
						]
					],
					[
						[
							318
						]
					],
					[
						[
							319
						]
					],
					[
						[
							320
						]
					],
					[
						[
							321
						]
					],
					[
						[
							322
						]
					],
					[
						[
							323
						]
					],
					[
						[
							324
						]
					],
					[
						[
							325
						]
					],
					[
						[
							326
						]
					],
					[
						[
							327
						]
					],
					[
						[
							328
						]
					],
					[
						[
							329
						]
					],
					[
						[
							330
						]
					],
					[
						[
							331
						]
					],
					[
						[
							332
						]
					],
					[
						[
							333,
							334,
							335,
							336,
							337,
							338,
							339,
							340,
							341,
							342,
							343,
							344,
							345,
							-346,
							346,
							347
						]
					],
					[
						[
							348
						]
					],
					[
						[
							349
						]
					],
					[
						[
							350
						]
					],
					[
						[
							351
						]
					],
					[
						[
							352
						]
					],
					[
						[
							353
						]
					],
					[
						[
							354
						]
					],
					[
						[
							355
						]
					],
					[
						[
							356
						]
					],
					[
						[
							357
						]
					],
					[
						[
							358
						]
					],
					[
						[
							359
						]
					],
					[
						[
							360
						]
					],
					[
						[
							361
						]
					],
					[
						[
							362
						]
					],
					[
						[
							363
						]
					],
					[
						[
							364
						]
					],
					[
						[
							365
						]
					],
					[
						[
							366
						]
					],
					[
						[
							367
						]
					],
					[
						[
							368
						]
					],
					[
						[
							369
						]
					],
					[
						[
							370
						]
					],
					[
						[
							371
						]
					],
					[
						[
							372
						]
					],
					[
						[
							373
						]
					],
					[
						[
							374
						]
					],
					[
						[
							375
						]
					],
					[
						[
							376
						]
					],
					[
						[
							377
						]
					],
					[
						[
							378
						]
					],
					[
						[
							379
						]
					],
					[
						[
							380
						]
					],
					[
						[
							381
						]
					],
					[
						[
							382
						]
					],
					[
						[
							383
						]
					],
					[
						[
							384
						]
					]
				],
				id: "CAN",
				properties: {
					name: "Canada"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						385,
						386,
						387,
						-148,
						388,
						-146,
						389,
						390,
						391,
						392,
						393
					]
				],
				id: "CHE",
				properties: {
					name: "Switzerland"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							394
						]
					],
					[
						[
							395
						]
					],
					[
						[
							396
						]
					],
					[
						[
							397
						]
					],
					[
						[
							398
						]
					],
					[
						[
							399
						]
					],
					[
						[
							400
						]
					],
					[
						[
							401
						]
					],
					[
						[
							402
						]
					],
					[
						[
							-44,
							403,
							-42,
							404
						]
					],
					[
						[
							405
						]
					],
					[
						[
							406
						]
					],
					[
						[
							407
						]
					],
					[
						[
							408
						]
					],
					[
						[
							409
						]
					],
					[
						[
							410
						]
					],
					[
						[
							411
						]
					],
					[
						[
							412
						]
					],
					[
						[
							413
						]
					],
					[
						[
							414
						]
					],
					[
						[
							415
						]
					],
					[
						[
							416
						]
					],
					[
						[
							417
						]
					],
					[
						[
							418
						]
					],
					[
						[
							419
						]
					],
					[
						[
							420
						]
					],
					[
						[
							421
						]
					],
					[
						[
							422
						]
					],
					[
						[
							423
						]
					],
					[
						[
							424
						]
					],
					[
						[
							425
						]
					],
					[
						[
							426
						]
					],
					[
						[
							427
						]
					],
					[
						[
							428
						]
					],
					[
						[
							429
						]
					],
					[
						[
							430
						]
					],
					[
						[
							431
						]
					],
					[
						[
							432
						]
					],
					[
						[
							433
						]
					],
					[
						[
							434
						]
					],
					[
						[
							435
						]
					],
					[
						[
							-50,
							436,
							437,
							-218
						]
					]
				],
				id: "CHL",
				properties: {
					name: "Chile"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							438
						]
					],
					[
						[
							439
						]
					],
					[
						[
							440
						]
					],
					[
						[
							441
						]
					],
					[
						[
							442,
							443,
							444,
							445,
							446,
							447,
							448,
							449,
							450,
							451,
							-258,
							452,
							453,
							454,
							455,
							456,
							-1,
							457,
							458,
							459,
							460,
							461,
							462,
							463,
							464
						]
					]
				],
				id: "CHN",
				properties: {
					name: "China"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							465,
							466
						]
					],
					[
						[
							-177,
							467,
							468,
							469,
							470,
							471
						]
					]
				],
				id: "CIV",
				properties: {
					name: "Côte d'Ivoire"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							472,
							-266,
							473,
							474,
							475,
							476,
							477,
							478,
							479
						]
					],
					[
						[
							480,
							481
						]
					]
				],
				id: "CMR",
				properties: {
					name: "Cameroon"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							482,
							483,
							484,
							485
						]
					],
					[
						[
							486,
							487,
							488,
							489
						]
					],
					[
						[
							490,
							491,
							492,
							493
						]
					]
				],
				id: "CNM",
				properties: {
					name: "Cyprus U.N. Buffer Zone"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							494
						]
					],
					[
						[
							495,
							496,
							497,
							498,
							499,
							500,
							501,
							502,
							503,
							-160,
							504,
							505,
							506,
							507,
							-10,
							508,
							-11,
							509,
							-264
						]
					]
				],
				id: "COD",
				properties: {
					name: "Dem. Rep. Congo"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-510,
						-13,
						510,
						511,
						-474,
						-265
					]
				],
				id: "COG",
				properties: {
					name: "Congo"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							512,
							-249,
							513,
							514,
							515,
							516,
							517
						]
					]
				],
				id: "COL",
				properties: {
					name: "Colombia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							518
						]
					],
					[
						[
							519
						]
					]
				],
				id: "COM",
				properties: {
					name: "Comoros"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							520
						]
					],
					[
						[
							521
						]
					],
					[
						[
							522
						]
					],
					[
						[
							523
						]
					]
				],
				id: "CPV",
				properties: {
					name: "Cape Verde"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							524,
							525,
							526,
							527
						]
					]
				],
				id: "CRI",
				properties: {
					name: "Costa Rica"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							528
						]
					],
					[
						[
							529
						]
					],
					[
						[
							530
						]
					],
					[
						[
							531,
							532,
							533,
							534
						]
					]
				],
				id: "CUB",
				properties: {
					name: "Cuba"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						535
					]
				],
				id: "CUW",
				properties: {
					name: "Curaçao"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							536,
							-488
						]
					],
					[
						[
							-486,
							537,
							-494,
							538
						]
					]
				],
				id: "CYN",
				properties: {
					name: "N. Cyprus"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							539,
							540
						]
					],
					[
						[
							541
						]
					],
					[
						[
							542,
							543,
							-484
						]
					],
					[
						[
							544,
							545,
							546,
							547,
							-490,
							548,
							-492
						]
					]
				],
				id: "CYP",
				properties: {
					name: "Cyprus"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						549,
						550,
						-151,
						551
					]
				],
				id: "CZE",
				properties: {
					name: "Czech Rep."
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							-387,
							552
						]
					],
					[
						[
							553,
							554
						]
					],
					[
						[
							555
						]
					],
					[
						[
							556,
							557,
							-552,
							-150,
							558,
							-394,
							559,
							560,
							-162,
							561,
							562,
							563
						]
					]
				],
				id: "DEU",
				properties: {
					name: "Germany"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						564,
						565,
						566,
						567,
						568,
						569
					]
				],
				id: "DJI",
				properties: {
					name: "Djibouti"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						570
					]
				],
				id: "DMA",
				properties: {
					name: "Dominica"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							571
						]
					],
					[
						[
							572
						]
					],
					[
						[
							573
						]
					],
					[
						[
							574
						]
					],
					[
						[
							575
						]
					],
					[
						[
							576
						]
					],
					[
						[
							577
						]
					],
					[
						[
							-564,
							578
						]
					]
				],
				id: "DNK",
				properties: {
					name: "Denmark"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							579,
							580,
							581,
							582,
							583,
							584
						]
					]
				],
				id: "DOM",
				properties: {
					name: "Dominican Rep."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						585,
						586,
						587,
						588,
						589,
						590,
						591,
						592
					]
				],
				id: "DZA",
				properties: {
					name: "Algeria"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							593
						]
					],
					[
						[
							594
						]
					],
					[
						[
							595
						]
					],
					[
						[
							596
						]
					],
					[
						[
							597
						]
					],
					[
						[
							598
						]
					],
					[
						[
							599,
							600,
							-515
						]
					]
				],
				id: "ECU",
				properties: {
					name: "Ecuador"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							601,
							602,
							603,
							604,
							605,
							606
						]
					]
				],
				id: "EGY",
				properties: {
					name: "Egypt"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							607
						]
					],
					[
						[
							-569,
							608,
							609,
							610
						]
					]
				],
				id: "ERI",
				properties: {
					name: "Eritrea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-485,
						-544,
						611,
						-541,
						612,
						-545,
						-491,
						-538
					],
					[
						-542
					]
				],
				id: "ESB",
				properties: {
					name: "Dhekelia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							613
						]
					],
					[
						[
							614
						]
					],
					[
						[
							615
						]
					],
					[
						[
							616
						]
					],
					[
						[
							617
						]
					],
					[
						[
							618
						]
					],
					[
						[
							619,
							620
						]
					],
					[
						[
							621,
							622
						]
					],
					[
						[
							623
						]
					],
					[
						[
							624
						]
					],
					[
						[
							625
						]
					],
					[
						[
							626
						]
					],
					[
						[
							627,
							-33,
							628,
							629,
							630,
							631,
							632,
							633
						]
					]
				],
				id: "ESP",
				properties: {
					name: "Spain"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							634
						]
					],
					[
						[
							635
						]
					],
					[
						[
							636,
							637,
							638,
							639,
							640,
							641,
							642,
							643,
							644
						]
					]
				],
				id: "EST",
				properties: {
					name: "Estonia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-568,
						645,
						-566,
						646,
						647,
						648,
						649,
						650,
						-609
					]
				],
				id: "ETH",
				properties: {
					name: "Ethiopia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							651
						]
					],
					[
						[
							652,
							653,
							654,
							655
						]
					]
				],
				id: "FIN",
				properties: {
					name: "Finland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							656
						]
					],
					[
						[
							657
						]
					],
					[
						[
							658
						]
					]
				],
				id: "FJI",
				properties: {
					name: "Fiji"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							659
						]
					],
					[
						[
							660
						]
					]
				],
				id: "FLK",
				properties: {
					name: "Falkland Is."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							661
						]
					],
					[
						[
							662
						]
					],
					[
						[
							-240,
							663,
							664
						]
					],
					[
						[
							665
						]
					],
					[
						[
							666
						]
					],
					[
						[
							667
						]
					],
					[
						[
							668
						]
					],
					[
						[
							669,
							-560,
							-393,
							670,
							-391,
							671,
							672,
							673,
							674,
							-629,
							-34,
							-628,
							675,
							-164
						],
						[
							-627
						]
					]
				],
				id: "FRA",
				properties: {
					name: "France"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							676
						]
					],
					[
						[
							677
						]
					]
				],
				id: "FRO",
				properties: {
					name: "Faeroe Is."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							678
						]
					]
				],
				id: "FSM",
				properties: {
					name: "Micronesia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-512,
							679,
							680,
							-475
						]
					]
				],
				id: "GAB",
				properties: {
					name: "Gabon"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							681
						]
					],
					[
						[
							682
						]
					],
					[
						[
							683,
							684
						]
					],
					[
						[
							685
						]
					],
					[
						[
							686
						]
					],
					[
						[
							687
						]
					],
					[
						[
							688
						]
					],
					[
						[
							689
						]
					],
					[
						[
							690
						]
					],
					[
						[
							691
						]
					],
					[
						[
							692
						]
					],
					[
						[
							693
						]
					],
					[
						[
							694
						]
					],
					[
						[
							695
						]
					]
				],
				id: "GBR",
				properties: {
					name: "United Kingdom"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-157,
						-57,
						696,
						697,
						698
					]
				],
				id: "GEO",
				properties: {
					name: "Georgia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						699,
						700,
						-466,
						701,
						-468,
						-176
					]
				],
				id: "GHA",
				properties: {
					name: "Ghana"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-631,
						702
					]
				],
				id: "GIB",
				properties: {
					name: "Gibraltar"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						703,
						-471,
						704,
						705,
						706,
						707,
						708
					]
				],
				id: "GIN",
				properties: {
					name: "Guinea"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						709,
						710
					]
				],
				id: "GMB",
				properties: {
					name: "Gambia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							711
						]
					],
					[
						[
							712,
							713,
							-708
						]
					]
				],
				id: "GNB",
				properties: {
					name: "Guinea-Bissau"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-681,
							714,
							-476
						]
					],
					[
						[
							715
						]
					]
				],
				id: "GNQ",
				properties: {
					name: "Eq. Guinea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							716
						]
					],
					[
						[
							717
						]
					],
					[
						[
							718
						]
					],
					[
						[
							719
						]
					],
					[
						[
							720
						]
					],
					[
						[
							721
						]
					],
					[
						[
							722
						]
					],
					[
						[
							723
						]
					],
					[
						[
							724
						]
					],
					[
						[
							725
						]
					],
					[
						[
							726
						]
					],
					[
						[
							727
						]
					],
					[
						[
							728
						]
					],
					[
						[
							729
						]
					],
					[
						[
							730
						]
					],
					[
						[
							731
						]
					],
					[
						[
							732,
							-186,
							733,
							734,
							-27,
							735,
							-25,
							736
						]
					]
				],
				id: "GRC",
				properties: {
					name: "Greece"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							737
						]
					]
				],
				id: "GRD",
				properties: {
					name: "Grenada"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							738
						]
					],
					[
						[
							739
						]
					],
					[
						[
							740
						]
					],
					[
						[
							741
						]
					],
					[
						[
							742
						]
					],
					[
						[
							743
						]
					],
					[
						[
							744
						]
					],
					[
						[
							745
						]
					],
					[
						[
							746
						]
					],
					[
						[
							747
						]
					],
					[
						[
							748
						]
					],
					[
						[
							749
						]
					],
					[
						[
							750
						]
					],
					[
						[
							751
						]
					],
					[
						[
							752
						]
					],
					[
						[
							753
						]
					],
					[
						[
							754
						]
					],
					[
						[
							755
						]
					],
					[
						[
							756
						]
					],
					[
						[
							757
						]
					],
					[
						[
							758
						]
					],
					[
						[
							759
						]
					],
					[
						[
							760
						]
					],
					[
						[
							761
						]
					],
					[
						[
							762
						]
					],
					[
						[
							763
						]
					]
				],
				id: "GRL",
				properties: {
					name: "Greenland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-213,
						764,
						765,
						766,
						767,
						768
					]
				],
				id: "GTM",
				properties: {
					name: "Guatemala"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						769
					]
				],
				id: "GUM",
				properties: {
					name: "Guam"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							770,
							-251,
							771,
							772
						]
					]
				],
				id: "GUY",
				properties: {
					name: "Guyana"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							773,
							-447
						]
					]
				],
				id: "HKG",
				properties: {
					name: "Hong Kong"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						774
					]
				],
				id: "HMD",
				properties: {
					name: "Heard I. and McDonald Is."
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							775,
							776,
							777,
							-766,
							778
						]
					]
				],
				id: "HND",
				properties: {
					name: "Honduras"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-204,
							779,
							780
						]
					],
					[
						[
							781
						]
					],
					[
						[
							782
						]
					],
					[
						[
							783
						]
					],
					[
						[
							784
						]
					],
					[
						[
							785,
							786,
							-206,
							787,
							788
						]
					]
				],
				id: "HRV",
				properties: {
					name: "Croatia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-582,
							789
						]
					],
					[
						[
							790
						]
					],
					[
						[
							-584,
							791,
							-580,
							792
						]
					]
				],
				id: "HTI",
				properties: {
					name: "Haiti"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						793,
						794,
						795,
						-786,
						796,
						-143,
						797
					]
				],
				id: "HUN",
				properties: {
					name: "Hungary"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							798
						]
					],
					[
						[
							799
						]
					],
					[
						[
							800
						]
					],
					[
						[
							801,
							802,
							803,
							804
						]
					],
					[
						[
							805
						]
					],
					[
						[
							806
						]
					],
					[
						[
							807
						]
					],
					[
						[
							808
						]
					],
					[
						[
							809
						]
					],
					[
						[
							810
						]
					],
					[
						[
							811
						]
					],
					[
						[
							812
						]
					],
					[
						[
							813
						]
					],
					[
						[
							814
						]
					],
					[
						[
							815
						]
					],
					[
						[
							816
						]
					],
					[
						[
							817
						]
					],
					[
						[
							818
						]
					],
					[
						[
							819
						]
					],
					[
						[
							820
						]
					],
					[
						[
							821
						]
					],
					[
						[
							822
						]
					],
					[
						[
							823
						]
					],
					[
						[
							824
						]
					],
					[
						[
							825
						]
					],
					[
						[
							826
						]
					],
					[
						[
							827
						]
					],
					[
						[
							828
						]
					],
					[
						[
							829
						]
					],
					[
						[
							830
						]
					],
					[
						[
							831
						]
					],
					[
						[
							832
						]
					],
					[
						[
							833
						]
					],
					[
						[
							834
						]
					],
					[
						[
							835
						]
					],
					[
						[
							836
						]
					],
					[
						[
							837
						]
					],
					[
						[
							838
						]
					],
					[
						[
							839
						]
					],
					[
						[
							840
						]
					],
					[
						[
							841
						]
					],
					[
						[
							842
						]
					],
					[
						[
							843
						]
					],
					[
						[
							844
						]
					],
					[
						[
							845
						]
					],
					[
						[
							846
						]
					],
					[
						[
							847
						]
					],
					[
						[
							848
						]
					],
					[
						[
							849
						]
					],
					[
						[
							850
						]
					],
					[
						[
							851
						]
					],
					[
						[
							852
						]
					],
					[
						[
							853
						]
					],
					[
						[
							854
						]
					],
					[
						[
							855
						]
					],
					[
						[
							856
						]
					],
					[
						[
							857,
							858
						]
					],
					[
						[
							859
						]
					],
					[
						[
							860
						]
					],
					[
						[
							861
						]
					],
					[
						[
							862
						]
					],
					[
						[
							863
						]
					],
					[
						[
							864
						]
					],
					[
						[
							865
						]
					],
					[
						[
							866
						]
					],
					[
						[
							867
						]
					],
					[
						[
							868
						]
					],
					[
						[
							869
						]
					],
					[
						[
							870
						]
					],
					[
						[
							871
						]
					],
					[
						[
							872
						]
					],
					[
						[
							873
						]
					],
					[
						[
							874
						]
					],
					[
						[
							875
						]
					],
					[
						[
							876
						]
					],
					[
						[
							877
						]
					],
					[
						[
							878
						]
					],
					[
						[
							879
						]
					],
					[
						[
							880
						]
					],
					[
						[
							881,
							882
						]
					],
					[
						[
							883
						]
					],
					[
						[
							884,
							885
						]
					],
					[
						[
							886
						]
					],
					[
						[
							887
						]
					]
				],
				id: "IDN",
				properties: {
					name: "Indonesia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						888
					]
				],
				id: "IMN",
				properties: {
					name: "Isle of Man"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							889
						]
					],
					[
						[
							890
						]
					],
					[
						[
							891
						]
					],
					[
						[
							892
						]
					],
					[
						[
							893,
							-453,
							-257,
							-452,
							894,
							-183,
							895,
							896,
							897,
							-455
						]
					]
				],
				id: "IND",
				properties: {
					name: "India"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-684,
							898
						]
					]
				],
				id: "IRL",
				properties: {
					name: "Ireland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							899
						]
					],
					[
						[
							-54,
							-156,
							900,
							901,
							-3,
							902,
							903,
							904,
							905,
							-152
						]
					]
				],
				id: "IRN",
				properties: {
					name: "Iran"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-905,
						906,
						907,
						908,
						909,
						910,
						911,
						912,
						913
					]
				],
				id: "IRQ",
				properties: {
					name: "Iraq"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							914
						]
					]
				],
				id: "ISL",
				properties: {
					name: "Iceland"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						915,
						916,
						917,
						918,
						919,
						920,
						921,
						-603,
						922,
						923,
						924,
						925
					]
				],
				id: "ISR",
				properties: {
					name: "Israel"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							926
						]
					],
					[
						[
							927
						]
					],
					[
						[
							928,
							929,
							-672,
							-390,
							-145
						],
						[
							930
						],
						[
							931
						]
					]
				],
				id: "ITA",
				properties: {
					name: "Italy"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						932
					]
				],
				id: "JAM",
				properties: {
					name: "Jamaica"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						933,
						934,
						-921,
						935,
						-919,
						936,
						937,
						-916,
						938,
						-910
					]
				],
				id: "JOR",
				properties: {
					name: "Jordan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							939
						]
					],
					[
						[
							940
						]
					],
					[
						[
							941
						]
					],
					[
						[
							942
						]
					],
					[
						[
							943
						]
					],
					[
						[
							944
						]
					],
					[
						[
							945
						]
					],
					[
						[
							946
						]
					],
					[
						[
							947
						]
					],
					[
						[
							948
						]
					],
					[
						[
							949
						]
					],
					[
						[
							950
						]
					],
					[
						[
							951
						]
					]
				],
				id: "JPN",
				properties: {
					name: "Japan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						952
					]
				],
				id: "KAB",
				properties: {
					name: "Baikonur"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-898,
						953,
						-456
					]
				],
				id: "KAS",
				properties: {
					name: "Siachen Glacier"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							954,
							955
						]
					],
					[
						[
							-460,
							956,
							957,
							958,
							959,
							960,
							961,
							962
						],
						[
							-953
						]
					]
				],
				id: "KAZ",
				properties: {
					name: "Kazakhstan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-649,
							963,
							964,
							965,
							966,
							967,
							968
						]
					]
				],
				id: "KEN",
				properties: {
					name: "Kenya"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-459,
						969,
						970,
						-957
					],
					[
						971
					],
					[
						972
					],
					[
						973
					]
				],
				id: "KGZ",
				properties: {
					name: "Kyrgyzstan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							974,
							975,
							976,
							977
						]
					]
				],
				id: "KHM",
				properties: {
					name: "Cambodia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							978
						]
					]
				],
				id: "KIR",
				properties: {
					name: "Kiribati"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							979
						]
					],
					[
						[
							980
						]
					],
					[
						[
							981
						]
					],
					[
						[
							982,
							983
						]
					]
				],
				id: "KOR",
				properties: {
					name: "Korea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						984,
						-18,
						985,
						986
					]
				],
				id: "XKX",
				properties: {
					name: "Kosovo"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							987
						]
					],
					[
						[
							988,
							-908,
							989
						]
					]
				],
				id: "KWT",
				properties: {
					name: "Kuwait"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						990,
						-977,
						991,
						992,
						-450
					]
				],
				id: "LAO",
				properties: {
					name: "Lao PDR"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-925,
						993,
						994
					]
				],
				id: "LBN",
				properties: {
					name: "Lebanon"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-470,
						995,
						996,
						-705
					]
				],
				id: "LBR",
				properties: {
					name: "Liberia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-606,
						997,
						998,
						999,
						-587,
						1000,
						1001
					]
				],
				id: "LBY",
				properties: {
					name: "Libya"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1002
					]
				],
				id: "LCA",
				properties: {
					name: "Saint Lucia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-389,
						-147
					]
				],
				id: "LIE",
				properties: {
					name: "Liechtenstein"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1003
						]
					]
				],
				id: "LKA",
				properties: {
					name: "Sri Lanka"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1004
					]
				],
				id: "LSO",
				properties: {
					name: "Lesotho"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1005,
							1006
						]
					],
					[
						[
							-210,
							1007,
							1008,
							1009,
							1010
						]
					]
				],
				id: "LTU",
				properties: {
					name: "Lithuania"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-561,
						-670,
						-163
					]
				],
				id: "LUX",
				properties: {
					name: "Luxembourg"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1011,
						-211,
						-1011,
						1012,
						-644
					]
				],
				id: "LVA",
				properties: {
					name: "Latvia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1013,
						1014
					]
				],
				id: "MAF",
				properties: {
					name: "St-Martin"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-622,
						1015,
						-620,
						1016,
						-592,
						1017,
						1018
					]
				],
				id: "MAR",
				properties: {
					name: "Morocco"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1019,
						-674
					]
				],
				id: "MCO",
				properties: {
					name: "Monaco"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1020,
						1021
					]
				],
				id: "MDA",
				properties: {
					name: "Moldova"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1022
						]
					],
					[
						[
							1023
						]
					]
				],
				id: "MDG",
				properties: {
					name: "Madagascar"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1024
						]
					],
					[
						[
							1025
						]
					],
					[
						[
							1026
						]
					],
					[
						[
							1027
						]
					],
					[
						[
							1028
						]
					],
					[
						[
							1029,
							1030,
							1031,
							1032,
							1033,
							-214,
							-769,
							1034,
							1035
						],
						[
							1036
						]
					]
				],
				id: "MEX",
				properties: {
					name: "Mexico"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-23,
							1037
						]
					],
					[
						[
							-187,
							-733,
							1038,
							-15,
							1039,
							-21,
							1040,
							-19,
							-985,
							1041
						]
					]
				],
				id: "MKD",
				properties: {
					name: "Macedonia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1042,
						-178,
						-472,
						-704,
						1043,
						1044,
						-589
					]
				],
				id: "MLI",
				properties: {
					name: "Mali"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1045
						]
					],
					[
						[
							1046
						]
					],
					[
						[
							1047
						]
					],
					[
						[
							1048
						]
					],
					[
						[
							1049
						]
					],
					[
						[
							1050
						]
					],
					[
						[
							-993,
							1051,
							1052,
							-181,
							-895,
							-451
						]
					]
				],
				id: "MMR",
				properties: {
					name: "Myanmar"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1053,
						-986,
						-31,
						1054,
						-16,
						1055,
						-29,
						1056,
						-780,
						-203
					]
				],
				id: "MNE",
				properties: {
					name: "Montenegro"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-464,
						1057,
						-462,
						1058
					]
				],
				id: "MNG",
				properties: {
					name: "Mongolia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1059,
							1060,
							1061,
							1062,
							1063,
							1064,
							1065,
							1066,
							1067
						]
					]
				],
				id: "MOZ",
				properties: {
					name: "Mozambique"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1068,
							1069,
							1070,
							-590,
							-1045
						]
					]
				],
				id: "MRT",
				properties: {
					name: "Mauritania"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1071
						]
					]
				],
				id: "MUS",
				properties: {
					name: "Mauritius"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1072,
							1073
						]
					],
					[
						[
							1074,
							1075
						]
					],
					[
						[
							1076,
							1077
						]
					],
					[
						[
							1078,
							1079
						]
					],
					[
						[
							1080,
							-1065,
							1081,
							1082
						]
					]
				],
				id: "MWI",
				properties: {
					name: "Malawi"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1083
						]
					],
					[
						[
							-882,
							1084
						]
					],
					[
						[
							1085
						]
					],
					[
						[
							1086
						]
					],
					[
						[
							1087,
							1088
						]
					],
					[
						[
							-886,
							1089,
							-256,
							1090,
							-253,
							1091
						]
					],
					[
						[
							1092
						]
					]
				],
				id: "MYS",
				properties: {
					name: "Malaysia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1093,
						-261,
						1094,
						1095,
						-8
					]
				],
				id: "NAM",
				properties: {
					name: "Namibia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1096
						]
					],
					[
						[
							1097
						]
					],
					[
						[
							1098
						]
					]
				],
				id: "NCL",
				properties: {
					name: "New Caledonia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1099,
						1100,
						-173,
						-174,
						-1043,
						-588,
						-1000
					]
				],
				id: "NER",
				properties: {
					name: "Niger"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1101,
							-478,
							1102,
							-169,
							-1101
						]
					]
				],
				id: "NGA",
				properties: {
					name: "Nigeria"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1103,
							-528,
							1104,
							-776
						]
					]
				],
				id: "NIC",
				properties: {
					name: "Nicaragua"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-166,
							1105
						]
					],
					[
						[
							1106
						]
					],
					[
						[
							-562,
							-168,
							1107
						],
						[
							1108
						]
					]
				],
				id: "NLD",
				properties: {
					name: "Netherlands"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1109
						]
					],
					[
						[
							1110
						]
					],
					[
						[
							1111
						]
					],
					[
						[
							1112
						]
					],
					[
						[
							1113
						]
					],
					[
						[
							1114
						]
					],
					[
						[
							1115
						]
					],
					[
						[
							1116
						]
					],
					[
						[
							1117
						]
					],
					[
						[
							1118
						]
					],
					[
						[
							1119
						]
					],
					[
						[
							1120
						]
					],
					[
						[
							1121
						]
					],
					[
						[
							1122
						]
					],
					[
						[
							1123,
							-656,
							1124,
							1125
						]
					],
					[
						[
							1126
						]
					],
					[
						[
							1127
						]
					],
					[
						[
							1128
						]
					],
					[
						[
							1129
						]
					],
					[
						[
							1130
						]
					],
					[
						[
							1131
						]
					],
					[
						[
							1132
						]
					]
				],
				id: "NOR",
				properties: {
					name: "Norway"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-894,
						-454
					]
				],
				id: "NPL",
				properties: {
					name: "Nepal"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1133
						]
					],
					[
						[
							1134
						]
					],
					[
						[
							1135
						]
					],
					[
						[
							1136
						]
					],
					[
						[
							1137
						]
					],
					[
						[
							1138
						]
					]
				],
				id: "NZL",
				properties: {
					name: "New Zealand"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1139
						]
					],
					[
						[
							1140,
							1141,
							-37,
							1142
						]
					],
					[
						[
							-41
						],
						[
							-35
						]
					],
					[
						[
							-40,
							1143
						]
					]
				],
				id: "OMN",
				properties: {
					name: "Oman"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-954,
							-897,
							1144,
							-903,
							-2,
							-457
						]
					]
				],
				id: "PAK",
				properties: {
					name: "Pakistan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1145
						]
					],
					[
						[
							-517,
							1146,
							-526,
							1147
						]
					]
				],
				id: "PAN",
				properties: {
					name: "Panama"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-248,
							-221,
							1148,
							-215,
							1149,
							-219,
							-438,
							1150,
							-600,
							-514
						]
					]
				],
				id: "PER",
				properties: {
					name: "Peru"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1151
						]
					],
					[
						[
							1152
						]
					],
					[
						[
							1153
						]
					],
					[
						[
							1154
						]
					],
					[
						[
							1155
						]
					],
					[
						[
							1156
						]
					],
					[
						[
							1157
						]
					],
					[
						[
							1158
						]
					],
					[
						[
							1159
						]
					],
					[
						[
							1160
						]
					],
					[
						[
							1161
						]
					],
					[
						[
							1162
						]
					],
					[
						[
							1163
						]
					],
					[
						[
							1164
						]
					],
					[
						[
							1165
						]
					],
					[
						[
							1166
						]
					],
					[
						[
							1167
						]
					],
					[
						[
							1168
						]
					],
					[
						[
							1169
						]
					],
					[
						[
							1170
						]
					],
					[
						[
							1171
						]
					],
					[
						[
							1172
						]
					],
					[
						[
							1173
						]
					],
					[
						[
							1174
						]
					],
					[
						[
							1175
						]
					],
					[
						[
							1176
						]
					],
					[
						[
							1177
						]
					],
					[
						[
							1178
						]
					],
					[
						[
							1179
						]
					],
					[
						[
							1180
						]
					],
					[
						[
							1181
						]
					]
				],
				id: "PHL",
				properties: {
					name: "Philippines"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1182
						]
					]
				],
				id: "PLW",
				properties: {
					name: "Palau"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1183
						]
					],
					[
						[
							1184
						]
					],
					[
						[
							1185
						]
					],
					[
						[
							1186
						]
					],
					[
						[
							1187
						]
					],
					[
						[
							1188
						]
					],
					[
						[
							1189
						]
					],
					[
						[
							1190
						]
					],
					[
						[
							1191
						]
					],
					[
						[
							1192
						]
					],
					[
						[
							1193
						]
					],
					[
						[
							1194
						]
					],
					[
						[
							-858,
							1195
						]
					],
					[
						[
							1196
						]
					],
					[
						[
							1197
						]
					],
					[
						[
							1198
						]
					],
					[
						[
							1199
						]
					]
				],
				id: "PNG",
				properties: {
					name: "Papua New Guinea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1200,
						1201,
						1202,
						-1008,
						-209,
						1203,
						1204,
						-550,
						-558,
						1205,
						-554,
						1206
					]
				],
				id: "POL",
				properties: {
					name: "Poland"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1207
						]
					]
				],
				id: "PRI",
				properties: {
					name: "Puerto Rico"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1208,
							1209,
							-983,
							1210,
							-445
						]
					]
				],
				id: "PRK",
				properties: {
					name: "Dem. Rep. Korea"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1211
						]
					],
					[
						[
							1212
						]
					],
					[
						[
							1213
						]
					],
					[
						[
							1214
						]
					],
					[
						[
							1215,
							-633
						]
					]
				],
				id: "PRT",
				properties: {
					name: "Portugal"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-247,
						1216,
						-245,
						-46,
						-217
					]
				],
				id: "PRY",
				properties: {
					name: "Paraguay"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							-602,
							1217,
							-923
						]
					],
					[
						[
							-938,
							1218,
							-917
						]
					]
				],
				id: "PSX",
				properties: {
					name: "Palestine"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1219
						]
					]
				],
				id: "PYF",
				properties: {
					name: "Fr. Polynesia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1220,
						1221
					]
				],
				id: "QAT",
				properties: {
					name: "Qatar"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1222,
						1223,
						-189,
						1224,
						-795,
						1225,
						-1021
					]
				],
				id: "ROU",
				properties: {
					name: "Romania"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1226
						]
					],
					[
						[
							1227
						]
					],
					[
						[
							1228
						]
					],
					[
						[
							1229
						]
					],
					[
						[
							1230
						]
					],
					[
						[
							1231
						]
					],
					[
						[
							1232
						]
					],
					[
						[
							1233
						]
					],
					[
						[
							1234
						]
					],
					[
						[
							1235
						]
					],
					[
						[
							1236
						]
					],
					[
						[
							-1203,
							1237,
							-1201,
							1238,
							-1006,
							1239,
							-1009
						]
					],
					[
						[
							1240
						]
					],
					[
						[
							1241
						]
					],
					[
						[
							1242,
							-639
						]
					],
					[
						[
							1243
						]
					],
					[
						[
							1244
						]
					],
					[
						[
							1245
						]
					],
					[
						[
							1246
						]
					],
					[
						[
							1247
						]
					],
					[
						[
							1248
						]
					],
					[
						[
							1249
						]
					],
					[
						[
							1250
						]
					],
					[
						[
							1251
						]
					],
					[
						[
							1252
						]
					],
					[
						[
							1253
						]
					],
					[
						[
							1254
						]
					],
					[
						[
							1255
						]
					],
					[
						[
							1256
						]
					],
					[
						[
							1257
						]
					],
					[
						[
							1258
						]
					],
					[
						[
							1259
						]
					],
					[
						[
							1260
						]
					],
					[
						[
							1261
						]
					],
					[
						[
							1262
						]
					],
					[
						[
							1263
						]
					],
					[
						[
							1264
						]
					],
					[
						[
							1265
						]
					],
					[
						[
							1266
						]
					],
					[
						[
							1267
						]
					],
					[
						[
							1268
						]
					],
					[
						[
							1269
						]
					],
					[
						[
							1270
						]
					],
					[
						[
							-1209,
							-444,
							1271,
							-465,
							-1059,
							-461,
							-963,
							1272,
							-154,
							-699,
							1273,
							1274,
							-207,
							-1012,
							-643,
							1275,
							-641,
							1276,
							-637,
							1277,
							-653,
							-1124,
							1278
						]
					],
					[
						[
							1279
						]
					],
					[
						[
							1280
						]
					],
					[
						[
							1281
						]
					],
					[
						[
							1282
						]
					],
					[
						[
							1283
						]
					],
					[
						[
							1284
						]
					],
					[
						[
							1285
						]
					],
					[
						[
							1286
						]
					],
					[
						[
							1287
						]
					],
					[
						[
							1288
						]
					],
					[
						[
							1289
						]
					],
					[
						[
							1290
						]
					],
					[
						[
							1291
						]
					],
					[
						[
							1292
						]
					],
					[
						[
							1293
						]
					],
					[
						[
							1294
						]
					],
					[
						[
							1295
						]
					],
					[
						[
							1296
						]
					],
					[
						[
							1297
						]
					],
					[
						[
							1298
						]
					]
				],
				id: "RUS",
				properties: {
					name: "Russia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1299,
						-161,
						-504,
						1300,
						-502,
						1301
					]
				],
				id: "RWA",
				properties: {
					name: "Rwanda"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-591,
						-1071,
						1302,
						-1018
					]
				],
				id: "ESH",
				properties: {
					name: "W. Sahara"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1303
						]
					],
					[
						[
							-989,
							1304,
							-1221,
							1305,
							-38,
							-1142,
							1306,
							1307,
							-934,
							-909
						]
					]
				],
				id: "SAU",
				properties: {
					name: "Saudi Arabia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1308,
							-610,
							-651,
							1309,
							-262,
							1310,
							-998,
							-605
						]
					]
				],
				id: "SDN",
				properties: {
					name: "Sudan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-650,
						-969,
						1311,
						-496,
						-263,
						-1310
					]
				],
				id: "SSD",
				properties: {
					name: "S. Sudan"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-1044,
						-709,
						-714,
						1312,
						-711,
						1313,
						-1069
					]
				],
				id: "SEN",
				properties: {
					name: "Senegal"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1314
					]
				],
				id: "SGP",
				properties: {
					name: "Singapore"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1315
						]
					]
				],
				id: "SGS",
				properties: {
					name: "S. Geo. and S. Sandw. Is."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1316
						]
					],
					[
						[
							1317
						]
					],
					[
						[
							1318
						]
					],
					[
						[
							1319
						]
					],
					[
						[
							1320
						]
					],
					[
						[
							1321
						]
					],
					[
						[
							1322
						]
					],
					[
						[
							1323
						]
					],
					[
						[
							1324
						]
					],
					[
						[
							1325
						]
					],
					[
						[
							1326
						]
					],
					[
						[
							1327
						]
					],
					[
						[
							1328
						]
					]
				],
				id: "SLB",
				properties: {
					name: "Solomon Is."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1329
						]
					],
					[
						[
							-997,
							1330,
							-706
						]
					]
				],
				id: "SLE",
				properties: {
					name: "Sierra Leone"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-778,
							1331,
							-767
						]
					]
				],
				id: "SLV",
				properties: {
					name: "El Salvador"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-931
					]
				],
				id: "SMR",
				properties: {
					name: "San Marino"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1332,
						-647,
						-565,
						1333
					]
				],
				id: "SOL",
				properties: {
					name: "Somaliland"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-964,
						-648,
						-1333,
						1334
					]
				],
				id: "SOM",
				properties: {
					name: "Somalia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-1225,
						-188,
						-1042,
						-987,
						-1054,
						-202,
						-787,
						-796
					]
				],
				id: "SRB",
				properties: {
					name: "Serbia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1335
						]
					]
				],
				id: "STP",
				properties: {
					name: "São Tomé and Principe"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-664,
						-239,
						-771,
						1336
					]
				],
				id: "SUR",
				properties: {
					name: "Suriname"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1337,
						-798,
						-142,
						-551,
						-1205
					]
				],
				id: "SVK",
				properties: {
					name: "Slovakia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-789,
						1338,
						-929,
						-144,
						-797
					]
				],
				id: "SVN",
				properties: {
					name: "Slovenia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1339
						]
					],
					[
						[
							1340
						]
					],
					[
						[
							1341
						]
					],
					[
						[
							1342,
							-1125,
							-655
						]
					]
				],
				id: "SWE",
				properties: {
					name: "Sweden"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-1061,
						1343
					]
				],
				id: "SWZ",
				properties: {
					name: "Swaziland"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						1344,
						-1014
					]
				],
				id: "SXM",
				properties: {
					name: "Sint Maarten"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-913,
						911,
						-911,
						-939,
						-926,
						-995,
						1345,
						1346
					]
				],
				id: "SYR",
				properties: {
					name: "Syria"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-1311,
						-267,
						-473,
						1347,
						-481,
						1348,
						-479,
						-1102,
						-1100,
						-999
					]
				],
				id: "TCD",
				properties: {
					name: "Chad"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-171,
						1349,
						-700,
						-175
					]
				],
				id: "TGO",
				properties: {
					name: "Togo"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1350
						]
					],
					[
						[
							1351
						]
					],
					[
						[
							-992,
							-976,
							1352,
							-1089,
							1353,
							-1052
						]
					]
				],
				id: "THA",
				properties: {
					name: "Thailand"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-974
						]
					],
					[
						[
							1354
						]
					],
					[
						[
							-970,
							-458,
							-6,
							1355
						]
					]
				],
				id: "TJK",
				properties: {
					name: "Tajikistan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-4,
							-902,
							1356,
							-961,
							1357,
							1358,
							1359
						]
					]
				],
				id: "TKM",
				properties: {
					name: "Turkmenistan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1360,
							-803
						]
					],
					[
						[
							-805,
							1361
						]
					]
				],
				id: "TLS",
				properties: {
					name: "Timor-Leste"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1362
						]
					]
				],
				id: "TON",
				properties: {
					name: "Tonga"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1363
						]
					]
				],
				id: "TTO",
				properties: {
					name: "Trinidad and Tobago"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1364
						]
					],
					[
						[
							-1001,
							-586,
							1365
						]
					]
				],
				id: "TUN",
				properties: {
					name: "Tunisia"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1366,
							-734,
							-185
						]
					],
					[
						[
							-697,
							-56,
							-153,
							-906,
							-914,
							-1347,
							1367
						]
					]
				],
				id: "TUR",
				properties: {
					name: "Turkey"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1368
						]
					]
				],
				id: "TWN",
				properties: {
					name: "Taiwan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1369
						]
					],
					[
						[
							1370
						]
					],
					[
						[
							1371
						]
					],
					[
						[
							1372
						]
					],
					[
						[
							1373,
							1374,
							1375,
							-966,
							1376,
							-1067,
							1377,
							-1074,
							1378,
							-1076,
							1379,
							-1078,
							1380,
							-1080,
							1381,
							-1083,
							1382,
							1383,
							-158,
							-1300,
							1384
						]
					]
				],
				id: "TZA",
				properties: {
					name: "Tanzania"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-1375,
							1385
						]
					],
					[
						[
							1386,
							-1385,
							-1302,
							-501,
							1387,
							-499,
							1388,
							-497,
							-1312,
							-968
						]
					]
				],
				id: "UGA",
				properties: {
					name: "Uganda"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1389,
							-1223,
							-1022,
							-1226,
							-794,
							-1338,
							-1204,
							-208,
							-1275
						],
						[
							1390
						],
						[
							1391
						]
					]
				],
				id: "UKR",
				properties: {
					name: "Ukraine"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1392,
						-242,
						1393,
						-48,
						-244
					]
				],
				id: "URY",
				properties: {
					name: "Uruguay"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1394
						]
					],
					[
						[
							1395
						]
					],
					[
						[
							1396
						]
					],
					[
						[
							1397
						]
					],
					[
						[
							1398
						]
					],
					[
						[
							1399
						]
					],
					[
						[
							1400
						]
					],
					[
						[
							1401
						]
					],
					[
						[
							1402
						]
					],
					[
						[
							1403
						]
					],
					[
						[
							1404
						]
					],
					[
						[
							1405
						]
					],
					[
						[
							1406
						]
					],
					[
						[
							1407
						]
					],
					[
						[
							1408
						]
					],
					[
						[
							1409
						]
					],
					[
						[
							1410,
							-344
						]
					],
					[
						[
							1411,
							-340,
							1412,
							-338,
							1413,
							-336,
							1414,
							-334,
							-278,
							1415,
							-276,
							1416,
							-1033,
							1417,
							-1031,
							1418,
							-1036,
							1419,
							-342
						]
					],
					[
						[
							1420
						]
					],
					[
						[
							1421
						]
					],
					[
						[
							1422
						]
					],
					[
						[
							1423
						]
					],
					[
						[
							1424
						]
					],
					[
						[
							1425
						]
					],
					[
						[
							1426
						]
					],
					[
						[
							1427
						]
					],
					[
						[
							1428
						]
					],
					[
						[
							1429
						]
					],
					[
						[
							1430
						]
					],
					[
						[
							1431
						]
					],
					[
						[
							1432
						]
					],
					[
						[
							1433
						]
					],
					[
						[
							1434
						]
					],
					[
						[
							1435
						]
					],
					[
						[
							1436
						]
					],
					[
						[
							1437
						]
					],
					[
						[
							1438
						]
					],
					[
						[
							1439
						]
					],
					[
						[
							1440
						]
					],
					[
						[
							1441
						]
					],
					[
						[
							1442
						]
					],
					[
						[
							1443
						]
					],
					[
						[
							1444
						]
					],
					[
						[
							1445
						]
					],
					[
						[
							1446
						]
					],
					[
						[
							1447
						]
					],
					[
						[
							1448
						]
					],
					[
						[
							1449
						]
					],
					[
						[
							1450
						]
					],
					[
						[
							1451
						]
					],
					[
						[
							1452
						]
					],
					[
						[
							1453
						]
					],
					[
						[
							-347,
							345,
							1454
						]
					]
				],
				id: "USA",
				properties: {
					name: "United States"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-534,
							1455
						]
					],
					[
						[
							1456,
							-532
						]
					]
				],
				id: "USG",
				properties: {
					name: "USNB Guantanamo Bay"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-973
						]
					],
					[
						[
							-972
						]
					],
					[
						[
							-955,
							1457,
							-958,
							-971,
							-1356,
							-5,
							-1360,
							1458,
							-1358,
							-960,
							1459
						],
						[
							-1355
						]
					]
				],
				id: "UZB",
				properties: {
					name: "Uzbekistan"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-932
					]
				],
				id: "VAT",
				properties: {
					name: "Vatican"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1460
						]
					]
				],
				id: "VCT",
				properties: {
					name: "St. Vin. and Gren."
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1461
						]
					],
					[
						[
							1462
						]
					],
					[
						[
							1463
						]
					],
					[
						[
							-772,
							-250,
							-513,
							1464
						]
					]
				],
				id: "VEN",
				properties: {
					name: "Venezuela"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1465
						]
					],
					[
						[
							1466,
							-978,
							-991,
							-449
						]
					]
				],
				id: "VNM",
				properties: {
					name: "Vietnam"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1467
						]
					],
					[
						[
							1468
						]
					],
					[
						[
							1469
						]
					],
					[
						[
							1470
						]
					],
					[
						[
							1471
						]
					],
					[
						[
							1472
						]
					],
					[
						[
							1473
						]
					],
					[
						[
							1474
						]
					],
					[
						[
							1475
						]
					],
					[
						[
							1476
						]
					],
					[
						[
							1477
						]
					],
					[
						[
							1478
						]
					]
				],
				id: "VUT",
				properties: {
					name: "Vanuatu"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						1479,
						-547
					]
				],
				id: "WSB",
				properties: {
					name: "Akrotiri"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						[
							1480
						]
					],
					[
						[
							1481
						]
					]
				],
				id: "WSM",
				properties: {
					name: "Samoa"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							1482
						]
					],
					[
						[
							1483,
							-1307,
							-1141
						]
					]
				],
				id: "YEM",
				properties: {
					name: "Yemen"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						[
							-1062,
							-1344,
							-1060,
							1484,
							-1095,
							-260,
							1485
						],
						[
							-1005
						]
					]
				],
				id: "ZAF",
				properties: {
					name: "South Africa"
				},
				type: "MultiPolygon"
			},
			{
				arcs: [
					[
						-1383,
						-1082,
						-1064,
						1486,
						1487,
						1488,
						-1094,
						-7,
						-508,
						1489,
						-506,
						1490
					]
				],
				id: "ZMB",
				properties: {
					name: "Zambia"
				},
				type: "Polygon"
			},
			{
				arcs: [
					[
						-1063,
						-1486,
						-259,
						-1489,
						1491,
						-1487
					]
				],
				id: "ZWE",
				properties: {
					name: "Zimbabwe"
				},
				type: "Polygon"
			}
		],
		type: "GeometryCollection"
	}
};
var transform$1 = {
	scale: [
		0.036003600360036005,
		0.01736514657995801
	],
	translate: [
		-180,
		-90
	]
};
var type$1 = "Topology";
var topology$1 = {
	arcs: arcs$1,
	objects: objects$1,
	transform: transform$1,
	type: type$1
};

var countriesAbbr = [
	{
		country: "Afghanistan",
		abbreviation: "AF"
	},
	{
		country: "Albania",
		abbreviation: "AL"
	},
	{
		country: "Algeria",
		abbreviation: "DZ"
	},
	{
		country: "American Samoa",
		abbreviation: "AS"
	},
	{
		country: "Andorra",
		abbreviation: "AD"
	},
	{
		country: "Angola",
		abbreviation: "AO"
	},
	{
		country: "Anguilla",
		abbreviation: "AI"
	},
	{
		country: "Antarctica",
		abbreviation: "AQ"
	},
	{
		country: "Antigua and Barbuda",
		abbreviation: "AG"
	},
	{
		country: "Argentina",
		abbreviation: "AR"
	},
	{
		country: "Armenia",
		abbreviation: "AM"
	},
	{
		country: "Aruba",
		abbreviation: "AW"
	},
	{
		country: "Australia",
		abbreviation: "AU"
	},
	{
		country: "Austria",
		abbreviation: "AT"
	},
	{
		country: "Azerbaijan",
		abbreviation: "AZ"
	},
	{
		country: "Bahamas",
		abbreviation: "BS"
	},
	{
		country: "Bahrain",
		abbreviation: "BH"
	},
	{
		country: "Bangladesh",
		abbreviation: "BD"
	},
	{
		country: "Barbados",
		abbreviation: "BB"
	},
	{
		country: "Belarus",
		abbreviation: "BY"
	},
	{
		country: "Belgium",
		abbreviation: "BE"
	},
	{
		country: "Belize",
		abbreviation: "BZ"
	},
	{
		country: "Benin",
		abbreviation: "BJ"
	},
	{
		country: "Bermuda",
		abbreviation: "BM"
	},
	{
		country: "Bhutan",
		abbreviation: "BT"
	},
	{
		country: "Bolivia",
		abbreviation: "BO"
	},
	{
		country: "Bosnia and Herzegovina",
		abbreviation: "BA"
	},
	{
		country: "Botswana",
		abbreviation: "BW"
	},
	{
		country: "Bouvet Island",
		abbreviation: "BV"
	},
	{
		country: "Brazil",
		abbreviation: "BR"
	},
	{
		country: "British Indian Ocean Territory",
		abbreviation: "IO"
	},
	{
		country: "Brunei",
		abbreviation: "BN"
	},
	{
		country: "Bulgaria",
		abbreviation: "BG"
	},
	{
		country: "Burkina Faso",
		abbreviation: "BF"
	},
	{
		country: "Burundi",
		abbreviation: "BI"
	},
	{
		country: "Cambodia",
		abbreviation: "KH"
	},
	{
		country: "Cameroon",
		abbreviation: "CM"
	},
	{
		country: "Canada",
		abbreviation: "CA"
	},
	{
		country: "Cape Verde",
		abbreviation: "CV"
	},
	{
		country: "Cayman Islands",
		abbreviation: "KY"
	},
	{
		country: "Central African Republic",
		abbreviation: "CF"
	},
	{
		country: "Chad",
		abbreviation: "TD"
	},
	{
		country: "Chile",
		abbreviation: "CL"
	},
	{
		country: "China",
		abbreviation: "CN"
	},
	{
		country: "Christmas Island",
		abbreviation: "CX"
	},
	{
		country: "Cocos (Keeling) Islands",
		abbreviation: "CC"
	},
	{
		country: "Colombia",
		abbreviation: "CO"
	},
	{
		country: "Comoros",
		abbreviation: "KM"
	},
	{
		country: "Congo",
		abbreviation: "CG"
	},
	{
		country: "Cook Islands",
		abbreviation: "CK"
	},
	{
		country: "Costa Rica",
		abbreviation: "CR"
	},
	{
		country: "Croatia",
		abbreviation: "HR"
	},
	{
		country: "Cuba",
		abbreviation: "CU"
	},
	{
		country: "Cyprus",
		abbreviation: "CY"
	},
	{
		country: "Czech Republic",
		abbreviation: "CZ"
	},
	{
		country: "Denmark",
		abbreviation: "DK"
	},
	{
		country: "Djibouti",
		abbreviation: "DJ"
	},
	{
		country: "Dominica",
		abbreviation: "DM"
	},
	{
		country: "Dominican Republic",
		abbreviation: "DO"
	},
	{
		country: "East Timor",
		abbreviation: "TP"
	},
	{
		country: "Ecuador",
		abbreviation: "EC"
	},
	{
		country: "Egypt",
		abbreviation: "EG"
	},
	{
		country: "El Salvador",
		abbreviation: "SV"
	},
	{
		country: "Equatorial Guinea",
		abbreviation: "GQ"
	},
	{
		country: "Eritrea",
		abbreviation: "ER"
	},
	{
		country: "Estonia",
		abbreviation: "EE"
	},
	{
		country: "Ethiopia",
		abbreviation: "ET"
	},
	{
		country: "Falkland Islands",
		abbreviation: "FK"
	},
	{
		country: "Faroe Islands",
		abbreviation: "FO"
	},
	{
		country: "Fiji Islands",
		abbreviation: "FJ"
	},
	{
		country: "Finland",
		abbreviation: "FI"
	},
	{
		country: "France",
		abbreviation: "FR"
	},
	{
		country: "French Guiana",
		abbreviation: "GF"
	},
	{
		country: "French Polynesia",
		abbreviation: "PF"
	},
	{
		country: "French Southern territories",
		abbreviation: "TF"
	},
	{
		country: "Gabon",
		abbreviation: "GA"
	},
	{
		country: "Gambia",
		abbreviation: "GM"
	},
	{
		country: "Georgia",
		abbreviation: "GE"
	},
	{
		country: "Germany",
		abbreviation: "DE"
	},
	{
		country: "Ghana",
		abbreviation: "GH"
	},
	{
		country: "Gibraltar",
		abbreviation: "GI"
	},
	{
		country: "Greece",
		abbreviation: "GR"
	},
	{
		country: "Greenland",
		abbreviation: "GL"
	},
	{
		country: "Grenada",
		abbreviation: "GD"
	},
	{
		country: "Guadeloupe",
		abbreviation: "GP"
	},
	{
		country: "Guam",
		abbreviation: "GU"
	},
	{
		country: "Guatemala",
		abbreviation: "GT"
	},
	{
		country: "Guernsey",
		abbreviation: "GG"
	},
	{
		country: "Guinea",
		abbreviation: "GN"
	},
	{
		country: "Guinea-Bissau",
		abbreviation: "GW"
	},
	{
		country: "Guyana",
		abbreviation: "GY"
	},
	{
		country: "Haiti",
		abbreviation: "HT"
	},
	{
		country: "Heard Island and McDonald Islands",
		abbreviation: "HM"
	},
	{
		country: "Holy See (Vatican City State)",
		abbreviation: "VA"
	},
	{
		country: "Honduras",
		abbreviation: "HN"
	},
	{
		country: "Hong Kong",
		abbreviation: "HK"
	},
	{
		country: "Hungary",
		abbreviation: "HU"
	},
	{
		country: "Iceland",
		abbreviation: "IS"
	},
	{
		country: "India",
		abbreviation: "IN"
	},
	{
		country: "Indonesia",
		abbreviation: "ID"
	},
	{
		country: "Iran",
		abbreviation: "IR"
	},
	{
		country: "Iraq",
		abbreviation: "IQ"
	},
	{
		country: "Ireland",
		abbreviation: "IE"
	},
	{
		country: "Isle of Man",
		abbreviation: "IM"
	},
	{
		country: "Israel",
		abbreviation: "IL"
	},
	{
		country: "Italy",
		abbreviation: "IT"
	},
	{
		country: "Ivory Coast",
		abbreviation: "CI"
	},
	{
		country: "Jamaica",
		abbreviation: "JM"
	},
	{
		country: "Japan",
		abbreviation: "JP"
	},
	{
		country: "Jersey",
		abbreviation: "JE"
	},
	{
		country: "Jordan",
		abbreviation: "JO"
	},
	{
		country: "Kazakhstan",
		abbreviation: "KZ"
	},
	{
		country: "Kenya",
		abbreviation: "KE"
	},
	{
		country: "Kiribati",
		abbreviation: "KI"
	},
	{
		country: "Kuwait",
		abbreviation: "KW"
	},
	{
		country: "Kyrgyzstan",
		abbreviation: "KG"
	},
	{
		country: "Laos",
		abbreviation: "LA"
	},
	{
		country: "Latvia",
		abbreviation: "LV"
	},
	{
		country: "Lebanon",
		abbreviation: "LB"
	},
	{
		country: "Lesotho",
		abbreviation: "LS"
	},
	{
		country: "Liberia",
		abbreviation: "LR"
	},
	{
		country: "Libyan Arab Jamahiriya",
		abbreviation: "LY"
	},
	{
		country: "Liechtenstein",
		abbreviation: "LI"
	},
	{
		country: "Lithuania",
		abbreviation: "LT"
	},
	{
		country: "Luxembourg",
		abbreviation: "LU"
	},
	{
		country: "Macao",
		abbreviation: "MO"
	},
	{
		country: "North Macedonia",
		abbreviation: "MK"
	},
	{
		country: "Madagascar",
		abbreviation: "MG"
	},
	{
		country: "Malawi",
		abbreviation: "MW"
	},
	{
		country: "Malaysia",
		abbreviation: "MY"
	},
	{
		country: "Maldives",
		abbreviation: "MV"
	},
	{
		country: "Mali",
		abbreviation: "ML"
	},
	{
		country: "Malta",
		abbreviation: "MT"
	},
	{
		country: "Marshall Islands",
		abbreviation: "MH"
	},
	{
		country: "Martinique",
		abbreviation: "MQ"
	},
	{
		country: "Mauritania",
		abbreviation: "MR"
	},
	{
		country: "Mauritius",
		abbreviation: "MU"
	},
	{
		country: "Mayotte",
		abbreviation: "YT"
	},
	{
		country: "Mexico",
		abbreviation: "MX"
	},
	{
		country: "Micronesia, Federated States of",
		abbreviation: "FM"
	},
	{
		country: "Moldova",
		abbreviation: "MD"
	},
	{
		country: "Monaco",
		abbreviation: "MC"
	},
	{
		country: "Mongolia",
		abbreviation: "MN"
	},
	{
		country: "Montenegro",
		abbreviation: "ME"
	},
	{
		country: "Montserrat",
		abbreviation: "MS"
	},
	{
		country: "Morocco",
		abbreviation: "MA"
	},
	{
		country: "Mozambique",
		abbreviation: "MZ"
	},
	{
		country: "Myanmar",
		abbreviation: "MM"
	},
	{
		country: "Namibia",
		abbreviation: "NA"
	},
	{
		country: "Nauru",
		abbreviation: "NR"
	},
	{
		country: "Nepal",
		abbreviation: "NP"
	},
	{
		country: "Netherlands",
		abbreviation: "NL"
	},
	{
		country: "Netherlands Antilles",
		abbreviation: "AN"
	},
	{
		country: "New Caledonia",
		abbreviation: "NC"
	},
	{
		country: "New Zealand",
		abbreviation: "NZ"
	},
	{
		country: "Nicaragua",
		abbreviation: "NI"
	},
	{
		country: "Niger",
		abbreviation: "NE"
	},
	{
		country: "Nigeria",
		abbreviation: "NG"
	},
	{
		country: "Niue",
		abbreviation: "NU"
	},
	{
		country: "Norfolk Island",
		abbreviation: "NF"
	},
	{
		country: "North Korea",
		abbreviation: "KP"
	},
	{
		country: "Northern Ireland",
		abbreviation: "GB"
	},
	{
		country: "Northern Mariana Islands",
		abbreviation: "MP"
	},
	{
		country: "Norway",
		abbreviation: "NO"
	},
	{
		country: "Oman",
		abbreviation: "OM"
	},
	{
		country: "Pakistan",
		abbreviation: "PK"
	},
	{
		country: "Palau",
		abbreviation: "PW"
	},
	{
		country: "Palestine",
		abbreviation: "PS"
	},
	{
		country: "Panama",
		abbreviation: "PA"
	},
	{
		country: "Papua New Guinea",
		abbreviation: "PG"
	},
	{
		country: "Paraguay",
		abbreviation: "PY"
	},
	{
		country: "Peru",
		abbreviation: "PE"
	},
	{
		country: "Philippines",
		abbreviation: "PH"
	},
	{
		country: "Pitcairn",
		abbreviation: "PN"
	},
	{
		country: "Poland",
		abbreviation: "PL"
	},
	{
		country: "Portugal",
		abbreviation: "PT"
	},
	{
		country: "Puerto Rico",
		abbreviation: "PR"
	},
	{
		country: "Qatar",
		abbreviation: "QA"
	},
	{
		country: "Reunion",
		abbreviation: "RE"
	},
	{
		country: "Romania",
		abbreviation: "RO"
	},
	{
		country: "Russian Federation",
		abbreviation: "RU"
	},
	{
		country: "Rwanda",
		abbreviation: "RW"
	},
	{
		country: "Saint Helena",
		abbreviation: "SH"
	},
	{
		country: "Saint Kitts and Nevis",
		abbreviation: "KN"
	},
	{
		country: "Saint Lucia",
		abbreviation: "LC"
	},
	{
		country: "Saint Pierre and Miquelon",
		abbreviation: "PM"
	},
	{
		country: "Saint Vincent and the Grenadines",
		abbreviation: "VC"
	},
	{
		country: "Samoa",
		abbreviation: "WS"
	},
	{
		country: "San Marino",
		abbreviation: "SM"
	},
	{
		country: "Sao Tome and Principe",
		abbreviation: "ST"
	},
	{
		country: "Saudi Arabia",
		abbreviation: "SA"
	},
	{
		country: "Senegal",
		abbreviation: "SN"
	},
	{
		country: "Serbia",
		abbreviation: "RS"
	},
	{
		country: "Seychelles",
		abbreviation: "SC"
	},
	{
		country: "Sierra Leone",
		abbreviation: "SL"
	},
	{
		country: "Singapore",
		abbreviation: "SG"
	},
	{
		country: "Slovakia",
		abbreviation: "SK"
	},
	{
		country: "Slovenia",
		abbreviation: "SI"
	},
	{
		country: "Solomon Islands",
		abbreviation: "SB"
	},
	{
		country: "Somalia",
		abbreviation: "SO"
	},
	{
		country: "South Africa",
		abbreviation: "ZA"
	},
	{
		country: "South Georgia and the South Sandwich Islands",
		abbreviation: "GS"
	},
	{
		country: "South Korea",
		abbreviation: "KR"
	},
	{
		country: "South Sudan",
		abbreviation: "SS"
	},
	{
		country: "Spain",
		abbreviation: "ES"
	},
	{
		country: "Sri Lanka",
		abbreviation: "LK"
	},
	{
		country: "Sudan",
		abbreviation: "SD"
	},
	{
		country: "Suriname",
		abbreviation: "SR"
	},
	{
		country: "Svalbard and Jan Mayen",
		abbreviation: "SJ"
	},
	{
		country: "Swaziland",
		abbreviation: "SZ"
	},
	{
		country: "Sweden",
		abbreviation: "SE"
	},
	{
		country: "Switzerland",
		abbreviation: "CH"
	},
	{
		country: "Syria",
		abbreviation: "SY"
	},
	{
		country: "Tajikistan",
		abbreviation: "TJ"
	},
	{
		country: "Tanzania",
		abbreviation: "TZ"
	},
	{
		country: "Thailand",
		abbreviation: "TH"
	},
	{
		country: "The Democratic Republic of Congo",
		abbreviation: "CD"
	},
	{
		country: "Timor-Leste",
		abbreviation: "TL"
	},
	{
		country: "Togo",
		abbreviation: "TG"
	},
	{
		country: "Tokelau",
		abbreviation: "TK"
	},
	{
		country: "Tonga",
		abbreviation: "TO"
	},
	{
		country: "Trinidad and Tobago",
		abbreviation: "TT"
	},
	{
		country: "Tunisia",
		abbreviation: "TN"
	},
	{
		country: "Turkey",
		abbreviation: "TR"
	},
	{
		country: "Turkmenistan",
		abbreviation: "TM"
	},
	{
		country: "Turks and Caicos Islands",
		abbreviation: "TC"
	},
	{
		country: "Tuvalu",
		abbreviation: "TV"
	},
	{
		country: "Uganda",
		abbreviation: "UG"
	},
	{
		country: "Ukraine",
		abbreviation: "UA"
	},
	{
		country: "United Arab Emirates",
		abbreviation: "AE"
	},
	{
		country: "United Kingdom",
		abbreviation: "UK"
	},
	{
		country: "United States",
		abbreviation: "US"
	},
	{
		country: "United States Minor Outlying Islands",
		abbreviation: "UM"
	},
	{
		country: "Uruguay",
		abbreviation: "UY"
	},
	{
		country: "Uzbekistan",
		abbreviation: "UZ"
	},
	{
		country: "Vanuatu",
		abbreviation: "VU"
	},
	{
		country: "Venezuela",
		abbreviation: "VE"
	},
	{
		country: "Vietnam",
		abbreviation: "VN"
	},
	{
		country: "Virgin Islands, British",
		abbreviation: "VG"
	},
	{
		country: "Virgin Islands, U.S.",
		abbreviation: "VI"
	},
	{
		country: "Wallis and Futuna",
		abbreviation: "WF"
	},
	{
		country: "Western Sahara",
		abbreviation: "EH"
	},
	{
		country: "Yemen",
		abbreviation: "YE"
	},
	{
		country: "Zambia",
		abbreviation: "ZM"
	},
	{
		country: "Zimbabwe",
		abbreviation: "ZW"
	}
];

function _templateObject$g() {
  var data = _taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 100%;\n  position: relative;\n  background-color: #ffffff;\n  padding: 10px;\n"]);

  _templateObject$g = function _templateObject() {
    return data;
  };

  return data;
}
var StyledWorldMapChartWrapper = styled__default.div(_templateObject$g());
var world = topojson.feature(topology$1, topology$1.objects.units);
var tooltipTimeout$9;

var WorldMapChart = function WorldMapChart(_ref) {
  var data = _ref.data,
      metric = _ref.metric,
      color = _ref.color,
      emptyDataMessage = _ref.emptyDataMessage;
  var svgRef = React.useRef(null);
  var chartId = React.useRef(uniqid());
  var isEmpty = !data || data.length === 0;

  var _useState = React.useState(0),
      width = _useState[0],
      setWidth = _useState[1];

  var _useState2 = React.useState(0),
      height = _useState2[0],
      setHeight = _useState2[1];

  var centerX = width / 2;
  var centerY = height / 2;
  var scale$1 = width / 630 * 100;
  var max = data && Math.max.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;
  var min = data && Math.min.apply(Math, data.map(function (item) {
    return item[metric];
  })) || 0;

  var _useTooltip = tooltip.useTooltip(),
      tooltipOpen = _useTooltip.tooltipOpen,
      tooltipLeft = _useTooltip.tooltipLeft,
      tooltipTop = _useTooltip.tooltipTop,
      tooltipData = _useTooltip.tooltipData,
      hideTooltip = _useTooltip.hideTooltip,
      showTooltip = _useTooltip.showTooltip;

  var windowSize = useWindowSize();
  var chartRef = React.useCallback(function (node) {
    if (node != null) {
      setWidth(node.getBoundingClientRect().width);
      setHeight(node.getBoundingClientRect().height);
    }
  }, [windowSize]);
  var colorsRange = getMapColors(color);
  var colorScale = React.useMemo(function () {
    return scale.scaleLinear({
      domain: [metric === METRICS.AFFINITY ? min : min * 100, metric === METRICS.AFFINITY ? max : max * 100],
      range: colorsRange
    });
  }, [metric, min, max, color]);
  var getFillColor = React.useCallback(function (item) {
    if (!metric) {
      return '#d8d7ea';
    }

    var value = item[metric] || 0;

    if (metric !== METRICS.AFFINITY) {
      value = value * 100;
    }

    return colorScale(value);
  }, [metric, colorScale]);
  var handleMouseMove = React.useCallback(function (event$1, feature, color) {
    if (color === void 0) {
      color = '#000000';
    }

    if (tooltipTimeout$9) clearTimeout(tooltipTimeout$9);
    if (!svgRef.current) return;
    var point = event.localPoint(svgRef.current, event$1);
    showTooltip({
      tooltipData: _extends({}, feature, {
        color: color
      }),
      tooltipTop: point === null || point === void 0 ? void 0 : point.y,
      tooltipLeft: point === null || point === void 0 ? void 0 : point.x
    });
  }, [svgRef, showTooltip]);
  var handleMouseLeave = React.useCallback(function (event) {
    tooltipTimeout$9 = window.setTimeout(function () {
      hideTooltip();
    }, 0);
  }, [hideTooltip]);

  if (isEmpty) {
    return /*#__PURE__*/React__default.createElement(StyledWorldMapChartWrapper, null, /*#__PURE__*/React__default.createElement(hxReactComponents.Box, {
      minWidth: "100%"
    }, /*#__PURE__*/React__default.createElement(hxReactComponents.EmptyState, {
      icon: "alert",
      mainText: emptyDataMessage,
      size: "large"
    })));
  }

  var checkGreatBritain = function checkGreatBritain(featureId, itemId) {
    return featureId === 'UK' && itemId === 'GB';
  };

  return /*#__PURE__*/React__default.createElement(StyledWorldMapChartWrapper, {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement("svg", {
    width: width,
    height: height,
    ref: svgRef
  }, /*#__PURE__*/React__default.createElement("rect", {
    x: 0,
    y: 0,
    width: width,
    height: height,
    fill: "#ffffff",
    rx: 14
  }), /*#__PURE__*/React__default.createElement(geo.Mercator, {
    data: world.features,
    scale: scale$1,
    translate: [centerX, centerY + 50]
  }, function (mercator) {
    return /*#__PURE__*/React__default.createElement(group.Group, {
      key: "group-" + chartId.current
    }, mercator.features.map(function (_ref2, i) {
      var feature = _ref2.feature,
          path = _ref2.path;
      var abbr = countriesAbbr.find(function (abbr) {
        return abbr.country === feature.properties.name;
      });
      var included = data && data.find(function (item) {
        return abbr && (item.id === abbr.abbreviation || checkGreatBritain(abbr.abbreviation, item.id));
      });

      if (included) {
        return /*#__PURE__*/React__default.createElement("path", {
          key: "map-feature-" + i,
          d: path || '',
          fill: getFillColor(included),
          stroke: "#ffffff",
          strokeWidth: 0.5,
          onMouseOver: function onMouseOver(event) {
            return handleMouseMove(event, included, getFillColor(included));
          },
          onMouseMove: function onMouseMove(event) {
            return handleMouseMove(event, included, getFillColor(included));
          },
          onMouseLeave: function onMouseLeave(event) {
            return handleMouseLeave(event);
          }
        });
      }

      if (abbr && abbr.country === 'Antarctica') {
        return null;
      }

      return /*#__PURE__*/React__default.createElement("path", {
        key: "map-feature-" + i,
        d: path || '',
        fill: "#d8d7ea",
        stroke: "#ffffff",
        strokeWidth: 0.5
      });
    }));
  }), metric && /*#__PURE__*/React__default.createElement(group.Group, {
    top: height - 40,
    left: centerX - 100
  }, /*#__PURE__*/React__default.createElement(gradient.LinearGradient, {
    from: colorsRange[0],
    to: colorsRange[1],
    id: "legend-gradient",
    vertical: false
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 0,
    y: -10
  }, FormatUtils.formattedValue(min, metric, metric !== METRICS.AFFINITY ? 1 : 2)), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 200,
    y: -10
  }, "" + FormatUtils.formattedValue(max, metric, metric !== METRICS.AFFINITY ? 1 : 2)), /*#__PURE__*/React__default.createElement("rect", {
    width: 200,
    height: 20,
    fill: "url(#legend-gradient)"
  }), /*#__PURE__*/React__default.createElement(text.Text, {
    fontSize: "10px",
    fontWeight: "bold",
    textAnchor: "middle",
    verticalAnchor: "middle",
    fill: "#000000",
    width: 100,
    height: 20,
    x: 100,
    y: 30
  }, MAP_CHART_FIELDS_LABEL[metric]))), tooltipOpen && tooltipData && /*#__PURE__*/React__default.createElement(ChartTooltip, {
    opened: tooltipOpen,
    top: tooltipTop || 0,
    left: tooltipLeft || 0,
    data: tooltipData
  }, metric === METRICS.REACH && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Reach: "), FormatUtils.formattedValue(tooltipData.target_audience_perc, METRICS.REACH, 1)), metric === METRICS.AFFINITY && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Affinity: "), FormatUtils.formattedValue(tooltipData.target_audience_affinity, METRICS.AFFINITY)), metric === METRICS.BASE && /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("span", null, "Base: "), FormatUtils.formattedValue(tooltipData.base_population_perc, METRICS.BASE))));
};

exports.BarGroupChart = BarGroupChart$1;
exports.BubbleChart = BubbleChart;
exports.CloudChart = CloudChart;
exports.ColumnChart = ColumnChart;
exports.DonutChart = DonutChart$1;
exports.DotsChart = DotsChart$1;
exports.DoubleChart = DoubleChart;
exports.LineChart = LineChart$1;
exports.ListChart = ListChart;
exports.MosaicChart = MosaicChart;
exports.PieChart = PieChart;
exports.SpiderChart = SpiderChart;
exports.StackedChart = StackedChart;
exports.UsaMapChart = UsaMapChart;
exports.VennDiagram = VennDiagram;
exports.WorldMapChart = WorldMapChart;
//# sourceMappingURL=index.js.map
